(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('react'), require('react-native'), require('react-native-svg')) :
  typeof define === 'function' && define.amd ? define(['exports', 'react', 'react-native', 'react-native-svg'], factory) :
  (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global["bootstrap-rn"] = {}, global.React, global.ReactNative, global.ReactNativeSvg));
})(this, (function (exports, React, reactNative, reactNativeSvg) { 'use strict';

  function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

  var React__default = /*#__PURE__*/_interopDefaultLegacy(React);

  const isRTL = () => {
    // To support previous RN versions. Newer versions use below getConstants()
    if (reactNative.I18nManager.isRTL !== undefined) {
      return reactNative.I18nManager.isRTL;
    } // @ts-ignore - RN web only


    if (reactNative.I18nManager.getConstants) {
      // @ts-ignore - RN web only
      return reactNative.I18nManager.getConstants().isRTL;
    }
  };

  const measureOffset = ref => new Promise(resolve => {
    if (ref.current) {
      ref.current.measureInWindow((x, y, width, height) => {
        resolve({
          top: y,
          left: x,
          width,
          height
        });
      });
    }
  });

  function useOverlayPosition(props) {
    let {
      targetRef,
      overlayRef,
      placement = 'bottom',
      offset = 0,
      crossOffset = 0,
      isOpen = true,
      shouldFlip = true,
      shouldOverlapWithTrigger = false
    } = props;
    let [position, setPosition] = React__default["default"].useState({
      position: {},
      arrowOffsetLeft: undefined,
      arrowOffsetTop: undefined,
      maxHeight: undefined,
      placement: undefined
    }); // Layout measurement happens asynchronously in RN. This causes initial flickr. Using opacity and setting it to 1 post calculation prevents that.

    let [rendered, setRendered] = React__default["default"].useState(false);

    let updatePosition = async () => {
      const [overlayOffset, triggerOffset] = await Promise.all([measureOffset(overlayRef), measureOffset(targetRef)]); // Sometimes measure returns height/width 0. Best solution would be to use onLayout callback, but that might diverege from React Aria's useOverlayPosition API. Decide later, this works for now

      if (!overlayOffset.width || !overlayOffset.height || !triggerOffset.width || !triggerOffset.height) {
        requestAnimationFrame(updatePosition);
        return;
      }

      const {
        height: windowHeight,
        width: windowWidth
      } = reactNative.Dimensions.get('window');
      const positions = calculatePosition({
        placement: translateRTL(placement),
        targetNode: triggerOffset,
        overlayNode: overlayOffset,
        scrollNode: overlayOffset,
        padding: 0,
        shouldFlip,
        boundaryElement: {
          top: 0,
          left: 0,
          width: windowWidth,
          height: windowHeight
        },
        offset,
        crossOffset,
        shouldOverlapWithTrigger
      });
      setPosition(positions);
      setRendered(true);
    };

    React__default["default"].useEffect(() => {
      return () => {
        setRendered(false);
      };
    }, []);
    React__default["default"].useLayoutEffect(() => {
      updatePosition();
    }, [placement, isOpen, offset, shouldFlip, crossOffset, shouldOverlapWithTrigger]);
    const returnProps = {
      rendered,
      overlayProps: {
        style: { ...position.position
        }
      },
      placement: position.placement,
      arrowProps: {
        style: {
          left: position.arrowOffsetLeft,
          top: position.arrowOffsetTop
        }
      },
      updatePosition
    };

    if (position.maxHeight !== undefined) {
      //@ts-ignore
      returnProps.overlayProps.style.maxHeight = position.maxHeight;
    }

    return returnProps;
  }

  function translateRTL(position) {
    if (isRTL()) {
      return position.replace('start', 'right').replace('end', 'left');
    }

    return position.replace('start', 'left').replace('end', 'right');
  }

  const calculatePosition = opts => {
    let {
      placement,
      targetNode,
      overlayNode,
      scrollNode,
      padding,
      shouldFlip,
      boundaryElement,
      offset,
      crossOffset,
      shouldOverlapWithTrigger
    } = opts;
    let childOffset = targetNode;
    let isContainerPositioned = false;
    let overlaySize = overlayNode;
    let margins = {
      top: 0,
      bottom: 0,
      left: 0,
      right: 0
    };
    let scrollSize = scrollNode;
    let boundaryDimensions = boundaryElement;
    let containerOffsetWithBoundary = overlayNode;
    return calculatePositionInternal(placement, childOffset, overlaySize, scrollSize, margins, padding, shouldFlip, boundaryDimensions, containerOffsetWithBoundary, offset, crossOffset, isContainerPositioned, shouldOverlapWithTrigger);
  };

  function calculatePositionInternal(placementInput, childOffset, overlaySize, scrollSize, margins, padding, flip, boundaryDimensions, containerOffsetWithBoundary, offset, crossOffset, isContainerPositioned, shouldOverlapWithTrigger) {
    let placementInfo = parsePlacement(placementInput);
    let {
      size,
      crossAxis,
      crossSize,
      placement,
      crossPlacement
    } = placementInfo;
    let position = computePosition(childOffset, boundaryDimensions, overlaySize, placementInfo, offset, crossOffset);
    let normalizedOffset = offset;
    let space = getAvailableSpace(boundaryDimensions, containerOffsetWithBoundary, childOffset, margins, padding + offset, placementInfo);

    if (flip && scrollSize[size] > space) {
      let flippedPlacementInfo = parsePlacement(`${FLIPPED_DIRECTION[placement]} ${crossPlacement}`);
      let flippedPosition = computePosition(childOffset, boundaryDimensions, overlaySize, flippedPlacementInfo, offset, crossOffset);
      let flippedSpace = getAvailableSpace(boundaryDimensions, containerOffsetWithBoundary, childOffset, margins, padding + offset, flippedPlacementInfo); // If the available space for the flipped position is greater than the original available space, flip.

      if (flippedSpace > space) {
        placementInfo = flippedPlacementInfo;
        position = flippedPosition;
        normalizedOffset = offset;
      }
    }

    let delta = getDelta(crossAxis, position[crossAxis], overlaySize[crossSize], boundaryDimensions, padding);
    position[crossAxis] += delta;
    let maxHeight = getMaxHeight(position, boundaryDimensions, containerOffsetWithBoundary, childOffset);
    overlaySize.height = Math.min(overlaySize.height, maxHeight);
    position = computePosition(childOffset, boundaryDimensions, overlaySize, placementInfo, normalizedOffset, crossOffset);
    delta = getDelta(crossAxis, position[crossAxis], overlaySize[crossSize], boundaryDimensions, padding);
    position[crossAxis] += delta;
    let arrowPosition = {};
    arrowPosition[crossAxis] = childOffset[crossAxis] - position[crossAxis] + childOffset[crossSize] / 2;

    if (shouldOverlapWithTrigger) {
      position[FLIPPED_DIRECTION[placementInfo.placement]] = position[FLIPPED_DIRECTION[placementInfo.placement]] - childOffset[size];
    }

    return {
      position,
      maxHeight,
      arrowOffsetLeft: arrowPosition.left,
      arrowOffsetTop: arrowPosition.top,
      placement: placementInfo.placement
    };
  }

  function getDelta(axis, offset, size, containerDimensions, padding) {
    //@ts-ignore
    let containerScroll = containerDimensions[axis]; //@ts-ignore

    let containerHeight = containerDimensions[AXIS_SIZE[axis]];
    let startEdgeOffset = offset - padding - containerScroll;
    let endEdgeOffset = offset + padding - containerScroll + size;

    if (startEdgeOffset < 0) {
      return -startEdgeOffset;
    } else if (endEdgeOffset > containerHeight) {
      return Math.max(containerHeight - endEdgeOffset, -startEdgeOffset);
    } else {
      return 0;
    }
  }

  function getMaxHeight(position, boundaryDimensions, _containerOffsetWithBoundary, childOffset, _margins, _padding) {
    return position.top != null ? // We want the distance between the top of the overlay to the bottom of the boundary
    Math.max(0, boundaryDimensions.height - // this is the bottom of the boundary
    position.top // this is the top of the overlay
    ) : // We want the distance between the top of the trigger to the top of the boundary
    Math.max(0, childOffset.top - // this is the top of the trigger
    0 // this is the top of the boundary
    );
  }

  function computePosition(childOffset, boundaryDimensions, overlaySize, placementInfo, offset, crossOffset, _containerOffsetWithBoundary, _isContainerPositioned) {
    let {
      placement,
      crossPlacement,
      axis,
      crossAxis,
      size,
      crossSize
    } = placementInfo;
    let position = {}; //@ts-ignore

    position[crossAxis] = childOffset[crossAxis];

    if (crossPlacement === 'center') {
      position[crossAxis] += (childOffset[crossSize] - overlaySize[crossSize]) / 2;
    } else if (crossPlacement !== crossAxis) {
      position[crossAxis] += childOffset[crossSize] - overlaySize[crossSize];
    }

    position[crossAxis] += crossOffset; // this is button center position - the overlay size + half of the button to align bottom of overlay with button center

    let minViablePosition = childOffset[crossAxis] + childOffset[crossSize] / 2 - overlaySize[crossSize]; // this is button position of center, aligns top of overlay with button center

    let maxViablePosition = childOffset[crossAxis] + childOffset[crossSize] / 2; // clamp it into the range of the min/max positions

    position[crossAxis] = Math.min(Math.max(minViablePosition, position[crossAxis]), maxViablePosition); // Floor these so the position isn't placed on a partial pixel, only whole pixels. Shouldn't matter if it was floored or ceiled, so chose one.

    if (placement === axis) {
      // If the container is positioned (non-static), then we use the container's actual
      // height, as `bottom` will be relative to this height.  But if the container is static,
      // then it can only be the `document.body`, and `bottom` will be relative to _its_
      // container, which should be as large as boundaryDimensions.
      const containerHeight = boundaryDimensions[size];
      position[FLIPPED_DIRECTION[axis]] = Math.floor(containerHeight - childOffset[axis] + offset);
    } else {
      position[axis] = Math.floor(childOffset[axis] + childOffset[size] + offset);
    }

    return position;
  }

  function getAvailableSpace(boundaryDimensions, _containerOffsetWithBoundary, childOffset, _margins, padding, placementInfo) {
    let {
      placement,
      axis,
      size
    } = placementInfo;

    if (placement === axis) {
      return Math.max(0, childOffset[axis] - padding);
    }

    return Math.max(0, boundaryDimensions[size] - childOffset[axis] - childOffset[size] - padding);
  }

  const AXIS = {
    top: 'top',
    bottom: 'top',
    left: 'left',
    right: 'left'
  };
  const FLIPPED_DIRECTION = {
    top: 'bottom',
    bottom: 'top',
    left: 'right',
    right: 'left'
  };
  const CROSS_AXIS = {
    top: 'left',
    left: 'top'
  };
  const AXIS_SIZE = {
    top: 'height',
    left: 'width'
  };
  const PARSED_PLACEMENT_CACHE = {};

  function parsePlacement(input) {
    if (PARSED_PLACEMENT_CACHE[input]) {
      return PARSED_PLACEMENT_CACHE[input];
    }

    let [placement, crossPlacement] = input.split(' ');
    let axis = AXIS[placement] || 'right';
    let crossAxis = CROSS_AXIS[axis];

    if (!AXIS[crossPlacement]) {
      crossPlacement = 'center';
    }

    let size = AXIS_SIZE[axis];
    let crossSize = AXIS_SIZE[crossAxis];
    PARSED_PLACEMENT_CACHE[input] = {
      placement,
      crossPlacement,
      axis,
      crossAxis,
      size,
      crossSize
    };
    return PARSED_PLACEMENT_CACHE[input];
  }

  function _extends$2() { _extends$2 = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends$2.apply(this, arguments); }
  const PortalContext = /*#__PURE__*/React__default["default"].createContext(null);
  let globalOverlayCounter = 0;
  function PortalProvider(props) {
    const [items, setItems] = React__default["default"].useState([]);

    const setOverlayItem = item => {
      const overlayId = ++globalOverlayCounter;
      setItems(prev => prev.concat([{
        id: overlayId,
        node: item
      }]));
      return overlayId;
    };

    const updateOverlayItem = (id, node) => {
      setItems(prev => prev.map(item => {
        if (item.id === id) {
          return {
            id,
            node
          };
        }

        return item;
      }));
    };

    const removeOverlayItem = id => {
      setItems(prev => {
        const newItems = prev.filter(item => item.id !== id);
        return newItems;
      });
    };

    return /*#__PURE__*/React__default["default"].createElement(PortalContext.Provider, {
      value: {
        items,
        setOverlayItem,
        removeOverlayItem,
        updateOverlayItem
      }
    }, props.children, items.map(item => {
      return /*#__PURE__*/React__default["default"].createElement(React__default["default"].Fragment, {
        key: item.id
      }, item.node);
    }));
  }

  function OverlayView(props) {
    return /*#__PURE__*/React__default["default"].createElement(reactNative.View, _extends$2({
      pointerEvents: "box-none",
      style: reactNative.StyleSheet.absoluteFill,
      collapsable: false
    }, props));
  }

  const OverlayProvider = PortalProvider;
  function OverlayContainer(props) {
    const context = usePortalProvider();
    const overlayId = React__default["default"].useRef(undefined);
    let contents = /*#__PURE__*/React__default["default"].createElement(OverlayView, props);
    React.useEffect(() => {
      // Mount
      if (overlayId.current === undefined) {
        overlayId.current = context === null || context === void 0 ? void 0 : context.setOverlayItem(contents);
      } // Update
      else {
          if (overlayId.current) {
            context === null || context === void 0 ? void 0 : context.updateOverlayItem(overlayId.current, contents);
          }
        }
    }, // To re-render the child
    [props]); // Unmount

    React.useEffect(() => {
      return () => {
        if (overlayId.current) {
          context === null || context === void 0 ? void 0 : context.removeOverlayItem(overlayId.current);
        }
      };
    }, []);
    return null;
  }

  function usePortalProvider() {
    const context = React__default["default"].useContext(PortalContext);
    return context;
  }

  function ownKeys(object, enumerableOnly) {
    var keys = Object.keys(object);

    if (Object.getOwnPropertySymbols) {
      var symbols = Object.getOwnPropertySymbols(object);
      enumerableOnly && (symbols = symbols.filter(function (sym) {
        return Object.getOwnPropertyDescriptor(object, sym).enumerable;
      })), keys.push.apply(keys, symbols);
    }

    return keys;
  }

  function _objectSpread2(target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = null != arguments[i] ? arguments[i] : {};
      i % 2 ? ownKeys(Object(source), !0).forEach(function (key) {
        _defineProperty(target, key, source[key]);
      }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) {
        Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
      });
    }

    return target;
  }

  function _typeof(obj) {
    "@babel/helpers - typeof";

    return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) {
      return typeof obj;
    } : function (obj) {
      return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
    }, _typeof(obj);
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];
      descriptor.enumerable = descriptor.enumerable || false;
      descriptor.configurable = true;
      if ("value" in descriptor) descriptor.writable = true;
      Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);
    if (staticProps) _defineProperties(Constructor, staticProps);
    Object.defineProperty(Constructor, "prototype", {
      writable: false
    });
    return Constructor;
  }

  function _defineProperty(obj, key, value) {
    if (key in obj) {
      Object.defineProperty(obj, key, {
        value: value,
        enumerable: true,
        configurable: true,
        writable: true
      });
    } else {
      obj[key] = value;
    }

    return obj;
  }

  function _extends$1() {
    _extends$1 = Object.assign || function (target) {
      for (var i = 1; i < arguments.length; i++) {
        var source = arguments[i];

        for (var key in source) {
          if (Object.prototype.hasOwnProperty.call(source, key)) {
            target[key] = source[key];
          }
        }
      }

      return target;
    };

    return _extends$1.apply(this, arguments);
  }

  function _setPrototypeOf$1(o, p) {
    _setPrototypeOf$1 = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;
      return o;
    };

    return _setPrototypeOf$1(o, p);
  }

  function _isNativeReflectConstruct$1() {
    if (typeof Reflect === "undefined" || !Reflect.construct) return false;
    if (Reflect.construct.sham) return false;
    if (typeof Proxy === "function") return true;

    try {
      Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {}));
      return true;
    } catch (e) {
      return false;
    }
  }

  function _construct$1(Parent, args, Class) {
    if (_isNativeReflectConstruct$1()) {
      _construct$1 = Reflect.construct;
    } else {
      _construct$1 = function _construct(Parent, args, Class) {
        var a = [null];
        a.push.apply(a, args);
        var Constructor = Function.bind.apply(Parent, a);
        var instance = new Constructor();
        if (Class) _setPrototypeOf$1(instance, Class.prototype);
        return instance;
      };
    }

    return _construct$1.apply(null, arguments);
  }

  function _objectWithoutPropertiesLoose(source, excluded) {
    if (source == null) return {};
    var target = {};
    var sourceKeys = Object.keys(source);
    var key, i;

    for (i = 0; i < sourceKeys.length; i++) {
      key = sourceKeys[i];
      if (excluded.indexOf(key) >= 0) continue;
      target[key] = source[key];
    }

    return target;
  }

  function _objectWithoutProperties(source, excluded) {
    if (source == null) return {};

    var target = _objectWithoutPropertiesLoose(source, excluded);

    var key, i;

    if (Object.getOwnPropertySymbols) {
      var sourceSymbolKeys = Object.getOwnPropertySymbols(source);

      for (i = 0; i < sourceSymbolKeys.length; i++) {
        key = sourceSymbolKeys[i];
        if (excluded.indexOf(key) >= 0) continue;
        if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue;
        target[key] = source[key];
      }
    }

    return target;
  }

  function _taggedTemplateLiteral(strings, raw) {
    if (!raw) {
      raw = strings.slice(0);
    }

    return Object.freeze(Object.defineProperties(strings, {
      raw: {
        value: Object.freeze(raw)
      }
    }));
  }

  function _slicedToArray(arr, i) {
    return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest();
  }

  function _toConsumableArray(arr) {
    return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread();
  }

  function _arrayWithoutHoles(arr) {
    if (Array.isArray(arr)) return _arrayLikeToArray(arr);
  }

  function _arrayWithHoles(arr) {
    if (Array.isArray(arr)) return arr;
  }

  function _iterableToArray(iter) {
    if (typeof Symbol !== "undefined" && iter[Symbol.iterator] != null || iter["@@iterator"] != null) return Array.from(iter);
  }

  function _iterableToArrayLimit(arr, i) {
    var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"];

    if (_i == null) return;
    var _arr = [];
    var _n = true;
    var _d = false;

    var _s, _e;

    try {
      for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) {
        _arr.push(_s.value);

        if (i && _arr.length === i) break;
      }
    } catch (err) {
      _d = true;
      _e = err;
    } finally {
      try {
        if (!_n && _i["return"] != null) _i["return"]();
      } finally {
        if (_d) throw _e;
      }
    }

    return _arr;
  }

  function _unsupportedIterableToArray(o, minLen) {
    if (!o) return;
    if (typeof o === "string") return _arrayLikeToArray(o, minLen);
    var n = Object.prototype.toString.call(o).slice(8, -1);
    if (n === "Object" && o.constructor) n = o.constructor.name;
    if (n === "Map" || n === "Set") return Array.from(o);
    if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen);
  }

  function _arrayLikeToArray(arr, len) {
    if (len == null || len > arr.length) len = arr.length;

    for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i];

    return arr2;
  }

  function _nonIterableSpread() {
    throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
  }

  function _nonIterableRest() {
    throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
  }

  var checkFunction = function checkFunction(char, silent) {
    if (typeof char !== 'function') {
      return true;
    }

    if (silent) {
      return false;
    }

    throw new Error("CSS syntax error: Unexpected function.");
  };

  var InputStream = /*#__PURE__*/function () {
    function InputStream(fragments) {
      for (var _len = arguments.length, tags = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
        tags[_key - 1] = arguments[_key];
      }

      _classCallCheck(this, InputStream);

      this.dictionary = fragments.reduce(function (result, current, i) {
        var value = current.split('');
        var tag = tags[i - 1];

        if (!tag) {
          return [].concat(_toConsumableArray(result), _toConsumableArray(value));
        }

        if (typeof tag !== 'string') {
          return [].concat(_toConsumableArray(result), [tag], _toConsumableArray(value));
        }

        return [].concat(_toConsumableArray(result), _toConsumableArray(tag.split('')), _toConsumableArray(value));
      });
      this.cursor = 0;
    }

    _createClass(InputStream, [{
      key: "peek",
      value: function peek() {
        var offset = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 0;
        return this.dictionary[this.cursor + offset];
      }
    }, {
      key: "read",
      value: function read(marker) {
        var char = this.peek();

        if (marker && marker !== char) {
          throw new Error("CSS syntax error: Expected \"".concat(marker, "\", but found \"").concat(char, "\""));
        }

        if (this.remainingChars() === 0) {
          throw new Error("CSS syntax error: Unexpected end of string.");
        }

        this.cursor += 1;
        return char;
      }
    }, {
      key: "charsWhile",
      value: function charsWhile(check) {
        var silent = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
        var value = '';

        while (checkFunction(this.peek(), silent) && check(this.peek())) {
          value += this.read();
        }

        return value;
      }
    }, {
      key: "remainingChars",
      value: function remainingChars() {
        return this.dictionary.length - this.cursor;
      }
    }]);

    return InputStream;
  }();

  function isIdent(char) {
    return /[a-z0-9_-]/i.test(char);
  }

  function isWhitespace(char) {
    return /\s/.test(char);
  }

  var breaksDeclaration = function breaksDeclaration(char) {
    return typeof char !== 'function' && char !== '$' && char !== ';' && char !== '}' && // char !== '(' &&
    char !== '';
  };

  var declaration = {
    locate: function locate(input) {
      return /[a-z_]/i.test(input.peek());
    },
    read: function read(input) {
      // Parse name.
      var name = input.charsWhile(isIdent); // Parse whitespaces, separator

      input.charsWhile(isWhitespace);
      input.read(':');
      input.charsWhile(isWhitespace, true); // Parse value.

      var value = [];

      do {
        // Add function to resolve variable.
        if (input.peek() === '$') {
          (function () {
            input.read('$');
            var variableName = input.charsWhile(isIdent);
            value.push(function (variables) {
              if (variables[variableName] === undefined) {
                throw new Error("Variable $".concat(variableName, " is not defined."));
              }

              return variables[variableName];
            });
          })();
        } // Add function.


        if (typeof input.peek() === 'function') {
          value.push(input.read());
        }

        var part = input.charsWhile(breaksDeclaration, true); // TODO: Parse functions

        /* if (input.peek() === '(') {
         } */

        if (part.length > 0) {
          value.push(part);
        }
      } while (input.peek() === '$' || typeof input.peek() === 'function');

      if (input.peek() === ';') {
        input.read(';');
      }

      return {
        type: 'declaration',
        name: name,
        value: value
      };
    }
  };

  var variable = {
    locate: function locate(input) {
      return input.peek() === '$';
    },
    read: function read(input) {
      input.read('$');

      if (!declaration.locate(input)) {
        throw new Error("CSS syntax error: Unexpected char after $.");
      }

      var _declaration$read = declaration.read(input),
          name = _declaration$read.name,
          value = _declaration$read.value;

      return {
        type: 'variable',
        name: name,
        value: value
      };
    }
  };

  var consumeArgumentSeperator = function consumeArgumentSeperator(input) {
    if (input.peek() !== ',') {
      return false;
    }

    input.read(',');
    return true;
  };

  var directive = {
    locate: function locate(input) {
      return input.peek() === '@';
    },
    read: function read(input, parseBlock) {
      input.read('@');
      var directiveName = input.charsWhile(isIdent);

      if (directiveName !== 'include') {
        throw new Error('Only @include directive is supported.');
      }

      input.charsWhile(isWhitespace);
      var name = input.charsWhile(isIdent);

      if (name.length === 0) {
        throw new Error('No name.');
      }

      input.charsWhile(isWhitespace);
      input.read('(');
      var args = [];

      do {
        input.charsWhile(isWhitespace);
        args.push(input.charsWhile(isIdent));
        input.charsWhile(isWhitespace);
      } while (consumeArgumentSeperator(input));

      input.read(')');
      input.charsWhile(isWhitespace);
      input.read('{');
      var children = [];

      while (input.peek() !== '}') {
        var block = parseBlock(input);

        if (block) {
          children.push(block);
        }
      }

      input.read('}');
      return {
        type: 'block',
        scopes: [{
          type: 'mixin',
          name: name,
          args: args
        }],
        children: children
      };
    }
  };

  var SELECTOR_TYPES = ['hover', 'focus', 'active'];
  var selector = {
    locate: function locate(input) {
      return input.peek() === '&' && input.peek(1) === ':';
    },
    read: function read(input, parseBlock) {
      input.read('&');
      input.read(':');
      var name = input.charsWhile(isIdent);

      if (!SELECTOR_TYPES.includes(name)) {
        throw new Error("CSS syntax error: Unexpected selector name \"".concat(name, "\"."));
      }

      input.charsWhile(isWhitespace);
      input.read('{');
      var children = [];

      while (input.peek() !== '}') {
        var block = parseBlock(input);

        if (block) {
          children.push(block);
        }
      }

      input.read('}');
      return {
        type: 'block',
        scopes: [{
          type: 'selector',
          name: name
        }],
        children: children
      };
    }
  };

  var consumeAsterisk = function consumeAsterisk(input) {
    input.read('*');

    if (input.peek() === '/') {
      input.read('/');
      return false;
    }

    return true;
  };

  var comment = {
    locate: function locate(input) {
      return input.peek() === '/' && (input.peek(1) === '*' || input.peek(1) === '/');
    },
    read: function read(input) {
      input.read('/'); // Read until new line for inline comments

      if (input.peek() === '/') {
        input.read('/');
        input.charsWhile(function (char) {
          return char !== '\n';
        });
        return null;
      }

      input.read('*'); // Read until comment ending

      do {
        input.charsWhile(function (char) {
          return char !== '*';
        });
      } while (consumeAsterisk(input));

      return null;
    }
  };

  function parseBlock(input) {
    if (isWhitespace(input.peek())) {
      input.charsWhile(isWhitespace);
      return null;
    }

    if (variable.locate(input)) {
      return variable.read(input);
    }

    if (declaration.locate(input)) {
      return declaration.read(input);
    }

    if (selector.locate(input)) {
      return selector.read(input, parseBlock);
    }

    if (directive.locate(input)) {
      return directive.read(input, parseBlock);
    }

    if (comment.locate(input)) {
      return comment.read(input);
    }

    throw new Error("CSS syntax error: Unknown error at \"".concat(input.peek(), "\""));
  }

  function parse$1() {
    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    var input = _construct$1(InputStream, args);

    var children = [];

    while (input.remainingChars() > 0) {
      var block = parseBlock(input);

      if (block) {
        children.push(block);
      }
    }

    return {
      type: 'root',
      children: children
    };
  }

  function createCommonjsModule(fn) {
    var module = { exports: {} };
  	return fn(module, module.exports), module.exports;
  }

  var openParentheses = "(".charCodeAt(0);
  var closeParentheses = ")".charCodeAt(0);
  var singleQuote = "'".charCodeAt(0);
  var doubleQuote = '"'.charCodeAt(0);
  var backslash = "\\".charCodeAt(0);
  var slash = "/".charCodeAt(0);
  var comma = ",".charCodeAt(0);
  var colon = ":".charCodeAt(0);
  var star = "*".charCodeAt(0);
  var uLower = "u".charCodeAt(0);
  var uUpper = "U".charCodeAt(0);
  var plus$1 = "+".charCodeAt(0);
  var isUnicodeRange = /^[a-f0-9?-]+$/i;

  var parse = function(input) {
    var tokens = [];
    var value = input;

    var next,
      quote,
      prev,
      token,
      escape,
      escapePos,
      whitespacePos,
      parenthesesOpenPos;
    var pos = 0;
    var code = value.charCodeAt(pos);
    var max = value.length;
    var stack = [{ nodes: tokens }];
    var balanced = 0;
    var parent;

    var name = "";
    var before = "";
    var after = "";

    while (pos < max) {
      // Whitespaces
      if (code <= 32) {
        next = pos;
        do {
          next += 1;
          code = value.charCodeAt(next);
        } while (code <= 32);
        token = value.slice(pos, next);

        prev = tokens[tokens.length - 1];
        if (code === closeParentheses && balanced) {
          after = token;
        } else if (prev && prev.type === "div") {
          prev.after = token;
          prev.sourceEndIndex += token.length;
        } else if (
          code === comma ||
          code === colon ||
          (code === slash &&
            value.charCodeAt(next + 1) !== star &&
            (!parent ||
              (parent && parent.type === "function" && parent.value !== "calc")))
        ) {
          before = token;
        } else {
          tokens.push({
            type: "space",
            sourceIndex: pos,
            sourceEndIndex: next,
            value: token
          });
        }

        pos = next;

        // Quotes
      } else if (code === singleQuote || code === doubleQuote) {
        next = pos;
        quote = code === singleQuote ? "'" : '"';
        token = {
          type: "string",
          sourceIndex: pos,
          quote: quote
        };
        do {
          escape = false;
          next = value.indexOf(quote, next + 1);
          if (~next) {
            escapePos = next;
            while (value.charCodeAt(escapePos - 1) === backslash) {
              escapePos -= 1;
              escape = !escape;
            }
          } else {
            value += quote;
            next = value.length - 1;
            token.unclosed = true;
          }
        } while (escape);
        token.value = value.slice(pos + 1, next);
        token.sourceEndIndex = token.unclosed ? next : next + 1;
        tokens.push(token);
        pos = next + 1;
        code = value.charCodeAt(pos);

        // Comments
      } else if (code === slash && value.charCodeAt(pos + 1) === star) {
        next = value.indexOf("*/", pos);

        token = {
          type: "comment",
          sourceIndex: pos,
          sourceEndIndex: next + 2
        };

        if (next === -1) {
          token.unclosed = true;
          next = value.length;
          token.sourceEndIndex = next;
        }

        token.value = value.slice(pos + 2, next);
        tokens.push(token);

        pos = next + 2;
        code = value.charCodeAt(pos);

        // Operation within calc
      } else if (
        (code === slash || code === star) &&
        parent &&
        parent.type === "function" &&
        parent.value === "calc"
      ) {
        token = value[pos];
        tokens.push({
          type: "word",
          sourceIndex: pos - before.length,
          sourceEndIndex: pos + token.length,
          value: token
        });
        pos += 1;
        code = value.charCodeAt(pos);

        // Dividers
      } else if (code === slash || code === comma || code === colon) {
        token = value[pos];

        tokens.push({
          type: "div",
          sourceIndex: pos - before.length,
          sourceEndIndex: pos + token.length,
          value: token,
          before: before,
          after: ""
        });
        before = "";

        pos += 1;
        code = value.charCodeAt(pos);

        // Open parentheses
      } else if (openParentheses === code) {
        // Whitespaces after open parentheses
        next = pos;
        do {
          next += 1;
          code = value.charCodeAt(next);
        } while (code <= 32);
        parenthesesOpenPos = pos;
        token = {
          type: "function",
          sourceIndex: pos - name.length,
          value: name,
          before: value.slice(parenthesesOpenPos + 1, next)
        };
        pos = next;

        if (name === "url" && code !== singleQuote && code !== doubleQuote) {
          next -= 1;
          do {
            escape = false;
            next = value.indexOf(")", next + 1);
            if (~next) {
              escapePos = next;
              while (value.charCodeAt(escapePos - 1) === backslash) {
                escapePos -= 1;
                escape = !escape;
              }
            } else {
              value += ")";
              next = value.length - 1;
              token.unclosed = true;
            }
          } while (escape);
          // Whitespaces before closed
          whitespacePos = next;
          do {
            whitespacePos -= 1;
            code = value.charCodeAt(whitespacePos);
          } while (code <= 32);
          if (parenthesesOpenPos < whitespacePos) {
            if (pos !== whitespacePos + 1) {
              token.nodes = [
                {
                  type: "word",
                  sourceIndex: pos,
                  sourceEndIndex: whitespacePos + 1,
                  value: value.slice(pos, whitespacePos + 1)
                }
              ];
            } else {
              token.nodes = [];
            }
            if (token.unclosed && whitespacePos + 1 !== next) {
              token.after = "";
              token.nodes.push({
                type: "space",
                sourceIndex: whitespacePos + 1,
                sourceEndIndex: next,
                value: value.slice(whitespacePos + 1, next)
              });
            } else {
              token.after = value.slice(whitespacePos + 1, next);
              token.sourceEndIndex = next;
            }
          } else {
            token.after = "";
            token.nodes = [];
          }
          pos = next + 1;
          token.sourceEndIndex = token.unclosed ? next : pos;
          code = value.charCodeAt(pos);
          tokens.push(token);
        } else {
          balanced += 1;
          token.after = "";
          token.sourceEndIndex = pos + 1;
          tokens.push(token);
          stack.push(token);
          tokens = token.nodes = [];
          parent = token;
        }
        name = "";

        // Close parentheses
      } else if (closeParentheses === code && balanced) {
        pos += 1;
        code = value.charCodeAt(pos);

        parent.after = after;
        parent.sourceEndIndex += after.length;
        after = "";
        balanced -= 1;
        stack[stack.length - 1].sourceEndIndex = pos;
        stack.pop();
        parent = stack[balanced];
        tokens = parent.nodes;

        // Words
      } else {
        next = pos;
        do {
          if (code === backslash) {
            next += 1;
          }
          next += 1;
          code = value.charCodeAt(next);
        } while (
          next < max &&
          !(
            code <= 32 ||
            code === singleQuote ||
            code === doubleQuote ||
            code === comma ||
            code === colon ||
            code === slash ||
            code === openParentheses ||
            (code === star &&
              parent &&
              parent.type === "function" &&
              parent.value === "calc") ||
            (code === slash &&
              parent.type === "function" &&
              parent.value === "calc") ||
            (code === closeParentheses && balanced)
          )
        );
        token = value.slice(pos, next);

        if (openParentheses === code) {
          name = token;
        } else if (
          (uLower === token.charCodeAt(0) || uUpper === token.charCodeAt(0)) &&
          plus$1 === token.charCodeAt(1) &&
          isUnicodeRange.test(token.slice(2))
        ) {
          tokens.push({
            type: "unicode-range",
            sourceIndex: pos,
            sourceEndIndex: next,
            value: token
          });
        } else {
          tokens.push({
            type: "word",
            sourceIndex: pos,
            sourceEndIndex: next,
            value: token
          });
        }

        pos = next;
      }
    }

    for (pos = stack.length - 1; pos; pos -= 1) {
      stack[pos].unclosed = true;
      stack[pos].sourceEndIndex = value.length;
    }

    return stack[0].nodes;
  };

  var walk$1 = function walk(nodes, cb, bubble) {
    var i, max, node, result;

    for (i = 0, max = nodes.length; i < max; i += 1) {
      node = nodes[i];
      if (!bubble) {
        result = cb(node, i, nodes);
      }

      if (
        result !== false &&
        node.type === "function" &&
        Array.isArray(node.nodes)
      ) {
        walk(node.nodes, cb, bubble);
      }

      if (bubble) {
        cb(node, i, nodes);
      }
    }
  };

  function stringifyNode(node, custom) {
    var type = node.type;
    var value = node.value;
    var buf;
    var customResult;

    if (custom && (customResult = custom(node)) !== undefined) {
      return customResult;
    } else if (type === "word" || type === "space") {
      return value;
    } else if (type === "string") {
      buf = node.quote || "";
      return buf + value + (node.unclosed ? "" : buf);
    } else if (type === "comment") {
      return "/*" + value + (node.unclosed ? "" : "*/");
    } else if (type === "div") {
      return (node.before || "") + value + (node.after || "");
    } else if (Array.isArray(node.nodes)) {
      buf = stringify(node.nodes, custom);
      if (type !== "function") {
        return buf;
      }
      return (
        value +
        "(" +
        (node.before || "") +
        buf +
        (node.after || "") +
        (node.unclosed ? "" : ")")
      );
    }
    return value;
  }

  function stringify(nodes, custom) {
    var result, i;

    if (Array.isArray(nodes)) {
      result = "";
      for (i = nodes.length - 1; ~i; i -= 1) {
        result = stringifyNode(nodes[i], custom) + result;
      }
      return result;
    }
    return stringifyNode(nodes, custom);
  }

  var stringify_1 = stringify;

  var minus = "-".charCodeAt(0);
  var plus = "+".charCodeAt(0);
  var dot = ".".charCodeAt(0);
  var exp = "e".charCodeAt(0);
  var EXP = "E".charCodeAt(0);

  // Check if three code points would start a number
  // https://www.w3.org/TR/css-syntax-3/#starts-with-a-number
  function likeNumber(value) {
    var code = value.charCodeAt(0);
    var nextCode;

    if (code === plus || code === minus) {
      nextCode = value.charCodeAt(1);

      if (nextCode >= 48 && nextCode <= 57) {
        return true;
      }

      var nextNextCode = value.charCodeAt(2);

      if (nextCode === dot && nextNextCode >= 48 && nextNextCode <= 57) {
        return true;
      }

      return false;
    }

    if (code === dot) {
      nextCode = value.charCodeAt(1);

      if (nextCode >= 48 && nextCode <= 57) {
        return true;
      }

      return false;
    }

    if (code >= 48 && code <= 57) {
      return true;
    }

    return false;
  }

  // Consume a number
  // https://www.w3.org/TR/css-syntax-3/#consume-number
  var unit = function(value) {
    var pos = 0;
    var length = value.length;
    var code;
    var nextCode;
    var nextNextCode;

    if (length === 0 || !likeNumber(value)) {
      return false;
    }

    code = value.charCodeAt(pos);

    if (code === plus || code === minus) {
      pos++;
    }

    while (pos < length) {
      code = value.charCodeAt(pos);

      if (code < 48 || code > 57) {
        break;
      }

      pos += 1;
    }

    code = value.charCodeAt(pos);
    nextCode = value.charCodeAt(pos + 1);

    if (code === dot && nextCode >= 48 && nextCode <= 57) {
      pos += 2;

      while (pos < length) {
        code = value.charCodeAt(pos);

        if (code < 48 || code > 57) {
          break;
        }

        pos += 1;
      }
    }

    code = value.charCodeAt(pos);
    nextCode = value.charCodeAt(pos + 1);
    nextNextCode = value.charCodeAt(pos + 2);

    if (
      (code === exp || code === EXP) &&
      ((nextCode >= 48 && nextCode <= 57) ||
        ((nextCode === plus || nextCode === minus) &&
          nextNextCode >= 48 &&
          nextNextCode <= 57))
    ) {
      pos += nextCode === plus || nextCode === minus ? 3 : 2;

      while (pos < length) {
        code = value.charCodeAt(pos);

        if (code < 48 || code > 57) {
          break;
        }

        pos += 1;
      }
    }

    return {
      number: value.slice(0, pos),
      unit: value.slice(pos)
    };
  };

  function ValueParser(value) {
    if (this instanceof ValueParser) {
      this.nodes = parse(value);
      return this;
    }
    return new ValueParser(value);
  }

  ValueParser.prototype.toString = function() {
    return Array.isArray(this.nodes) ? stringify_1(this.nodes) : "";
  };

  ValueParser.prototype.walk = function(cb, bubble) {
    walk$1(this.nodes, cb, bubble);
    return this;
  };

  ValueParser.unit = unit;

  ValueParser.walk = walk$1;

  ValueParser.stringify = stringify_1;

  var lib = ValueParser;

  var camelize = function(obj) {
      if (typeof obj === 'string') return camelCase(obj);
      return walk(obj);
  };

  function walk (obj) {
      if (!obj || typeof obj !== 'object') return obj;
      if (isDate(obj) || isRegex(obj)) return obj;
      if (isArray(obj)) return map(obj, walk);
      return reduce(objectKeys(obj), function (acc, key) {
          var camel = camelCase(key);
          acc[camel] = walk(obj[key]);
          return acc;
      }, {});
  }

  function camelCase(str) {
      return str.replace(/[_.-](\w|$)/g, function (_,x) {
          return x.toUpperCase();
      });
  }

  var isArray = Array.isArray || function (obj) {
      return Object.prototype.toString.call(obj) === '[object Array]';
  };

  var isDate = function (obj) {
      return Object.prototype.toString.call(obj) === '[object Date]';
  };

  var isRegex = function (obj) {
      return Object.prototype.toString.call(obj) === '[object RegExp]';
  };

  var has$3 = Object.prototype.hasOwnProperty;
  var objectKeys = Object.keys || function (obj) {
      var keys = [];
      for (var key in obj) {
          if (has$3.call(obj, key)) keys.push(key);
      }
      return keys;
  };

  function map (xs, f) {
      if (xs.map) return xs.map(f);
      var res = [];
      for (var i = 0; i < xs.length; i++) {
          res.push(f(xs[i], i));
      }
      return res;
  }

  function reduce (xs, f, acc) {
      if (xs.reduce) return xs.reduce(f, acc);
      for (var i = 0; i < xs.length; i++) {
          acc = f(acc, xs[i], i);
      }
      return acc;
  }

  var black = "#000000";
  var silver = "#c0c0c0";
  var gray = "#808080";
  var white = "#ffffff";
  var maroon = "#800000";
  var red = "#ff0000";
  var purple = "#800080";
  var fuchsia = "#ff00ff";
  var green = "#008000";
  var lime = "#00ff00";
  var olive = "#808000";
  var yellow = "#ffff00";
  var navy = "#000080";
  var blue = "#0000ff";
  var teal = "#008080";
  var aqua = "#00ffff";
  var orange = "#ffa500";
  var aliceblue = "#f0f8ff";
  var antiquewhite = "#faebd7";
  var aquamarine = "#7fffd4";
  var azure = "#f0ffff";
  var beige = "#f5f5dc";
  var bisque = "#ffe4c4";
  var blanchedalmond = "#ffebcd";
  var blueviolet = "#8a2be2";
  var brown = "#a52a2a";
  var burlywood = "#deb887";
  var cadetblue = "#5f9ea0";
  var chartreuse = "#7fff00";
  var chocolate = "#d2691e";
  var coral = "#ff7f50";
  var cornflowerblue = "#6495ed";
  var cornsilk = "#fff8dc";
  var crimson = "#dc143c";
  var darkblue = "#00008b";
  var darkcyan = "#008b8b";
  var darkgoldenrod = "#b8860b";
  var darkgray = "#a9a9a9";
  var darkgreen = "#006400";
  var darkgrey = "#a9a9a9";
  var darkkhaki = "#bdb76b";
  var darkmagenta = "#8b008b";
  var darkolivegreen = "#556b2f";
  var darkorange = "#ff8c00";
  var darkorchid = "#9932cc";
  var darkred = "#8b0000";
  var darksalmon = "#e9967a";
  var darkseagreen = "#8fbc8f";
  var darkslateblue = "#483d8b";
  var darkslategray = "#2f4f4f";
  var darkslategrey = "#2f4f4f";
  var darkturquoise = "#00ced1";
  var darkviolet = "#9400d3";
  var deeppink = "#ff1493";
  var deepskyblue = "#00bfff";
  var dimgray = "#696969";
  var dimgrey = "#696969";
  var dodgerblue = "#1e90ff";
  var firebrick = "#b22222";
  var floralwhite = "#fffaf0";
  var forestgreen = "#228b22";
  var gainsboro = "#dcdcdc";
  var ghostwhite = "#f8f8ff";
  var gold = "#ffd700";
  var goldenrod = "#daa520";
  var greenyellow = "#adff2f";
  var grey = "#808080";
  var honeydew = "#f0fff0";
  var hotpink = "#ff69b4";
  var indianred = "#cd5c5c";
  var indigo = "#4b0082";
  var ivory = "#fffff0";
  var khaki = "#f0e68c";
  var lavender = "#e6e6fa";
  var lavenderblush = "#fff0f5";
  var lawngreen = "#7cfc00";
  var lemonchiffon = "#fffacd";
  var lightblue = "#add8e6";
  var lightcoral = "#f08080";
  var lightcyan = "#e0ffff";
  var lightgoldenrodyellow = "#fafad2";
  var lightgray = "#d3d3d3";
  var lightgreen = "#90ee90";
  var lightgrey = "#d3d3d3";
  var lightpink = "#ffb6c1";
  var lightsalmon = "#ffa07a";
  var lightseagreen = "#20b2aa";
  var lightskyblue = "#87cefa";
  var lightslategray = "#778899";
  var lightslategrey = "#778899";
  var lightsteelblue = "#b0c4de";
  var lightyellow = "#ffffe0";
  var limegreen = "#32cd32";
  var linen = "#faf0e6";
  var mediumaquamarine = "#66cdaa";
  var mediumblue = "#0000cd";
  var mediumorchid = "#ba55d3";
  var mediumpurple = "#9370db";
  var mediumseagreen = "#3cb371";
  var mediumslateblue = "#7b68ee";
  var mediumspringgreen = "#00fa9a";
  var mediumturquoise = "#48d1cc";
  var mediumvioletred = "#c71585";
  var midnightblue = "#191970";
  var mintcream = "#f5fffa";
  var mistyrose = "#ffe4e1";
  var moccasin = "#ffe4b5";
  var navajowhite = "#ffdead";
  var oldlace = "#fdf5e6";
  var olivedrab = "#6b8e23";
  var orangered = "#ff4500";
  var orchid = "#da70d6";
  var palegoldenrod = "#eee8aa";
  var palegreen = "#98fb98";
  var paleturquoise = "#afeeee";
  var palevioletred = "#db7093";
  var papayawhip = "#ffefd5";
  var peachpuff = "#ffdab9";
  var peru = "#cd853f";
  var pink = "#ffc0cb";
  var plum = "#dda0dd";
  var powderblue = "#b0e0e6";
  var rosybrown = "#bc8f8f";
  var royalblue = "#4169e1";
  var saddlebrown = "#8b4513";
  var salmon = "#fa8072";
  var sandybrown = "#f4a460";
  var seagreen = "#2e8b57";
  var seashell = "#fff5ee";
  var sienna = "#a0522d";
  var skyblue = "#87ceeb";
  var slateblue = "#6a5acd";
  var slategray = "#708090";
  var slategrey = "#708090";
  var snow = "#fffafa";
  var springgreen = "#00ff7f";
  var steelblue = "#4682b4";
  var tan = "#d2b48c";
  var thistle = "#d8bfd8";
  var tomato = "#ff6347";
  var turquoise = "#40e0d0";
  var violet = "#ee82ee";
  var wheat = "#f5deb3";
  var whitesmoke = "#f5f5f5";
  var yellowgreen = "#9acd32";
  var rebeccapurple = "#663399";
  var require$$0 = {
  	black: black,
  	silver: silver,
  	gray: gray,
  	white: white,
  	maroon: maroon,
  	red: red,
  	purple: purple,
  	fuchsia: fuchsia,
  	green: green,
  	lime: lime,
  	olive: olive,
  	yellow: yellow,
  	navy: navy,
  	blue: blue,
  	teal: teal,
  	aqua: aqua,
  	orange: orange,
  	aliceblue: aliceblue,
  	antiquewhite: antiquewhite,
  	aquamarine: aquamarine,
  	azure: azure,
  	beige: beige,
  	bisque: bisque,
  	blanchedalmond: blanchedalmond,
  	blueviolet: blueviolet,
  	brown: brown,
  	burlywood: burlywood,
  	cadetblue: cadetblue,
  	chartreuse: chartreuse,
  	chocolate: chocolate,
  	coral: coral,
  	cornflowerblue: cornflowerblue,
  	cornsilk: cornsilk,
  	crimson: crimson,
  	darkblue: darkblue,
  	darkcyan: darkcyan,
  	darkgoldenrod: darkgoldenrod,
  	darkgray: darkgray,
  	darkgreen: darkgreen,
  	darkgrey: darkgrey,
  	darkkhaki: darkkhaki,
  	darkmagenta: darkmagenta,
  	darkolivegreen: darkolivegreen,
  	darkorange: darkorange,
  	darkorchid: darkorchid,
  	darkred: darkred,
  	darksalmon: darksalmon,
  	darkseagreen: darkseagreen,
  	darkslateblue: darkslateblue,
  	darkslategray: darkslategray,
  	darkslategrey: darkslategrey,
  	darkturquoise: darkturquoise,
  	darkviolet: darkviolet,
  	deeppink: deeppink,
  	deepskyblue: deepskyblue,
  	dimgray: dimgray,
  	dimgrey: dimgrey,
  	dodgerblue: dodgerblue,
  	firebrick: firebrick,
  	floralwhite: floralwhite,
  	forestgreen: forestgreen,
  	gainsboro: gainsboro,
  	ghostwhite: ghostwhite,
  	gold: gold,
  	goldenrod: goldenrod,
  	greenyellow: greenyellow,
  	grey: grey,
  	honeydew: honeydew,
  	hotpink: hotpink,
  	indianred: indianred,
  	indigo: indigo,
  	ivory: ivory,
  	khaki: khaki,
  	lavender: lavender,
  	lavenderblush: lavenderblush,
  	lawngreen: lawngreen,
  	lemonchiffon: lemonchiffon,
  	lightblue: lightblue,
  	lightcoral: lightcoral,
  	lightcyan: lightcyan,
  	lightgoldenrodyellow: lightgoldenrodyellow,
  	lightgray: lightgray,
  	lightgreen: lightgreen,
  	lightgrey: lightgrey,
  	lightpink: lightpink,
  	lightsalmon: lightsalmon,
  	lightseagreen: lightseagreen,
  	lightskyblue: lightskyblue,
  	lightslategray: lightslategray,
  	lightslategrey: lightslategrey,
  	lightsteelblue: lightsteelblue,
  	lightyellow: lightyellow,
  	limegreen: limegreen,
  	linen: linen,
  	mediumaquamarine: mediumaquamarine,
  	mediumblue: mediumblue,
  	mediumorchid: mediumorchid,
  	mediumpurple: mediumpurple,
  	mediumseagreen: mediumseagreen,
  	mediumslateblue: mediumslateblue,
  	mediumspringgreen: mediumspringgreen,
  	mediumturquoise: mediumturquoise,
  	mediumvioletred: mediumvioletred,
  	midnightblue: midnightblue,
  	mintcream: mintcream,
  	mistyrose: mistyrose,
  	moccasin: moccasin,
  	navajowhite: navajowhite,
  	oldlace: oldlace,
  	olivedrab: olivedrab,
  	orangered: orangered,
  	orchid: orchid,
  	palegoldenrod: palegoldenrod,
  	palegreen: palegreen,
  	paleturquoise: paleturquoise,
  	palevioletred: palevioletred,
  	papayawhip: papayawhip,
  	peachpuff: peachpuff,
  	peru: peru,
  	pink: pink,
  	plum: plum,
  	powderblue: powderblue,
  	rosybrown: rosybrown,
  	royalblue: royalblue,
  	saddlebrown: saddlebrown,
  	salmon: salmon,
  	sandybrown: sandybrown,
  	seagreen: seagreen,
  	seashell: seashell,
  	sienna: sienna,
  	skyblue: skyblue,
  	slateblue: slateblue,
  	slategray: slategray,
  	slategrey: slategrey,
  	snow: snow,
  	springgreen: springgreen,
  	steelblue: steelblue,
  	tan: tan,
  	thistle: thistle,
  	tomato: tomato,
  	turquoise: turquoise,
  	violet: violet,
  	wheat: wheat,
  	whitesmoke: whitesmoke,
  	yellowgreen: yellowgreen,
  	rebeccapurple: rebeccapurple
  };

  var cssColorKeywords = require$$0;

  var cssToReactNative = createCommonjsModule(function (module, exports) {

  Object.defineProperty(exports, '__esModule', {
    value: true
  });

  function _interopDefault(ex) {
    return ex && typeof ex === 'object' && 'default' in ex ? ex['default'] : ex;
  }



  var parse__default = _interopDefault(lib);

  var camelizeStyleName = _interopDefault(camelize);

  var cssColorKeywords$1 = _interopDefault(cssColorKeywords);

  var matchString = function matchString(node) {
    if (node.type !== 'string') return null;
    return node.value.replace(/\\([0-9a-f]{1,6})(?:\s|$)/gi, function (match, charCode) {
      return String.fromCharCode(parseInt(charCode, 16));
    }).replace(/\\/g, '');
  };

  var hexColorRe = /^(#(?:[0-9a-f]{3,4}){1,2})$/i;
  var cssFunctionNameRe = /^(rgba?|hsla?|hwb|lab|lch|gray|color)$/;

  var matchColor = function matchColor(node) {
    if (node.type === 'word' && (hexColorRe.test(node.value) || node.value in cssColorKeywords$1 || node.value === 'transparent')) {
      return node.value;
    } else if (node.type === 'function' && cssFunctionNameRe.test(node.value)) {
      return lib.stringify(node);
    }

    return null;
  };

  var noneRe = /^(none)$/i;
  var autoRe = /^(auto)$/i;
  var identRe = /(^-?[_a-z][_a-z0-9-]*$)/i; // Note if these are wrong, you'll need to change index.js too

  var numberRe = /^([+-]?(?:\d*\.)?\d+(?:e[+-]?\d+)?)$/i; // Note lengthRe is sneaky: you can omit units for 0

  var lengthRe = /^(0$|(?:[+-]?(?:\d*\.)?\d+(?:e[+-]?\d+)?)(?=px$))/i;
  var unsupportedUnitRe = /^([+-]?(?:\d*\.)?\d+(?:e[+-]?\d+)?(ch|em|ex|rem|vh|vw|vmin|vmax|cm|mm|in|pc|pt))$/i;
  var angleRe = /^([+-]?(?:\d*\.)?\d+(?:e[+-]?\d+)?(?:deg|rad))$/i;
  var percentRe = /^([+-]?(?:\d*\.)?\d+(?:e[+-]?\d+)?%)$/i;

  var noopToken = function noopToken(predicate) {
    return function (node) {
      return predicate(node) ? '<token>' : null;
    };
  };

  var valueForTypeToken = function valueForTypeToken(type) {
    return function (node) {
      return node.type === type ? node.value : null;
    };
  };

  var regExpToken = function regExpToken(regExp, transform) {
    if (transform === void 0) {
      transform = String;
    }

    return function (node) {
      if (node.type !== 'word') return null;
      var match = node.value.match(regExp);
      if (match === null) return null;
      var value = transform(match[1]);
      return value;
    };
  };

  var SPACE = noopToken(function (node) {
    return node.type === 'space';
  });
  var SLASH = noopToken(function (node) {
    return node.type === 'div' && node.value === '/';
  });
  var COMMA = noopToken(function (node) {
    return node.type === 'div' && node.value === ',';
  });
  var WORD = valueForTypeToken('word');
  var NONE = regExpToken(noneRe);
  var AUTO = regExpToken(autoRe);
  var NUMBER = regExpToken(numberRe, Number);
  var LENGTH = regExpToken(lengthRe, Number);
  var UNSUPPORTED_LENGTH_UNIT = regExpToken(unsupportedUnitRe);
  var ANGLE = regExpToken(angleRe, function (angle) {
    return angle.toLowerCase();
  });
  var PERCENT = regExpToken(percentRe);
  var IDENT = regExpToken(identRe);
  var STRING = matchString;
  var COLOR = matchColor;
  var LINE = regExpToken(/^(none|underline|line-through)$/i);
  var BORDER_STYLE = regExpToken(/^(solid|dashed|dotted)$/);
  var defaultBorderWidth = 1;
  var defaultBorderColor = 'black';
  var defaultBorderStyle = 'solid';

  var border = function border(tokenStream) {
    var borderWidth;
    var borderColor;
    var borderStyle;

    if (tokenStream.matches(NONE)) {
      tokenStream.expectEmpty();
      return {
        borderWidth: 0,
        borderColor: 'black',
        borderStyle: 'solid'
      };
    }

    var partsParsed = 0;

    while (partsParsed < 3 && tokenStream.hasTokens()) {
      if (partsParsed !== 0) tokenStream.expect(SPACE);

      if (borderWidth === undefined && tokenStream.matches(LENGTH, UNSUPPORTED_LENGTH_UNIT)) {
        borderWidth = tokenStream.lastValue;
      } else if (borderColor === undefined && tokenStream.matches(COLOR)) {
        borderColor = tokenStream.lastValue;
      } else if (borderStyle === undefined && tokenStream.matches(BORDER_STYLE)) {
        borderStyle = tokenStream.lastValue;
      } else {
        tokenStream["throw"]();
      }

      partsParsed += 1;
    }

    tokenStream.expectEmpty();
    if (borderWidth === undefined) borderWidth = defaultBorderWidth;
    if (borderColor === undefined) borderColor = defaultBorderColor;
    if (borderStyle === undefined) borderStyle = defaultBorderStyle;
    return {
      borderWidth: borderWidth,
      borderColor: borderColor,
      borderStyle: borderStyle
    };
  };

  var directionFactory = function directionFactory(_ref) {
    var _ref$types = _ref.types,
        types = _ref$types === void 0 ? [LENGTH, UNSUPPORTED_LENGTH_UNIT, PERCENT] : _ref$types,
        _ref$directions = _ref.directions,
        directions = _ref$directions === void 0 ? ['Top', 'Right', 'Bottom', 'Left'] : _ref$directions,
        _ref$prefix = _ref.prefix,
        prefix = _ref$prefix === void 0 ? '' : _ref$prefix,
        _ref$suffix = _ref.suffix,
        suffix = _ref$suffix === void 0 ? '' : _ref$suffix;
    return function (tokenStream) {
      var _ref2;

      var values = []; // borderWidth doesn't currently allow a percent value, but may do in the future

      values.push(tokenStream.expect.apply(tokenStream, types));

      while (values.length < 4 && tokenStream.hasTokens()) {
        tokenStream.expect(SPACE);
        values.push(tokenStream.expect.apply(tokenStream, types));
      }

      tokenStream.expectEmpty();
      var top = values[0],
          _values$ = values[1],
          right = _values$ === void 0 ? top : _values$,
          _values$2 = values[2],
          bottom = _values$2 === void 0 ? top : _values$2,
          _values$3 = values[3],
          left = _values$3 === void 0 ? right : _values$3;

      var keyFor = function keyFor(n) {
        return "" + prefix + directions[n] + suffix;
      };

      return _ref2 = {}, _ref2[keyFor(0)] = top, _ref2[keyFor(1)] = right, _ref2[keyFor(2)] = bottom, _ref2[keyFor(3)] = left, _ref2;
    };
  };

  var parseShadowOffset = function parseShadowOffset(tokenStream) {
    var width = tokenStream.expect(LENGTH);
    var height = tokenStream.matches(SPACE) ? tokenStream.expect(LENGTH) : width;
    tokenStream.expectEmpty();
    return {
      width: width,
      height: height
    };
  };

  var parseShadow = function parseShadow(tokenStream) {
    var offsetX;
    var offsetY;
    var radius;
    var color;

    if (tokenStream.matches(NONE)) {
      tokenStream.expectEmpty();
      return {
        offset: {
          width: 0,
          height: 0
        },
        radius: 0,
        color: 'black'
      };
    }

    var didParseFirst = false;

    while (tokenStream.hasTokens()) {
      if (didParseFirst) tokenStream.expect(SPACE);

      if (offsetX === undefined && tokenStream.matches(LENGTH, UNSUPPORTED_LENGTH_UNIT)) {
        offsetX = tokenStream.lastValue;
        tokenStream.expect(SPACE);
        offsetY = tokenStream.expect(LENGTH, UNSUPPORTED_LENGTH_UNIT);
        tokenStream.saveRewindPoint();

        if (tokenStream.matches(SPACE) && tokenStream.matches(LENGTH, UNSUPPORTED_LENGTH_UNIT)) {
          radius = tokenStream.lastValue;
        } else {
          tokenStream.rewind();
        }
      } else if (color === undefined && tokenStream.matches(COLOR)) {
        color = tokenStream.lastValue;
      } else {
        tokenStream["throw"]();
      }

      didParseFirst = true;
    }

    if (offsetX === undefined) tokenStream["throw"]();
    return {
      offset: {
        width: offsetX,
        height: offsetY
      },
      radius: radius !== undefined ? radius : 0,
      color: color !== undefined ? color : 'black'
    };
  };

  var boxShadow = function boxShadow(tokenStream) {
    var _parseShadow = parseShadow(tokenStream),
        offset = _parseShadow.offset,
        radius = _parseShadow.radius,
        color = _parseShadow.color;

    return {
      shadowOffset: offset,
      shadowRadius: radius,
      shadowColor: color,
      shadowOpacity: 1
    };
  };

  var defaultFlexGrow = 1;
  var defaultFlexShrink = 1;
  var defaultFlexBasis = 0;

  var flex = function flex(tokenStream) {
    var flexGrow;
    var flexShrink;
    var flexBasis;

    if (tokenStream.matches(NONE)) {
      tokenStream.expectEmpty();
      return {
        flexGrow: 0,
        flexShrink: 0,
        flexBasis: 'auto'
      };
    }

    tokenStream.saveRewindPoint();

    if (tokenStream.matches(AUTO) && !tokenStream.hasTokens()) {
      return {
        flexGrow: 1,
        flexShrink: 1,
        flexBasis: 'auto'
      };
    }

    tokenStream.rewind();
    var partsParsed = 0;

    while (partsParsed < 2 && tokenStream.hasTokens()) {
      if (partsParsed !== 0) tokenStream.expect(SPACE);

      if (flexGrow === undefined && tokenStream.matches(NUMBER)) {
        flexGrow = tokenStream.lastValue;
        tokenStream.saveRewindPoint();

        if (tokenStream.matches(SPACE) && tokenStream.matches(NUMBER)) {
          flexShrink = tokenStream.lastValue;
        } else {
          tokenStream.rewind();
        }
      } else if (flexBasis === undefined && tokenStream.matches(LENGTH, UNSUPPORTED_LENGTH_UNIT, PERCENT)) {
        flexBasis = tokenStream.lastValue;
      } else if (flexBasis === undefined && tokenStream.matches(AUTO)) {
        flexBasis = 'auto';
      } else {
        tokenStream["throw"]();
      }

      partsParsed += 1;
    }

    tokenStream.expectEmpty();
    if (flexGrow === undefined) flexGrow = defaultFlexGrow;
    if (flexShrink === undefined) flexShrink = defaultFlexShrink;
    if (flexBasis === undefined) flexBasis = defaultFlexBasis;
    return {
      flexGrow: flexGrow,
      flexShrink: flexShrink,
      flexBasis: flexBasis
    };
  };

  var FLEX_WRAP = regExpToken(/(nowrap|wrap|wrap-reverse)/);
  var FLEX_DIRECTION = regExpToken(/(row|row-reverse|column|column-reverse)/);
  var defaultFlexWrap = 'nowrap';
  var defaultFlexDirection = 'row';

  var flexFlow = function flexFlow(tokenStream) {
    var flexWrap;
    var flexDirection;
    var partsParsed = 0;

    while (partsParsed < 2 && tokenStream.hasTokens()) {
      if (partsParsed !== 0) tokenStream.expect(SPACE);

      if (flexWrap === undefined && tokenStream.matches(FLEX_WRAP)) {
        flexWrap = tokenStream.lastValue;
      } else if (flexDirection === undefined && tokenStream.matches(FLEX_DIRECTION)) {
        flexDirection = tokenStream.lastValue;
      } else {
        tokenStream["throw"]();
      }

      partsParsed += 1;
    }

    tokenStream.expectEmpty();
    if (flexWrap === undefined) flexWrap = defaultFlexWrap;
    if (flexDirection === undefined) flexDirection = defaultFlexDirection;
    return {
      flexWrap: flexWrap,
      flexDirection: flexDirection
    };
  };

  var fontFamily = function fontFamily(tokenStream) {
    var fontFamily;

    if (tokenStream.matches(STRING)) {
      fontFamily = tokenStream.lastValue;
    } else {
      fontFamily = tokenStream.expect(IDENT);

      while (tokenStream.hasTokens()) {
        tokenStream.expect(SPACE);
        var nextIdent = tokenStream.expect(IDENT);
        fontFamily += " " + nextIdent;
      }
    }

    tokenStream.expectEmpty();
    return {
      fontFamily: fontFamily
    };
  };

  var NORMAL = regExpToken(/^(normal)$/);
  var STYLE = regExpToken(/^(italic)$/);
  var WEIGHT = regExpToken(/^([1-9]00|bold)$/);
  var VARIANT = regExpToken(/^(small-caps)$/);
  var defaultFontStyle = 'normal';
  var defaultFontWeight = 'normal';
  var defaultFontVariant = [];

  var font = function font(tokenStream) {
    var fontStyle;
    var fontWeight;
    var fontVariant; // let fontSize;

    var lineHeight; // let fontFamily;

    var numStyleWeightVariantMatched = 0;

    while (numStyleWeightVariantMatched < 3 && tokenStream.hasTokens()) {
      if (tokenStream.matches(NORMAL)) ;else if (fontStyle === undefined && tokenStream.matches(STYLE)) {
        fontStyle = tokenStream.lastValue;
      } else if (fontWeight === undefined && tokenStream.matches(WEIGHT)) {
        fontWeight = tokenStream.lastValue;
      } else if (fontVariant === undefined && tokenStream.matches(VARIANT)) {
        fontVariant = [tokenStream.lastValue];
      } else {
        break;
      }
      tokenStream.expect(SPACE);
      numStyleWeightVariantMatched += 1;
    }

    var fontSize = tokenStream.expect(LENGTH, UNSUPPORTED_LENGTH_UNIT);

    if (tokenStream.matches(SLASH)) {
      lineHeight = tokenStream.expect(LENGTH, UNSUPPORTED_LENGTH_UNIT);
    }

    tokenStream.expect(SPACE);

    var _fontFamily = fontFamily(tokenStream),
        fontFamily$1 = _fontFamily.fontFamily;

    if (fontStyle === undefined) fontStyle = defaultFontStyle;
    if (fontWeight === undefined) fontWeight = defaultFontWeight;
    if (fontVariant === undefined) fontVariant = defaultFontVariant;
    var out = {
      fontStyle: fontStyle,
      fontWeight: fontWeight,
      fontVariant: fontVariant,
      fontSize: fontSize,
      fontFamily: fontFamily$1
    };
    if (lineHeight !== undefined) out.lineHeight = lineHeight;
    return out;
  };

  var ALIGN_CONTENT = regExpToken(/(flex-(?:start|end)|center|stretch|space-(?:between|around))/);
  var JUSTIFY_CONTENT = regExpToken(/(flex-(?:start|end)|center|space-(?:between|around|evenly))/);

  var placeContent = function placeContent(tokenStream) {
    var alignContent = tokenStream.expect(ALIGN_CONTENT);
    var justifyContent;

    if (tokenStream.hasTokens()) {
      tokenStream.expect(SPACE);
      justifyContent = tokenStream.expect(JUSTIFY_CONTENT);
    } else {
      justifyContent = 'stretch';
    }

    tokenStream.expectEmpty();
    return {
      alignContent: alignContent,
      justifyContent: justifyContent
    };
  };

  var STYLE$1 = regExpToken(/^(solid|double|dotted|dashed)$/);
  var defaultTextDecorationLine = 'none';
  var defaultTextDecorationStyle = 'solid';
  var defaultTextDecorationColor = 'black';

  var textDecoration = function textDecoration(tokenStream) {
    var line;
    var style;
    var color;
    var didParseFirst = false;

    while (tokenStream.hasTokens()) {
      if (didParseFirst) tokenStream.expect(SPACE);

      if (line === undefined && tokenStream.matches(LINE)) {
        var lines = [tokenStream.lastValue.toLowerCase()];
        tokenStream.saveRewindPoint();

        if (lines[0] !== 'none' && tokenStream.matches(SPACE) && tokenStream.matches(LINE)) {
          lines.push(tokenStream.lastValue.toLowerCase()); // Underline comes before line-through

          lines.sort().reverse();
        } else {
          tokenStream.rewind();
        }

        line = lines.join(' ');
      } else if (style === undefined && tokenStream.matches(STYLE$1)) {
        style = tokenStream.lastValue;
      } else if (color === undefined && tokenStream.matches(COLOR)) {
        color = tokenStream.lastValue;
      } else {
        tokenStream["throw"]();
      }

      didParseFirst = true;
    }

    return {
      textDecorationLine: line !== undefined ? line : defaultTextDecorationLine,
      textDecorationColor: color !== undefined ? color : defaultTextDecorationColor,
      textDecorationStyle: style !== undefined ? style : defaultTextDecorationStyle
    };
  };

  var textDecorationLine = function textDecorationLine(tokenStream) {
    var lines = [];
    var didParseFirst = false;

    while (tokenStream.hasTokens()) {
      if (didParseFirst) tokenStream.expect(SPACE);
      lines.push(tokenStream.expect(LINE).toLowerCase());
      didParseFirst = true;
    }

    lines.sort().reverse();
    return {
      textDecorationLine: lines.join(' ')
    };
  };

  var textShadow = function textShadow(tokenStream) {
    var _parseShadow2 = parseShadow(tokenStream),
        offset = _parseShadow2.offset,
        radius = _parseShadow2.radius,
        color = _parseShadow2.color;

    return {
      textShadowOffset: offset,
      textShadowRadius: radius,
      textShadowColor: color
    };
  };

  var oneOfType = function oneOfType(tokenType) {
    return function (functionStream) {
      var value = functionStream.expect(tokenType);
      functionStream.expectEmpty();
      return value;
    };
  };

  var singleNumber = oneOfType(NUMBER);
  var singleLength = oneOfType(LENGTH);
  var singleAngle = oneOfType(ANGLE);

  var xyTransformFactory = function xyTransformFactory(tokenType) {
    return function (key, valueIfOmitted) {
      return function (functionStream) {
        var _ref3, _ref4;

        var x = functionStream.expect(tokenType);
        var y;

        if (functionStream.hasTokens()) {
          functionStream.expect(COMMA);
          y = functionStream.expect(tokenType);
        } else if (valueIfOmitted !== undefined) {
          y = valueIfOmitted;
        } else {
          // Assumption, if x === y, then we can omit XY
          // I.e. scale(5) => [{ scale: 5 }] rather than [{ scaleX: 5 }, { scaleY: 5 }]
          return x;
        }

        functionStream.expectEmpty();
        return [(_ref3 = {}, _ref3[key + "Y"] = y, _ref3), (_ref4 = {}, _ref4[key + "X"] = x, _ref4)];
      };
    };
  };

  var xyNumber = xyTransformFactory(NUMBER);
  var xyLength = xyTransformFactory(LENGTH);
  var xyAngle = xyTransformFactory(ANGLE);
  var partTransforms = {
    perspective: singleNumber,
    scale: xyNumber('scale'),
    scaleX: singleNumber,
    scaleY: singleNumber,
    translate: xyLength('translate', 0),
    translateX: singleLength,
    translateY: singleLength,
    rotate: singleAngle,
    rotateX: singleAngle,
    rotateY: singleAngle,
    rotateZ: singleAngle,
    skewX: singleAngle,
    skewY: singleAngle,
    skew: xyAngle('skew', '0deg')
  };

  var transform = function transform(tokenStream) {
    var transforms = [];
    var didParseFirst = false;

    while (tokenStream.hasTokens()) {
      if (didParseFirst) tokenStream.expect(SPACE);
      var functionStream = tokenStream.expectFunction();
      var functionName = functionStream.functionName;
      var transformedValues = partTransforms[functionName](functionStream);

      if (!Array.isArray(transformedValues)) {
        var _ref5;

        transformedValues = [(_ref5 = {}, _ref5[functionName] = transformedValues, _ref5)];
      }

      transforms = transformedValues.concat(transforms);
      didParseFirst = true;
    }

    return {
      transform: transforms
    };
  };

  var background = function background(tokenStream) {
    return {
      backgroundColor: tokenStream.expect(COLOR)
    };
  };

  var borderColor = directionFactory({
    types: [COLOR],
    prefix: 'border',
    suffix: 'Color'
  });
  var borderRadius = directionFactory({
    directions: ['TopLeft', 'TopRight', 'BottomRight', 'BottomLeft'],
    prefix: 'border',
    suffix: 'Radius'
  });
  var borderWidth = directionFactory({
    prefix: 'border',
    suffix: 'Width'
  });
  var margin = directionFactory({
    types: [LENGTH, UNSUPPORTED_LENGTH_UNIT, PERCENT, AUTO],
    prefix: 'margin'
  });
  var padding = directionFactory({
    prefix: 'padding'
  });

  var fontVariant = function fontVariant(tokenStream) {
    return {
      fontVariant: [tokenStream.expect(IDENT)]
    };
  };

  var fontWeight = function fontWeight(tokenStream) {
    return {
      fontWeight: tokenStream.expect(WORD) // Also match numbers as strings

    };
  };

  var shadowOffset = function shadowOffset(tokenStream) {
    return {
      shadowOffset: parseShadowOffset(tokenStream)
    };
  };

  var textShadowOffset = function textShadowOffset(tokenStream) {
    return {
      textShadowOffset: parseShadowOffset(tokenStream)
    };
  };

  var transforms = {
    background: background,
    border: border,
    borderColor: borderColor,
    borderRadius: borderRadius,
    borderWidth: borderWidth,
    boxShadow: boxShadow,
    flex: flex,
    flexFlow: flexFlow,
    font: font,
    fontFamily: fontFamily,
    fontVariant: fontVariant,
    fontWeight: fontWeight,
    margin: margin,
    padding: padding,
    placeContent: placeContent,
    shadowOffset: shadowOffset,
    textShadow: textShadow,
    textShadowOffset: textShadowOffset,
    textDecoration: textDecoration,
    textDecorationLine: textDecorationLine,
    transform: transform
  };
  var propertiesWithoutUnits;

  {
    propertiesWithoutUnits = ['aspectRatio', 'elevation', 'flexGrow', 'flexShrink', 'opacity', 'shadowOpacity', 'zIndex'];
  }

  var devPropertiesWithUnitsRegExp = propertiesWithoutUnits != null ? new RegExp(propertiesWithoutUnits.join('|')) : null;
  var SYMBOL_MATCH = 'SYMBOL_MATCH';

  var TokenStream =
  /*#__PURE__*/
  function () {
    function TokenStream(nodes, parent) {
      this.index = 0;
      this.nodes = nodes;
      this.functionName = parent != null ? parent.value : null;
      this.lastValue = null;
      this.rewindIndex = -1;
    }

    var _proto = TokenStream.prototype;

    _proto.hasTokens = function hasTokens() {
      return this.index <= this.nodes.length - 1;
    };

    _proto[SYMBOL_MATCH] = function () {
      if (!this.hasTokens()) return null;
      var node = this.nodes[this.index];

      for (var i = 0; i < arguments.length; i += 1) {
        var tokenDescriptor = i < 0 || arguments.length <= i ? undefined : arguments[i];
        var value = tokenDescriptor(node);

        if (value !== null) {
          this.index += 1;
          this.lastValue = value;
          return value;
        }
      }

      return null;
    };

    _proto.matches = function matches() {
      return this[SYMBOL_MATCH].apply(this, arguments) !== null;
    };

    _proto.expect = function expect() {
      var value = this[SYMBOL_MATCH].apply(this, arguments);
      return value !== null ? value : this["throw"]();
    };

    _proto.matchesFunction = function matchesFunction() {
      var node = this.nodes[this.index];
      if (node.type !== 'function') return null;
      var value = new TokenStream(node.nodes, node);
      this.index += 1;
      this.lastValue = null;
      return value;
    };

    _proto.expectFunction = function expectFunction() {
      var value = this.matchesFunction();
      return value !== null ? value : this["throw"]();
    };

    _proto.expectEmpty = function expectEmpty() {
      if (this.hasTokens()) this["throw"]();
    };

    _proto["throw"] = function _throw() {
      throw new Error("Unexpected token type: " + this.nodes[this.index].type);
    };

    _proto.saveRewindPoint = function saveRewindPoint() {
      this.rewindIndex = this.index;
    };

    _proto.rewind = function rewind() {
      if (this.rewindIndex === -1) throw new Error('Internal error');
      this.index = this.rewindIndex;
      this.lastValue = null;
    };

    return TokenStream;
  }();
  /* eslint-disable no-param-reassign */
  // Note if this is wrong, you'll need to change tokenTypes.js too


  var numberOrLengthRe = /^([+-]?(?:\d*\.)?\d+(?:e[+-]?\d+)?)(?:px)?$/i;
  var numberOnlyRe = /^[+-]?(?:\d*\.\d*|[1-9]\d*)(?:e[+-]?\d+)?$/i;
  var boolRe = /^true|false$/i;
  var nullRe = /^null$/i;
  var undefinedRe = /^undefined$/i; // Undocumented export

  var transformRawValue = function transformRawValue(propName, value) {
    {
      var needsUnit = !devPropertiesWithUnitsRegExp.test(propName);
      var isNumberWithoutUnit = numberOnlyRe.test(value);

      if (needsUnit && isNumberWithoutUnit) {
        // eslint-disable-next-line no-console
        console.warn("Expected style \"" + propName + ": " + value + "\" to contain units");
      }

      if (!needsUnit && value !== '0' && !isNumberWithoutUnit) {
        // eslint-disable-next-line no-console
        console.warn("Expected style \"" + propName + ": " + value + "\" to be unitless");
      }
    }

    var numberMatch = value.match(numberOrLengthRe);
    if (numberMatch !== null) return Number(numberMatch[1]);
    var boolMatch = value.match(boolRe);
    if (boolMatch !== null) return boolMatch[0].toLowerCase() === 'true';
    var nullMatch = value.match(nullRe);
    if (nullMatch !== null) return null;
    var undefinedMatch = value.match(undefinedRe);
    if (undefinedMatch !== null) return undefined;
    return value;
  };

  var baseTransformShorthandValue = function baseTransformShorthandValue(propName, value) {
    var ast = parse__default(value);
    var tokenStream = new TokenStream(ast.nodes);
    return transforms[propName](tokenStream);
  };

  var transformShorthandValue = function (propName, value) {
    try {
      return baseTransformShorthandValue(propName, value);
    } catch (e) {
      throw new Error("Failed to parse declaration \"" + propName + ": " + value + "\"");
    }
  };

  var getStylesForProperty = function getStylesForProperty(propName, inputValue, allowShorthand) {
    var _ref6;

    var isRawValue = allowShorthand === false || !(propName in transforms);
    var value = inputValue.trim();
    var propValues = isRawValue ? (_ref6 = {}, _ref6[propName] = transformRawValue(propName, value), _ref6) : transformShorthandValue(propName, value);
    return propValues;
  };

  var getPropertyName = function getPropertyName(propName) {
    var isCustomProp = /^--\w+/.test(propName);

    if (isCustomProp) {
      return propName;
    }

    return camelizeStyleName(propName);
  };

  var index = function index(rules, shorthandBlacklist) {
    if (shorthandBlacklist === void 0) {
      shorthandBlacklist = [];
    }

    return rules.reduce(function (accum, rule) {
      var propertyName = getPropertyName(rule[0]);
      var value = rule[1];
      var allowShorthand = shorthandBlacklist.indexOf(propertyName) === -1;
      return Object.assign(accum, getStylesForProperty(propertyName, value, allowShorthand));
    }, {});
  };

  exports["default"] = index;
  exports.getPropertyName = getPropertyName;
  exports.getStylesForProperty = getStylesForProperty;
  exports.transformRawValue = transformRawValue;
  });

  var transformREMUnitRE = /([+-]+)?([\d.Ee]+)rem/g;

  function rem(value) {
    if (reactNative.Platform.OS === 'web') {
      return value;
    }

    return value.replace(transformREMUnitRE, function (_, unary, number) {
      return "".concat(unary || '').concat(reactNative.PixelRatio.getFontScale() * 16 * number, "px");
    });
  }

  var valueRE = /^([+-]?(?:\d+|\d*\.\d+))([a-z]*|%)$/;

  var parseValue = function parseValue(value) {
    if (Array.isArray(value)) {
      return value;
    }

    if (typeof value === 'number') {
      return [value, null];
    }

    var matchedValue = value.match(valueRE);

    if (matchedValue) {
      return [parseFloat(value), matchedValue[2]];
    }

    return [value, undefined];
  };

  var getUnit = function getUnit(left, right) {
    if (!left && !right) {
      return '';
    }

    if (!left) {
      return right;
    }

    if (!right || left === right) {
      return left;
    }

    throw new Error("Different units ".concat(left, " and ").concat(right, " found for arithmetic operation."));
  };

  var POWER = Math.pow(10, 8);

  var fixRounding = function fixRounding(value) {
    return Math.round(value * POWER) / POWER;
  };

  var calculateValue = function calculateValue(leftValue, operator, rightValue) {
    if (operator === '+') {
      return leftValue + rightValue;
    }

    if (operator === '-') {
      return leftValue - rightValue;
    }

    if (operator === '*') {
      return fixRounding(leftValue * rightValue);
    }

    if (operator === '/') {
      return fixRounding(leftValue / rightValue);
    }

    if (operator === '%') {
      return leftValue % rightValue;
    }

    throw new Error('Unknown operator.');
  };

  function calculate(left, operator, right) {
    var _parseValue = parseValue(left),
        _parseValue2 = _slicedToArray(_parseValue, 2),
        leftValue = _parseValue2[0],
        leftUnit = _parseValue2[1];

    var _parseValue3 = parseValue(right),
        _parseValue4 = _slicedToArray(_parseValue3, 2),
        rightValue = _parseValue4[0],
        rightUnit = _parseValue4[1];

    var unit = getUnit(leftUnit, rightUnit);
    return "".concat(calculateValue(leftValue, operator, rightValue)).concat(unit);
  }

  var convertToREM = function convertToREM(value) {
    var remValue = value / (reactNative.PixelRatio.getFontScale() * 16);
    return [remValue, 'rem'];
  }; // Use calculateAdvanced for mixed px/rem units.


  function calculateAdvanced(left, operator, right) {
    var parsedLeft = parseValue(left);

    var _parsedLeft = _slicedToArray(parsedLeft, 2),
        leftValue = _parsedLeft[0],
        leftUnit = _parsedLeft[1];

    var parsedRight = parseValue(right);

    var _parsedRight = _slicedToArray(parsedRight, 2),
        rightValue = _parsedRight[0],
        rightUnit = _parsedRight[1];

    if (leftUnit === 'px' && rightUnit === 'rem') {
      return calculate(convertToREM(leftValue), operator, parsedRight);
    }

    if (leftUnit === 'rem' && rightUnit === 'px') {
      return calculate(parsedLeft, operator, convertToREM(rightValue));
    }

    return calculate(parsedLeft, operator, parsedRight);
  }

  var formulaRE = /([+-])?([\d.Ee]+)(rem|px)?\s*(\+|-|\*|%)\s*([+-])?([\d.Ee]+)(rem|px)?/g;

  function formula(value) {
    // Naïve approach to calculate simple formulas.
    // TODO: Support more complex formulas including parenthesis.
    return value.replace(formulaRE, function (_) {
      var leftUnary = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : '';
      var leftNumber = arguments.length > 2 ? arguments[2] : undefined;
      var leftUnit = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : null;
      var operator = arguments.length > 4 ? arguments[4] : undefined;
      var rightUnary = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : '';
      var rightNumber = arguments.length > 6 ? arguments[6] : undefined;
      var rightUnit = arguments.length > 7 && arguments[7] !== undefined ? arguments[7] : null;
      var leftValue = [parseFloat("".concat(leftUnary).concat(leftNumber)), leftUnit];
      var rightValue = [parseFloat("".concat(rightUnary).concat(rightNumber)), rightUnit];
      return calculate(leftValue, operator, rightValue);
    });
  }

  function _extends() {
    _extends = Object.assign ? Object.assign.bind() : function (target) {
      for (var i = 1; i < arguments.length; i++) {
        var source = arguments[i];

        for (var key in source) {
          if (Object.prototype.hasOwnProperty.call(source, key)) {
            target[key] = source[key];
          }
        }
      }

      return target;
    };
    return _extends.apply(this, arguments);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }

    return self;
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function _setPrototypeOf(o, p) {
      o.__proto__ = p;
      return o;
    };
    return _setPrototypeOf(o, p);
  }

  function _inheritsLoose(subClass, superClass) {
    subClass.prototype = Object.create(superClass.prototype);
    subClass.prototype.constructor = subClass;
    _setPrototypeOf(subClass, superClass);
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf.bind() : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };
    return _getPrototypeOf(o);
  }

  function _isNativeFunction(fn) {
    return Function.toString.call(fn).indexOf("[native code]") !== -1;
  }

  function _isNativeReflectConstruct() {
    if (typeof Reflect === "undefined" || !Reflect.construct) return false;
    if (Reflect.construct.sham) return false;
    if (typeof Proxy === "function") return true;

    try {
      Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {}));
      return true;
    } catch (e) {
      return false;
    }
  }

  function _construct(Parent, args, Class) {
    if (_isNativeReflectConstruct()) {
      _construct = Reflect.construct.bind();
    } else {
      _construct = function _construct(Parent, args, Class) {
        var a = [null];
        a.push.apply(a, args);
        var Constructor = Function.bind.apply(Parent, a);
        var instance = new Constructor();
        if (Class) _setPrototypeOf(instance, Class.prototype);
        return instance;
      };
    }

    return _construct.apply(null, arguments);
  }

  function _wrapNativeSuper(Class) {
    var _cache = typeof Map === "function" ? new Map() : undefined;

    _wrapNativeSuper = function _wrapNativeSuper(Class) {
      if (Class === null || !_isNativeFunction(Class)) return Class;

      if (typeof Class !== "function") {
        throw new TypeError("Super expression must either be null or a function");
      }

      if (typeof _cache !== "undefined") {
        if (_cache.has(Class)) return _cache.get(Class);

        _cache.set(Class, Wrapper);
      }

      function Wrapper() {
        return _construct(Class, arguments, _getPrototypeOf(this).constructor);
      }

      Wrapper.prototype = Object.create(Class.prototype, {
        constructor: {
          value: Wrapper,
          enumerable: false,
          writable: true,
          configurable: true
        }
      });
      return _setPrototypeOf(Wrapper, Class);
    };

    return _wrapNativeSuper(Class);
  }

  // based on https://github.com/styled-components/styled-components/blob/fcf6f3804c57a14dd7984dfab7bc06ee2edca044/src/utils/error.js

  /**
   * Parse errors.md and turn it into a simple hash of code: message
   * @private
   */
  var ERRORS = {
    "1": "Passed invalid arguments to hsl, please pass multiple numbers e.g. hsl(360, 0.75, 0.4) or an object e.g. rgb({ hue: 255, saturation: 0.4, lightness: 0.75 }).\n\n",
    "2": "Passed invalid arguments to hsla, please pass multiple numbers e.g. hsla(360, 0.75, 0.4, 0.7) or an object e.g. rgb({ hue: 255, saturation: 0.4, lightness: 0.75, alpha: 0.7 }).\n\n",
    "3": "Passed an incorrect argument to a color function, please pass a string representation of a color.\n\n",
    "4": "Couldn't generate valid rgb string from %s, it returned %s.\n\n",
    "5": "Couldn't parse the color string. Please provide the color as a string in hex, rgb, rgba, hsl or hsla notation.\n\n",
    "6": "Passed invalid arguments to rgb, please pass multiple numbers e.g. rgb(255, 205, 100) or an object e.g. rgb({ red: 255, green: 205, blue: 100 }).\n\n",
    "7": "Passed invalid arguments to rgba, please pass multiple numbers e.g. rgb(255, 205, 100, 0.75) or an object e.g. rgb({ red: 255, green: 205, blue: 100, alpha: 0.75 }).\n\n",
    "8": "Passed invalid argument to toColorString, please pass a RgbColor, RgbaColor, HslColor or HslaColor object.\n\n",
    "9": "Please provide a number of steps to the modularScale helper.\n\n",
    "10": "Please pass a number or one of the predefined scales to the modularScale helper as the ratio.\n\n",
    "11": "Invalid value passed as base to modularScale, expected number or em string but got \"%s\"\n\n",
    "12": "Expected a string ending in \"px\" or a number passed as the first argument to %s(), got \"%s\" instead.\n\n",
    "13": "Expected a string ending in \"px\" or a number passed as the second argument to %s(), got \"%s\" instead.\n\n",
    "14": "Passed invalid pixel value (\"%s\") to %s(), please pass a value like \"12px\" or 12.\n\n",
    "15": "Passed invalid base value (\"%s\") to %s(), please pass a value like \"12px\" or 12.\n\n",
    "16": "You must provide a template to this method.\n\n",
    "17": "You passed an unsupported selector state to this method.\n\n",
    "18": "minScreen and maxScreen must be provided as stringified numbers with the same units.\n\n",
    "19": "fromSize and toSize must be provided as stringified numbers with the same units.\n\n",
    "20": "expects either an array of objects or a single object with the properties prop, fromSize, and toSize.\n\n",
    "21": "expects the objects in the first argument array to have the properties `prop`, `fromSize`, and `toSize`.\n\n",
    "22": "expects the first argument object to have the properties `prop`, `fromSize`, and `toSize`.\n\n",
    "23": "fontFace expects a name of a font-family.\n\n",
    "24": "fontFace expects either the path to the font file(s) or a name of a local copy.\n\n",
    "25": "fontFace expects localFonts to be an array.\n\n",
    "26": "fontFace expects fileFormats to be an array.\n\n",
    "27": "radialGradient requries at least 2 color-stops to properly render.\n\n",
    "28": "Please supply a filename to retinaImage() as the first argument.\n\n",
    "29": "Passed invalid argument to triangle, please pass correct pointingDirection e.g. 'right'.\n\n",
    "30": "Passed an invalid value to `height` or `width`. Please provide a pixel based unit.\n\n",
    "31": "The animation shorthand only takes 8 arguments. See the specification for more information: http://mdn.io/animation\n\n",
    "32": "To pass multiple animations please supply them in arrays, e.g. animation(['rotate', '2s'], ['move', '1s'])\nTo pass a single animation please supply them in simple values, e.g. animation('rotate', '2s')\n\n",
    "33": "The animation shorthand arrays can only have 8 elements. See the specification for more information: http://mdn.io/animation\n\n",
    "34": "borderRadius expects a radius value as a string or number as the second argument.\n\n",
    "35": "borderRadius expects one of \"top\", \"bottom\", \"left\" or \"right\" as the first argument.\n\n",
    "36": "Property must be a string value.\n\n",
    "37": "Syntax Error at %s.\n\n",
    "38": "Formula contains a function that needs parentheses at %s.\n\n",
    "39": "Formula is missing closing parenthesis at %s.\n\n",
    "40": "Formula has too many closing parentheses at %s.\n\n",
    "41": "All values in a formula must have the same unit or be unitless.\n\n",
    "42": "Please provide a number of steps to the modularScale helper.\n\n",
    "43": "Please pass a number or one of the predefined scales to the modularScale helper as the ratio.\n\n",
    "44": "Invalid value passed as base to modularScale, expected number or em/rem string but got %s.\n\n",
    "45": "Passed invalid argument to hslToColorString, please pass a HslColor or HslaColor object.\n\n",
    "46": "Passed invalid argument to rgbToColorString, please pass a RgbColor or RgbaColor object.\n\n",
    "47": "minScreen and maxScreen must be provided as stringified numbers with the same units.\n\n",
    "48": "fromSize and toSize must be provided as stringified numbers with the same units.\n\n",
    "49": "Expects either an array of objects or a single object with the properties prop, fromSize, and toSize.\n\n",
    "50": "Expects the objects in the first argument array to have the properties prop, fromSize, and toSize.\n\n",
    "51": "Expects the first argument object to have the properties prop, fromSize, and toSize.\n\n",
    "52": "fontFace expects either the path to the font file(s) or a name of a local copy.\n\n",
    "53": "fontFace expects localFonts to be an array.\n\n",
    "54": "fontFace expects fileFormats to be an array.\n\n",
    "55": "fontFace expects a name of a font-family.\n\n",
    "56": "linearGradient requries at least 2 color-stops to properly render.\n\n",
    "57": "radialGradient requries at least 2 color-stops to properly render.\n\n",
    "58": "Please supply a filename to retinaImage() as the first argument.\n\n",
    "59": "Passed invalid argument to triangle, please pass correct pointingDirection e.g. 'right'.\n\n",
    "60": "Passed an invalid value to `height` or `width`. Please provide a pixel based unit.\n\n",
    "61": "Property must be a string value.\n\n",
    "62": "borderRadius expects a radius value as a string or number as the second argument.\n\n",
    "63": "borderRadius expects one of \"top\", \"bottom\", \"left\" or \"right\" as the first argument.\n\n",
    "64": "The animation shorthand only takes 8 arguments. See the specification for more information: http://mdn.io/animation.\n\n",
    "65": "To pass multiple animations please supply them in arrays, e.g. animation(['rotate', '2s'], ['move', '1s'])\\nTo pass a single animation please supply them in simple values, e.g. animation('rotate', '2s').\n\n",
    "66": "The animation shorthand arrays can only have 8 elements. See the specification for more information: http://mdn.io/animation.\n\n",
    "67": "You must provide a template to this method.\n\n",
    "68": "You passed an unsupported selector state to this method.\n\n",
    "69": "Expected a string ending in \"px\" or a number passed as the first argument to %s(), got %s instead.\n\n",
    "70": "Expected a string ending in \"px\" or a number passed as the second argument to %s(), got %s instead.\n\n",
    "71": "Passed invalid pixel value %s to %s(), please pass a value like \"12px\" or 12.\n\n",
    "72": "Passed invalid base value %s to %s(), please pass a value like \"12px\" or 12.\n\n",
    "73": "Please provide a valid CSS variable.\n\n",
    "74": "CSS variable not found and no default was provided.\n\n",
    "75": "important requires a valid style object, got a %s instead.\n\n",
    "76": "fromSize and toSize must be provided as stringified numbers with the same units as minScreen and maxScreen.\n\n",
    "77": "remToPx expects a value in \"rem\" but you provided it in \"%s\".\n\n",
    "78": "base must be set in \"px\" or \"%\" but you set it in \"%s\".\n"
  };
  /**
   * super basic version of sprintf
   * @private
   */

  function format() {
    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    var a = args[0];
    var b = [];
    var c;

    for (c = 1; c < args.length; c += 1) {
      b.push(args[c]);
    }

    b.forEach(function (d) {
      a = a.replace(/%[a-z]/, d);
    });
    return a;
  }
  /**
   * Create an error file out of errors.md for development and a simple web link to the full errors
   * in production mode.
   * @private
   */


  var PolishedError = /*#__PURE__*/function (_Error) {
    _inheritsLoose(PolishedError, _Error);

    function PolishedError(code) {
      var _this;

      {
        for (var _len2 = arguments.length, args = new Array(_len2 > 1 ? _len2 - 1 : 0), _key2 = 1; _key2 < _len2; _key2++) {
          args[_key2 - 1] = arguments[_key2];
        }

        _this = _Error.call(this, format.apply(void 0, [ERRORS[code]].concat(args))) || this;
      }

      return _assertThisInitialized(_this);
    }

    return PolishedError;
  }( /*#__PURE__*/_wrapNativeSuper(Error));

  function colorToInt(color) {
    return Math.round(color * 255);
  }

  function convertToInt(red, green, blue) {
    return colorToInt(red) + "," + colorToInt(green) + "," + colorToInt(blue);
  }

  function hslToRgb(hue, saturation, lightness, convert) {
    if (convert === void 0) {
      convert = convertToInt;
    }

    if (saturation === 0) {
      // achromatic
      return convert(lightness, lightness, lightness);
    } // formulae from https://en.wikipedia.org/wiki/HSL_and_HSV


    var huePrime = (hue % 360 + 360) % 360 / 60;
    var chroma = (1 - Math.abs(2 * lightness - 1)) * saturation;
    var secondComponent = chroma * (1 - Math.abs(huePrime % 2 - 1));
    var red = 0;
    var green = 0;
    var blue = 0;

    if (huePrime >= 0 && huePrime < 1) {
      red = chroma;
      green = secondComponent;
    } else if (huePrime >= 1 && huePrime < 2) {
      red = secondComponent;
      green = chroma;
    } else if (huePrime >= 2 && huePrime < 3) {
      green = chroma;
      blue = secondComponent;
    } else if (huePrime >= 3 && huePrime < 4) {
      green = secondComponent;
      blue = chroma;
    } else if (huePrime >= 4 && huePrime < 5) {
      red = secondComponent;
      blue = chroma;
    } else if (huePrime >= 5 && huePrime < 6) {
      red = chroma;
      blue = secondComponent;
    }

    var lightnessModification = lightness - chroma / 2;
    var finalRed = red + lightnessModification;
    var finalGreen = green + lightnessModification;
    var finalBlue = blue + lightnessModification;
    return convert(finalRed, finalGreen, finalBlue);
  }

  var namedColorMap = {
    aliceblue: 'f0f8ff',
    antiquewhite: 'faebd7',
    aqua: '00ffff',
    aquamarine: '7fffd4',
    azure: 'f0ffff',
    beige: 'f5f5dc',
    bisque: 'ffe4c4',
    black: '000',
    blanchedalmond: 'ffebcd',
    blue: '0000ff',
    blueviolet: '8a2be2',
    brown: 'a52a2a',
    burlywood: 'deb887',
    cadetblue: '5f9ea0',
    chartreuse: '7fff00',
    chocolate: 'd2691e',
    coral: 'ff7f50',
    cornflowerblue: '6495ed',
    cornsilk: 'fff8dc',
    crimson: 'dc143c',
    cyan: '00ffff',
    darkblue: '00008b',
    darkcyan: '008b8b',
    darkgoldenrod: 'b8860b',
    darkgray: 'a9a9a9',
    darkgreen: '006400',
    darkgrey: 'a9a9a9',
    darkkhaki: 'bdb76b',
    darkmagenta: '8b008b',
    darkolivegreen: '556b2f',
    darkorange: 'ff8c00',
    darkorchid: '9932cc',
    darkred: '8b0000',
    darksalmon: 'e9967a',
    darkseagreen: '8fbc8f',
    darkslateblue: '483d8b',
    darkslategray: '2f4f4f',
    darkslategrey: '2f4f4f',
    darkturquoise: '00ced1',
    darkviolet: '9400d3',
    deeppink: 'ff1493',
    deepskyblue: '00bfff',
    dimgray: '696969',
    dimgrey: '696969',
    dodgerblue: '1e90ff',
    firebrick: 'b22222',
    floralwhite: 'fffaf0',
    forestgreen: '228b22',
    fuchsia: 'ff00ff',
    gainsboro: 'dcdcdc',
    ghostwhite: 'f8f8ff',
    gold: 'ffd700',
    goldenrod: 'daa520',
    gray: '808080',
    green: '008000',
    greenyellow: 'adff2f',
    grey: '808080',
    honeydew: 'f0fff0',
    hotpink: 'ff69b4',
    indianred: 'cd5c5c',
    indigo: '4b0082',
    ivory: 'fffff0',
    khaki: 'f0e68c',
    lavender: 'e6e6fa',
    lavenderblush: 'fff0f5',
    lawngreen: '7cfc00',
    lemonchiffon: 'fffacd',
    lightblue: 'add8e6',
    lightcoral: 'f08080',
    lightcyan: 'e0ffff',
    lightgoldenrodyellow: 'fafad2',
    lightgray: 'd3d3d3',
    lightgreen: '90ee90',
    lightgrey: 'd3d3d3',
    lightpink: 'ffb6c1',
    lightsalmon: 'ffa07a',
    lightseagreen: '20b2aa',
    lightskyblue: '87cefa',
    lightslategray: '789',
    lightslategrey: '789',
    lightsteelblue: 'b0c4de',
    lightyellow: 'ffffe0',
    lime: '0f0',
    limegreen: '32cd32',
    linen: 'faf0e6',
    magenta: 'f0f',
    maroon: '800000',
    mediumaquamarine: '66cdaa',
    mediumblue: '0000cd',
    mediumorchid: 'ba55d3',
    mediumpurple: '9370db',
    mediumseagreen: '3cb371',
    mediumslateblue: '7b68ee',
    mediumspringgreen: '00fa9a',
    mediumturquoise: '48d1cc',
    mediumvioletred: 'c71585',
    midnightblue: '191970',
    mintcream: 'f5fffa',
    mistyrose: 'ffe4e1',
    moccasin: 'ffe4b5',
    navajowhite: 'ffdead',
    navy: '000080',
    oldlace: 'fdf5e6',
    olive: '808000',
    olivedrab: '6b8e23',
    orange: 'ffa500',
    orangered: 'ff4500',
    orchid: 'da70d6',
    palegoldenrod: 'eee8aa',
    palegreen: '98fb98',
    paleturquoise: 'afeeee',
    palevioletred: 'db7093',
    papayawhip: 'ffefd5',
    peachpuff: 'ffdab9',
    peru: 'cd853f',
    pink: 'ffc0cb',
    plum: 'dda0dd',
    powderblue: 'b0e0e6',
    purple: '800080',
    rebeccapurple: '639',
    red: 'f00',
    rosybrown: 'bc8f8f',
    royalblue: '4169e1',
    saddlebrown: '8b4513',
    salmon: 'fa8072',
    sandybrown: 'f4a460',
    seagreen: '2e8b57',
    seashell: 'fff5ee',
    sienna: 'a0522d',
    silver: 'c0c0c0',
    skyblue: '87ceeb',
    slateblue: '6a5acd',
    slategray: '708090',
    slategrey: '708090',
    snow: 'fffafa',
    springgreen: '00ff7f',
    steelblue: '4682b4',
    tan: 'd2b48c',
    teal: '008080',
    thistle: 'd8bfd8',
    tomato: 'ff6347',
    turquoise: '40e0d0',
    violet: 'ee82ee',
    wheat: 'f5deb3',
    white: 'fff',
    whitesmoke: 'f5f5f5',
    yellow: 'ff0',
    yellowgreen: '9acd32'
  };
  /**
   * Checks if a string is a CSS named color and returns its equivalent hex value, otherwise returns the original color.
   * @private
   */

  function nameToHex(color) {
    if (typeof color !== 'string') return color;
    var normalizedColorName = color.toLowerCase();
    return namedColorMap[normalizedColorName] ? "#" + namedColorMap[normalizedColorName] : color;
  }

  var hexRegex = /^#[a-fA-F0-9]{6}$/;
  var hexRgbaRegex = /^#[a-fA-F0-9]{8}$/;
  var reducedHexRegex = /^#[a-fA-F0-9]{3}$/;
  var reducedRgbaHexRegex = /^#[a-fA-F0-9]{4}$/;
  var rgbRegex = /^rgb\(\s*(\d{1,3})\s*(?:,)?\s*(\d{1,3})\s*(?:,)?\s*(\d{1,3})\s*\)$/i;
  var rgbaRegex = /^rgb(?:a)?\(\s*(\d{1,3})\s*(?:,)?\s*(\d{1,3})\s*(?:,)?\s*(\d{1,3})\s*(?:,|\/)\s*([-+]?\d*[.]?\d+[%]?)\s*\)$/i;
  var hslRegex = /^hsl\(\s*(\d{0,3}[.]?[0-9]+(?:deg)?)\s*(?:,)?\s*(\d{1,3}[.]?[0-9]?)%\s*(?:,)?\s*(\d{1,3}[.]?[0-9]?)%\s*\)$/i;
  var hslaRegex = /^hsl(?:a)?\(\s*(\d{0,3}[.]?[0-9]+(?:deg)?)\s*(?:,)?\s*(\d{1,3}[.]?[0-9]?)%\s*(?:,)?\s*(\d{1,3}[.]?[0-9]?)%\s*(?:,|\/)\s*([-+]?\d*[.]?\d+[%]?)\s*\)$/i;
  /**
   * Returns an RgbColor or RgbaColor object. This utility function is only useful
   * if want to extract a color component. With the color util `toColorString` you
   * can convert a RgbColor or RgbaColor object back to a string.
   *
   * @example
   * // Assigns `{ red: 255, green: 0, blue: 0 }` to color1
   * const color1 = parseToRgb('rgb(255, 0, 0)');
   * // Assigns `{ red: 92, green: 102, blue: 112, alpha: 0.75 }` to color2
   * const color2 = parseToRgb('hsla(210, 10%, 40%, 0.75)');
   */

  function parseToRgb(color) {
    if (typeof color !== 'string') {
      throw new PolishedError(3);
    }

    var normalizedColor = nameToHex(color);

    if (normalizedColor.match(hexRegex)) {
      return {
        red: parseInt("" + normalizedColor[1] + normalizedColor[2], 16),
        green: parseInt("" + normalizedColor[3] + normalizedColor[4], 16),
        blue: parseInt("" + normalizedColor[5] + normalizedColor[6], 16)
      };
    }

    if (normalizedColor.match(hexRgbaRegex)) {
      var alpha = parseFloat((parseInt("" + normalizedColor[7] + normalizedColor[8], 16) / 255).toFixed(2));
      return {
        red: parseInt("" + normalizedColor[1] + normalizedColor[2], 16),
        green: parseInt("" + normalizedColor[3] + normalizedColor[4], 16),
        blue: parseInt("" + normalizedColor[5] + normalizedColor[6], 16),
        alpha: alpha
      };
    }

    if (normalizedColor.match(reducedHexRegex)) {
      return {
        red: parseInt("" + normalizedColor[1] + normalizedColor[1], 16),
        green: parseInt("" + normalizedColor[2] + normalizedColor[2], 16),
        blue: parseInt("" + normalizedColor[3] + normalizedColor[3], 16)
      };
    }

    if (normalizedColor.match(reducedRgbaHexRegex)) {
      var _alpha = parseFloat((parseInt("" + normalizedColor[4] + normalizedColor[4], 16) / 255).toFixed(2));

      return {
        red: parseInt("" + normalizedColor[1] + normalizedColor[1], 16),
        green: parseInt("" + normalizedColor[2] + normalizedColor[2], 16),
        blue: parseInt("" + normalizedColor[3] + normalizedColor[3], 16),
        alpha: _alpha
      };
    }

    var rgbMatched = rgbRegex.exec(normalizedColor);

    if (rgbMatched) {
      return {
        red: parseInt("" + rgbMatched[1], 10),
        green: parseInt("" + rgbMatched[2], 10),
        blue: parseInt("" + rgbMatched[3], 10)
      };
    }

    var rgbaMatched = rgbaRegex.exec(normalizedColor.substring(0, 50));

    if (rgbaMatched) {
      return {
        red: parseInt("" + rgbaMatched[1], 10),
        green: parseInt("" + rgbaMatched[2], 10),
        blue: parseInt("" + rgbaMatched[3], 10),
        alpha: parseFloat("" + rgbaMatched[4]) > 1 ? parseFloat("" + rgbaMatched[4]) / 100 : parseFloat("" + rgbaMatched[4])
      };
    }

    var hslMatched = hslRegex.exec(normalizedColor);

    if (hslMatched) {
      var hue = parseInt("" + hslMatched[1], 10);
      var saturation = parseInt("" + hslMatched[2], 10) / 100;
      var lightness = parseInt("" + hslMatched[3], 10) / 100;
      var rgbColorString = "rgb(" + hslToRgb(hue, saturation, lightness) + ")";
      var hslRgbMatched = rgbRegex.exec(rgbColorString);

      if (!hslRgbMatched) {
        throw new PolishedError(4, normalizedColor, rgbColorString);
      }

      return {
        red: parseInt("" + hslRgbMatched[1], 10),
        green: parseInt("" + hslRgbMatched[2], 10),
        blue: parseInt("" + hslRgbMatched[3], 10)
      };
    }

    var hslaMatched = hslaRegex.exec(normalizedColor.substring(0, 50));

    if (hslaMatched) {
      var _hue = parseInt("" + hslaMatched[1], 10);

      var _saturation = parseInt("" + hslaMatched[2], 10) / 100;

      var _lightness = parseInt("" + hslaMatched[3], 10) / 100;

      var _rgbColorString = "rgb(" + hslToRgb(_hue, _saturation, _lightness) + ")";

      var _hslRgbMatched = rgbRegex.exec(_rgbColorString);

      if (!_hslRgbMatched) {
        throw new PolishedError(4, normalizedColor, _rgbColorString);
      }

      return {
        red: parseInt("" + _hslRgbMatched[1], 10),
        green: parseInt("" + _hslRgbMatched[2], 10),
        blue: parseInt("" + _hslRgbMatched[3], 10),
        alpha: parseFloat("" + hslaMatched[4]) > 1 ? parseFloat("" + hslaMatched[4]) / 100 : parseFloat("" + hslaMatched[4])
      };
    }

    throw new PolishedError(5);
  }

  /**
   * Reduces hex values if possible e.g. #ff8866 to #f86
   * @private
   */
  var reduceHexValue = function reduceHexValue(value) {
    if (value.length === 7 && value[1] === value[2] && value[3] === value[4] && value[5] === value[6]) {
      return "#" + value[1] + value[3] + value[5];
    }

    return value;
  };

  var reduceHexValue$1 = reduceHexValue;

  function numberToHex(value) {
    var hex = value.toString(16);
    return hex.length === 1 ? "0" + hex : hex;
  }

  /**
   * Returns a string value for the color. The returned result is the smallest possible hex notation.
   *
   * @example
   * // Styles as object usage
   * const styles = {
   *   background: rgb(255, 205, 100),
   *   background: rgb({ red: 255, green: 205, blue: 100 }),
   * }
   *
   * // styled-components usage
   * const div = styled.div`
   *   background: ${rgb(255, 205, 100)};
   *   background: ${rgb({ red: 255, green: 205, blue: 100 })};
   * `
   *
   * // CSS in JS Output
   *
   * element {
   *   background: "#ffcd64";
   *   background: "#ffcd64";
   * }
   */
  function rgb(value, green, blue) {
    if (typeof value === 'number' && typeof green === 'number' && typeof blue === 'number') {
      return reduceHexValue$1("#" + numberToHex(value) + numberToHex(green) + numberToHex(blue));
    } else if (typeof value === 'object' && green === undefined && blue === undefined) {
      return reduceHexValue$1("#" + numberToHex(value.red) + numberToHex(value.green) + numberToHex(value.blue));
    }

    throw new PolishedError(6);
  }

  /**
   * Returns a string value for the color. The returned result is the smallest possible rgba or hex notation.
   *
   * Can also be used to fade a color by passing a hex value or named CSS color along with an alpha value.
   *
   * @example
   * // Styles as object usage
   * const styles = {
   *   background: rgba(255, 205, 100, 0.7),
   *   background: rgba({ red: 255, green: 205, blue: 100, alpha: 0.7 }),
   *   background: rgba(255, 205, 100, 1),
   *   background: rgba('#ffffff', 0.4),
   *   background: rgba('black', 0.7),
   * }
   *
   * // styled-components usage
   * const div = styled.div`
   *   background: ${rgba(255, 205, 100, 0.7)};
   *   background: ${rgba({ red: 255, green: 205, blue: 100, alpha: 0.7 })};
   *   background: ${rgba(255, 205, 100, 1)};
   *   background: ${rgba('#ffffff', 0.4)};
   *   background: ${rgba('black', 0.7)};
   * `
   *
   * // CSS in JS Output
   *
   * element {
   *   background: "rgba(255,205,100,0.7)";
   *   background: "rgba(255,205,100,0.7)";
   *   background: "#ffcd64";
   *   background: "rgba(255,255,255,0.4)";
   *   background: "rgba(0,0,0,0.7)";
   * }
   */
  function rgba$1(firstValue, secondValue, thirdValue, fourthValue) {
    if (typeof firstValue === 'string' && typeof secondValue === 'number') {
      var rgbValue = parseToRgb(firstValue);
      return "rgba(" + rgbValue.red + "," + rgbValue.green + "," + rgbValue.blue + "," + secondValue + ")";
    } else if (typeof firstValue === 'number' && typeof secondValue === 'number' && typeof thirdValue === 'number' && typeof fourthValue === 'number') {
      return fourthValue >= 1 ? rgb(firstValue, secondValue, thirdValue) : "rgba(" + firstValue + "," + secondValue + "," + thirdValue + "," + fourthValue + ")";
    } else if (typeof firstValue === 'object' && secondValue === undefined && thirdValue === undefined && fourthValue === undefined) {
      return firstValue.alpha >= 1 ? rgb(firstValue.red, firstValue.green, firstValue.blue) : "rgba(" + firstValue.red + "," + firstValue.green + "," + firstValue.blue + "," + firstValue.alpha + ")";
    }

    throw new PolishedError(7);
  }

  // Type definitions taken from https://github.com/gcanti/flow-static-land/blob/master/src/Fun.js
  // eslint-disable-next-line no-unused-vars
  // eslint-disable-next-line no-unused-vars
  // eslint-disable-next-line no-redeclare
  function curried(f, length, acc) {
    return function fn() {
      // eslint-disable-next-line prefer-rest-params
      var combined = acc.concat(Array.prototype.slice.call(arguments));
      return combined.length >= length ? f.apply(this, combined) : curried(f, length, combined);
    };
  } // eslint-disable-next-line no-redeclare


  function curry(f) {
    // eslint-disable-line no-redeclare
    return curried(f, f.length, []);
  }

  /**
   * Mixes the two provided colors together by calculating the average of each of the RGB components weighted to the first color by the provided weight.
   *
   * @example
   * // Styles as object usage
   * const styles = {
   *   background: mix(0.5, '#f00', '#00f')
   *   background: mix(0.25, '#f00', '#00f')
   *   background: mix('0.5', 'rgba(255, 0, 0, 0.5)', '#00f')
   * }
   *
   * // styled-components usage
   * const div = styled.div`
   *   background: ${mix(0.5, '#f00', '#00f')};
   *   background: ${mix(0.25, '#f00', '#00f')};
   *   background: ${mix('0.5', 'rgba(255, 0, 0, 0.5)', '#00f')};
   * `
   *
   * // CSS in JS Output
   *
   * element {
   *   background: "#7f007f";
   *   background: "#3f00bf";
   *   background: "rgba(63, 0, 191, 0.75)";
   * }
   */

  function mix(weight, color, otherColor) {
    if (color === 'transparent') return otherColor;
    if (otherColor === 'transparent') return color;
    if (weight === 0) return otherColor;
    var parsedColor1 = parseToRgb(color);

    var color1 = _extends({}, parsedColor1, {
      alpha: typeof parsedColor1.alpha === 'number' ? parsedColor1.alpha : 1
    });

    var parsedColor2 = parseToRgb(otherColor);

    var color2 = _extends({}, parsedColor2, {
      alpha: typeof parsedColor2.alpha === 'number' ? parsedColor2.alpha : 1
    }); // The formula is copied from the original Sass implementation:
    // http://sass-lang.com/documentation/Sass/Script/Functions.html#mix-instance_method


    var alphaDelta = color1.alpha - color2.alpha;
    var x = parseFloat(weight) * 2 - 1;
    var y = x * alphaDelta === -1 ? x : x + alphaDelta;
    var z = 1 + x * alphaDelta;
    var weight1 = (y / z + 1) / 2.0;
    var weight2 = 1 - weight1;
    var mixedColor = {
      red: Math.floor(color1.red * weight1 + color2.red * weight2),
      green: Math.floor(color1.green * weight1 + color2.green * weight2),
      blue: Math.floor(color1.blue * weight1 + color2.blue * weight2),
      alpha: color1.alpha * parseFloat(weight) + color2.alpha * (1 - parseFloat(weight))
    };
    return rgba$1(mixedColor);
  } // prettier-ignore


  var curriedMix = /*#__PURE__*/curry
  /* ::<number | string, string, string, string> */
  (mix);
  var mix$1 = curriedMix;

  var transformRgbaRE = /rgba\(\s*([#0-9a-z]+)\s*,\s*([\d.Ee]+)\s*\)/g;

  function rgba(value) {
    return value.replace(transformRgbaRE, function (_, color, alpha) {
      return rgba$1(color, Number(alpha));
    });
  }

  function backgroundSize(value) {
    var values = value.split(' ');

    var _values = _slicedToArray(values, 2),
        first = _values[0],
        _values$ = _values[1],
        second = _values$ === void 0 ? 'auto' : _values$;

    if (values.length === 1) {
      return {
        backgroundSize: cssToReactNative.transformRawValue('backgroundSize', first)
      };
    }

    if (values.length === 2) {
      return {
        backgroundSize: {
          width: cssToReactNative.transformRawValue('backgroundSize', first),
          height: cssToReactNative.transformRawValue('backgroundSize', second)
        }
      };
    }

    return null;
  }

  var positionRE = /(top|right|bottom|left|center)/;

  var sortPairs = function sortPairs(first, second) {
    var firstValue = {
      position: first[0],
      offset: first[1] ? cssToReactNative.transformRawValue('backgroundPosition', first[1]) : undefined
    };
    var secondValue = {
      position: second[0],
      offset: second[1] ? cssToReactNative.transformRawValue('backgroundPosition', second[1]) : undefined
    };
    var shouldReversePairs = first[0] === 'top' || first[0] === 'bottom' || second[0] === 'left' || second[0] === 'right';
    return shouldReversePairs ? [secondValue, firstValue] : [firstValue, secondValue];
  }; // Spec: https://w3c.github.io/csswg-drafts/css-backgrounds-3/#background-position


  function backgroundPosition(value) {
    var values = value.split(' ');

    var _values = _slicedToArray(values, 4),
        first = _values[0],
        _values$ = _values[1],
        second = _values$ === void 0 ? 'center' : _values$,
        third = _values[2],
        fourth = _values[3];

    if (values.length <= 2) {
      var _sortPairs = sortPairs(first.match(positionRE) ? [first] : ['left', first], second.match(positionRE) ? [second] : ['top', second]),
          _sortPairs2 = _slicedToArray(_sortPairs, 2),
          x = _sortPairs2[0],
          y = _sortPairs2[1];

      return {
        backgroundPositionX: x,
        backgroundPositionY: y
      };
    }

    if (values.length <= 4) {
      var _ref = second.match(positionRE) ? sortPairs([first], [second, third]) : sortPairs([first, second], [third, fourth]),
          _ref2 = _slicedToArray(_ref, 2),
          _x = _ref2[0],
          _y = _ref2[1];

      return {
        backgroundPositionX: _x,
        backgroundPositionY: _y
      };
    }

    return null;
  }

  function backgroundPositionX(value) {
    var values = value.split(' ');

    var _values = _slicedToArray(values, 2),
        first = _values[0],
        _values$ = _values[1],
        second = _values$ === void 0 ? 'auto' : _values$;

    if (values.length === 1) {
      return {
        backgroundPositionX: cssToReactNative.transformRawValue('backgroundPositionX', first)
      };
    }

    if (values.length === 2) {
      return {
        backgroundPositionX: {
          position: cssToReactNative.transformRawValue('backgroundPositionX', first),
          offset: cssToReactNative.transformRawValue('backgroundPositionX', second)
        }
      };
    }

    return null;
  }

  function backgroundPositionY(value) {
    var values = value.split(' ');

    var _values = _slicedToArray(values, 2),
        first = _values[0],
        _values$ = _values[1],
        second = _values$ === void 0 ? 'auto' : _values$;

    if (values.length === 1) {
      return {
        backgroundPositionY: cssToReactNative.transformRawValue('backgroundPositionY', first)
      };
    }

    if (values.length === 2) {
      return {
        backgroundPositionY: {
          position: cssToReactNative.transformRawValue('backgroundPositionY', first),
          offset: cssToReactNative.transformRawValue('backgroundPositionY', second)
        }
      };
    }

    return null;
  }

  var urlRE = /^url\(.*?\)$/g;

  var applyVariables = function applyVariables(variables, key, value) {
    return typeof value === 'function' ? value(variables, key) : value;
  };

  var applyTransforms = function applyTransforms(result) {
    // Do not transform values that belong to an url().
    if (result.match(urlRE)) {
      return result;
    }

    return rgba(formula(rem(result)));
  };

  var resolveValue = function resolveValue(value, definition, theme, options) {
    var variables = options.preferTheme ? _objectSpread2(_objectSpread2({}, definition.variables), theme) : _objectSpread2(_objectSpread2({}, theme), definition.variables); // If there is only one part, we allow other results than strings as well.

    if (value.length === 1) {
      var result = applyVariables(variables, options.key, value[0]);
      return typeof result === 'string' ? applyTransforms(result) : result;
    }

    var stringifiedResult = value.reduce(function (previous, current) {
      return "".concat(previous).concat(applyVariables(variables, options.key, current));
    }, '');
    return applyTransforms(stringifiedResult);
  };

  function transform(children, theme) {
    var options = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
    var scopes = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : [];
    var variables = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : {};
    var definitions = [{
      scopes: scopes,
      declarations: {},
      variables: _objectSpread2({}, variables)
    }];
    children.forEach(function (child) {
      if (child.type === 'variable' || child.type === 'declaration') {
        // Transform value to react native compatible value.
        var value = resolveValue(child.value, definitions[0], theme, options);

        if (child.type === 'variable') {
          definitions[0].variables[child.name] = value;
        } // Only add value if value is not null.


        if (child.type === 'declaration' && value !== 'null') {
          if (child.name === 'box-shadow') {
            if (reactNative.Platform.OS === 'web') {
              Object.assign(definitions[0].declarations, {
                boxShadow: value
              });
            }
          } else if (child.name === 'margin-vertical') {
            Object.assign(definitions[0].declarations, _objectSpread2(_objectSpread2({}, cssToReactNative.getStylesForProperty('marginTop', value)), cssToReactNative.getStylesForProperty('marginBottom', value)));
          } else if (child.name === 'margin-horizontal') {
            // Among other things workaround for react-native issue #350
            // https://github.com/facebook/react-native/issues/350#issuecomment-375238958
            Object.assign(definitions[0].declarations, _objectSpread2(_objectSpread2({}, cssToReactNative.getStylesForProperty('marginLeft', value)), cssToReactNative.getStylesForProperty('marginRight', value)));
          } else if (child.name === 'padding-vertical') {
            Object.assign(definitions[0].declarations, _objectSpread2(_objectSpread2({}, cssToReactNative.getStylesForProperty('paddingTop', value)), cssToReactNative.getStylesForProperty('paddingBottom', value)));
          } else if (child.name === 'padding-horizontal') {
            Object.assign(definitions[0].declarations, _objectSpread2(_objectSpread2({}, cssToReactNative.getStylesForProperty('paddingLeft', value)), cssToReactNative.getStylesForProperty('paddingRight', value)));
          } else if (child.name === 'background-size') {
            Object.assign(definitions[0].declarations, backgroundSize(value));
          } else if (child.name === 'background-position') {
            Object.assign(definitions[0].declarations, backgroundPosition(value));
          } else if (child.name === 'background-position-x') {
            Object.assign(definitions[0].declarations, backgroundPositionX(value));
          } else if (child.name === 'background-position-y') {
            Object.assign(definitions[0].declarations, backgroundPositionY(value));
          } else if (child.name === 'border-color' && value.split(' ').length === 1) {
            // Workaround for react-native issue #19981
            // https://github.com/facebook/react-native/issues/19981
            Object.assign(definitions[0].declarations, {
              borderColor: value
            });
          } else {
            // TODO: Pre-process css-to-react-native transformation, so that we only
            // need to insert theme variables here.
            Object.assign(definitions[0].declarations, cssToReactNative.getStylesForProperty(cssToReactNative.getPropertyName(child.name), value));
          }
        }
      }

      if (child.type === 'block') {
        definitions = definitions.concat(transform(child.children, theme, options, // Add child scopes to current scopes.
        [].concat(_toConsumableArray(scopes), _toConsumableArray(child.scopes)), // Pass down variables, so that we can extend them.
        definitions[0].variables));
      }
    }); // Filter empty definitions and return.

    return definitions.filter(function (definition) {
      return Object.keys(definition.declarations).length > 0 || Object.keys(definition.variables).length > 0;
    });
  }

  var mediaBreakpointUp$3 = {
    include: function include() {
      return true;
    },
    apply: function apply(scope, _ref) {
      var media = _ref.media;
      return media.up(scope.args[0]) && media.down(scope.args[1]);
    }
  };

  var mediaBreakpointUp$2 = {
    include: function include() {
      return true;
    },
    apply: function apply(scope, _ref) {
      var media = _ref.media;
      return media.down(scope.args[0]);
    }
  };

  var mediaBreakpointUp$1 = {
    include: function include() {
      return true;
    },
    apply: function apply(scope, _ref) {
      var media = _ref.media;
      return media.up(scope.args[0]) && media.down(scope.args[0]);
    }
  };

  var mediaBreakpointUp = {
    include: function include() {
      return true;
    },
    apply: function apply(scope, _ref) {
      var media = _ref.media;
      return media.up(scope.args[0]);
    }
  };

  var platform = {
    include: function include(scope) {
      return scope.args[0] === 'native' ? reactNative.Platform.OS === 'android' || reactNative.Platform.OS === 'ios' : reactNative.Platform.OS === scope.args[0];
    },
    apply: function apply() {
      return true;
    }
  };

  var BOOTSTRAP_RN_STYLE = Symbol.for('bootstrap-rn.style');
  var mixins = {
    'media-breakpoint-between': mediaBreakpointUp$3,
    'media-breakpoint-down': mediaBreakpointUp$2,
    'media-breakpoint-only': mediaBreakpointUp$1,
    'media-breakpoint-up': mediaBreakpointUp,
    platform: platform
  };

  var hasInteraction = function hasInteraction(_ref) {
    var scopes = _ref.scopes;
    return scopes.some(function (scope) {
      return scope.type === 'selector';
    });
  };

  function createStyle(definitions) {
    // If there is only one definition without conditions, return.
    if (definitions.length === 1 && definitions[0].scopes.length === 0) {
      return definitions[0].declarations;
    } // Filter definitions that should not be used based on mixins.


    var platformDefinitions = definitions.filter(function (item) {
      return item.scopes.every(function (scope) {
        if (scope.type !== 'mixin') {
          return true;
        }

        return mixins[scope.name].include(scope);
      });
    }); // Create style sheets.

    var styles = reactNative.StyleSheet.create(_objectSpread2({}, platformDefinitions.map(function (item) {
      return item.declarations;
    })));

    var resolve = function resolve(state) {
      var interaction = state.interaction;
      var basicStyles = [];
      var interactionStyles = [];
      Object.values(styles).forEach(function (style, key) {
        var active = platformDefinitions[key].scopes.every(function (scope) {
          if (scope.type === 'selector') {
            if (scope.name === 'hover') {
              return interaction && interaction.hovered;
            }

            if (scope.name === 'focus') {
              return interaction && interaction.focused;
            }

            if (scope.name === 'active') {
              return interaction && interaction.pressed;
            }
          }

          if (scope.type === 'mixin') {
            return mixins[scope.name].apply(scope, state);
          }

          throw new Error("Unknown scope type \"".concat(scope.type, "\""));
        });

        if (active) {
          if (hasInteraction(platformDefinitions[key])) {
            interactionStyles.push(style);
          } else {
            basicStyles.push(style);
          }
        }
      });
      return [basicStyles, interactionStyles];
    };

    resolve.$$typeof = BOOTSTRAP_RN_STYLE;
    return resolve;
  }

  function css() {
    var ast = parse$1.apply(void 0, arguments);

    var result = function result(theme, key) {
      var transformed = transform(ast.children, theme, {
        key: key
      });
      return createStyle(transformed);
    };

    result.ast = ast;
    return result;
  }

  function each(source, apply) {
    return Object.entries(source).map(function (_ref) {
      var _ref2 = _slicedToArray(_ref, 2),
          key = _ref2[0],
          value = _ref2[1];

      var resolve = typeof value === 'function' ? value : function () {
        return value;
      };
      return apply(key, resolve);
    }).reduce(function (carry, item) {
      return Object.assign(carry, item);
    }, {});
  }
  function normalize$1(value) {
    return value.reduce(function (carry, item) {
      return Object.assign(carry, item);
    }, {});
  }
  function makeProxy(name, keys) {
    return keys.reduce(function (result, key) {
      return _objectSpread2(_objectSpread2({}, result), {}, _defineProperty({}, key, function (t) {
        return t[name][key];
      }));
    }, {});
  }
  function makeArray(length, callback) {
    return Array.from({
      length: length
    }, function (_, i) {
      return callback ? callback(i) : i;
    });
  }
  function getStyles(styles, keys) {
    return keys.filter(function (key) {
      return !!key;
    }).map(function (key) {
      return styles[key];
    });
  }
  function concatRefs() {
    for (var _len = arguments.length, refs = new Array(_len), _key = 0; _key < _len; _key++) {
      refs[_key] = arguments[_key];
    }

    return function (element) {
      refs.forEach(function (ref) {
        if (typeof ref === 'function') {
          ref(element);
        } else if (ref) {
          // eslint-disable-next-line no-param-reassign
          ref.current = element;
        }
      });
    };
  }
  function concatFns() {
    for (var _len2 = arguments.length, fns = new Array(_len2), _key2 = 0; _key2 < _len2; _key2++) {
      fns[_key2] = arguments[_key2];
    }

    return function (event) {
      fns.forEach(function (fn) {
        if (fn) {
          fn(event);
        }
      });
    };
  }
  function optional(condition, value) {
    return condition ? value : undefined;
  }
  function getElementId(identifier, name) {
    return "".concat(identifier).concat(name ? "-".concat(name) : '');
  }
  function transformPlacement$1(placement) {
    if (placement === 'left') {
      return reactNative.I18nManager.isRTL ? 'end' : 'start';
    }

    if (placement === 'right') {
      return reactNative.I18nManager.isRTL ? 'start' : 'end';
    }

    return placement;
  }
  function convertToNumber(value) {
    return parseFloat(value.replace(/([+-])?([\d.Ee]+)rem/g, function (_, unary, number) {
      return "".concat(unary || '').concat(reactNative.PixelRatio.getFontScale() * 16 * number, "px");
    }));
  }

  // keys, but not the resolved values. The values are added later by the used
  // theme.
  // Color system

  makeProxy('grays', ['100', '200', '300', '400', '500', '600', '700', '800', '900']);
  makeProxy('colors', ['blue', 'indigo', 'purple', 'pink', 'red', 'orange', 'yellow', 'green', 'teal', 'cyan']);
  var THEME_COLORS = makeProxy('theme-colors', ['primary', 'secondary', 'success', 'info', 'warning', 'danger', 'light', 'dark']);
  makeProxy('blues', ['blue-100', 'blue-200', 'blue-300', 'blue-400', 'blue-500', 'blue-600', 'blue-700', 'blue-800', 'blue-900']);
  makeProxy('indigos', ['indigo-100', 'indigo-200', 'indigo-300', 'indigo-400', 'indigo-500', 'indigo-600', 'indigo-700', 'indigo-800', 'indigo-900']);
  makeProxy('purples', ['purple-100', 'purple-200', 'purple-300', 'purple-400', 'purple-500', 'purple-600', 'purple-700', 'purple-800', 'purple-900']);
  makeProxy('pinks', ['pink-100', 'pink-200', 'pink-300', 'pink-400', 'pink-500', 'pink-600', 'pink-700', 'pink-800', 'pink-900']);
  makeProxy('reds', ['red-100', 'red-200', 'red-300', 'red-400', 'red-500', 'red-600', 'red-700', 'red-800', 'red-900']);
  makeProxy('oranges', ['orange-100', 'orange-200', 'orange-300', 'orange-400', 'orange-500', 'orange-600', 'orange-700', 'orange-800', 'orange-900']);
  makeProxy('yellows', ['yellow-100', 'yellow-200', 'yellow-300', 'yellow-400', 'yellow-500', 'yellow-600', 'yellow-700', 'yellow-800', 'yellow-900']);
  makeProxy('greens', ['green-100', 'green-200', 'green-300', 'green-400', 'green-500', 'green-600', 'green-700', 'green-800', 'green-900']);
  makeProxy('teals', ['teal-100', 'teal-200', 'teal-300', 'teal-400', 'teal-500', 'teal-600', 'teal-700', 'teal-800', 'teal-900']);
  makeProxy('cyans', ['cyan-100', 'cyan-200', 'cyan-300', 'cyan-400', 'cyan-500', 'cyan-600', 'cyan-700', 'cyan-800', 'cyan-900']); // Spacing
  //
  // Control the default styling of most Bootstrap elements by modifying these
  // variables. Mostly focused on spacing.
  // You can add more entries to the $spacers map, should you need more variation.

  var SPACERS = makeProxy('spacers', [0, 1, 2, 3, 4, 5]); // Position
  //
  // Define the edge positioning anchors of the position utilities.

  var POSITION_VALUES = makeProxy('position-values', [0, 50, 100]); // Grid breakpoints
  //
  // Define the minimum dimensions at which your layout will change,
  // adapting to different screen sizes, for use in media queries.

  var GRID_BREAKPOINTS = makeProxy('grid-breakpoints', ['xs', 'sm', 'md', 'lg', 'xl', 'xxl']); // Grid containers
  //
  // Define the maximum width of ".container" for different screen sizes.

  var CONTAINER_MAX_WIDTHS = makeProxy('container-max-widths', ['sm', 'md', 'lg', 'xl', 'xxl']); // Grid columns
  //
  // Set the number of columns and specify the width of the gutters.

  var GRID_COLUMNS = 12;
  //
  // Define common padding and border radius sizes and more.

  var BORDER_WIDTHS = makeProxy('border-widths', [1, 2, 3, 4, 5]);
  makeProxy('aspect-ratios', ['1x1', '4x3', '16x9', '21x9']); // Typography
  //
  // Font, line-height, and color for body text, headings, and more.

  var FONT_SIZES = makeProxy('font-sizes', [1, 2, 3, 4, 5, 6]);
  var DISPLAY_FONT_SIZES = makeProxy('display-font-sizes', [1, 2, 3, 4, 5, 6]); // Forms

  var FORM_VALIDATION_STATES = makeProxy('form-validation-states', ['valid', 'invalid']);

  var UTILITIES_COLORS = THEME_COLORS;
  var UTILITIES_TEXT_COLORS = _objectSpread2(_objectSpread2({}, UTILITIES_COLORS), {}, {
    black: function black(t) {
      return t.black;
    },
    white: function white(t) {
      return t.white;
    },
    body: function body(t) {
      return t['body-color'];
    }
  });
  var UTILITIES_BG_COLORS = _objectSpread2(_objectSpread2({}, UTILITIES_COLORS), {}, {
    black: function black(t) {
      return t.black;
    },
    white: function white(t) {
      return t.white;
    },
    body: function body(t) {
      return t['body-bg'];
    }
  });
  var NEGATIVE_SPACERS = each(SPACERS, function (key, value) {
    if (key === 0) {
      return null;
    }

    return _defineProperty({}, "n".concat(key), function n(t) {
      return "-".concat(value(t));
    });
  });

  var utilities = {
    align: {
      property: 'text-align-vertical',
      class: 'align',
      values: {
        // baseline: 'baseline',
        top: 'top',
        center: 'center',
        // 'middle',
        bottom: 'bottom' // 'text-bottom': 'text-bottom',
        // 'text-top': 'text-top',

      }
    },

    /* float: {
      responsive: true,
      property: 'float',
      values: {
        start: 'left',
        end: 'right',
        none: 'none',
      },
    }, */
    // Opacity utilities
    opacity: {
      property: 'opacity',
      values: {
        0: '0',
        25: '0.25',
        50: '0.5',
        75: '0.75',
        100: '1'
      }
    },
    overflow: {
      property: 'overflow',
      values: {
        // auto: 'auto',
        hidden: 'hidden',
        visible: 'visible',
        scroll: 'scroll'
      }
    },
    display: {
      responsive: true,
      print: true,
      property: 'display',
      class: 'd',
      values: {
        // inline: 'inline',
        // 'inline-block': 'inline-block',
        // block: 'block',
        // grid: 'grid',
        // table: 'table',
        // 'table-row': 'table-row',
        // 'table-cell': 'table-cell',
        flex: 'flex',
        // 'inline-flex': 'inline-flex',
        none: 'none'
      }
    },
    shadow: {
      property: 'box-shadow',
      class: 'shadow',
      values: {
        null: function _null(t) {
          return t['box-shadow'];
        },
        sm: function sm(t) {
          return t['box-shadow-sm'];
        },
        lg: function lg(t) {
          return t['box-shadow-lg'];
        },
        none: 'none'
      }
    },
    position: {
      property: 'position',
      values: {
        // static: 'static',
        relative: 'relative',
        absolute: 'absolute' // fixed: 'fixed',
        // sticky: 'sticky',

      }
    },
    top: {
      property: 'top',
      values: POSITION_VALUES
    },
    bottom: {
      property: 'bottom',
      values: POSITION_VALUES
    },
    start: {
      property: 'left',
      class: 'start',
      values: POSITION_VALUES
    },
    end: {
      property: 'right',
      class: 'end',
      values: POSITION_VALUES
    },

    /* translateMiddle: {
      property: 'transform',
      class: 'translate-middle',
      values: {
        null: translate(-50%, -50%),
        x: translateX(-50%),
        y: translateY(-50%),
      },
    }, */
    border: {
      property: 'border',
      values: {
        null: function _null(t) {
          return "".concat(t['border-width'], " solid ").concat(t['border-color']);
        },
        0: '0'
      }
    },
    // TODO: Find a way to write border-top as border-top-width, ...

    /* borderTop: {
      property: 'border-top',
      values: {
        null: (t) => `${t['border-width']} solid ${t['border-color']}`,
        0: '0',
      },
    }, */

    /* borderRight: {
      property: 'border-right',
      class: 'border-end',
      values: {
        null: (t) => `${t['border-width']} solid ${t['border-color']}`,
        0: '0',
      },
    }, */

    /* borderBottom: {
      property: 'border-bottom',
      values: {
        null: (t) => `${t['border-width']} solid ${t['border-color']}`,
        0: '0',
      },
    }, */

    /* borderLeft: {
      property: 'border-left',
      class: 'border-start',
      values: {
        null: (t) => `${t['border-width']} solid ${t['border-color']}`,
        0: '0',
      },
    }, */
    borderColor: {
      property: 'border-color',
      class: 'border',
      values: _objectSpread2(_objectSpread2({}, THEME_COLORS), {}, {
        white: 'white'
      })
    },
    borderWidth: {
      property: 'border-width',
      class: 'border',
      values: BORDER_WIDTHS
    },
    width: {
      property: 'width',
      class: 'w',
      values: {
        25: '25%',
        50: '50%',
        75: '75%',
        100: '100%',
        auto: 'auto'
      }
    },
    maxWidth: {
      property: 'max-width',
      class: 'mw',
      values: {
        100: '100%'
      }
    },
    viewportWidth: {
      property: 'width',
      class: 'vw',
      values: {
        100: '100vw' // TODO: native support

      }
    },
    minViewportWidth: {
      property: 'min-width',
      class: 'min-vw',
      values: {
        100: '100vw' // TODO: native support

      }
    },
    height: {
      property: 'height',
      class: 'h',
      values: {
        25: '25%',
        50: '50%',
        75: '75%',
        100: '100%',
        auto: 'auto'
      }
    },
    maxHeight: {
      property: 'max-height',
      class: 'mh',
      values: {
        100: '100%'
      }
    },
    viewportHeight: {
      property: 'height',
      class: 'vh',
      values: {
        100: '100vh' // TODO: native support

      }
    },
    minViewportHeight: {
      property: 'min-height',
      class: 'min-vh',
      values: {
        100: '100vh' // TODO: native support

      }
    },
    // Flex utilities
    flex: {
      responsive: true,
      property: 'flex',
      values: {
        fill: '1 1 auto'
      }
    },
    flexDirection: {
      responsive: true,
      property: 'flex-direction',
      class: 'flex',
      values: {
        row: 'row',
        column: 'column',
        'row-reverse': 'row-reverse',
        'column-reverse': 'column-reverse'
      }
    },
    flexGrow: {
      responsive: true,
      property: 'flex-grow',
      class: 'flex',
      values: {
        'grow-0': '0',
        'grow-1': '1'
      }
    },
    flexShrink: {
      responsive: true,
      property: 'flex-shrink',
      class: 'flex',
      values: {
        'shrink-0': '0',
        'shrink-1': '1'
      }
    },
    flexWrap: {
      responsive: true,
      property: 'flex-wrap',
      class: 'flex',
      values: {
        wrap: 'wrap',
        nowrap: 'nowrap',
        'wrap-reverse': 'wrap-reverse'
      }
    },

    /* gap: {
      responsive: true,
      property: 'gap',
      class: 'gap',
      values: SPACERS,
    }, */
    justifyContent: {
      responsive: true,
      property: 'justify-content',
      values: {
        start: 'flex-start',
        end: 'flex-end',
        center: 'center',
        between: 'space-between',
        around: 'space-around' // evenly: 'space-evenly', // TODO: For some reason this is converted into "spacNaNvenly"

      }
    },
    alignItems: {
      responsive: true,
      property: 'align-items',
      values: {
        start: 'flex-start',
        end: 'flex-end',
        center: 'center',
        baseline: 'baseline',
        stretch: 'stretch'
      }
    },
    alignContent: {
      responsive: true,
      property: 'align-content',
      values: {
        start: 'flex-start',
        end: 'flex-end',
        center: 'center',
        between: 'space-between',
        around: 'space-around',
        stretch: 'stretch'
      }
    },
    alignSelf: {
      responsive: true,
      property: 'align-self',
      values: {
        auto: 'auto',
        start: 'flex-start',
        end: 'flex-end',
        center: 'center',
        baseline: 'baseline',
        stretch: 'stretch'
      }
    },

    /* order: {
      responsive: true,
      property: 'order',
      values: {
        first: '-1',
        0: '0',
        1: '1',
        2: '2',
        3: '3',
        4: '4',
        5: '5',
        last: '6',
      },
    }, */
    // Margin utilities
    margin: {
      responsive: true,
      property: 'margin',
      class: 'm',
      values: _objectSpread2(_objectSpread2({}, SPACERS), {}, {
        auto: 'auto'
      })
    },
    marginX: {
      responsive: true,
      property: 'margin-horizontal',
      class: 'mx',
      values: _objectSpread2(_objectSpread2({}, SPACERS), {}, {
        auto: 'auto'
      })
    },
    marginY: {
      responsive: true,
      property: 'margin-vertical',
      class: 'my',
      values: _objectSpread2(_objectSpread2({}, SPACERS), {}, {
        auto: 'auto'
      })
    },
    marginTop: {
      responsive: true,
      property: 'margin-top',
      class: 'mt',
      values: _objectSpread2(_objectSpread2({}, SPACERS), {}, {
        auto: 'auto'
      })
    },
    marginEnd: {
      responsive: true,
      property: 'margin-right',
      class: 'me',
      values: _objectSpread2(_objectSpread2({}, SPACERS), {}, {
        auto: 'auto'
      })
    },
    marginBottom: {
      responsive: true,
      property: 'margin-bottom',
      class: 'mb',
      values: _objectSpread2(_objectSpread2({}, SPACERS), {}, {
        auto: 'auto'
      })
    },
    marginStart: {
      responsive: true,
      property: 'margin-left',
      class: 'ms',
      values: _objectSpread2(_objectSpread2({}, SPACERS), {}, {
        auto: 'auto'
      })
    },
    // Negative margin utilities
    negativeMargin: {
      responsive: true,
      property: 'margin',
      class: 'm',
      values: NEGATIVE_SPACERS
    },
    negativeMarginX: {
      responsive: true,
      property: 'margin-horizontal',
      class: 'mx',
      values: NEGATIVE_SPACERS
    },
    negativeMarginY: {
      responsive: true,
      property: 'margin-vertical',
      class: 'my',
      values: NEGATIVE_SPACERS
    },
    negativeMarginTop: {
      responsive: true,
      property: 'margin-top',
      class: 'mt',
      values: NEGATIVE_SPACERS
    },
    negativeMarginEnd: {
      responsive: true,
      property: 'margin-right',
      class: 'me',
      values: NEGATIVE_SPACERS
    },
    negativeMarginBottom: {
      responsive: true,
      property: 'margin-bottom',
      class: 'mb',
      values: NEGATIVE_SPACERS
    },
    negativeMarginStart: {
      responsive: true,
      property: 'margin-left',
      class: 'ms',
      values: NEGATIVE_SPACERS
    },
    // Padding utilities
    padding: {
      responsive: true,
      property: 'padding',
      class: 'p',
      values: SPACERS
    },
    paddingX: {
      responsive: true,
      property: 'padding-horizontal',
      class: 'px',
      values: SPACERS
    },
    paddingY: {
      responsive: true,
      property: 'padding-vertical',
      class: 'py',
      values: SPACERS
    },
    paddingTop: {
      responsive: true,
      property: 'padding-top',
      class: 'pt',
      values: SPACERS
    },
    paddingEnd: {
      responsive: true,
      property: 'padding-right',
      class: 'pe',
      values: SPACERS
    },
    paddingBottom: {
      responsive: true,
      property: 'padding-bottom',
      class: 'pb',
      values: SPACERS
    },
    paddingStart: {
      responsive: true,
      property: 'padding-left',
      class: 'ps',
      values: SPACERS
    },
    // Text
    fontFamily: {
      property: 'font-family',
      class: 'font',
      values: {
        monospace: function monospace(t) {
          return t['font-family-monospace'];
        }
      }
    },
    fontSize: {
      rfs: true,
      property: 'font-size',
      class: 'fs',
      values: FONT_SIZES
    },
    fontStyle: {
      property: 'font-style',
      class: 'fst',
      values: {
        italic: 'italic',
        normal: 'normal'
      }
    },
    fontWeight: {
      property: 'font-weight',
      class: 'fw',
      values: {
        light: function light(t) {
          return t['font-weight-light'];
        },
        // lighter: (t) => t['font-weight-lighter'],
        normal: function normal(t) {
          return t['font-weight-normal'];
        },
        bold: function bold(t) {
          return t['font-weight-bold'];
        } // bolder: (t) => t['font-weight-bolder'],

      }
    },
    lineHeight: {
      property: 'line-height',
      class: 'lh',
      // Multiply line-height with font-size for react-native support.
      values: {
        1: function _(t) {
          return t['font-size-base'];
        },
        sm: function sm(t) {
          return "".concat(t['font-size-sm'], " * ").concat(t['line-height-sm']);
        },
        base: function base(t) {
          return "".concat(t['font-size-base'], " * ").concat(t['line-height-base']);
        },
        lg: function lg(t) {
          return "".concat(t['font-size-lg'], " * ").concat(t['line-height-lg']);
        }
      }
    },
    textAlign: {
      responsive: true,
      property: 'text-align',
      class: 'text',
      values: {
        start: 'left',
        end: 'right',
        center: 'center'
      }
    },
    textDecoration: {
      property: 'text-decoration',
      class: 'text',
      values: {
        none: 'none',
        underline: 'underline',
        'line-through': 'line-through'
      }
    },
    textTransform: {
      property: 'text-transform',
      class: 'text',
      values: {
        lowercase: 'lowercase',
        uppercase: 'uppercase',
        capitalize: 'capitalize'
      }
    },

    /* whiteSpace: {
      property: 'white-space',
      class: 'text',
      values: {
        wrap: 'normal',
        nowrap: 'nowrap',
      },
    }, */

    /* wordWrap: {
      property: ['word-wrap', 'word-break'],
      class: 'text',
      values: {
        break: 'break-word',
      },
      rtl: false,
    }, */
    color: {
      property: 'color',
      class: 'text',
      // 'local-vars': { 'text-opacity': 1 },
      values: _objectSpread2(_objectSpread2({}, UTILITIES_TEXT_COLORS), {}, {
        muted: function muted(t) {
          return t['text-muted'];
        },
        'black-50': function black50(t) {
          return "rgba(".concat(t.black, ", 0.5)");
        },
        'white-50': function white50(t) {
          return "rgba(".concat(t.white, ", 0.5)");
        }
      })
    },
    textOpacity: {
      property: 'opacity',
      // 'css-var': true,
      class: 'text-opacity',
      values: {
        25: '0.25',
        50: '0.5',
        75: '0.75',
        100: '1'
      }
    },
    backgroundColor: {
      property: 'background-color',
      class: 'bg',
      // 'local-vars': { 'bg-opacity': 1 },
      values: _objectSpread2(_objectSpread2({}, UTILITIES_BG_COLORS), {}, {
        transparent: 'transparent'
      })
    },
    bgOpacity: {
      property: 'opacity',
      // 'css-var': true,
      class: 'bg-opacity',
      values: {
        10: '0.1',
        25: '0.25',
        50: '0.50',
        75: '0.75',
        100: '1'
      }
    },

    /* gradient: {
      property: 'background-image',
      class: 'bg',
      values: {
        gradient: 'var(--#{$variable-prefix}gradient))',
      },
    }, */

    /* userSelect: {
      property: 'user-select',
      values: {
        all: 'all',
        auto: 'auto',
        none: 'none',
      },
    }, */

    /* pointerEvents: {
      property: 'pointer-events',
      class: 'pe',
      values: {
        none: 'none',
        auto: 'auto',
      },
    }, */
    rounded: {
      property: 'border-radius',
      class: 'rounded',
      values: {
        null: function _null(t) {
          return t['border-radius'];
        },
        0: '0',
        1: function _(t) {
          return t['border-radius-sm'];
        },
        2: function _(t) {
          return t['border-radius'];
        },
        3: function _(t) {
          return t['border-radius-lg'];
        },
        circle: '500px',
        // TODO: How to implement 50%?
        pill: function pill(t) {
          return t['border-radius-pill'];
        }
      }
    } // TODO: Support multiple properties for rounded-* utilities.

    /* roundedTop: {
      property: ['border-top-left-radius', 'border-top-right-radius'],
      class: 'rounded-top',
      values: {
        null: (t) => t['border-radius'],
      },
    }, */

    /* roundedEnd: {
      property: ['border-top-right-radius', 'border-bottom-right-radius'],
      class: 'rounded-end',
      values: {
        null: (t) => t['border-radius'],
      },
    }, */

    /* roundedBottom: {
      property: ['border-bottom-right-radius', 'border-bottom-left-radius'],
      class: 'rounded-bottom',
      values: {
        null: (t) => t['border-radius'],
      },
    }, */

    /* roundedStart: {
      property: ['border-bottom-left-radius', 'border-top-left-radius'],
      class: 'rounded-start',
      values: {
        null: (t) => t['border-radius'],
      },
    }, */

    /* visibility: {
      property: 'visibility',
      class: 'null',
      values: {
        visible: 'visible',
        invisible: 'hidden',
      },
    }, */

  };

  var _templateObject$1e, _templateObject2$V;
  function makeUtility(options) {
    return each(options.values, function (key, value) {
      var name = options.class || options.property;
      var suffix = key === 'null' ? '' : "-".concat(key);

      var styles = _defineProperty({}, "".concat(name).concat(suffix), css(_templateObject$1e || (_templateObject$1e = _taggedTemplateLiteral(["\n        ", ": ", ";\n      "])), options.property, value));

      if (!options.responsive) {
        return styles;
      }

      return _objectSpread2(_objectSpread2({}, styles), each(GRID_BREAKPOINTS, function (breakpoint) {
        if (breakpoint === 'xs') {
          return null;
        }

        return _defineProperty({}, "".concat(name, "-").concat(breakpoint).concat(suffix), css(_templateObject2$V || (_templateObject2$V = _taggedTemplateLiteral(["\n            @include media-breakpoint-up(", ") {\n              ", ": ", ";\n            }\n          "])), breakpoint, options.property, value));
      }));
    });
  }
  function makeUtilities(resolve) {
    var customUtilities = typeof resolve === 'function' ? resolve(utilities) : resolve;
    var definitions = Object.values(_objectSpread2(_objectSpread2({}, utilities), customUtilities)).reduce(function (result, utility) {
      if (!utility) {
        return result;
      }

      return Object.assign(result, makeUtility(utility));
    }, {});
    return definitions;
  }

  var fn = function fn(handle) {
    return function () {
      for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
        args[_key] = arguments[_key];
      }

      return function (t) {
        var input = args.map(function (arg) {
          var value = typeof arg === 'function' ? arg(t) : arg;
          return value;
        });
        return handle(input, t);
      };
    };
  };
  /* eslint-disable arrow-body-style */

  var escapedCharacters = {
    '<': '%3c',
    '>': '%3e',
    '#': '%23',
    '(': '%28',
    ')': '%29'
  };
  var escapeSvg = function escapeSvg(string) {
    var strReplace = function strReplace(val) {
      return Object.entries(escapedCharacters).reduce(function (result, _ref) {
        var _ref2 = _slicedToArray(_ref, 2),
            char = _ref2[0],
            encoded = _ref2[1];

        return result.replace(new RegExp("\\".concat(char), 'g'), encoded);
      }, val);
    };

    return string.startsWith('url(') ? "url(\"".concat(strReplace(string.slice(5, -2)), "\")") : strReplace(string);
  }; // Color contrast
  // A list of pre-calculated numbers of pow(divide((divide($value, 255) + .055), 1.055), 2.4). (from 0 to 255)

  var luminanceList = [0.0008, 0.001, 0.0011, 0.0013, 0.0015, 0.0017, 0.002, 0.0022, 0.0025, 0.0027, 0.003, 0.0033, 0.0037, 0.004, 0.0044, 0.0048, 0.0052, 0.0056, 0.006, 0.0065, 0.007, 0.0075, 0.008, 0.0086, 0.0091, 0.0097, 0.0103, 0.011, 0.0116, 0.0123, 0.013, 0.0137, 0.0144, 0.0152, 0.016, 0.0168, 0.0176, 0.0185, 0.0194, 0.0203, 0.0212, 0.0222, 0.0232, 0.0242, 0.0252, 0.0262, 0.0273, 0.0284, 0.0296, 0.0307, 0.0319, 0.0331, 0.0343, 0.0356, 0.0369, 0.0382, 0.0395, 0.0409, 0.0423, 0.0437, 0.0452, 0.0467, 0.0482, 0.0497, 0.0513, 0.0529, 0.0545, 0.0561, 0.0578, 0.0595, 0.0612, 0.063, 0.0648, 0.0666, 0.0685, 0.0704, 0.0723, 0.0742, 0.0762, 0.0782, 0.0802, 0.0823, 0.0844, 0.0865, 0.0887, 0.0908, 0.0931, 0.0953, 0.0976, 0.0999, 0.1022, 0.1046, 0.107, 0.1095, 0.1119, 0.1144, 0.117, 0.1195, 0.1221, 0.1248, 0.1274, 0.1301, 0.1329, 0.1356, 0.1384, 0.1413, 0.1441, 0.147, 0.15, 0.1529, 0.1559, 0.159, 0.162, 0.1651, 0.1683, 0.1714, 0.1746, 0.1779, 0.1812, 0.1845, 0.1878, 0.1912, 0.1946, 0.1981, 0.2016, 0.2051, 0.2086, 0.2122, 0.2159, 0.2195, 0.2232, 0.227, 0.2307, 0.2346, 0.2384, 0.2423, 0.2462, 0.2502, 0.2542, 0.2582, 0.2623, 0.2664, 0.2705, 0.2747, 0.2789, 0.2831, 0.2874, 0.2918, 0.2961, 0.3005, 0.305, 0.3095, 0.314, 0.3185, 0.3231, 0.3278, 0.3325, 0.3372, 0.3419, 0.3467, 0.3515, 0.3564, 0.3613, 0.3663, 0.3712, 0.3763, 0.3813, 0.3864, 0.3916, 0.3968, 0.402, 0.4072, 0.4125, 0.4179, 0.4233, 0.4287, 0.4342, 0.4397, 0.4452, 0.4508, 0.4564, 0.4621, 0.4678, 0.4735, 0.4793, 0.4851, 0.491, 0.4969, 0.5029, 0.5089, 0.5149, 0.521, 0.5271, 0.5333, 0.5395, 0.5457, 0.552, 0.5583, 0.5647, 0.5711, 0.5776, 0.5841, 0.5906, 0.5972, 0.6038, 0.6105, 0.6172, 0.624, 0.6308, 0.6376, 0.6445, 0.6514, 0.6584, 0.6654, 0.6724, 0.6795, 0.6867, 0.6939, 0.7011, 0.7084, 0.7157, 0.7231, 0.7305, 0.7379, 0.7454, 0.7529, 0.7605, 0.7682, 0.7758, 0.7835, 0.7913, 0.7991, 0.807, 0.8148, 0.8228, 0.8308, 0.8388, 0.8469, 0.855, 0.8632, 0.8714, 0.8796, 0.8879, 0.8963, 0.9047, 0.9131, 0.9216, 0.9301, 0.9387, 0.9473, 0.956, 0.9647, 0.9734, 0.9823, 0.9911, 1]; // Return WCAG2.0 relative luminance
  // See https://www.w3.org/WAI/GL/wiki/Relative_luminance
  // See https://www.w3.org/TR/WCAG20-TECHS/G17.html#G17-tests

  var luminance = function luminance(color) {
    var rgb = parseToRgb(color);
    Object.entries(rgb).forEach(function (_ref3) {
      var _ref4 = _slicedToArray(_ref3, 2),
          name = _ref4[0],
          value = _ref4[1];

      rgb[name] = value / 255 < 0.03928 ? value / 255 / 12.92 : luminanceList[value];
    });
    return rgb.red * 0.2126 + rgb.green * 0.7152 + rgb.blue * 0.0722;
  }; // Return opaque color
  // opaque(#fff, rgba(0, 0, 0, .5)) => #808080


  var opaque = function opaque(background, foreground) {
    var opacity = parseToRgb(foreground).alpha || 1;
    return mix$1(opacity, rgba$1(foreground, 1), background);
  };

  var contrastRatio = function contrastRatio(background, foreground) {
    var l1 = luminance(background);
    var l2 = luminance(opaque(background, foreground));
    return l1 > l2 ? (l1 + 0.05) / (l2 + 0.05) : (l2 + 0.05) / (l1 + 0.05);
  };

  var colorContrast = fn(function (_ref5, t) {
    var _ref6 = _slicedToArray(_ref5, 1),
        background = _ref6[0];

    var foregrounds = [t['color-contrast-light'], t['color-contrast-dark'], t.white, t.black];
    var maxRatio = 0;
    var maxRatioColor = null;
    var result = foregrounds.find(function (color) {
      var ratio = contrastRatio(background, color);

      if (ratio > t['min-contrast-ratio']) {
        return true;
      }

      if (ratio > maxRatio) {
        maxRatio = ratio;
        maxRatioColor = color;
      }

      return false;
    });

    if (result) {
      return result;
    } // eslint-disable-next-line no-console


    console.warn("Found no color leading to ".concat(t['min-contrast-ratio'], ":1 contrast ratio against ").concat(background, "..."));
    return maxRatioColor;
  }); // Tint a color: mix a color with white

  var tintColor = fn(function (_ref7, t) {
    var _ref8 = _slicedToArray(_ref7, 2),
        weight = _ref8[0],
        color = _ref8[1];

    return mix$1(weight, t.white, color);
  }); // Shade a color: mix a color with black

  var shadeColor = fn(function (_ref9, t) {
    var _ref10 = _slicedToArray(_ref9, 2),
        weight = _ref10[0],
        color = _ref10[1];

    return mix$1(weight, t.black, color);
  }); // Shade the color if the weight is positive, else tint it

  var shiftColor = fn(function (_ref11, t) {
    var _ref12 = _slicedToArray(_ref11, 2),
        weight = _ref12[0],
        color = _ref12[1];

    var handle = weight > 0 ? shadeColor(weight, color) : tintColor(-weight, color);
    return handle(t);
  });
  var add = fn(function (_ref13) {
    var _ref14 = _slicedToArray(_ref13, 2),
        value1 = _ref14[0],
        value2 = _ref14[1];

    if (value1 === null) {
      return value2;
    }

    if (value2 === null) {
      return value1;
    }

    return calculateAdvanced(value1, '+', value2);
  });
  var subtract = fn(function (_ref15) {
    var _ref16 = _slicedToArray(_ref15, 2),
        value1 = _ref16[0],
        value2 = _ref16[1];

    if (value1 === null && value2 === null) {
      return null;
    }

    if (value1 === null) {
      return "-".concat(value2);
    }

    if (value2 === null) {
      return value1;
    }

    return calculateAdvanced(value1, '-', value2);
  });
  var divide = fn(function (_ref17) {
    var _ref18 = _slicedToArray(_ref17, 2),
        dividend = _ref18[0],
        divisor = _ref18[1];

    if (Math.abs(parseFloat(dividend)) === 0) {
      return 0;
    }

    if (Math.abs(parseFloat(divisor)) === 0) {
      throw new Error('Cannot divide by 0');
    }

    return calculateAdvanced(dividend, '/', divisor);
  });
  /* eslint-enable */

  var _templateObject$1d;

  var url = function url(val) {
    return function (t) {
      return "url(\"".concat(val.replace(/#{\$(.*?)}/g, function (_, key) {
        return t[key];
      }), "\")");
    };
  };

  var variables = css(_templateObject$1d || (_templateObject$1d = _taggedTemplateLiteral(["\n  // Color system\n\n  $white: #fff;\n  $gray-100: #f8f9fa;\n  $gray-200: #e9ecef;\n  $gray-300: #dee2e6;\n  $gray-400: #ced4da;\n  $gray-500: #adb5bd;\n  $gray-600: #6c757d;\n  $gray-700: #495057;\n  $gray-800: #343a40;\n  $gray-900: #212529;\n  $black: #000;\n\n  $grays: ", ";\n\n  $blue: #0d6efd;\n  $indigo: #6610f2;\n  $purple: #6f42c1;\n  $pink: #d63384;\n  $red: #dc3545;\n  $orange: #fd7e14;\n  $yellow: #ffc107;\n  $green: #198754;\n  $teal: #20c997;\n  $cyan: #0dcaf0;\n\n  $colors: ", ";\n\n  $primary: $blue;\n  $secondary: $gray-600;\n  $success: $green;\n  $info: $cyan;\n  $warning: $yellow;\n  $danger: $red;\n  $light: $gray-100;\n  $dark: $gray-900;\n\n  $theme-colors: ", ";\n\n  // The contrast ratio to reach against white, to determine if color changes from \"light\" to \"dark\". Acceptable values for WCAG 2.0 are 3, 4.5 and 7.\n  // See https://www.w3.org/TR/WCAG20/#visual-audio-contrast-contrast\n  $min-contrast-ratio: 4.5;\n\n  // Customize the light and dark text colors for use in our color contrast function.\n  $color-contrast-dark: $black;\n  $color-contrast-light: $white;\n\n  $blue-100: tint-color($blue, 80%);\n  $blue-200: tint-color($blue, 60%);\n  $blue-300: tint-color($blue, 40%);\n  $blue-400: tint-color($blue, 20%);\n  $blue-500: $blue;\n  $blue-600: shade-color($blue, 20%);\n  $blue-700: shade-color($blue, 40%);\n  $blue-800: shade-color($blue, 60%);\n  $blue-900: shade-color($blue, 80%);\n\n  $indigo-100: tint-color($indigo, 80%);\n  $indigo-200: tint-color($indigo, 60%);\n  $indigo-300: tint-color($indigo, 40%);\n  $indigo-400: tint-color($indigo, 20%);\n  $indigo-500: $indigo;\n  $indigo-600: shade-color($indigo, 20%);\n  $indigo-700: shade-color($indigo, 40%);\n  $indigo-800: shade-color($indigo, 60%);\n  $indigo-900: shade-color($indigo, 80%);\n\n  $purple-100: tint-color($purple, 80%);\n  $purple-200: tint-color($purple, 60%);\n  $purple-300: tint-color($purple, 40%);\n  $purple-400: tint-color($purple, 20%);\n  $purple-500: $purple;\n  $purple-600: shade-color($purple, 20%);\n  $purple-700: shade-color($purple, 40%);\n  $purple-800: shade-color($purple, 60%);\n  $purple-900: shade-color($purple, 80%);\n\n  $pink-100: tint-color($pink, 80%);\n  $pink-200: tint-color($pink, 60%);\n  $pink-300: tint-color($pink, 40%);\n  $pink-400: tint-color($pink, 20%);\n  $pink-500: $pink;\n  $pink-600: shade-color($pink, 20%);\n  $pink-700: shade-color($pink, 40%);\n  $pink-800: shade-color($pink, 60%);\n  $pink-900: shade-color($pink, 80%);\n\n  $red-100: tint-color($red, 80%);\n  $red-200: tint-color($red, 60%);\n  $red-300: tint-color($red, 40%);\n  $red-400: tint-color($red, 20%);\n  $red-500: $red;\n  $red-600: shade-color($red, 20%);\n  $red-700: shade-color($red, 40%);\n  $red-800: shade-color($red, 60%);\n  $red-900: shade-color($red, 80%);\n\n  $orange-100: tint-color($orange, 80%);\n  $orange-200: tint-color($orange, 60%);\n  $orange-300: tint-color($orange, 40%);\n  $orange-400: tint-color($orange, 20%);\n  $orange-500: $orange;\n  $orange-600: shade-color($orange, 20%);\n  $orange-700: shade-color($orange, 40%);\n  $orange-800: shade-color($orange, 60%);\n  $orange-900: shade-color($orange, 80%);\n\n  $yellow-100: tint-color($yellow, 80%);\n  $yellow-200: tint-color($yellow, 60%);\n  $yellow-300: tint-color($yellow, 40%);\n  $yellow-400: tint-color($yellow, 20%);\n  $yellow-500: $yellow;\n  $yellow-600: shade-color($yellow, 20%);\n  $yellow-700: shade-color($yellow, 40%);\n  $yellow-800: shade-color($yellow, 60%);\n  $yellow-900: shade-color($yellow, 80%);\n\n  $green-100: tint-color($green, 80%);\n  $green-200: tint-color($green, 60%);\n  $green-300: tint-color($green, 40%);\n  $green-400: tint-color($green, 20%);\n  $green-500: $green;\n  $green-600: shade-color($green, 20%);\n  $green-700: shade-color($green, 40%);\n  $green-800: shade-color($green, 60%);\n  $green-900: shade-color($green, 80%);\n\n  $teal-100: tint-color($teal, 80%);\n  $teal-200: tint-color($teal, 60%);\n  $teal-300: tint-color($teal, 40%);\n  $teal-400: tint-color($teal, 20%);\n  $teal-500: $teal;\n  $teal-600: shade-color($teal, 20%);\n  $teal-700: shade-color($teal, 40%);\n  $teal-800: shade-color($teal, 60%);\n  $teal-900: shade-color($teal, 80%);\n\n  $cyan-100: tint-color($cyan, 80%);\n  $cyan-200: tint-color($cyan, 60%);\n  $cyan-300: tint-color($cyan, 40%);\n  $cyan-400: tint-color($cyan, 20%);\n  $cyan-500: $cyan;\n  $cyan-600: shade-color($cyan, 20%);\n  $cyan-700: shade-color($cyan, 40%);\n  $cyan-800: shade-color($cyan, 60%);\n  $cyan-900: shade-color($cyan, 80%);\n\n  $blues: ", ";\n\n  $indigos: ", ";\n\n  $purples: ", ";\n\n  $pinks: ", ";\n\n  $reds: ", ";\n\n  $oranges: ", ";\n\n  $yellows: ", ";\n\n  $greens: ", ";\n\n  $teals: ", ";\n\n  $cyans: ", ";\n\n  // Characters which are escaped by the escape-svg function\n  // $escaped characters\n\n  // Options\n  //\n  // Quickly modify global styling by enabling or disabling optional features.\n\n  // NOTE: Handled by JavaScript.\n\n  // Gradient\n  //\n  // The gradient which is added to components if \"$enable-gradients\" is \"true\"\n  // This gradient is also added to elements with \".bg-gradient\"\n  $gradient: linear-gradient(180deg, rgba($white, 0.15), rgba($white, 0));\n\n  // Spacing\n  //\n  // Control the default styling of most Bootstrap elements by modifying these\n  // variables. Mostly focused on spacing.\n  // You can add more entries to the $spacers map, should you need more variation.\n\n  $spacer: 1rem;\n  $spacers: ", ";\n\n  // Position\n  //\n  // Define the edge positioning anchors of the position utilities.\n\n  $position-values: ", ";\n\n  // Placeholder\n\n  $placeholder-opacity-max: 0.5;\n  $placeholder-opacity-min: 0.2;\n\n  // Body\n  //\n  // Settings for the \"<body>\" element.\n\n  $body-bg: $white;\n  $body-color: $gray-900;\n  $body-text-align: null;\n\n  // Links\n  //\n  // Style anchor elements.\n\n  $link-color: $primary;\n  $link-decoration: underline;\n  $link-shade-percentage: 0.2; // 20%;\n  $link-hover-color: ", ";\n  $link-hover-decoration: null;\n\n  $stretched-link-pseudo-element: after;\n  $stretched-link-z-index: 1;\n\n  // Paragraphs\n  //\n  // Style p element.\n\n  $paragraph-margin-bottom: 1rem;\n\n  // Grid breakpoints\n  //\n  // Define the minimum dimensions at which your layout will change,\n  // adapting to different screen sizes, for use in media queries.\n\n  $grid-breakpoints: ", ";\n\n  // Grid containers\n  //\n  // Define the maximum width of \".container\" for different screen sizes.\n\n  $container-max-widths: ", ";\n\n  // Grid columns\n  //\n  // Set the number of columns and specify the width of the gutters.\n\n  // $grid-columns: 12;\n  $grid-gutter-width: 1.5rem;\n  // $grid-row-columns: 6;\n\n  // Container padding\n\n  $container-padding-x: $grid-gutter-width * 0.5;\n\n  // Components\n  //\n  // Define common padding and border radius sizes and more.\n\n  $border-width: 1px;\n  $border-widths: ", ";\n\n  $border-color: $gray-300;\n\n  $border-radius: 0.25rem;\n  $border-radius-sm: 0.2rem;\n  $border-radius-lg: 0.3rem;\n  $border-radius-pill: 50rem;\n\n  $box-shadow: 0 0.5rem 1rem rgba($black, 0.15);\n  $box-shadow-sm: 0 0.125rem 0.25rem rgba($black, 0.075);\n  $box-shadow-lg: 0 1rem 3rem rgba($black, 0.175);\n  $box-shadow-inset: inset 0 1px 2px rgba($black, 0.075);\n\n  $component-active-color: $white;\n  $component-active-bg: $primary;\n\n  $caret-width: 0.3em;\n  $caret-vertical-align: $caret-width * 0.85;\n  $caret-spacing: $caret-width * 0.85;\n\n  $transition-base: all 0.2s ease-in-out;\n  $transition-fade: opacity 0.15s linear;\n  $transition-collapse: height 0.35s ease;\n  $transition-collapse-width: width 0.35s ease;\n\n  $aspect-ratios: ", ";\n\n  // Typography\n  //\n  // Font, line-height, and color for body text, headings, and more.\n\n  $font-family-sans-serif: ", ";\n  $font-family-monospace: ", ";\n  $font-family-base: $font-family-sans-serif;\n  $font-family-code: $font-family-monospace;\n\n  // $font-size-root affects the value of \"rem\", which is used for as well font sizes, paddings, and margins\n  // $font-size-base affects the font size of the body text\n  $font-size-root: null;\n  $font-size-base: 1rem; // Assumes the browser default, typically \"16px\"\n  $font-size-sm: $font-size-base * 0.875;\n  $font-size-lg: $font-size-base * 1.25;\n\n  $font-weight-lighter: 300; // lighter;\n  $font-weight-light: 300;\n  $font-weight-normal: 400;\n  $font-weight-bold: 700;\n  $font-weight-bolder: 500; // bolder;\n\n  $font-weight-base: $font-weight-normal;\n\n  $line-height-base: 1.5;\n  $line-height-sm: 1.25;\n  $line-height-lg: 2;\n\n  $h1-font-size: $font-size-base * 2.5;\n  $h2-font-size: $font-size-base * 2;\n  $h3-font-size: $font-size-base * 1.75;\n  $h4-font-size: $font-size-base * 1.5;\n  $h5-font-size: $font-size-base * 1.25;\n  $h6-font-size: $font-size-base;\n\n  $font-sizes: ", ";\n\n  $headings-margin-bottom: $spacer * 0.5;\n  $headings-font-family: null;\n  $headings-font-style: null;\n  $headings-font-weight: 500;\n  $headings-line-height: 1.2;\n  $headings-color: null;\n\n  $display-font-sizes: ", ";\n\n  $display-font-weight: 300;\n  $display-line-height: $headings-line-height;\n\n  $lead-font-size: $font-size-base * 1.25;\n  $lead-font-weight: 300;\n\n  $small-font-size: $font-size-base * 0.875; // 0.875em;\n\n  $sub-sup-font-size: $font-size-base * 0.75; // 0.75em;\n\n  $text-muted: $gray-600;\n\n  $initialism-font-size: $small-font-size;\n\n  $blockquote-margin-y: $spacer;\n  $blockquote-font-size: $font-size-base * 1.25;\n  $blockquote-footer-color: $gray-600;\n  $blockquote-footer-font-size: $small-font-size;\n\n  $hr-margin-y: $spacer;\n  $hr-color: inherit;\n  $hr-bg-color: currentColor;\n  $hr-border-width: 0;\n  $hr-height: $border-width;\n  $hr-opacity: 0.25;\n\n  $legend-margin-bottom: 0.5rem;\n  $legend-font-size: 1.5rem;\n  $legend-font-weight: null;\n\n  $mark-padding: $font-size-base * 0.2; // 0.2em;\n\n  $dt-font-weight: $font-weight-bold;\n\n  $nested-kbd-font-weight: $font-weight-bold;\n\n  $list-inline-padding: 0.5rem;\n\n  $mark-bg: #fcf8e3;\n\n  // ...\n\n  // Buttons + Forms\n  //\n  // Shared variables that are reassigned to \"$input-\" and \"$btn-\" specific variables.\n\n  $input-btn-padding-y: 0.375rem;\n  $input-btn-padding-x: 0.75rem;\n  $input-btn-font-family: null;\n  $input-btn-font-size: $font-size-base;\n  $input-btn-line-height: $line-height-base;\n\n  $input-btn-focus-width: 0.25rem;\n  $input-btn-focus-color-opacity: 0.25;\n  $input-btn-focus-color: rgba(\n    $component-active-bg,\n    $input-btn-focus-color-opacity\n  );\n  $input-btn-focus-blur: 0;\n  $input-btn-focus-box-shadow: 0 0 $input-btn-focus-blur $input-btn-focus-width\n    $input-btn-focus-color;\n\n  $input-btn-padding-y-sm: 0.25rem;\n  $input-btn-padding-x-sm: 0.5rem;\n  $input-btn-font-size-sm: $font-size-sm;\n\n  $input-btn-padding-y-lg: 0.5rem;\n  $input-btn-padding-x-lg: 1rem;\n  $input-btn-font-size-lg: $font-size-lg;\n\n  $input-btn-border-width: $border-width;\n\n  // Buttons\n  //\n  // For each of Bootstrap's buttons, define text, background, and border color.\n\n  $btn-padding-y: $input-btn-padding-y;\n  $btn-padding-x: $input-btn-padding-x;\n  $btn-font-family: $input-btn-font-family;\n  $btn-font-size: $input-btn-font-size;\n  $btn-line-height: $input-btn-line-height;\n  $btn-white-space: null; // Set to \"nowrap\" to prevent text wrapping\n\n  $btn-padding-y-sm: $input-btn-padding-y-sm;\n  $btn-padding-x-sm: $input-btn-padding-x-sm;\n  $btn-font-size-sm: $input-btn-font-size-sm;\n\n  $btn-padding-y-lg: $input-btn-padding-y-lg;\n  $btn-padding-x-lg: $input-btn-padding-x-lg;\n  $btn-font-size-lg: $input-btn-font-size-lg;\n\n  $btn-border-width: $input-btn-border-width;\n\n  $btn-font-weight: $font-weight-normal;\n  $btn-box-shadow: inset 0 1px 0 rgba($white, 0.15),\n    0 1px 1px rgba($black, 0.075);\n  $btn-focus-width: $input-btn-focus-width;\n  $btn-focus-box-shadow: $input-btn-focus-box-shadow;\n  $btn-disabled-opacity: 0.65;\n  $btn-active-box-shadow: inset 0 3px 5px rgba($black, 0.125);\n\n  $btn-link-color: $link-color;\n  $btn-link-hover-color: $link-hover-color;\n  $btn-link-disabled-color: $gray-600;\n\n  // Allows for customizing button radius independently from global border radius\n  $btn-border-radius: $border-radius;\n  $btn-border-radius-sm: $border-radius-sm;\n  $btn-border-radius-lg: $border-radius-lg;\n\n  $btn-transition: color 0.15s ease-in-out, background-color 0.15s ease-in-out,\n    border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;\n\n  $btn-hover-bg-shade-amount: 0.15; // 15%;\n  $btn-hover-bg-tint-amount: 0.15; // 15%;\n  $btn-hover-border-shade-amount: 0.2; // 20%;\n  $btn-hover-border-tint-amount: 0.1; // 10%;\n  $btn-active-bg-shade-amount: 0.2; // 20%;\n  $btn-active-bg-tint-amount: 0.2; // 20%;\n  $btn-active-border-shade-amount: 0.25; // 25%;\n  $btn-active-border-tint-amount: 0.1; // 10%;\n\n  // Breadcrumb\n\n  $breadcrumb-font-size: $font-size-base; // null;\n  $breadcrumb-padding-y: 0;\n  $breadcrumb-padding-x: 0;\n  $breadcrumb-item-padding-x: 0.5rem;\n  $breadcrumb-margin-bottom: 1rem;\n  $breadcrumb-bg: null;\n  $breadcrumb-divider-color: $gray-600;\n  $breadcrumb-active-color: $gray-600;\n  $breadcrumb-divider: ", "; // quote('/');\n  $breadcrumb-divider-flipped: $breadcrumb-divider;\n  $breadcrumb-border-radius: null;\n\n  // Forms\n\n  $form-text-margin-top: 0.25rem;\n  $form-text-font-size: $small-font-size;\n  $form-text-font-style: null;\n  $form-text-font-weight: null;\n  $form-text-color: $text-muted;\n\n  $form-label-margin-bottom: 0.5rem;\n  $form-label-font-size: $font-size-base; // null;\n  $form-label-font-style: null;\n  $form-label-font-weight: null;\n  $form-label-color: null;\n\n  $input-padding-y: $input-btn-padding-y;\n  $input-padding-x: $input-btn-padding-x;\n  $input-font-family: $input-btn-font-family;\n  $input-font-size: $input-btn-font-size;\n  $input-font-weight: $font-weight-base;\n  $input-line-height: $input-btn-line-height;\n\n  $input-padding-y-sm: $input-btn-padding-y-sm;\n  $input-padding-x-sm: $input-btn-padding-x-sm;\n  $input-font-size-sm: $input-btn-font-size-sm;\n\n  $input-padding-y-lg: $input-btn-padding-y-lg;\n  $input-padding-x-lg: $input-btn-padding-x-lg;\n  $input-font-size-lg: $input-btn-font-size-lg;\n\n  $input-bg: $body-bg;\n  $input-disabled-bg: $gray-200;\n  $input-disabled-border-color: null;\n\n  $input-color: $body-color;\n  $input-border-color: $gray-400;\n  $input-border-width: $input-btn-border-width;\n  $input-box-shadow: $box-shadow-inset;\n\n  $input-border-radius: $border-radius;\n  $input-border-radius-sm: $border-radius-sm;\n  $input-border-radius-lg: $border-radius-lg;\n\n  $input-focus-bg: $input-bg;\n  $input-focus-border-color: ", ";\n  $input-focus-color: $input-color;\n  $input-focus-width: $input-btn-focus-width;\n  $input-focus-box-shadow: $input-btn-focus-box-shadow;\n\n  $input-placeholder-color: $gray-600;\n  $input-plaintext-color: $body-color;\n\n  $input-height-border: $input-border-width * 2;\n\n  $input-height-inner: ", ";\n  $input-height-inner-half: ", ";\n  $input-height-inner-quarter: ", ";\n\n  $input-height: ", ";\n  $input-height-sm: ", ";\n  $input-height-lg: ", ";\n\n  $input-transition: border-color 0.15s ease-in-out,\n    box-shadow 0.15s ease-in-out;\n\n  $form-color-width: 3rem;\n\n  $form-check-input-width: $font-size-base * 1; // 1em;\n  $form-check-min-height: $font-size-base * $line-height-base;\n  $form-check-padding-start: $form-check-input-width + 0.5rem; // 0.5em;\n  $form-check-margin-bottom: 0.125rem;\n  $form-check-label-color: null;\n  $form-check-label-cursor: null;\n  $form-check-transition: null;\n\n  $form-check-input-active-filter: brightness(90%);\n\n  $form-check-input-bg: $input-bg;\n  $form-check-input-border: 1px solid rgba($black, 0.25);\n  $form-check-input-border-radius: $font-size-base * 0.25; // 0.25em;\n  $form-check-radio-border-radius: 50px; // 50%;\n  $form-check-input-focus-border: $input-focus-border-color;\n  $form-check-input-focus-box-shadow: $input-btn-focus-box-shadow;\n\n  $form-check-input-checked-color: $component-active-color;\n  $form-check-input-checked-bg-color: $component-active-bg;\n  $form-check-input-checked-border-color: $form-check-input-checked-bg-color;\n  $form-check-input-checked-bg-image: ", ";\n  $form-check-radio-checked-bg-image: ", ";\n\n  $form-check-input-indeterminate-color: $component-active-color;\n  $form-check-input-indeterminate-bg-color: $component-active-bg;\n  $form-check-input-indeterminate-border-color: $form-check-input-indeterminate-bg-color;\n  $form-check-input-indeterminate-bg-image: ", ";\n\n  $form-check-input-disabled-opacity: 0.5;\n  $form-check-label-disabled-opacity: $form-check-input-disabled-opacity;\n  $form-check-btn-check-disabled-opacity: $btn-disabled-opacity;\n\n  $form-check-inline-margin-end: 1rem;\n\n  $form-switch-color: rgba($black, 0.25);\n  $form-switch-width: 2rem;\n  $form-switch-padding-start: $form-switch-width + 0.5rem;\n  $form-switch-bg-image: ", ";\n  $form-switch-border-radius: $form-switch-width;\n  $form-switch-transition: background-position 0.15s ease-in-out;\n\n  $form-switch-focus-color: $input-focus-border-color;\n  $form-switch-focus-bg-image: ", ";\n\n  $form-switch-checked-color: $component-active-color;\n  $form-switch-checked-bg-image: ", ";\n  $form-switch-checked-bg-position: right center;\n\n  $input-group-addon-padding-y: $input-padding-y;\n  $input-group-addon-padding-x: $input-padding-x;\n  $input-group-addon-font-weight: $input-font-weight;\n  $input-group-addon-color: $input-color;\n  $input-group-addon-bg: $gray-200;\n  $input-group-addon-border-color: $input-border-color;\n\n  $form-select-padding-y: $input-padding-y;\n  $form-select-padding-x: $input-padding-x;\n  $form-select-font-family: $input-font-family;\n  $form-select-font-size: $input-font-size;\n  $form-select-indicator-padding: $form-select-padding-x * 3; // Extra padding for background-image\n  $form-select-font-weight: $input-font-weight;\n  $form-select-line-height: $input-line-height;\n  $form-select-color: $input-color;\n  $form-select-bg: $input-bg;\n  $form-select-disabled-color: null;\n  $form-select-disabled-bg: $gray-200;\n  $form-select-disabled-border-color: $input-disabled-border-color;\n  $form-select-bg-position: right $form-select-padding-x center;\n  $form-select-bg-size: 16px 12px; // In pixels because image dimensions\n  $form-select-indicator-color: $gray-800;\n  $form-select-indicator: ", ";\n\n  $form-select-feedback-icon-padding-end: $form-select-padding-x * 2.5 +\n    $form-select-indicator-padding;\n  $form-select-feedback-icon-position: center right\n    $form-select-indicator-padding;\n  $form-select-feedback-icon-size: $input-height-inner-half\n    $input-height-inner-half;\n\n  $form-select-border-width: $input-border-width;\n  $form-select-border-color: $input-border-color;\n  $form-select-border-radius: $input-border-radius;\n  $form-select-box-shadow: $box-shadow-inset;\n\n  $form-select-focus-border-color: $input-focus-border-color;\n  $form-select-focus-width: $input-focus-width;\n  $form-select-focus-box-shadow: 0 0 0 $form-select-focus-width\n    $input-btn-focus-color;\n\n  $form-select-padding-y-sm: $input-padding-y-sm;\n  $form-select-padding-x-sm: $input-padding-x-sm;\n  $form-select-font-size-sm: $input-font-size-sm;\n  $form-select-border-radius-sm: $input-border-radius-sm;\n\n  $form-select-padding-y-lg: $input-padding-y-lg;\n  $form-select-padding-x-lg: $input-padding-x-lg;\n  $form-select-font-size-lg: $input-font-size-lg;\n  $form-select-border-radius-lg: $input-border-radius-lg;\n\n  $form-select-transition: $input-transition;\n\n  $form-range-track-width: 100%;\n  $form-range-track-height: 0.5rem;\n  $form-range-track-cursor: pointer;\n  $form-range-track-bg: $gray-300;\n  $form-range-track-border-radius: 1rem;\n  $form-range-track-box-shadow: $box-shadow-inset;\n\n  $form-range-thumb-width: 1rem;\n  $form-range-thumb-height: $form-range-thumb-width;\n  $form-range-thumb-bg: $component-active-bg;\n  $form-range-thumb-border: 0;\n  $form-range-thumb-border-radius: 1rem;\n  $form-range-thumb-box-shadow: 0 0.1rem 0.25rem rgba($black, 0.1);\n  $form-range-thumb-focus-box-shadow: 0 0 0 1px $body-bg,\n    $input-focus-box-shadow;\n  $form-range-thumb-focus-box-shadow-width: $input-focus-width; // For focus box shadow issue in Edge\n  $form-range-thumb-active-bg: tint-color($component-active-bg, 70%);\n  $form-range-thumb-disabled-bg: $gray-500;\n  $form-range-thumb-transition: background-color 0.15s ease-in-out,\n    border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;\n\n  $form-file-button-color: $input-color;\n  $form-file-button-bg: $input-group-addon-bg;\n  $form-file-button-hover-bg: shade-color($form-file-button-bg, 5%);\n\n  $form-floating-height: ", ";\n  $form-floating-line-height: 1.25;\n  $form-floating-padding-x: $input-padding-x;\n  $form-floating-padding-y: 1rem;\n  $form-floating-input-padding-t: 1.625rem;\n  $form-floating-input-padding-b: 0.625rem;\n  $form-floating-label-opacity: 0.65;\n  $form-floating-label-transform: scale(0.85) translateY(-0.5rem)\n    translateX(0.15rem);\n  $form-floating-transition: opacity 0.1s ease-in-out,\n    transform 0.1s ease-in-out;\n\n  // Form validation\n\n  $form-feedback-margin-top: $form-text-margin-top;\n  $form-feedback-font-size: $form-text-font-size;\n  $form-feedback-font-style: $form-text-font-style;\n  $form-feedback-valid-color: $success;\n  $form-feedback-invalid-color: $danger;\n\n  $form-feedback-icon-valid-color: $form-feedback-valid-color;\n  $form-feedback-icon-valid: ", ";\n  $form-feedback-icon-invalid-color: $form-feedback-invalid-color;\n  $form-feedback-icon-invalid: ", ";\n\n  $form-validation-states: ", ";\n\n  // Z-index master list\n  //\n  // Warning: Avoid customizing these values. They're used for a bird's eye view\n  // of components dependent on the z-axis and are designed to all work together.\n\n  $zindex-dropdown: 1000;\n  $zindex-sticky: 1020;\n  $zindex-fixed: 1030;\n  $zindex-offcanvas-backdrop: 1040;\n  $zindex-offcanvas: 1045;\n  $zindex-modal-backdrop: 1050;\n  $zindex-modal: 1055;\n  $zindex-popover: 1070;\n  $zindex-tooltip: 1080;\n\n  // Navs\n\n  $nav-link-padding-y: 0.5rem;\n  $nav-link-padding-x: 1rem;\n  $nav-link-font-size: null;\n  $nav-link-font-weight: null;\n  $nav-link-color: $link-color;\n  $nav-link-hover-color: $link-hover-color;\n  $nav-link-transition: color 0.15s ease-in-out,\n    background-color 0.15s ease-in-out, border-color 0.15s ease-in-out;\n  $nav-link-disabled-color: $gray-600;\n\n  $nav-tabs-border-color: $gray-300;\n  $nav-tabs-border-width: $border-width;\n  $nav-tabs-border-radius: $border-radius;\n  $nav-tabs-link-hover-border-color: $gray-200 $gray-200 $nav-tabs-border-color;\n  $nav-tabs-link-active-color: $gray-700;\n  $nav-tabs-link-active-bg: $body-bg;\n  $nav-tabs-link-active-border-color: $gray-300 $gray-300\n    $nav-tabs-link-active-bg;\n\n  $nav-pills-border-radius: $border-radius;\n  $nav-pills-link-active-color: $component-active-color;\n  $nav-pills-link-active-bg: $component-active-bg;\n\n  // Navbar\n\n  $navbar-padding-y: $spacer * 0.5;\n  $navbar-padding-x: null;\n\n  $navbar-nav-link-padding-x: 0.5rem;\n\n  $navbar-brand-font-size: $font-size-lg;\n\n  $nav-link-height: $font-size-base * $line-height-base + $nav-link-padding-y *\n    2;\n  $navbar-brand-height: $navbar-brand-font-size * $line-height-base;\n  $navbar-brand-padding-y-intermediate-result: $nav-link-height -\n    $navbar-brand-height;\n  $navbar-brand-padding-y: $navbar-brand-padding-y-intermediate-result * 0.5;\n  $navbar-brand-margin-end: 1rem;\n\n  $navbar-toggler-padding-y: 0.25rem;\n  $navbar-toggler-padding-x: 0.75rem;\n  $navbar-toggler-font-size: $font-size-lg;\n  $navbar-toggler-border-radius: $btn-border-radius;\n  $navbar-toggler-focus-width: $btn-focus-width;\n  $navbar-toggler-transition: box-shadow 0.15s ease-in-out;\n\n  $navbar-dark-color: rgba($white, 0.55);\n  $navbar-dark-hover-color: rgba($white, 0.75);\n  $navbar-dark-active-color: $white;\n  $navbar-dark-disabled-color: rgba($white, 0.25);\n  $navbar-dark-toggler-icon-bg: ", ";\n  $navbar-dark-toggler-border-color: rgba($white, 0.1);\n\n  $navbar-light-color: rgba($black, 0.55);\n  $navbar-light-hover-color: rgba($black, 0.7);\n  $navbar-light-active-color: rgba($black, 0.9);\n  $navbar-light-disabled-color: rgba($black, 0.3);\n  $navbar-light-toggler-icon-bg: ", ";\n  $navbar-light-toggler-border-color: rgba($black, 0.1);\n\n  $navbar-light-brand-color: $navbar-light-active-color;\n  $navbar-light-brand-hover-color: $navbar-light-active-color;\n  $navbar-dark-brand-color: $navbar-dark-active-color;\n  $navbar-dark-brand-hover-color: $navbar-dark-active-color;\n\n  // Dropdowns\n  //\n  // Dropdown menu container and contents.\n\n  $dropdown-min-width: 10rem;\n  $dropdown-padding-x: 0;\n  $dropdown-padding-y: 0.5rem;\n  $dropdown-spacer: 0.125rem;\n  $dropdown-font-size: $font-size-base;\n  $dropdown-color: $body-color;\n  $dropdown-bg: $white;\n  $dropdown-border-color: rgba($black, 0.15);\n  $dropdown-border-radius: $border-radius;\n  $dropdown-border-width: $border-width;\n  $dropdown-inner-border-radius: ", ";\n  $dropdown-divider-bg: $dropdown-border-color;\n  $dropdown-divider-margin-y: $spacer * 0.5;\n  $dropdown-box-shadow: $box-shadow;\n\n  $dropdown-link-color: $gray-900;\n\n  $dropdown-link-hover-color: ", ";\n  $dropdown-link-hover-bg: $gray-200;\n\n  $dropdown-link-active-color: $component-active-color;\n  $dropdown-link-active-bg: $component-active-bg;\n\n  $dropdown-link-disabled-color: $gray-500;\n\n  $dropdown-item-padding-y: $spacer * 0.25;\n  $dropdown-item-padding-x: $spacer;\n\n  $dropdown-header-color: $gray-600;\n  $dropdown-header-padding: $dropdown-padding-y $dropdown-item-padding-x;\n\n  $dropdown-dark-color: $gray-300;\n  $dropdown-dark-bg: $gray-800;\n  $dropdown-dark-border-color: $dropdown-border-color;\n  $dropdown-dark-divider-bg: $dropdown-divider-bg;\n  $dropdown-dark-box-shadow: null;\n  $dropdown-dark-link-color: $dropdown-dark-color;\n  $dropdown-dark-link-hover-color: $white;\n  $dropdown-dark-link-hover-bg: rgba($white, 0.15);\n  $dropdown-dark-link-active-color: $dropdown-link-active-color;\n  $dropdown-dark-link-active-bg: $dropdown-link-active-bg;\n  $dropdown-dark-link-disabled-color: $gray-500;\n  $dropdown-dark-header-color: $gray-500;\n\n  // ...\n\n  // Cards\n\n  $card-spacer-y: $spacer;\n  $card-spacer-x: $spacer;\n  $card-title-spacer-y: $spacer * 0.5;\n  $card-border-width: $border-width;\n  $card-border-color: rgba($black, 0.125);\n  $card-border-radius: $border-radius;\n  $card-box-shadow: null;\n  $card-inner-border-radius: ", ";\n  $card-cap-padding-y: $card-spacer-y * 0.5;\n  $card-cap-padding-x: $card-spacer-x;\n  $card-cap-bg: rgba($black, 0.03);\n  $card-cap-color: null;\n  $card-height: null;\n  $card-color: null;\n  $card-bg: $white;\n  $card-img-overlay-padding: $spacer;\n  $card-group-margin: $grid-gutter-width * 0.5;\n\n  // ...\n\n  // Tooltips\n\n  $tooltip-font-size: $font-size-sm;\n  $tooltip-max-width: 200px;\n  $tooltip-color: $white;\n  $tooltip-bg: $black;\n  $tooltip-border-radius: $border-radius;\n  $tooltip-opacity: 0.9;\n  $tooltip-padding-y: $spacer * 0.25;\n  $tooltip-padding-x: $spacer * 0.5;\n  $tooltip-margin: 0;\n\n  $tooltip-arrow-width: 0.8rem;\n  $tooltip-arrow-height: 0.4rem;\n  $tooltip-arrow-color: $tooltip-bg;\n\n  // Popovers\n\n  $popover-font-size: $font-size-sm;\n  $popover-bg: $white;\n  $popover-max-width: 276px;\n  $popover-border-width: $border-width;\n  $popover-border-color: rgba($black, 0.2);\n  $popover-border-radius: $border-radius-lg;\n  $popover-inner-border-radius: ", ";\n  $popover-box-shadow: $box-shadow;\n\n  $popover-header-bg: ", ";\n  $popover-header-color: $headings-color;\n  $popover-header-padding-y: 0.5rem;\n  $popover-header-padding-x: $spacer;\n\n  $popover-body-color: $body-color;\n  $popover-body-padding-y: $spacer;\n  $popover-body-padding-x: $spacer;\n\n  $popover-arrow-width: 1rem;\n  $popover-arrow-height: 0.5rem;\n  $popover-arrow-color: $popover-bg;\n\n  $popover-arrow-outer-color: $popover-border-color;\n\n  // Toasts\n\n  $toast-max-width: 350px;\n  $toast-padding-x: 0.75rem;\n  $toast-padding-y: 0.5rem;\n  $toast-font-size: 0.875rem;\n  $toast-color: null;\n  $toast-background-color: rgba($white, 0.85);\n  $toast-border-width: 1px;\n  $toast-border-color: rgba($black, 0.1);\n  $toast-border-radius: $border-radius;\n  $toast-box-shadow: $box-shadow;\n  $toast-spacing: $container-padding-x;\n\n  $toast-header-color: $gray-600;\n  $toast-header-background-color: rgba($white, 0.85);\n  $toast-header-border-color: rgba($black, 0.05);\n\n  // Badges\n\n  $badge-font-size: $font-size-base * 0.75; // 0.75em;\n  $badge-font-weight: $font-weight-bold;\n  $badge-color: $white;\n  $badge-padding-y: $badge-font-size * 0.35; // 0.35em;\n  $badge-padding-x: $badge-font-size * 0.65; // 0.65em;\n  $badge-border-radius: $border-radius;\n\n  // Modals\n\n  $modal-inner-padding: $spacer;\n\n  $modal-footer-margin-between: 0.5rem;\n\n  $modal-dialog-margin: 0.5rem;\n  $modal-dialog-margin-y-sm-up: 1.75rem;\n\n  $modal-title-line-height: $line-height-base;\n\n  $modal-content-color: null;\n  $modal-content-bg: $white;\n  $modal-content-border-color: rgba($black, 0.65); // rgba($black, 0.2);\n  $modal-content-border-width: $border-width;\n  $modal-content-border-radius: $border-radius-lg;\n  $modal-content-inner-border-radius: ", ";\n  $modal-content-box-shadow-xs: $box-shadow-sm;\n  $modal-content-box-shadow-sm-up: $box-shadow;\n\n  $modal-backdrop-bg: $black;\n  $modal-backdrop-opacity: 0.5;\n  $modal-header-border-color: $border-color;\n  $modal-footer-border-color: $modal-header-border-color;\n  $modal-header-border-width: $modal-content-border-width;\n  $modal-footer-border-width: $modal-header-border-width;\n  $modal-header-padding-y: $modal-inner-padding;\n  $modal-header-padding-x: $modal-inner-padding;\n  $modal-header-padding: $modal-header-padding-y $modal-header-padding-x; // Keep this for backwards compatibility\n\n  $modal-sm: 300px;\n  $modal-md: 500px;\n  $modal-lg: 800px;\n  $modal-xl: 1140px;\n\n  $modal-fade-transform: translate(0, -50px);\n  $modal-show-transform: none;\n  $modal-transition: transform 0.3s ease-out;\n  $modal-scale-transform: scale(1.02);\n\n  // ...\n\n  // Alerts\n  //\n  // Define alert colors, border radius, and padding.\n\n  $alert-padding-y: $spacer;\n  $alert-padding-x: $spacer;\n  $alert-margin-bottom: 1rem;\n  $alert-border-radius: $border-radius;\n  $alert-link-font-weight: $font-weight-bold;\n  $alert-border-width: $border-width;\n  $alert-bg-scale: -0.8; // 80%;\n  $alert-border-scale: -0.7; // 70%;\n  $alert-color-scale: 0.4; // 40%;\n  $alert-dismissible-padding-r: $alert-padding-x * 3; // 3x covers width of x plus default padding on either side\n\n  // Pagination\n\n  $pagination-padding-y: 0.375rem;\n  $pagination-padding-x: 0.75rem;\n  $pagination-padding-y-sm: 0.25rem;\n  $pagination-padding-x-sm: 0.5rem;\n  $pagination-padding-y-lg: 0.75rem;\n  $pagination-padding-x-lg: 1.5rem;\n\n  $pagination-color: $link-color;\n  $pagination-bg: $white;\n  $pagination-border-width: $border-width;\n  $pagination-border-radius: $border-radius;\n  $pagination-margin-start: -$pagination-border-width;\n  $pagination-border-color: $gray-300;\n\n  $pagination-focus-color: $link-hover-color;\n  $pagination-focus-bg: $gray-200;\n  $pagination-focus-box-shadow: $input-btn-focus-box-shadow;\n  $pagination-focus-outline: 0;\n\n  $pagination-hover-color: $link-hover-color;\n  $pagination-hover-bg: $gray-200;\n  $pagination-hover-border-color: $gray-300;\n\n  $pagination-active-color: $component-active-color;\n  $pagination-active-bg: $component-active-bg;\n  $pagination-active-border-color: $pagination-active-bg;\n\n  $pagination-disabled-color: $gray-600;\n  $pagination-disabled-bg: $white;\n  $pagination-disabled-border-color: $gray-300;\n\n  $pagination-transition: color 0.15s ease-in-out,\n    background-color 0.15s ease-in-out, border-color 0.15s ease-in-out,\n    box-shadow 0.15s ease-in-out;\n\n  $pagination-border-radius-sm: $border-radius-sm;\n  $pagination-border-radius-lg: $border-radius-lg;\n\n  // Progress bars\n\n  $progress-height: 1rem;\n  $progress-font-size: $font-size-base * 0.75;\n  $progress-bg: $gray-200;\n  $progress-border-radius: $border-radius;\n  $progress-box-shadow: $box-shadow-inset;\n  $progress-bar-color: $white;\n  $progress-bar-bg: $primary;\n  $progress-bar-animation-timing: 1s linear infinite;\n  $progress-bar-transition: width 0.6s ease;\n\n  // List group\n\n  $list-group-color: $gray-900;\n  $list-group-bg: $white;\n  $list-group-border-color: rgba($black, 0.125);\n  $list-group-border-width: $border-width;\n  $list-group-border-radius: $border-radius;\n\n  $list-group-item-padding-y: $spacer * 0.5;\n  $list-group-item-padding-x: $spacer;\n  $list-group-item-bg-scale: -0.8; // 80%;\n  $list-group-item-color-scale: 0.4; // 40%;\n\n  $list-group-hover-bg: $gray-100;\n  $list-group-active-color: $component-active-color;\n  $list-group-active-bg: $component-active-bg;\n  $list-group-active-border-color: $list-group-active-bg;\n\n  $list-group-disabled-color: $gray-600;\n  $list-group-disabled-bg: $list-group-bg;\n\n  $list-group-action-color: $gray-700;\n  $list-group-action-hover-color: $list-group-action-color;\n\n  $list-group-action-active-color: $body-color;\n  $list-group-action-active-bg: $gray-200;\n\n  // ...\n\n  // Spinners\n\n  $spinner-width: 2rem;\n  $spinner-height: $spinner-width;\n  $spinner-vertical-align: $font-size-base * -0.125; // -.125em;\n  $spinner-border-width: $font-size-base * 0.25; // .25em;\n  $spinner-animation-speed: 0.75s;\n\n  $spinner-width-sm: 1rem;\n  $spinner-height-sm: $spinner-width-sm;\n  $spinner-border-width-sm: $font-size-base * 0.2; // .2em;\n\n  // Close\n\n  $btn-close-width: $font-size-base * 1; // 1em;\n  $btn-close-height: $btn-close-width;\n  $btn-close-padding-x: $font-size-base * 0.25; // .25em;\n  $btn-close-padding-y: $btn-close-padding-x;\n  $btn-close-color: $black;\n  $btn-close-bg: ", ";\n  $btn-close-focus-shadow: $input-btn-focus-box-shadow;\n  $btn-close-opacity: 0.5;\n  $btn-close-hover-opacity: 0.75;\n  $btn-close-focus-opacity: 1;\n  $btn-close-disabled-opacity: 0.25;\n  // $btn-close-white-filter: invert(1) grayscale(100%) brightness(200%);\n\n  // Offcanvas\n\n  $offcanvas-padding-y: $modal-inner-padding;\n  $offcanvas-padding-x: $modal-inner-padding;\n  $offcanvas-horizontal-width: 400px;\n  $offcanvas-vertical-height: 200px; // 30vh;\n  $offcanvas-transition-duration: 0.3s;\n  $offcanvas-border-color: $modal-content-border-color;\n  $offcanvas-border-width: $modal-content-border-width;\n  $offcanvas-title-line-height: $modal-title-line-height;\n  $offcanvas-bg-color: $modal-content-bg;\n  $offcanvas-color: $modal-content-color;\n  $offcanvas-box-shadow: $modal-content-box-shadow-xs;\n  $offcanvas-backdrop-bg: $modal-backdrop-bg;\n  $offcanvas-backdrop-opacity: $modal-backdrop-opacity;\n\n  // Code\n\n  $code-font-size: $small-font-size;\n  $code-color: $pink;\n\n  $kbd-padding-y: 0.2rem;\n  $kbd-padding-x: 0.4rem;\n  $kbd-font-size: $code-font-size;\n  $kbd-color: $white;\n  $kbd-bg: $gray-900;\n\n  $pre-color: null;\n"])), function (t) {
    return {
      100: t['gray-100'],
      200: t['gray-200'],
      300: t['gray-300'],
      400: t['gray-400'],
      500: t['gray-500'],
      600: t['gray-600'],
      700: t['gray-700'],
      800: t['gray-800'],
      900: t['gray-900']
    };
  }, function (t) {
    return {
      blue: t.blue,
      indigo: t.indigo,
      purple: t.purple,
      pink: t.pink,
      red: t.red,
      orange: t.orange,
      yellow: t.yellow,
      green: t.green,
      teal: t.teal,
      cyan: t.cyan
    };
  }, function (t) {
    return {
      primary: t.primary,
      secondary: t.secondary,
      success: t.success,
      info: t.info,
      warning: t.warning,
      danger: t.danger,
      light: t.light,
      dark: t.dark
    };
  }, function (t) {
    return {
      'blue-100': t['blue-100'],
      'blue-200': t['blue-200'],
      'blue-300': t['blue-300'],
      'blue-400': t['blue-400'],
      'blue-500': t['blue-500'],
      'blue-600': t['blue-600'],
      'blue-700': t['blue-700'],
      'blue-800': t['blue-800'],
      'blue-900': t['blue-900']
    };
  }, function (t) {
    return {
      'indigo-100': t['indigo-100'],
      'indigo-200': t['indigo-200'],
      'indigo-300': t['indigo-300'],
      'indigo-400': t['indigo-400'],
      'indigo-500': t['indigo-500'],
      'indigo-600': t['indigo-600'],
      'indigo-700': t['indigo-700'],
      'indigo-800': t['indigo-800'],
      'indigo-900': t['indigo-900']
    };
  }, function (t) {
    return {
      'purple-100': t['purple-100'],
      'purple-200': t['purple-200'],
      'purple-300': t['purple-300'],
      'purple-400': t['purple-400'],
      'purple-500': t['purple-500'],
      'purple-600': t['purple-600'],
      'purple-700': t['purple-700'],
      'purple-800': t['purple-800'],
      'purple-900': t['purple-900']
    };
  }, function (t) {
    return {
      'pink-100': t['pink-100'],
      'pink-200': t['pink-200'],
      'pink-300': t['pink-300'],
      'pink-400': t['pink-400'],
      'pink-500': t['pink-500'],
      'pink-600': t['pink-600'],
      'pink-700': t['pink-700'],
      'pink-800': t['pink-800'],
      'pink-900': t['pink-900']
    };
  }, function (t) {
    return {
      'red-100': t['red-100'],
      'red-200': t['red-200'],
      'red-300': t['red-300'],
      'red-400': t['red-400'],
      'red-500': t['red-500'],
      'red-600': t['red-600'],
      'red-700': t['red-700'],
      'red-800': t['red-800'],
      'red-900': t['red-900']
    };
  }, function (t) {
    return {
      'orange-100': t['orange-100'],
      'orange-200': t['orange-200'],
      'orange-300': t['orange-300'],
      'orange-400': t['orange-400'],
      'orange-500': t['orange-500'],
      'orange-600': t['orange-600'],
      'orange-700': t['orange-700'],
      'orange-800': t['orange-800'],
      'orange-900': t['orange-900']
    };
  }, function (t) {
    return {
      'yellow-100': t['yellow-100'],
      'yellow-200': t['yellow-200'],
      'yellow-300': t['yellow-300'],
      'yellow-400': t['yellow-400'],
      'yellow-500': t['yellow-500'],
      'yellow-600': t['yellow-600'],
      'yellow-700': t['yellow-700'],
      'yellow-800': t['yellow-800'],
      'yellow-900': t['yellow-900']
    };
  }, function (t) {
    return {
      'green-100': t['green-100'],
      'green-200': t['green-200'],
      'green-300': t['green-300'],
      'green-400': t['green-400'],
      'green-500': t['green-500'],
      'green-600': t['green-600'],
      'green-700': t['green-700'],
      'green-800': t['green-800'],
      'green-900': t['green-900']
    };
  }, function (t) {
    return {
      'teal-100': t['teal-100'],
      'teal-200': t['teal-200'],
      'teal-300': t['teal-300'],
      'teal-400': t['teal-400'],
      'teal-500': t['teal-500'],
      'teal-600': t['teal-600'],
      'teal-700': t['teal-700'],
      'teal-800': t['teal-800'],
      'teal-900': t['teal-900']
    };
  }, function (t) {
    return {
      'cyan-100': t['cyan-100'],
      'cyan-200': t['cyan-200'],
      'cyan-300': t['cyan-300'],
      'cyan-400': t['cyan-400'],
      'cyan-500': t['cyan-500'],
      'cyan-600': t['cyan-600'],
      'cyan-700': t['cyan-700'],
      'cyan-800': t['cyan-800'],
      'cyan-900': t['cyan-900']
    };
  }, function (t) {
    return {
      0: '0px',
      1: "".concat(t.spacer, " * 0.25"),
      2: "".concat(t.spacer, " * 0.5"),
      3: t.spacer,
      4: "".concat(t.spacer, " * 1.5"),
      5: "".concat(t.spacer, " * 3")
    };
  }, function () {
    return {
      0: '0px',
      50: '50%',
      100: '100%'
    };
  }, shiftColor(function (t) {
    return t['link-shade-percentage'];
  }, function (t) {
    return t['link-color'];
  }), function () {
    return {
      xs: 0,
      sm: 576,
      md: 768,
      lg: 992,
      xl: 1200,
      xxl: 1400
    };
  }, function () {
    return {
      sm: '540px',
      md: '720px',
      lg: '960px',
      xl: '1140px',
      xxl: '1320px'
    };
  }, function () {
    return {
      1: '1px',
      2: '2px',
      3: '3px',
      4: '4px',
      5: '5px'
    };
  }, function () {
    return {
      '1x1': '100%',
      '4x3': 'calc(3 / 4 * 100%)',
      '16x9': 'calc(9 / 16 * 100%)',
      '21x9': 'calc(9 / 21 * 100%)'
    };
  }, function () {
    return reactNative.Platform.select({
      native: 'System',
      default: "\"system-ui, -apple-system, 'Segoe UI', Roboto, 'Helvetica Neue', Arial, 'Noto Sans', 'Liberation Sans', sans-serif, 'Apple Color Emoji', 'Segoe UI Emoji', 'Segoe UI Symbol', 'Noto Color Emoji'\""
    });
  }, function () {
    return reactNative.Platform.select({
      android: 'monospace',
      ios: 'Courier',
      default: "\"SFMono-Regular, Menlo, Monaco, Consolas, 'Liberation Mono', 'Courier New', monospace\""
    });
  }, function (t) {
    return {
      1: t['h1-font-size'],
      2: t['h2-font-size'],
      3: t['h3-font-size'],
      4: t['h4-font-size'],
      5: t['h5-font-size'],
      6: t['h6-font-size']
    };
  }, function () {
    return {
      1: '5rem',
      2: '4.5rem',
      3: '4rem',
      4: '3.5rem',
      5: '3rem',
      6: '2.5rem'
    };
  }, function () {
    return '/';
  }, tintColor(0.5, function (t) {
    return t['component-active-bg'];
  }), add(function (t) {
    return calculate(t['input-line-height'], '*', 1);
  }, function (t) {
    return calculate(t['input-padding-y'], '*', 2);
  }), add(function (t) {
    return calculate(t['input-line-height'], '*', 0.5);
  }, function (t) {
    return t['input-padding-y'];
  }), add(function (t) {
    return calculate(t['input-line-height'], '*', 0.25);
  }, function (t) {
    return calculate(t['input-padding-y'], '*', 0.5);
  }), add(function (t) {
    return calculate(t['input-line-height'], '*', t['input-font-size']);
  }, // 1em
  add(function (t) {
    return calculate(t['input-padding-y'], '*', 2);
  }, function (t) {
    return t['input-height-border'];
  })), add(function (t) {
    return calculate(t['input-line-height'], '*', t['input-font-size-sm']);
  }, // 1em
  add(function (t) {
    return calculate(t['input-padding-y-sm'], '*', 2);
  }, function (t) {
    return t['input-height-border'];
  })), add(function (t) {
    return calculate(t['input-line-height'], '*', t['input-font-size-lg']);
  }, // 1em
  add(function (t) {
    return calculate(t['input-padding-y-lg'], '*', 2);
  }, function (t) {
    return t['input-height-border'];
  })), url("data:image/svg+xml,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 20 20'><path fill='none' stroke='#{$form-check-input-checked-color}' stroke-linecap='round' stroke-linejoin='round' stroke-width='3' d='m6 10 3 3 6-6'/></svg>"), url("data:image/svg+xml,<svg xmlns='http://www.w3.org/2000/svg' viewBox='-4 -4 8 8'><circle r='2' fill='#{$form-check-input-checked-color}'/></svg>"), url("data:image/svg+xml,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 20 20'><path fill='none' stroke='#{$form-check-input-indeterminate-color}' stroke-linecap='round' stroke-linejoin='round' stroke-width='3' d='M6 10h8'/></svg>"), url("data:image/svg+xml,<svg xmlns='http://www.w3.org/2000/svg' viewBox='-4 -4 8 8'><circle r='3' fill='#{$form-switch-color}'/></svg>"), url("data:image/svg+xml,<svg xmlns='http://www.w3.org/2000/svg' viewBox='-4 -4 8 8'><circle r='3' fill='#{$form-switch-focus-color}'/></svg>"), url("data:image/svg+xml,<svg xmlns='http://www.w3.org/2000/svg' viewBox='-4 -4 8 8'><circle r='3' fill='#{$form-switch-checked-color}'/></svg>"), url("data:image/svg+xml,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 16 16'><path fill='none' stroke='#{$form-select-indicator-color}' stroke-linecap='round' stroke-linejoin='round' stroke-width='2' d='m2 5 6 6 6-6'/></svg>"), add('3.5rem', function (t) {
    return t['input-height-border'];
  }), url("data:image/svg+xml,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 8 8'><path fill='#{$form-feedback-icon-valid-color}' d='M2.3 6.73.6 4.53c-.4-1.04.46-1.4 1.1-.8l1.1 1.4 3.4-3.8c.6-.63 1.6-.27 1.2.7l-4 4.6c-.43.5-.8.4-1.1.1z'/></svg>"), url("data:image/svg+xml,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 12 12' width='12' height='12' fill='none' stroke='#{$form-feedback-icon-invalid-color}'><circle cx='6' cy='6' r='4.5'/><path stroke-linejoin='round' d='M5.8 3.6h.4L6 6.5z'/><circle cx='6' cy='8.2' r='.6' fill='#{$form-feedback-icon-invalid-color}' stroke='none'/></svg>"), function (t) {
    return {
      valid: {
        color: t['form-feedback-valid-color'],
        icon: t['form-feedback-icon-valid']
      },
      invalid: {
        color: t['form-feedback-invalid-color'],
        icon: t['form-feedback-icon-invalid']
      }
    };
  }, url("data:image/svg+xml,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 30 30'><path stroke='#{$navbar-dark-color}' stroke-linecap='round' stroke-miterlimit='10' stroke-width='2' d='M4 7h22M4 15h22M4 23h22'/></svg>"), url("data:image/svg+xml,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 30 30'><path stroke='#{$navbar-light-color}' stroke-linecap='round' stroke-miterlimit='10' stroke-width='2' d='M4 7h22M4 15h22M4 23h22'/></svg>"), subtract(function (t) {
    return t['dropdown-border-radius'];
  }, function (t) {
    return t['dropdown-border-width'];
  }), shadeColor(0.1, function (t) {
    return t['dropdown-link-color'];
  }), subtract(function (t) {
    return t['card-border-radius'];
  }, function (t) {
    return t['card-border-width'];
  }), subtract(function (t) {
    return t['popover-border-radius'];
  }, function (t) {
    return t['popover-border-width'];
  }), shadeColor(0.06, function (t) {
    return t['popover-bg'];
  }), subtract(function (t) {
    return t['modal-content-border-radius'];
  }, function (t) {
    return t['modal-content-border-width'];
  }), url("data:image/svg+xml,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 16 16' fill='#{$btn-close-color}'><path d='M.293.293a1 1 0 0 1 1.414 0L8 6.586 14.293.293a1 1 0 1 1 1.414 1.414L9.414 8l6.293 6.293a1 1 0 0 1-1.414 1.414L8 9.414l-6.293 6.293a1 1 0 0 1-1.414-1.414L6.586 8 .293 1.707a1 1 0 0 1 0-1.414z'/></svg>"));

  var extractVariables = function extractVariables(source) {
    var baseVariables = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
    var options = arguments.length > 2 ? arguments[2] : undefined;

    if (typeof source !== 'function') {
      // TODO: Resolve t => ... functions on source object.
      return _objectSpread2(_objectSpread2({}, source), baseVariables);
    }

    var result = transform(source.ast.children, baseVariables, options);
    return _objectSpread2(_objectSpread2({}, result[0].variables), baseVariables);
  };

  function makeTheme(customVariables) {
    var customTheme = extractVariables(customVariables);
    return extractVariables(variables, customTheme, {
      preferTheme: true
    });
  }

  var activeKey = null;
  var themes = {};
  var sheets = [];

  var createSheet = function createSheet(sheet) {
    var theme = themes[activeKey];
    var statelessSource = {};
    var statefulSource = {}; // Apply theme to themeable styles.

    Object.entries(sheet.source).forEach(function (_ref) {
      var _ref2 = _slicedToArray(_ref, 2),
          key = _ref2[0],
          style = _ref2[1];

      // Resolve theme.
      var value = typeof style === 'function' ? style(theme, activeKey) : style;

      if (typeof value === 'function') {
        statefulSource[key] = value;
      } else {
        statelessSource[key] = value;
      }
    }); // Wrap stateful and stateless in a proxy, so that we can update the styles on theme change.
    // For using Object.assign below we need some additional methods on the proxy that are mentioned here:
    // https://stackoverflow.com/questions/43185453/object-assign-and-proxies

    return new Proxy({
      keys: Object.keys(sheet.source),
      stateless: reactNative.StyleSheet.create(statelessSource),
      stateful: statefulSource
    }, {
      get: function get(target, prop) {
        return target.stateless[prop] || target.stateful[prop] || undefined;
      },
      ownKeys: function ownKeys(target) {
        return target.keys;
      },
      getOwnPropertyDescriptor: function getOwnPropertyDescriptor(target, name) {
        var proxy = this;
        return {
          get value() {
            return proxy.get(target, name);
          },

          configurable: true,
          enumerable: true
        };
      },
      has: function has(target, name) {
        return target.keys.indexOf(name) >= 0;
      }
    });
  };

  var absoluteFill = reactNative.StyleSheet.absoluteFill,
      absoluteFillObject = reactNative.StyleSheet.absoluteFillObject,
      hairlineWidth = reactNative.StyleSheet.hairlineWidth;
  var StyleSheet = {
    create: function create(source) {
      // Create sheet object.
      var sheet = {
        source: source,
        cache: {},
        active: null
      }; // If initialized, set active sheet based by active theme.

      if (activeKey !== null) {
        sheet.cache[activeKey] = createSheet(sheet);
        sheet.active = sheet.cache[activeKey];
      } else {
        // Placeholder until build method is called.
        sheet.active = {};
      }

      sheets.push(sheet);
      return sheet.active;
    },
    build: function build(theme) {
      var key = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'default';

      if (!themes[key]) {
        themes[key] = theme;
      } // If theme is already set, we don't need to do anything.


      if (key === activeKey) {
        return;
      } // Set new theme active.


      activeKey = key; // Update style sheets.

      sheets.forEach(function (_, i) {
        // If there is no result for the active theme, we'll create a themed
        // style sheet.
        if (!sheets[i].cache[key]) {
          sheets[i].cache[key] = createSheet(sheets[i]);
        } // Assign active object, which is also returned from the create
        // function, so style changes will be applied on next rerender in
        // the components as well.


        Object.assign(sheets[i].active, sheets[i].cache[key]);
      });
    },
    value: function value(key) {
      if (activeKey === null) {
        throw new Error('Use of StyleSheet.value() before initializing.');
      }

      var theme = themes[activeKey];
      return theme[key];
    },
    // Add default styles from StyleSheet
    absoluteFill: absoluteFill,
    absoluteFillObject: absoluteFillObject,
    hairlineWidth: hairlineWidth
  };

  var Context = /*#__PURE__*/React__default["default"].createContext();
  Context.displayName = 'BootstrapRNContext';

  /** @license React v16.13.1
   * react-is.development.js
   *
   * Copyright (c) Facebook, Inc. and its affiliates.
   *
   * This source code is licensed under the MIT license found in the
   * LICENSE file in the root directory of this source tree.
   */

  var reactIs_development = createCommonjsModule(function (module, exports) {



  {
    (function() {

  // The Symbol used to tag the ReactElement-like types. If there is no native Symbol
  // nor polyfill, then a plain number is used for performance.
  var hasSymbol = typeof Symbol === 'function' && Symbol.for;
  var REACT_ELEMENT_TYPE = hasSymbol ? Symbol.for('react.element') : 0xeac7;
  var REACT_PORTAL_TYPE = hasSymbol ? Symbol.for('react.portal') : 0xeaca;
  var REACT_FRAGMENT_TYPE = hasSymbol ? Symbol.for('react.fragment') : 0xeacb;
  var REACT_STRICT_MODE_TYPE = hasSymbol ? Symbol.for('react.strict_mode') : 0xeacc;
  var REACT_PROFILER_TYPE = hasSymbol ? Symbol.for('react.profiler') : 0xead2;
  var REACT_PROVIDER_TYPE = hasSymbol ? Symbol.for('react.provider') : 0xeacd;
  var REACT_CONTEXT_TYPE = hasSymbol ? Symbol.for('react.context') : 0xeace; // TODO: We don't use AsyncMode or ConcurrentMode anymore. They were temporary
  // (unstable) APIs that have been removed. Can we remove the symbols?

  var REACT_ASYNC_MODE_TYPE = hasSymbol ? Symbol.for('react.async_mode') : 0xeacf;
  var REACT_CONCURRENT_MODE_TYPE = hasSymbol ? Symbol.for('react.concurrent_mode') : 0xeacf;
  var REACT_FORWARD_REF_TYPE = hasSymbol ? Symbol.for('react.forward_ref') : 0xead0;
  var REACT_SUSPENSE_TYPE = hasSymbol ? Symbol.for('react.suspense') : 0xead1;
  var REACT_SUSPENSE_LIST_TYPE = hasSymbol ? Symbol.for('react.suspense_list') : 0xead8;
  var REACT_MEMO_TYPE = hasSymbol ? Symbol.for('react.memo') : 0xead3;
  var REACT_LAZY_TYPE = hasSymbol ? Symbol.for('react.lazy') : 0xead4;
  var REACT_BLOCK_TYPE = hasSymbol ? Symbol.for('react.block') : 0xead9;
  var REACT_FUNDAMENTAL_TYPE = hasSymbol ? Symbol.for('react.fundamental') : 0xead5;
  var REACT_RESPONDER_TYPE = hasSymbol ? Symbol.for('react.responder') : 0xead6;
  var REACT_SCOPE_TYPE = hasSymbol ? Symbol.for('react.scope') : 0xead7;

  function isValidElementType(type) {
    return typeof type === 'string' || typeof type === 'function' || // Note: its typeof might be other than 'symbol' or 'number' if it's a polyfill.
    type === REACT_FRAGMENT_TYPE || type === REACT_CONCURRENT_MODE_TYPE || type === REACT_PROFILER_TYPE || type === REACT_STRICT_MODE_TYPE || type === REACT_SUSPENSE_TYPE || type === REACT_SUSPENSE_LIST_TYPE || typeof type === 'object' && type !== null && (type.$$typeof === REACT_LAZY_TYPE || type.$$typeof === REACT_MEMO_TYPE || type.$$typeof === REACT_PROVIDER_TYPE || type.$$typeof === REACT_CONTEXT_TYPE || type.$$typeof === REACT_FORWARD_REF_TYPE || type.$$typeof === REACT_FUNDAMENTAL_TYPE || type.$$typeof === REACT_RESPONDER_TYPE || type.$$typeof === REACT_SCOPE_TYPE || type.$$typeof === REACT_BLOCK_TYPE);
  }

  function typeOf(object) {
    if (typeof object === 'object' && object !== null) {
      var $$typeof = object.$$typeof;

      switch ($$typeof) {
        case REACT_ELEMENT_TYPE:
          var type = object.type;

          switch (type) {
            case REACT_ASYNC_MODE_TYPE:
            case REACT_CONCURRENT_MODE_TYPE:
            case REACT_FRAGMENT_TYPE:
            case REACT_PROFILER_TYPE:
            case REACT_STRICT_MODE_TYPE:
            case REACT_SUSPENSE_TYPE:
              return type;

            default:
              var $$typeofType = type && type.$$typeof;

              switch ($$typeofType) {
                case REACT_CONTEXT_TYPE:
                case REACT_FORWARD_REF_TYPE:
                case REACT_LAZY_TYPE:
                case REACT_MEMO_TYPE:
                case REACT_PROVIDER_TYPE:
                  return $$typeofType;

                default:
                  return $$typeof;
              }

          }

        case REACT_PORTAL_TYPE:
          return $$typeof;
      }
    }

    return undefined;
  } // AsyncMode is deprecated along with isAsyncMode

  var AsyncMode = REACT_ASYNC_MODE_TYPE;
  var ConcurrentMode = REACT_CONCURRENT_MODE_TYPE;
  var ContextConsumer = REACT_CONTEXT_TYPE;
  var ContextProvider = REACT_PROVIDER_TYPE;
  var Element = REACT_ELEMENT_TYPE;
  var ForwardRef = REACT_FORWARD_REF_TYPE;
  var Fragment = REACT_FRAGMENT_TYPE;
  var Lazy = REACT_LAZY_TYPE;
  var Memo = REACT_MEMO_TYPE;
  var Portal = REACT_PORTAL_TYPE;
  var Profiler = REACT_PROFILER_TYPE;
  var StrictMode = REACT_STRICT_MODE_TYPE;
  var Suspense = REACT_SUSPENSE_TYPE;
  var hasWarnedAboutDeprecatedIsAsyncMode = false; // AsyncMode should be deprecated

  function isAsyncMode(object) {
    {
      if (!hasWarnedAboutDeprecatedIsAsyncMode) {
        hasWarnedAboutDeprecatedIsAsyncMode = true; // Using console['warn'] to evade Babel and ESLint

        console['warn']('The ReactIs.isAsyncMode() alias has been deprecated, ' + 'and will be removed in React 17+. Update your code to use ' + 'ReactIs.isConcurrentMode() instead. It has the exact same API.');
      }
    }

    return isConcurrentMode(object) || typeOf(object) === REACT_ASYNC_MODE_TYPE;
  }
  function isConcurrentMode(object) {
    return typeOf(object) === REACT_CONCURRENT_MODE_TYPE;
  }
  function isContextConsumer(object) {
    return typeOf(object) === REACT_CONTEXT_TYPE;
  }
  function isContextProvider(object) {
    return typeOf(object) === REACT_PROVIDER_TYPE;
  }
  function isElement(object) {
    return typeof object === 'object' && object !== null && object.$$typeof === REACT_ELEMENT_TYPE;
  }
  function isForwardRef(object) {
    return typeOf(object) === REACT_FORWARD_REF_TYPE;
  }
  function isFragment(object) {
    return typeOf(object) === REACT_FRAGMENT_TYPE;
  }
  function isLazy(object) {
    return typeOf(object) === REACT_LAZY_TYPE;
  }
  function isMemo(object) {
    return typeOf(object) === REACT_MEMO_TYPE;
  }
  function isPortal(object) {
    return typeOf(object) === REACT_PORTAL_TYPE;
  }
  function isProfiler(object) {
    return typeOf(object) === REACT_PROFILER_TYPE;
  }
  function isStrictMode(object) {
    return typeOf(object) === REACT_STRICT_MODE_TYPE;
  }
  function isSuspense(object) {
    return typeOf(object) === REACT_SUSPENSE_TYPE;
  }

  exports.AsyncMode = AsyncMode;
  exports.ConcurrentMode = ConcurrentMode;
  exports.ContextConsumer = ContextConsumer;
  exports.ContextProvider = ContextProvider;
  exports.Element = Element;
  exports.ForwardRef = ForwardRef;
  exports.Fragment = Fragment;
  exports.Lazy = Lazy;
  exports.Memo = Memo;
  exports.Portal = Portal;
  exports.Profiler = Profiler;
  exports.StrictMode = StrictMode;
  exports.Suspense = Suspense;
  exports.isAsyncMode = isAsyncMode;
  exports.isConcurrentMode = isConcurrentMode;
  exports.isContextConsumer = isContextConsumer;
  exports.isContextProvider = isContextProvider;
  exports.isElement = isElement;
  exports.isForwardRef = isForwardRef;
  exports.isFragment = isFragment;
  exports.isLazy = isLazy;
  exports.isMemo = isMemo;
  exports.isPortal = isPortal;
  exports.isProfiler = isProfiler;
  exports.isStrictMode = isStrictMode;
  exports.isSuspense = isSuspense;
  exports.isValidElementType = isValidElementType;
  exports.typeOf = typeOf;
    })();
  }
  });

  var reactIs = createCommonjsModule(function (module) {

  {
    module.exports = reactIs_development;
  }
  });

  /*
  object-assign
  (c) Sindre Sorhus
  @license MIT
  */
  /* eslint-disable no-unused-vars */
  var getOwnPropertySymbols = Object.getOwnPropertySymbols;
  var hasOwnProperty = Object.prototype.hasOwnProperty;
  var propIsEnumerable = Object.prototype.propertyIsEnumerable;

  function toObject(val) {
  	if (val === null || val === undefined) {
  		throw new TypeError('Object.assign cannot be called with null or undefined');
  	}

  	return Object(val);
  }

  function shouldUseNative() {
  	try {
  		if (!Object.assign) {
  			return false;
  		}

  		// Detect buggy property enumeration order in older V8 versions.

  		// https://bugs.chromium.org/p/v8/issues/detail?id=4118
  		var test1 = new String('abc');  // eslint-disable-line no-new-wrappers
  		test1[5] = 'de';
  		if (Object.getOwnPropertyNames(test1)[0] === '5') {
  			return false;
  		}

  		// https://bugs.chromium.org/p/v8/issues/detail?id=3056
  		var test2 = {};
  		for (var i = 0; i < 10; i++) {
  			test2['_' + String.fromCharCode(i)] = i;
  		}
  		var order2 = Object.getOwnPropertyNames(test2).map(function (n) {
  			return test2[n];
  		});
  		if (order2.join('') !== '0123456789') {
  			return false;
  		}

  		// https://bugs.chromium.org/p/v8/issues/detail?id=3056
  		var test3 = {};
  		'abcdefghijklmnopqrst'.split('').forEach(function (letter) {
  			test3[letter] = letter;
  		});
  		if (Object.keys(Object.assign({}, test3)).join('') !==
  				'abcdefghijklmnopqrst') {
  			return false;
  		}

  		return true;
  	} catch (err) {
  		// We don't expect any of the above to throw, but better to be safe.
  		return false;
  	}
  }

  var objectAssign = shouldUseNative() ? Object.assign : function (target, source) {
  	var from;
  	var to = toObject(target);
  	var symbols;

  	for (var s = 1; s < arguments.length; s++) {
  		from = Object(arguments[s]);

  		for (var key in from) {
  			if (hasOwnProperty.call(from, key)) {
  				to[key] = from[key];
  			}
  		}

  		if (getOwnPropertySymbols) {
  			symbols = getOwnPropertySymbols(from);
  			for (var i = 0; i < symbols.length; i++) {
  				if (propIsEnumerable.call(from, symbols[i])) {
  					to[symbols[i]] = from[symbols[i]];
  				}
  			}
  		}
  	}

  	return to;
  };

  /**
   * Copyright (c) 2013-present, Facebook, Inc.
   *
   * This source code is licensed under the MIT license found in the
   * LICENSE file in the root directory of this source tree.
   */

  var ReactPropTypesSecret$2 = 'SECRET_DO_NOT_PASS_THIS_OR_YOU_WILL_BE_FIRED';

  var ReactPropTypesSecret_1 = ReactPropTypesSecret$2;

  var has$2 = Function.call.bind(Object.prototype.hasOwnProperty);

  var ReactPropTypesSecret$1 = ReactPropTypesSecret_1;

  var has$1 = has$2;

  /**
   * Copyright (c) 2013-present, Facebook, Inc.
   *
   * This source code is licensed under the MIT license found in the
   * LICENSE file in the root directory of this source tree.
   */

  var printWarning$1 = function() {};

  {
    var ReactPropTypesSecret = ReactPropTypesSecret$1;
    var loggedTypeFailures = {};
    var has = has$1;

    printWarning$1 = function(text) {
      var message = 'Warning: ' + text;
      if (typeof console !== 'undefined') {
        console.error(message);
      }
      try {
        // --- Welcome to debugging React ---
        // This error was thrown as a convenience so that you can use this stack
        // to find the callsite that caused this warning to fire.
        throw new Error(message);
      } catch (x) { /**/ }
    };
  }

  /**
   * Assert that the values match with the type specs.
   * Error messages are memorized and will only be shown once.
   *
   * @param {object} typeSpecs Map of name to a ReactPropType
   * @param {object} values Runtime values that need to be type-checked
   * @param {string} location e.g. "prop", "context", "child context"
   * @param {string} componentName Name of the component for error messages.
   * @param {?Function} getStack Returns the component stack.
   * @private
   */
  function checkPropTypes$1(typeSpecs, values, location, componentName, getStack) {
    {
      for (var typeSpecName in typeSpecs) {
        if (has(typeSpecs, typeSpecName)) {
          var error;
          // Prop type validation may throw. In case they do, we don't want to
          // fail the render phase where it didn't fail before. So we log it.
          // After these have been cleaned up, we'll let them throw.
          try {
            // This is intentionally an invariant that gets caught. It's the same
            // behavior as without this statement except with a better message.
            if (typeof typeSpecs[typeSpecName] !== 'function') {
              var err = Error(
                (componentName || 'React class') + ': ' + location + ' type `' + typeSpecName + '` is invalid; ' +
                'it must be a function, usually from the `prop-types` package, but received `' + typeof typeSpecs[typeSpecName] + '`.' +
                'This often happens because of typos such as `PropTypes.function` instead of `PropTypes.func`.'
              );
              err.name = 'Invariant Violation';
              throw err;
            }
            error = typeSpecs[typeSpecName](values, typeSpecName, componentName, location, null, ReactPropTypesSecret);
          } catch (ex) {
            error = ex;
          }
          if (error && !(error instanceof Error)) {
            printWarning$1(
              (componentName || 'React class') + ': type specification of ' +
              location + ' `' + typeSpecName + '` is invalid; the type checker ' +
              'function must return `null` or an `Error` but returned a ' + typeof error + '. ' +
              'You may have forgotten to pass an argument to the type checker ' +
              'creator (arrayOf, instanceOf, objectOf, oneOf, oneOfType, and ' +
              'shape all require an argument).'
            );
          }
          if (error instanceof Error && !(error.message in loggedTypeFailures)) {
            // Only monitor this failure once because there tends to be a lot of the
            // same error.
            loggedTypeFailures[error.message] = true;

            var stack = getStack ? getStack() : '';

            printWarning$1(
              'Failed ' + location + ' type: ' + error.message + (stack != null ? stack : '')
            );
          }
        }
      }
    }
  }

  /**
   * Resets warning cache when testing.
   *
   * @private
   */
  checkPropTypes$1.resetWarningCache = function() {
    {
      loggedTypeFailures = {};
    }
  };

  var checkPropTypes_1 = checkPropTypes$1;

  var checkPropTypes = checkPropTypes_1;

  /**
   * Copyright (c) 2013-present, Facebook, Inc.
   *
   * This source code is licensed under the MIT license found in the
   * LICENSE file in the root directory of this source tree.
   */








  var printWarning = function() {};

  {
    printWarning = function(text) {
      var message = 'Warning: ' + text;
      if (typeof console !== 'undefined') {
        console.error(message);
      }
      try {
        // --- Welcome to debugging React ---
        // This error was thrown as a convenience so that you can use this stack
        // to find the callsite that caused this warning to fire.
        throw new Error(message);
      } catch (x) {}
    };
  }

  function emptyFunctionThatReturnsNull() {
    return null;
  }

  var factoryWithTypeCheckers = function(isValidElement, throwOnDirectAccess) {
    /* global Symbol */
    var ITERATOR_SYMBOL = typeof Symbol === 'function' && Symbol.iterator;
    var FAUX_ITERATOR_SYMBOL = '@@iterator'; // Before Symbol spec.

    /**
     * Returns the iterator method function contained on the iterable object.
     *
     * Be sure to invoke the function with the iterable as context:
     *
     *     var iteratorFn = getIteratorFn(myIterable);
     *     if (iteratorFn) {
     *       var iterator = iteratorFn.call(myIterable);
     *       ...
     *     }
     *
     * @param {?object} maybeIterable
     * @return {?function}
     */
    function getIteratorFn(maybeIterable) {
      var iteratorFn = maybeIterable && (ITERATOR_SYMBOL && maybeIterable[ITERATOR_SYMBOL] || maybeIterable[FAUX_ITERATOR_SYMBOL]);
      if (typeof iteratorFn === 'function') {
        return iteratorFn;
      }
    }

    /**
     * Collection of methods that allow declaration and validation of props that are
     * supplied to React components. Example usage:
     *
     *   var Props = require('ReactPropTypes');
     *   var MyArticle = React.createClass({
     *     propTypes: {
     *       // An optional string prop named "description".
     *       description: Props.string,
     *
     *       // A required enum prop named "category".
     *       category: Props.oneOf(['News','Photos']).isRequired,
     *
     *       // A prop named "dialog" that requires an instance of Dialog.
     *       dialog: Props.instanceOf(Dialog).isRequired
     *     },
     *     render: function() { ... }
     *   });
     *
     * A more formal specification of how these methods are used:
     *
     *   type := array|bool|func|object|number|string|oneOf([...])|instanceOf(...)
     *   decl := ReactPropTypes.{type}(.isRequired)?
     *
     * Each and every declaration produces a function with the same signature. This
     * allows the creation of custom validation functions. For example:
     *
     *  var MyLink = React.createClass({
     *    propTypes: {
     *      // An optional string or URI prop named "href".
     *      href: function(props, propName, componentName) {
     *        var propValue = props[propName];
     *        if (propValue != null && typeof propValue !== 'string' &&
     *            !(propValue instanceof URI)) {
     *          return new Error(
     *            'Expected a string or an URI for ' + propName + ' in ' +
     *            componentName
     *          );
     *        }
     *      }
     *    },
     *    render: function() {...}
     *  });
     *
     * @internal
     */

    var ANONYMOUS = '<<anonymous>>';

    // Important!
    // Keep this list in sync with production version in `./factoryWithThrowingShims.js`.
    var ReactPropTypes = {
      array: createPrimitiveTypeChecker('array'),
      bigint: createPrimitiveTypeChecker('bigint'),
      bool: createPrimitiveTypeChecker('boolean'),
      func: createPrimitiveTypeChecker('function'),
      number: createPrimitiveTypeChecker('number'),
      object: createPrimitiveTypeChecker('object'),
      string: createPrimitiveTypeChecker('string'),
      symbol: createPrimitiveTypeChecker('symbol'),

      any: createAnyTypeChecker(),
      arrayOf: createArrayOfTypeChecker,
      element: createElementTypeChecker(),
      elementType: createElementTypeTypeChecker(),
      instanceOf: createInstanceTypeChecker,
      node: createNodeChecker(),
      objectOf: createObjectOfTypeChecker,
      oneOf: createEnumTypeChecker,
      oneOfType: createUnionTypeChecker,
      shape: createShapeTypeChecker,
      exact: createStrictShapeTypeChecker,
    };

    /**
     * inlined Object.is polyfill to avoid requiring consumers ship their own
     * https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object/is
     */
    /*eslint-disable no-self-compare*/
    function is(x, y) {
      // SameValue algorithm
      if (x === y) {
        // Steps 1-5, 7-10
        // Steps 6.b-6.e: +0 != -0
        return x !== 0 || 1 / x === 1 / y;
      } else {
        // Step 6.a: NaN == NaN
        return x !== x && y !== y;
      }
    }
    /*eslint-enable no-self-compare*/

    /**
     * We use an Error-like object for backward compatibility as people may call
     * PropTypes directly and inspect their output. However, we don't use real
     * Errors anymore. We don't inspect their stack anyway, and creating them
     * is prohibitively expensive if they are created too often, such as what
     * happens in oneOfType() for any type before the one that matched.
     */
    function PropTypeError(message, data) {
      this.message = message;
      this.data = data && typeof data === 'object' ? data: {};
      this.stack = '';
    }
    // Make `instanceof Error` still work for returned errors.
    PropTypeError.prototype = Error.prototype;

    function createChainableTypeChecker(validate) {
      {
        var manualPropTypeCallCache = {};
        var manualPropTypeWarningCount = 0;
      }
      function checkType(isRequired, props, propName, componentName, location, propFullName, secret) {
        componentName = componentName || ANONYMOUS;
        propFullName = propFullName || propName;

        if (secret !== ReactPropTypesSecret$1) {
          if (throwOnDirectAccess) {
            // New behavior only for users of `prop-types` package
            var err = new Error(
              'Calling PropTypes validators directly is not supported by the `prop-types` package. ' +
              'Use `PropTypes.checkPropTypes()` to call them. ' +
              'Read more at http://fb.me/use-check-prop-types'
            );
            err.name = 'Invariant Violation';
            throw err;
          } else if (typeof console !== 'undefined') {
            // Old behavior for people using React.PropTypes
            var cacheKey = componentName + ':' + propName;
            if (
              !manualPropTypeCallCache[cacheKey] &&
              // Avoid spamming the console because they are often not actionable except for lib authors
              manualPropTypeWarningCount < 3
            ) {
              printWarning(
                'You are manually calling a React.PropTypes validation ' +
                'function for the `' + propFullName + '` prop on `' + componentName + '`. This is deprecated ' +
                'and will throw in the standalone `prop-types` package. ' +
                'You may be seeing this warning due to a third-party PropTypes ' +
                'library. See https://fb.me/react-warning-dont-call-proptypes ' + 'for details.'
              );
              manualPropTypeCallCache[cacheKey] = true;
              manualPropTypeWarningCount++;
            }
          }
        }
        if (props[propName] == null) {
          if (isRequired) {
            if (props[propName] === null) {
              return new PropTypeError('The ' + location + ' `' + propFullName + '` is marked as required ' + ('in `' + componentName + '`, but its value is `null`.'));
            }
            return new PropTypeError('The ' + location + ' `' + propFullName + '` is marked as required in ' + ('`' + componentName + '`, but its value is `undefined`.'));
          }
          return null;
        } else {
          return validate(props, propName, componentName, location, propFullName);
        }
      }

      var chainedCheckType = checkType.bind(null, false);
      chainedCheckType.isRequired = checkType.bind(null, true);

      return chainedCheckType;
    }

    function createPrimitiveTypeChecker(expectedType) {
      function validate(props, propName, componentName, location, propFullName, secret) {
        var propValue = props[propName];
        var propType = getPropType(propValue);
        if (propType !== expectedType) {
          // `propValue` being instance of, say, date/regexp, pass the 'object'
          // check, but we can offer a more precise error message here rather than
          // 'of type `object`'.
          var preciseType = getPreciseType(propValue);

          return new PropTypeError(
            'Invalid ' + location + ' `' + propFullName + '` of type ' + ('`' + preciseType + '` supplied to `' + componentName + '`, expected ') + ('`' + expectedType + '`.'),
            {expectedType: expectedType}
          );
        }
        return null;
      }
      return createChainableTypeChecker(validate);
    }

    function createAnyTypeChecker() {
      return createChainableTypeChecker(emptyFunctionThatReturnsNull);
    }

    function createArrayOfTypeChecker(typeChecker) {
      function validate(props, propName, componentName, location, propFullName) {
        if (typeof typeChecker !== 'function') {
          return new PropTypeError('Property `' + propFullName + '` of component `' + componentName + '` has invalid PropType notation inside arrayOf.');
        }
        var propValue = props[propName];
        if (!Array.isArray(propValue)) {
          var propType = getPropType(propValue);
          return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type ' + ('`' + propType + '` supplied to `' + componentName + '`, expected an array.'));
        }
        for (var i = 0; i < propValue.length; i++) {
          var error = typeChecker(propValue, i, componentName, location, propFullName + '[' + i + ']', ReactPropTypesSecret$1);
          if (error instanceof Error) {
            return error;
          }
        }
        return null;
      }
      return createChainableTypeChecker(validate);
    }

    function createElementTypeChecker() {
      function validate(props, propName, componentName, location, propFullName) {
        var propValue = props[propName];
        if (!isValidElement(propValue)) {
          var propType = getPropType(propValue);
          return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type ' + ('`' + propType + '` supplied to `' + componentName + '`, expected a single ReactElement.'));
        }
        return null;
      }
      return createChainableTypeChecker(validate);
    }

    function createElementTypeTypeChecker() {
      function validate(props, propName, componentName, location, propFullName) {
        var propValue = props[propName];
        if (!reactIs.isValidElementType(propValue)) {
          var propType = getPropType(propValue);
          return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type ' + ('`' + propType + '` supplied to `' + componentName + '`, expected a single ReactElement type.'));
        }
        return null;
      }
      return createChainableTypeChecker(validate);
    }

    function createInstanceTypeChecker(expectedClass) {
      function validate(props, propName, componentName, location, propFullName) {
        if (!(props[propName] instanceof expectedClass)) {
          var expectedClassName = expectedClass.name || ANONYMOUS;
          var actualClassName = getClassName(props[propName]);
          return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type ' + ('`' + actualClassName + '` supplied to `' + componentName + '`, expected ') + ('instance of `' + expectedClassName + '`.'));
        }
        return null;
      }
      return createChainableTypeChecker(validate);
    }

    function createEnumTypeChecker(expectedValues) {
      if (!Array.isArray(expectedValues)) {
        {
          if (arguments.length > 1) {
            printWarning(
              'Invalid arguments supplied to oneOf, expected an array, got ' + arguments.length + ' arguments. ' +
              'A common mistake is to write oneOf(x, y, z) instead of oneOf([x, y, z]).'
            );
          } else {
            printWarning('Invalid argument supplied to oneOf, expected an array.');
          }
        }
        return emptyFunctionThatReturnsNull;
      }

      function validate(props, propName, componentName, location, propFullName) {
        var propValue = props[propName];
        for (var i = 0; i < expectedValues.length; i++) {
          if (is(propValue, expectedValues[i])) {
            return null;
          }
        }

        var valuesString = JSON.stringify(expectedValues, function replacer(key, value) {
          var type = getPreciseType(value);
          if (type === 'symbol') {
            return String(value);
          }
          return value;
        });
        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of value `' + String(propValue) + '` ' + ('supplied to `' + componentName + '`, expected one of ' + valuesString + '.'));
      }
      return createChainableTypeChecker(validate);
    }

    function createObjectOfTypeChecker(typeChecker) {
      function validate(props, propName, componentName, location, propFullName) {
        if (typeof typeChecker !== 'function') {
          return new PropTypeError('Property `' + propFullName + '` of component `' + componentName + '` has invalid PropType notation inside objectOf.');
        }
        var propValue = props[propName];
        var propType = getPropType(propValue);
        if (propType !== 'object') {
          return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type ' + ('`' + propType + '` supplied to `' + componentName + '`, expected an object.'));
        }
        for (var key in propValue) {
          if (has$1(propValue, key)) {
            var error = typeChecker(propValue, key, componentName, location, propFullName + '.' + key, ReactPropTypesSecret$1);
            if (error instanceof Error) {
              return error;
            }
          }
        }
        return null;
      }
      return createChainableTypeChecker(validate);
    }

    function createUnionTypeChecker(arrayOfTypeCheckers) {
      if (!Array.isArray(arrayOfTypeCheckers)) {
        printWarning('Invalid argument supplied to oneOfType, expected an instance of array.') ;
        return emptyFunctionThatReturnsNull;
      }

      for (var i = 0; i < arrayOfTypeCheckers.length; i++) {
        var checker = arrayOfTypeCheckers[i];
        if (typeof checker !== 'function') {
          printWarning(
            'Invalid argument supplied to oneOfType. Expected an array of check functions, but ' +
            'received ' + getPostfixForTypeWarning(checker) + ' at index ' + i + '.'
          );
          return emptyFunctionThatReturnsNull;
        }
      }

      function validate(props, propName, componentName, location, propFullName) {
        var expectedTypes = [];
        for (var i = 0; i < arrayOfTypeCheckers.length; i++) {
          var checker = arrayOfTypeCheckers[i];
          var checkerResult = checker(props, propName, componentName, location, propFullName, ReactPropTypesSecret$1);
          if (checkerResult == null) {
            return null;
          }
          if (checkerResult.data && has$1(checkerResult.data, 'expectedType')) {
            expectedTypes.push(checkerResult.data.expectedType);
          }
        }
        var expectedTypesMessage = (expectedTypes.length > 0) ? ', expected one of type [' + expectedTypes.join(', ') + ']': '';
        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` supplied to ' + ('`' + componentName + '`' + expectedTypesMessage + '.'));
      }
      return createChainableTypeChecker(validate);
    }

    function createNodeChecker() {
      function validate(props, propName, componentName, location, propFullName) {
        if (!isNode(props[propName])) {
          return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` supplied to ' + ('`' + componentName + '`, expected a ReactNode.'));
        }
        return null;
      }
      return createChainableTypeChecker(validate);
    }

    function invalidValidatorError(componentName, location, propFullName, key, type) {
      return new PropTypeError(
        (componentName || 'React class') + ': ' + location + ' type `' + propFullName + '.' + key + '` is invalid; ' +
        'it must be a function, usually from the `prop-types` package, but received `' + type + '`.'
      );
    }

    function createShapeTypeChecker(shapeTypes) {
      function validate(props, propName, componentName, location, propFullName) {
        var propValue = props[propName];
        var propType = getPropType(propValue);
        if (propType !== 'object') {
          return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type `' + propType + '` ' + ('supplied to `' + componentName + '`, expected `object`.'));
        }
        for (var key in shapeTypes) {
          var checker = shapeTypes[key];
          if (typeof checker !== 'function') {
            return invalidValidatorError(componentName, location, propFullName, key, getPreciseType(checker));
          }
          var error = checker(propValue, key, componentName, location, propFullName + '.' + key, ReactPropTypesSecret$1);
          if (error) {
            return error;
          }
        }
        return null;
      }
      return createChainableTypeChecker(validate);
    }

    function createStrictShapeTypeChecker(shapeTypes) {
      function validate(props, propName, componentName, location, propFullName) {
        var propValue = props[propName];
        var propType = getPropType(propValue);
        if (propType !== 'object') {
          return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type `' + propType + '` ' + ('supplied to `' + componentName + '`, expected `object`.'));
        }
        // We need to check all keys in case some are required but missing from props.
        var allKeys = objectAssign({}, props[propName], shapeTypes);
        for (var key in allKeys) {
          var checker = shapeTypes[key];
          if (has$1(shapeTypes, key) && typeof checker !== 'function') {
            return invalidValidatorError(componentName, location, propFullName, key, getPreciseType(checker));
          }
          if (!checker) {
            return new PropTypeError(
              'Invalid ' + location + ' `' + propFullName + '` key `' + key + '` supplied to `' + componentName + '`.' +
              '\nBad object: ' + JSON.stringify(props[propName], null, '  ') +
              '\nValid keys: ' + JSON.stringify(Object.keys(shapeTypes), null, '  ')
            );
          }
          var error = checker(propValue, key, componentName, location, propFullName + '.' + key, ReactPropTypesSecret$1);
          if (error) {
            return error;
          }
        }
        return null;
      }

      return createChainableTypeChecker(validate);
    }

    function isNode(propValue) {
      switch (typeof propValue) {
        case 'number':
        case 'string':
        case 'undefined':
          return true;
        case 'boolean':
          return !propValue;
        case 'object':
          if (Array.isArray(propValue)) {
            return propValue.every(isNode);
          }
          if (propValue === null || isValidElement(propValue)) {
            return true;
          }

          var iteratorFn = getIteratorFn(propValue);
          if (iteratorFn) {
            var iterator = iteratorFn.call(propValue);
            var step;
            if (iteratorFn !== propValue.entries) {
              while (!(step = iterator.next()).done) {
                if (!isNode(step.value)) {
                  return false;
                }
              }
            } else {
              // Iterator will provide entry [k,v] tuples rather than values.
              while (!(step = iterator.next()).done) {
                var entry = step.value;
                if (entry) {
                  if (!isNode(entry[1])) {
                    return false;
                  }
                }
              }
            }
          } else {
            return false;
          }

          return true;
        default:
          return false;
      }
    }

    function isSymbol(propType, propValue) {
      // Native Symbol.
      if (propType === 'symbol') {
        return true;
      }

      // falsy value can't be a Symbol
      if (!propValue) {
        return false;
      }

      // 19.4.3.5 Symbol.prototype[@@toStringTag] === 'Symbol'
      if (propValue['@@toStringTag'] === 'Symbol') {
        return true;
      }

      // Fallback for non-spec compliant Symbols which are polyfilled.
      if (typeof Symbol === 'function' && propValue instanceof Symbol) {
        return true;
      }

      return false;
    }

    // Equivalent of `typeof` but with special handling for array and regexp.
    function getPropType(propValue) {
      var propType = typeof propValue;
      if (Array.isArray(propValue)) {
        return 'array';
      }
      if (propValue instanceof RegExp) {
        // Old webkits (at least until Android 4.0) return 'function' rather than
        // 'object' for typeof a RegExp. We'll normalize this here so that /bla/
        // passes PropTypes.object.
        return 'object';
      }
      if (isSymbol(propType, propValue)) {
        return 'symbol';
      }
      return propType;
    }

    // This handles more types than `getPropType`. Only used for error messages.
    // See `createPrimitiveTypeChecker`.
    function getPreciseType(propValue) {
      if (typeof propValue === 'undefined' || propValue === null) {
        return '' + propValue;
      }
      var propType = getPropType(propValue);
      if (propType === 'object') {
        if (propValue instanceof Date) {
          return 'date';
        } else if (propValue instanceof RegExp) {
          return 'regexp';
        }
      }
      return propType;
    }

    // Returns a string that is postfixed to a warning about an invalid type.
    // For example, "undefined" or "of type array"
    function getPostfixForTypeWarning(value) {
      var type = getPreciseType(value);
      switch (type) {
        case 'array':
        case 'object':
          return 'an ' + type;
        case 'boolean':
        case 'date':
        case 'regexp':
          return 'a ' + type;
        default:
          return type;
      }
    }

    // Returns class name of the object, if any.
    function getClassName(propValue) {
      if (!propValue.constructor || !propValue.constructor.name) {
        return ANONYMOUS;
      }
      return propValue.constructor.name;
    }

    ReactPropTypes.checkPropTypes = checkPropTypes;
    ReactPropTypes.resetWarningCache = checkPropTypes.resetWarningCache;
    ReactPropTypes.PropTypes = ReactPropTypes;

    return ReactPropTypes;
  };

  var require$$1 = factoryWithTypeCheckers;

  /**
   * Copyright (c) 2013-present, Facebook, Inc.
   *
   * This source code is licensed under the MIT license found in the
   * LICENSE file in the root directory of this source tree.
   */

  var propTypes$1A = createCommonjsModule(function (module) {
  {
    var ReactIs = reactIs;

    // By explicitly using `prop-types` you are opting into new development behavior.
    // http://fb.me/prop-types-in-prod
    var throwOnDirectAccess = true;
    module.exports = require$$1(ReactIs.isElement, throwOnDirectAccess);
  }
  });

  var PropTypes = propTypes$1A;

  function useViewport(initialViewport) {
    var _useState = React.useState(initialViewport),
        _useState2 = _slicedToArray(_useState, 2),
        viewport = _useState2[0],
        setViewport = _useState2[1];

    var breakpoints = StyleSheet.value('grid-breakpoints');

    var calculateViewport = function calculateViewport(width) {
      if (width < breakpoints.sm) {
        return 'xs';
      }

      if (width < breakpoints.md) {
        return 'sm';
      }

      if (width < breakpoints.lg) {
        return 'md';
      }

      if (width < breakpoints.xl) {
        return 'lg';
      }

      return 'xl';
    };

    var handleChange = function handleChange(dimensions) {
      var nextViewport = calculateViewport(dimensions.window.width);

      if (viewport !== nextViewport) {
        setViewport(nextViewport);
      }
    }; // Initially determine viewport after mounting.


    React.useEffect(function () {
      handleChange({
        window: reactNative.Dimensions.get('window')
      });
    }, []);
    React.useEffect(function () {
      var subscription = reactNative.Dimensions.addEventListener('change', handleChange);
      return function () {
        subscription.remove();
      };
    }, [viewport]);
    return viewport;
  }

  var propTypes$1z = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types,
    utilities: PropTypes.object,
    // eslint-disable-next-line react/forbid-prop-types,
    modifiers: PropTypes.object,
    ssrViewport: PropTypes.string
  };

  function Provider(props) {
    var children = props.children,
        _props$utilities = props.utilities,
        utilities = _props$utilities === void 0 ? {} : _props$utilities,
        _props$modifiers = props.modifiers,
        modifiers = _props$modifiers === void 0 ? {} : _props$modifiers,
        ssrViewport = props.ssrViewport;
    var viewport = useViewport(ssrViewport);
    var fixed = React.useMemo(function () {
      return [];
    }, []);
    var counter = React.useRef(0);
    var context = {
      utilities: utilities,
      modifiers: modifiers,
      fixed: fixed,
      getViewport: function getViewport() {
        return viewport;
      },
      addFixedElement: function addFixedElement(ref) {
        fixed.push(ref);
        return {
          remove: function remove() {
            var index = fixed.findIndex(function (item) {
              return item === ref;
            });
            fixed.splice(index, 1);
          }
        };
      },
      generateKey: function generateKey(prefix) {
        counter.current += 1;
        return "ui-".concat(prefix, "-").concat(counter.current);
      }
    };
    return /*#__PURE__*/React__default["default"].createElement(Context.Provider, {
      value: context
    }, /*#__PURE__*/React__default["default"].createElement(OverlayProvider, null, children));
  }

  Provider.propTypes = propTypes$1z;

  var TextStyleContext = /*#__PURE__*/React__default["default"].createContext();
  TextStyleContext.displayName = 'TextStyleContext';

  function useMedia() {
    var context = React.useContext(Context);
    var viewport = context.getViewport();
    var breakpoints = StyleSheet.value('grid-breakpoints');
    var breakpointKeys = Object.keys(breakpoints);
    return {
      up: function up(point) {
        return breakpointKeys.indexOf(viewport) >= breakpointKeys.indexOf(point);
      },
      down: function down(point) {
        return breakpointKeys.indexOf(viewport) <= breakpointKeys.indexOf(point);
      },
      only: function only(point) {
        return viewport === point;
      },
      between: function between(lower, upper) {
        return this.up(lower) && this.down(upper);
      }
    };
  }

  var normalize = function normalize(style) {
    if (!Array.isArray(style)) {
      return [style];
    }

    return style.filter(function (val) {
      return !!val;
    }).reduce(function (res, val) {
      return [].concat(_toConsumableArray(res), _toConsumableArray(normalize(val)));
    }, []);
  };

  function useStyle(style, styleName) {
    var _useContext = React.useContext(Context),
        utilitiesStyles = _useContext.utilities;

    var utilities = React.useMemo(function () {
      if (!styleName) {
        return null;
      }

      var names = styleName.split(' ');
      return names.map(function (name) {
        if (!utilitiesStyles[name]) {
          // eslint-disable-next-line no-console
          console.warn("Unknown utility style \"".concat(name, "\"."));
          return null;
        }

        return utilitiesStyles[name];
      });
    }, [styleName]);
    var styles = normalize(utilities ? [style].concat(_toConsumableArray(utilities)) : style);
    return function (state) {
      var basicStyles = [];
      var interactionStyles = [];
      styles.forEach(function (value) {
        if (value && value.$$typeof === BOOTSTRAP_RN_STYLE) {
          // Style is a bootstrap style that contains basic and interaction styles.
          var _value = value(state),
              _value2 = _slicedToArray(_value, 2),
              resolvedBasicStyles = _value2[0],
              resolvedInteractionStyles = _value2[1];

          basicStyles.push.apply(basicStyles, _toConsumableArray(resolvedBasicStyles));
          interactionStyles.push.apply(interactionStyles, _toConsumableArray(resolvedInteractionStyles));
        } else if (typeof value === 'function') {
          // Style is some other custom function type style.
          basicStyles.push(value(state));
        } else {
          // Style is basic object style.
          basicStyles.push(value);
        }
      }); // Put basic styles first, then interaction styles for hover, focus, pressed.

      return [].concat(basicStyles, interactionStyles);
    };
  }

  var _excluded$1x = ["children", "style", "textStyle", "styleName"];
  var propTypes$1y = {
    children: PropTypes.node,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    styleName: PropTypes.any
  };
  var View = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        textStyle = props.textStyle,
        styleName = props.styleName,
        elementProps = _objectWithoutProperties(props, _excluded$1x);

    var media = useMedia();
    var context = React.useContext(TextStyleContext);
    var resolveStyle = useStyle(style, styleName);
    var resolveTextStyle = useStyle([context && context.style, textStyle]);
    var hasTextStyle = context && context.style || textStyle;
    return /*#__PURE__*/React__default["default"].createElement(reactNative.View, _extends$1({}, elementProps, {
      ref: ref,
      style: resolveStyle({
        media: media
      })
    }), hasTextStyle ? /*#__PURE__*/React__default["default"].createElement(TextStyleContext.Provider, {
      value: {
        style: resolveTextStyle({
          media: media
        }),
        hasAncestor: context && context.hasTextAncestor
      }
    }, children) : children);
  });
  View.displayName = 'View';
  View.propTypes = propTypes$1y;

  var _excluded$1w = ["children", "color", "dismissible", "style", "textStyle"];

  var _templateObject$1c, _templateObject2$U, _templateObject3$s;
  var propTypes$1x = {
    children: PropTypes.node.isRequired,
    color: PropTypes.oneOf(Object.keys(THEME_COLORS)),
    dismissible: PropTypes.bool,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any
  };
  var styles$1e = StyleSheet.create(_objectSpread2(_objectSpread2({
    '.alert': css(_templateObject$1c || (_templateObject$1c = _taggedTemplateLiteral(["\n    position: relative;\n    padding: $alert-padding-y $alert-padding-x;\n    margin-bottom: $alert-margin-bottom;\n    background-color: transparent;\n    border: $alert-border-width solid transparent;\n    border-radius: $alert-border-radius;\n  "])))
  }, each(THEME_COLORS, function (state, value) {
    var _ref;

    return _ref = {}, _defineProperty(_ref, ".alert-".concat(state), css(_templateObject2$U || (_templateObject2$U = _taggedTemplateLiteral(["\n      background-color: ", ";\n      border-color: ", ";\n    "])), shiftColor(function (t) {
      return t['alert-bg-scale'];
    }, value), shiftColor(function (t) {
      return t['alert-border-scale'];
    }, value))), _defineProperty(_ref, ".alert-".concat(state, " --text"), css(_templateObject3$s || (_templateObject3$s = _taggedTemplateLiteral(["\n      color: ", ";\n    "])), shiftColor(function (t) {
      return t['alert-color-scale'];
    }, value))), _ref;
  })), {}, {
    '.alert-dismissible': {// TODO
    }
  }));
  var Alert = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        _props$color = props.color,
        color = _props$color === void 0 ? 'primary' : _props$color,
        _props$dismissible = props.dismissible,
        dismissible = _props$dismissible === void 0 ? false : _props$dismissible,
        style = props.style,
        textStyle = props.textStyle,
        elementProps = _objectWithoutProperties(props, _excluded$1w);

    var classes = getStyles(styles$1e, ['.alert', ".alert-".concat(color), dismissible && '.alert-dismissible']);
    var textClasses = getStyles(styles$1e, [".alert-".concat(color, " --text")]);
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      accessibilityRole: "alert",
      style: [classes, style],
      textStyle: [textClasses, textStyle]
    }), children);
  });
  Alert.displayName = 'Alert';
  Alert.propTypes = propTypes$1x;

  var _excluded$1v = ["color", "bold", "italic", "mark", "small", "style", "styleName"];

  var _templateObject$1b, _templateObject2$T, _templateObject3$r, _templateObject4$n, _templateObject5$k;
  var propTypes$1w = {
    color: PropTypes.oneOf([].concat(_toConsumableArray(Object.keys(THEME_COLORS)), ['muted', 'black-50', 'white-50'])),
    small: PropTypes.bool,
    mark: PropTypes.bool,
    bold: PropTypes.bool,
    italic: PropTypes.bool,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    styleName: PropTypes.any
  };
  var styles$1d = StyleSheet.create({
    text: css(_templateObject$1b || (_templateObject$1b = _taggedTemplateLiteral(["\n    font-family: $font-family-base;\n    font-size: $font-size-base;\n    font-weight: $font-weight-base;\n    line-height: $font-size-base * $line-height-base;\n  "]))),
    strong: css(_templateObject2$T || (_templateObject2$T = _taggedTemplateLiteral(["\n    font-weight: $font-weight-bolder;\n  "]))),
    italic: css(_templateObject3$r || (_templateObject3$r = _taggedTemplateLiteral(["\n    font-style: italic;\n  "]))),
    small: css(_templateObject4$n || (_templateObject4$n = _taggedTemplateLiteral(["\n    font-size: $small-font-size;\n    line-height: $small-font-size * $line-height-base;\n  "]))),
    mark: css(_templateObject5$k || (_templateObject5$k = _taggedTemplateLiteral(["\n    padding: $mark-padding;\n    background-color: $mark-bg;\n  "])))
  });

  var getStyleName = function getStyleName(styleName, color) {
    if (!color) {
      return styleName;
    }

    return styleName ? "text-".concat(color, " ").concat(styleName) : "text-".concat(color);
  };

  var Text = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var color = props.color,
        _props$bold = props.bold,
        bold = _props$bold === void 0 ? false : _props$bold,
        _props$italic = props.italic,
        italic = _props$italic === void 0 ? false : _props$italic,
        _props$mark = props.mark,
        mark = _props$mark === void 0 ? false : _props$mark,
        _props$small = props.small,
        small = _props$small === void 0 ? false : _props$small,
        style = props.style,
        styleName = props.styleName,
        elementProps = _objectWithoutProperties(props, _excluded$1v);

    var media = useMedia();
    var context = React.useContext(TextStyleContext);
    var classes = getStyles(styles$1d, [bold && 'strong', italic && 'italic', small && 'small', mark && 'mark']);
    var resolveStyle = useStyle([// eslint-disable-next-line react/destructuring-assignment
    (!context || !context.hasTextAncestor) && styles$1d.text, // eslint-disable-next-line react/destructuring-assignment
    context && context.style, classes, style], getStyleName(styleName, color));
    var element = /*#__PURE__*/React__default["default"].createElement(reactNative.Text, _extends$1({}, elementProps, {
      ref: ref,
      style: resolveStyle({
        media: media
      })
    })); // eslint-disable-next-line react/destructuring-assignment

    if (context && context.hasTextAncestor && !context.style) {
      return element;
    } // If we are not in an ancestor context yet, we need to set hasTextAncestor
    // to true for nested text components. Furthermore we need to reset the
    // context style, because we only need to apply the style once.


    return /*#__PURE__*/React__default["default"].createElement(TextStyleContext.Provider, {
      value: {
        style: null,
        hasTextAncestor: true
      }
    }, element);
  });
  Text.displayName = 'Text';
  Text.propTypes = propTypes$1w;

  var _excluded$1u = ["children", "style", "textStyle"];

  var _templateObject$1a, _templateObject2$S;
  var propTypes$1v = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any
  };
  var styles$1c = StyleSheet.create({
    '.badge': css(_templateObject$1a || (_templateObject$1a = _taggedTemplateLiteral(["\n    // display: inline-block;\n    padding: $badge-padding-y $badge-padding-x;\n    border-radius: $badge-border-radius;\n    // @include gradient-bg();\n  "]))),
    '.badge --text': css(_templateObject2$S || (_templateObject2$S = _taggedTemplateLiteral(["\n    font-size: $badge-font-size;\n    font-weight: $badge-font-weight;\n    line-height: $badge-font-size * 1;\n    color: $badge-color;\n    text-align: center;\n    // white-space: nowrap;\n    // vertical-align: baseline;\n  "])))
  });
  var Badge = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        textStyle = props.textStyle,
        elementProps = _objectWithoutProperties(props, _excluded$1u);

    var classes = getStyles(styles$1c, ['.badge']);
    var textClasses = getStyles(styles$1c, ['.badge --text']); // composite component

    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style]
    }), /*#__PURE__*/React__default["default"].createElement(Text, {
      style: [textClasses, textStyle]
    }, children));
  });
  Badge.displayName = 'Badge';
  Badge.propTypes = propTypes$1v;

  var ListContext = /*#__PURE__*/React__default["default"].createContext();
  ListContext.displayName = 'ListContext';

  var wrapChildren = function wrapChildren(children, cache) {
    return React__default["default"].Children.map(children, function (child) {
      if (child === null) {
        return null;
      }

      if (child.type === React__default["default"].Fragment) {
        return /*#__PURE__*/React__default["default"].createElement(React__default["default"].Fragment, {
          key: child.key
        }, wrapChildren(child.props.children, cache));
      }

      if ( /*#__PURE__*/React__default["default"].isValidElement(child) && _typeof(child) === 'object') {
        // eslint-disable-next-line no-param-reassign
        cache.count += 1;
        var pos = cache.count;
        return /*#__PURE__*/React__default["default"].createElement(ListContext.Provider, {
          value: {
            nth: function nth(value) {
              return pos === value;
            },

            get first() {
              return pos === 1;
            },

            get last() {
              return pos === cache.count;
            },

            get length() {
              return cache.count;
            }

          },
          key: child.key
        }, child);
      }

      return null;
    });
  };

  function useList(children) {
    return wrapChildren(children, {
      count: 0
    });
  }

  var prefix = 'Invariant failed';
  function invariant(condition, message) {
      if (condition) {
          return;
      }
      var provided = typeof message === 'function' ? message() : message;
      var value = provided ? prefix + ": " + provided : prefix;
      throw new Error(value);
  }

  function useForcedContext(Context) {
    var context = React.useContext(Context);
    invariant(context, "Failed to get context \"".concat(Context.displayName, "\"."));
    return context;
  }

  var _excluded$1t = ["children", "active", "style", "dividerStyle", "textStyle"];

  var _templateObject$19, _templateObject2$R, _templateObject3$q;
  var propTypes$1u = {
    children: PropTypes.node.isRequired,
    active: PropTypes.bool,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    dividerStyle: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any
  };
  var styles$1b = StyleSheet.create({
    '.breadcrumb-item + .breadcrumb-item': css(_templateObject$19 || (_templateObject$19 = _taggedTemplateLiteral(["\n    flex-direction: row; // added for bootstrap-rn\n    padding-left: $breadcrumb-item-padding-x;\n  "]))),
    '.breadcrumb-item + .breadcrumb-item::before': css(_templateObject2$R || (_templateObject2$R = _taggedTemplateLiteral(["\n    // float: left; // Suppress inline spacings and underlining of the separator\n    padding-right: $breadcrumb-item-padding-x;\n    color: $breadcrumb-divider-color;\n  "]))),
    '.breadcrumb-item.active --text': css(_templateObject3$q || (_templateObject3$q = _taggedTemplateLiteral(["\n    color: $breadcrumb-active-color;\n  "])))
  });
  var BreadcrumbItem = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        _props$active = props.active,
        active = _props$active === void 0 ? false : _props$active,
        style = props.style,
        dividerStyle = props.dividerStyle,
        textStyle = props.textStyle,
        elementProps = _objectWithoutProperties(props, _excluded$1t);

    var _useForcedContext = useForcedContext(ListContext),
        first = _useForcedContext.first;

    var classes = getStyles(styles$1b, [!first && '.breadcrumb-item + .breadcrumb-item']);
    var textClasses = getStyles(styles$1b, [active && '.breadcrumb-item.active --text']);
    var dividerClasses = getStyles(styles$1b, ['.breadcrumb-item + .breadcrumb-item::before']);
    var role = reactNative.Platform.OS === 'web' ? 'listitem' : null;
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      accessibilityRole: role
    }, optional(active, {
      accessibilityCurrent: 'page'
    }), {
      style: [classes, style],
      textStyle: [textClasses, textStyle]
    }), !first && /*#__PURE__*/React__default["default"].createElement(Text, {
      selectable: false,
      style: [dividerClasses, dividerStyle]
    }, reactNative.I18nManager.isRTL ? StyleSheet.value('breadcrumb-divider-flipped') : StyleSheet.value('breadcrumb-divider')), children);
  });
  BreadcrumbItem.displayName = 'BreadcrumbItem';
  BreadcrumbItem.propTypes = propTypes$1u;

  var _excluded$1s = ["children", "style", "textStyle"];

  var _templateObject$18, _templateObject2$Q;
  var propTypes$1t = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any
  };
  var styles$1a = StyleSheet.create({
    '.breadcrumb': css(_templateObject$18 || (_templateObject$18 = _taggedTemplateLiteral(["\n    display: flex;\n    flex-direction: row; // added for bootstrap-rn\n    flex-wrap: wrap;\n    padding: $breadcrumb-padding-y $breadcrumb-padding-x;\n    margin-bottom: $breadcrumb-margin-bottom;\n    // list-style: none;\n    background-color: $breadcrumb-bg;\n    border-radius: $breadcrumb-border-radius;\n  "]))),
    '.breadcrumb --text': css(_templateObject2$Q || (_templateObject2$Q = _taggedTemplateLiteral(["\n    font-size: $breadcrumb-font-size;\n    line-height: $breadcrumb-font-size * $line-height-base; // added for bootstrap-rn\n  "])))
  });
  var Breadcrumb = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        textStyle = props.textStyle,
        elementProps = _objectWithoutProperties(props, _excluded$1s);

    var list = useList(children);
    var classes = getStyles(styles$1a, ['.breadcrumb']);
    var textClasses = getStyles(styles$1a, ['.breadcrumb --text']);
    var role = reactNative.Platform.OS === 'web' ? 'list' : null;
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      accessibilityRole: role,
      style: [classes, style],
      textStyle: [textClasses, textStyle]
    }), list);
  });
  Breadcrumb.displayName = 'Breadcrumb';
  Breadcrumb.propTypes = propTypes$1t;
  Breadcrumb.Item = BreadcrumbItem;

  var ButtonGroupContext = /*#__PURE__*/React__default["default"].createContext();
  ButtonGroupContext.displayName = 'ButtonGroupContext';

  var _excluded$1r = ["children", "size", "style"];

  var _templateObject$17;
  var propTypes$1s = {
    children: PropTypes.node.isRequired,
    size: PropTypes.oneOf(['lg', 'sm']),
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$19 = StyleSheet.create({
    '.btn-group': css(_templateObject$17 || (_templateObject$17 = _taggedTemplateLiteral(["\n    flex-direction: row; // added for bootstrap-rn\n    border-radius: $btn-border-radius;\n  "])))
  });
  var ButtonGroup = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        size = props.size,
        style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded$1r);

    var list = useList(children);
    var classes = getStyles(styles$19, ['.btn-group']); // Accessiblity role tabpanel is only supported on web.

    var role = reactNative.Platform.OS === 'web' ? 'group' : null;
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      accessibilityRole: role,
      style: [classes, style]
    }), /*#__PURE__*/React__default["default"].createElement(ButtonGroupContext.Provider, {
      value: {
        size: size
      }
    }, list));
  });
  ButtonGroup.displayName = 'ButtonGroup';
  ButtonGroup.propTypes = propTypes$1s;

  var _excluded$1q = ["children", "style"];

  var _templateObject$16;
  var propTypes$1r = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$18 = StyleSheet.create({
    '.btn-toolbar': css(_templateObject$16 || (_templateObject$16 = _taggedTemplateLiteral(["\n    display: flex;\n    flex-direction: row; // added for bootstrap-rn\n    flex-wrap: wrap;\n    justify-content: flex-start;\n  "])))
  });
  var ButtonToolbar = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded$1q);

    var classes = getStyles(styles$18, ['.btn-toolbar']);
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      accessibilityRole: "toolbar",
      style: [classes, style]
    }), children);
  });
  ButtonToolbar.displayName = 'ButtonToolbar';
  ButtonToolbar.propTypes = propTypes$1r;

  var _excluded$1p = ["ref"];
  function useModifier(name, props, ref) {
    var context = useForcedContext(Context);
    var useModifierHook = context.modifiers[name];

    if (!useModifier) {
      return [props, ref];
    }

    var _useModifierHook = useModifierHook(props),
        modifierRef = _useModifierHook.ref,
        modifierProps = _objectWithoutProperties(_useModifierHook, _excluded$1p);

    return [modifierProps, concatRefs(modifierRef, ref)];
  }

  var _excluded$1o = ["toggle", "dismiss"],
      _excluded2$2 = ["ref"];

  var getActionHook = function getActionHook(toggle, dismiss) {
    if (toggle) {
      return toggle.useToggle || toggle;
    }

    if (dismiss) {
      return dismiss.useDismiss || dismiss;
    }

    return null;
  };

  function useAction(props, ref) {
    var toggle = props.toggle,
        dismiss = props.dismiss,
        restProps = _objectWithoutProperties(props, _excluded$1o);

    var useActionHook = getActionHook(toggle, dismiss);

    if (!useActionHook) {
      return [props, ref];
    }

    if (typeof useActionHook !== 'function') {
      throw new Error('Action hook must be of type function.');
    }

    var _useActionHook = useActionHook(restProps),
        actionRef = _useActionHook.ref,
        actionProps = _objectWithoutProperties(_useActionHook, _excluded2$2);

    return [actionProps, concatRefs(actionRef, ref)];
  }

  var _excluded$1n = ["children", "active", "style", "activeStyle", "textStyle", "activeTextStyle", "styleName"];
  var propTypes$1q = {
    children: PropTypes.node,
    active: PropTypes.bool,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    activeStyle: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    activeTextStyle: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    styleName: PropTypes.any
  }; // One of the following should be set for aria support:
  // 1) accessibilityRole
  // 2) accessibilityLabel + accessibilityHint
  // 3) accessibilityActions + onAccessibilityAction

  var getRole$2 = function getRole(props) {
    var accessibilityRole = props.accessibilityRole,
        accessibilityLabel = props.accessibilityLabel,
        accessibilityActions = props.accessibilityActions;

    if (accessibilityRole) {
      return accessibilityRole;
    }

    if (accessibilityLabel || accessibilityActions) {
      return null;
    }

    return 'button';
  };
  var Pressable = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var _useModifier = useModifier('useActionable', props, ref),
        _useModifier2 = _slicedToArray(_useModifier, 2),
        modifierProps = _useModifier2[0],
        modifierRef = _useModifier2[1];

    var _useAction = useAction(modifierProps, modifierRef),
        _useAction2 = _slicedToArray(_useAction, 2),
        actionProps = _useAction2[0],
        actionRef = _useAction2[1];

    var children = actionProps.children,
        _actionProps$active = actionProps.active,
        active = _actionProps$active === void 0 ? false : _actionProps$active,
        style = actionProps.style,
        activeStyle = actionProps.activeStyle,
        textStyle = actionProps.textStyle,
        activeTextStyle = actionProps.activeTextStyle,
        styleName = actionProps.styleName,
        elementProps = _objectWithoutProperties(actionProps, _excluded$1n);

    var media = useMedia();
    var context = React.useContext(TextStyleContext);
    var resolveStyle = useStyle(style, styleName);
    var resolveActiveStyle = useStyle(active && activeStyle);
    var resolveTextStyle = useStyle([context && context.style, textStyle]);
    var resolveActiveTextStyle = useStyle(active && activeTextStyle);
    var hasTextStyle = context && context.style || textStyle;
    return /*#__PURE__*/React__default["default"].createElement(reactNative.Pressable, _extends$1({}, elementProps, {
      ref: actionRef,
      accessibilityRole: getRole$2(actionProps),
      style: function style(interaction) {
        return [resolveStyle({
          media: media,
          interaction: interaction
        }), resolveActiveStyle({
          media: media,
          interaction: interaction
        })];
      }
    }), hasTextStyle ? function (interaction) {
      return /*#__PURE__*/React__default["default"].createElement(TextStyleContext.Provider, {
        value: {
          style: [resolveTextStyle({
            media: media,
            interaction: interaction
          }), resolveActiveTextStyle({
            media: media,
            interaction: interaction
          })],
          hasAncestor: context && context.hasTextAncestor
        }
      }, children);
    } : children);
  });
  Pressable.displayName = 'Pressable';
  Pressable.propTypes = propTypes$1q;

  var _excluded$1m = ["active", "handlePress"];
  function useToggleButton(props) {
    var active = props.active,
        handlePress = props.handlePress,
        restProps = _objectWithoutProperties(props, _excluded$1m);

    var _useState = React.useState(active),
        _useState2 = _slicedToArray(_useState, 2),
        pressed = _useState2[0],
        setPressed = _useState2[1];

    return _objectSpread2(_objectSpread2({}, restProps), {}, {
      active: pressed,
      onPress: function onPress(event) {
        if (handlePress) handlePress(event);
        setPressed(function (value) {
          return !value;
        });
      },
      accessibilityPressed: pressed
    });
  }

  var _excluded$1l = ["children", "color", "size", "outline", "active", "disabled", "style", "activeStyle", "textStyle", "activeTextStyle"];

  var _templateObject$15, _templateObject2$P, _templateObject3$p, _templateObject4$m, _templateObject5$j, _templateObject6$g, _templateObject7$b, _templateObject8$b, _templateObject9$a, _templateObject10$a, _templateObject11$7, _templateObject12$5, _templateObject13$5, _templateObject14$4, _templateObject15$3, _templateObject16$1, _templateObject17$1, _templateObject18$1, _templateObject19$1, _templateObject20$1, _templateObject21, _templateObject22, _templateObject23;
  var propTypes$1p = {
    children: PropTypes.node.isRequired,
    color: PropTypes.oneOf([].concat(_toConsumableArray(Object.keys(THEME_COLORS)), ['link'])),
    size: PropTypes.oneOf(['lg', 'sm']),
    outline: PropTypes.bool,
    active: PropTypes.bool,
    disabled: PropTypes.bool,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    activeStyle: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    activeTextStyle: PropTypes.any
  };
  var styles$17 = StyleSheet.create(_objectSpread2(_objectSpread2({
    '.btn': css(_templateObject$15 || (_templateObject$15 = _taggedTemplateLiteral(["\n    flex-direction: row; // added for bootstrap-rn\n    justify-content: center; // added for bootstrap-rn\n    // display: inline-block;\n    @include platform(web) {\n      // cursor: if($enable-button-pointers, pointer, null);\n      user-select: none;\n    }\n    background-color: transparent;\n    border: $btn-border-width solid transparent;\n    padding: $btn-padding-y $btn-padding-x;\n    // Manually declare to provide an override to the browser default\n    border-radius: $btn-border-radius;\n    // @include transition($btn-transition);\n\n    &:focus {\n      // outline: 0;\n      // box-shadow: $btn-focus-box-shadow;\n    }\n\n    &:active {\n      // @include box-shadow($btn-active-box-shadow);\n\n      &:focus {\n        // @include box-shadow($btn-focus-box-shadow, $btn-active-box-shadow);\n      }\n    }\n  "]))),
    '.btn --text': css(_templateObject2$P || (_templateObject2$P = _taggedTemplateLiteral(["\n    font-family: $btn-font-family;\n    font-weight: $btn-font-weight;\n    line-height: $btn-font-size * $btn-line-height;\n    color: $body-color;\n    text-align: center;\n    text-decoration: none; // if($link-decoration == none, null, none);\n    white-space: $btn-white-space;\n    // vertical-align: middle;\n    font-size: $btn-font-size;\n\n    &:hover {\n      color: $body-color;\n      text-decoration: none; // if($link-decoration == none, null, none);\n    }\n  "]))),
    '.btn.disabled': css(_templateObject3$p || (_templateObject3$p = _taggedTemplateLiteral(["\n    // pointer-events: none;\n    opacity: $btn-disabled-opacity;\n    // @include box-shadow(none);\n  "])))
  }, each(THEME_COLORS, function (color, value) {
    var _ref;

    return _ref = {}, _defineProperty(_ref, ".btn-".concat(color), css(_templateObject4$m || (_templateObject4$m = _taggedTemplateLiteral(["\n      background-color: ", ";\n      border-color: ", ";\n      // @include box-shadow($btn-box-shadow);\n\n      &:hover {\n        background-color: ", ";\n        border-color: ", ";\n      }\n\n      &:focus {\n        background-color: ", ";\n        border-color: ", ";\n        /* @if $enable-shadows {\n          @include box-shadow($btn-box-shadow, 0 0 0 $btn-focus-width rgba(mix($color, $border, 15%), .5));\n        } @else {\n          // Avoid using mixin so we can pass custom focus shadow properly\n          box-shadow: 0 0 0 $btn-focus-width rgba(mix($color, $border, 15%), .5);\n        } */\n      }\n\n      &:active {\n        background-color: ", ";\n        // Remove CSS gradients if they're enabled\n        // background-image: if($enable-gradients, none, null);\n        border-color: ", ";\n      }\n    "])), value, value, shadeColor(function (t) {
      return t['btn-hover-bg-shade-amount'];
    }, value), shadeColor(function (t) {
      return t['btn-hover-border-shade-amount'];
    }, value), shadeColor(function (t) {
      return t['btn-hover-bg-shade-amount'];
    }, value), shadeColor(function (t) {
      return t['btn-hover-border-shade-amount'];
    }, value), shadeColor(function (t) {
      return t['btn-active-bg-shade-amount'];
    }, value), shadeColor(function (t) {
      return t['btn-active-border-shade-amount'];
    }, value))), _defineProperty(_ref, ".btn-".concat(color, " --text"), css(_templateObject5$j || (_templateObject5$j = _taggedTemplateLiteral(["\n      color: ", ";\n\n      &:hover {\n        color: ", ";\n      }\n\n      &:focus {\n        color: ", ";\n      }\n\n      &:active {\n        color: ", ";\n      }\n    "])), colorContrast(value), colorContrast(value), colorContrast(value), colorContrast(value))), _defineProperty(_ref, ".btn-".concat(color, ".active"), css(_templateObject6$g || (_templateObject6$g = _taggedTemplateLiteral(["\n      background-color: ", ";\n      // Remove CSS gradients if they're enabled\n      // background-image: if($enable-gradients, none, null);\n      border-color: ", ";\n    "])), shadeColor(function (t) {
      return t['btn-active-bg-shade-amount'];
    }, value), shadeColor(function (t) {
      return t['btn-active-border-shade-amount'];
    }, value))), _defineProperty(_ref, ".btn-".concat(color, ".active --text"), css(_templateObject7$b || (_templateObject7$b = _taggedTemplateLiteral(["\n      color: ", ";\n    "])), colorContrast(value))), _defineProperty(_ref, ".btn-".concat(color, ".disabled"), css(_templateObject8$b || (_templateObject8$b = _taggedTemplateLiteral(["\n      $disabled-background: ", ";\n      $disabled-border: ", ";\n\n      background-color: $disabled-background;\n      // Remove CSS gradients if they're enabled\n      // background-image: if($enable-gradients, none, null);\n      border-color: $disabled-border;\n    "])), value, value)), _defineProperty(_ref, ".btn-".concat(color, ".disabled --text"), css(_templateObject9$a || (_templateObject9$a = _taggedTemplateLiteral(["\n      $disabled-color: ", ";\n\n      color: $disabled-color;\n    "])), colorContrast(value))), _defineProperty(_ref, ".btn-outline-".concat(color), css(_templateObject10$a || (_templateObject10$a = _taggedTemplateLiteral(["\n      border-color: ", ";\n\n      &:hover {\n        background-color: ", ";\n        border-color: ", ";\n      }\n\n      &:focus {\n        // box-shadow: 0 0 0 $btn-focus-width rgba($color, .5);\n      }\n\n      &:active {\n        background-color: ", ";\n        border-color: ", ";\n\n        /* &:focus {\n          @if $enable-shadows {\n            @include box-shadow(\n              $btn-active-box-shadow,\n              0 0 0 $btn-focus-width rgba($color, 0.5)\n            );\n          } @else {\n            // Avoid using mixin so we can pass custom focus shadow properly\n            box-shadow: 0 0 0 $btn-focus-width rgba($color, 0.5);\n          }\n        } */\n      }\n    "])), value, value, value, value, value)), _defineProperty(_ref, ".btn-outline-".concat(color, " --text"), css(_templateObject11$7 || (_templateObject11$7 = _taggedTemplateLiteral(["\n      color: ", ";\n\n      &:hover {\n        color: ", ";\n      }\n\n      &:active {\n        color: ", ";\n      }\n    "])), value, colorContrast(value), colorContrast(value))), _defineProperty(_ref, ".btn-outline-".concat(color, ".disabled"), css(_templateObject12$5 || (_templateObject12$5 = _taggedTemplateLiteral(["\n      background-color: transparent;\n    "])))), _defineProperty(_ref, ".btn-outline-".concat(color, ".disabled --text"), css(_templateObject13$5 || (_templateObject13$5 = _taggedTemplateLiteral(["\n      color: ", ";\n    "])), value)), _ref;
  })), {}, {
    '.btn-link --text': css(_templateObject14$4 || (_templateObject14$4 = _taggedTemplateLiteral(["\n    font-weight: $font-weight-normal;\n    color: $btn-link-color;\n    text-decoration-color: $btn-link-color; // added for bootstrap-rn\n    text-decoration-line: $link-decoration;\n\n    &:hover {\n      color: $btn-link-hover-color;\n      text-decoration-color: $btn-link-hover-color; // added for bootstrap-rn\n      text-decoration-line: $link-hover-decoration;\n    }\n\n    &:focus {\n      text-decoration-line: $link-hover-decoration;\n    }\n\n    // No need for an active state here\n  "]))),
    '.btn-link.disabled --text': css(_templateObject15$3 || (_templateObject15$3 = _taggedTemplateLiteral(["\n    color: $btn-link-disabled-color;\n  "]))),
    '.btn-lg': css(_templateObject16$1 || (_templateObject16$1 = _taggedTemplateLiteral(["\n    padding: $btn-padding-y-lg $btn-padding-x-lg;\n    // Manually declare to provide an override to the browser default\n    border-radius: $btn-border-radius-lg;\n  "]))),
    '.btn-lg --text': css(_templateObject17$1 || (_templateObject17$1 = _taggedTemplateLiteral(["\n    line-height: $btn-font-size-lg * $btn-line-height;\n    font-size: $btn-font-size-lg;\n  "]))),
    '.btn-sm': css(_templateObject18$1 || (_templateObject18$1 = _taggedTemplateLiteral(["\n    padding: $btn-padding-y-sm $btn-padding-x-sm;\n    // Manually declare to provide an override to the browser default\n    border-radius: $btn-border-radius-sm;\n  "]))),
    '.btn-sm --text': css(_templateObject19$1 || (_templateObject19$1 = _taggedTemplateLiteral(["\n    line-height: $btn-font-size-sm * $btn-line-height;\n    font-size: $btn-font-size-sm;\n  "]))),
    '.btn-group > .btn': css(_templateObject20$1 || (_templateObject20$1 = _taggedTemplateLiteral(["\n    position: relative;\n    // flex: 1 1 auto;\n\n    &:hover {\n      z-index: 1;\n    }\n    &:focus {\n      z-index: 1;\n    }\n    &:active {\n      z-index: 1;\n    }\n  "]))),
    '.btn-group > .btn.active': css(_templateObject21 || (_templateObject21 = _taggedTemplateLiteral(["\n    z-index: 2; // 1;\n  "]))),
    '.btn-group > .btn:not(:first-child)': css(_templateObject22 || (_templateObject22 = _taggedTemplateLiteral(["\n    margin-left: -$btn-border-width;\n    border-top-left-radius: 0;\n    border-bottom-left-radius: 0;\n  "]))),
    '.btn-group > .btn:not(:last-child)': css(_templateObject23 || (_templateObject23 = _taggedTemplateLiteral(["\n    border-top-right-radius: 0;\n    border-bottom-right-radius: 0;\n  "])))
  }));

  var getVariant = function getVariant(color, outline) {
    if (color === 'link') {
      return null;
    }

    if (outline) {
      return ".btn-outline-".concat(color);
    }

    return ".btn-".concat(color);
  };

  var hasSize = function hasSize(size, group, value) {
    if (size !== undefined || !group) {
      return size === value;
    }

    return group.size === value;
  };

  var Button = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        _props$color = props.color,
        color = _props$color === void 0 ? 'primary' : _props$color,
        size = props.size,
        _props$outline = props.outline,
        outline = _props$outline === void 0 ? false : _props$outline,
        _props$active = props.active,
        active = _props$active === void 0 ? false : _props$active,
        _props$disabled = props.disabled,
        disabled = _props$disabled === void 0 ? false : _props$disabled,
        style = props.style,
        activeStyle = props.activeStyle,
        textStyle = props.textStyle,
        activeTextStyle = props.activeTextStyle,
        elementProps = _objectWithoutProperties(props, _excluded$1l);

    invariant(color !== 'link' || !outline, 'Button link variant is only available as non outline style.');
    var listItem = React.useContext(ListContext);
    var group = React.useContext(ButtonGroupContext);
    var classes = getStyles(styles$17, ['.btn', getVariant(color, outline), disabled && '.btn.disabled', disabled && "".concat(getVariant(color, outline), ".disabled"), hasSize(size, group, 'lg') && '.btn-lg', hasSize(size, group, 'sm') && '.btn-sm', group && '.btn-group > .btn', group && active && '.btn-group > .btn.active', group && !listItem.first && '.btn-group > .btn:not(:first-child)', group && !listItem.last && '.btn-group > .btn:not(:last-child)']);
    var activeClasses = getStyles(styles$17, ["".concat(getVariant(color, outline), ".active")]);
    var textClasses = getStyles(styles$17, ['.btn --text', "".concat(getVariant(color, outline), " --text"), color === 'link' && '.btn-link --text', disabled && "".concat(getVariant(color, outline), ".disabled --text"), disabled && color === 'link' && '.btn-link.disabled --text', hasSize(size, group, 'lg') && '.btn-lg --text', hasSize(size, group, 'sm') && '.btn-sm --text']);
    var activeTextClasses = getStyles(styles$17, ["".concat(getVariant(color, outline), ".active --text")]);
    return /*#__PURE__*/React__default["default"].createElement(Pressable, _extends$1({}, elementProps, {
      ref: ref,
      active: active,
      disabled: disabled,
      style: [].concat(_toConsumableArray(classes), [style]),
      activeStyle: [].concat(_toConsumableArray(activeClasses), [activeStyle]),
      textStyle: [].concat(_toConsumableArray(textClasses), [textStyle]),
      activeTextStyle: [].concat(_toConsumableArray(activeTextClasses), [activeTextStyle])
    }), children);
  });
  Button.displayName = 'Button';
  Button.propTypes = propTypes$1p;
  Button.useToggle = useToggleButton;

  var _excluded$1k = ["children", "style", "textStyle"];

  var _templateObject$14, _templateObject2$O;
  var propTypes$1o = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any
  };
  var styles$16 = StyleSheet.create({
    blockquote: css(_templateObject$14 || (_templateObject$14 = _taggedTemplateLiteral(["\n    margin-bottom: $blockquote-margin-y;\n  "]))),
    'blockquote --text': css(_templateObject2$O || (_templateObject2$O = _taggedTemplateLiteral(["\n    font-size: $blockquote-font-size;\n  "])))
  });
  var Blockquote = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        textStyle = props.textStyle,
        elementProps = _objectWithoutProperties(props, _excluded$1k);

    var classes = getStyles(styles$16, ['blockquote']);
    var textClasses = getStyles(styles$16, ['blockquote --text']); // Accessiblity role blockquote is only supported on web.

    var role = reactNative.Platform.OS === 'web' ? 'blockquote' : null;
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      accessibilityRole: role,
      style: [classes, style],
      textStyle: [textClasses, textStyle]
    }), children);
  });
  Blockquote.displayName = 'Blockquote';
  Blockquote.propTypes = propTypes$1o;

  var _excluded$1j = ["children", "style", "textStyle", "styleName"];

  var _templateObject$13, _templateObject2$N;
  var propTypes$1n = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    styleName: PropTypes.any
  };
  var styles$15 = StyleSheet.create({
    body: css(_templateObject$13 || (_templateObject$13 = _taggedTemplateLiteral(["\n    background-color: $body-bg;\n    height: 100%; // added for bootstrap-rn\n  "]))),
    'body --text': css(_templateObject2$N || (_templateObject2$N = _taggedTemplateLiteral(["\n    color: $body-color;\n    text-align: $body-text-align;\n  "])))
  });
  var Body = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        textStyle = props.textStyle,
        styleName = props.styleName,
        elementProps = _objectWithoutProperties(props, _excluded$1j);

    var classes = getStyles(styles$15, ['body']);
    var textClasses = getStyles(styles$15, ['body --text']);
    var media = useMedia();
    var resolveStyle = useStyle([classes, style], styleName);
    var resolveTextStyle = useStyle([textClasses, textStyle]);
    return /*#__PURE__*/React__default["default"].createElement(reactNative.SafeAreaView, _extends$1({}, elementProps, {
      ref: ref,
      style: resolveStyle({
        media: media
      })
    }), /*#__PURE__*/React__default["default"].createElement(TextStyleContext.Provider, {
      value: {
        style: resolveTextStyle({
          media: media
        })
      }
    }, children));
  });
  Body.displayName = 'Body';
  Body.propTypes = propTypes$1n;

  var _excluded$1i = ["children", "style", "textStyle"];

  var _templateObject$12, _templateObject2$M;
  var propTypes$1m = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any
  };
  var styles$14 = StyleSheet.create({
    '.card-body': css(_templateObject$12 || (_templateObject$12 = _taggedTemplateLiteral(["\n    // flex: 1 1 auto;\n    padding: $card-spacer-y $card-spacer-x;\n  "]))),
    '.card-body --text': css(_templateObject2$M || (_templateObject2$M = _taggedTemplateLiteral(["\n    color: $card-color;\n  "])))
  });
  var CardBody = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        textStyle = props.textStyle,
        elementProps = _objectWithoutProperties(props, _excluded$1i);

    var classes = getStyles(styles$14, ['.card-body']);
    var textClasses = getStyles(styles$14, [".card-body --text"]);
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style],
      textStyle: [textClasses, textStyle]
    }), children);
  });
  CardBody.displayName = 'CardBody';
  CardBody.propTypes = propTypes$1m;

  var _excluded$1h = ["children", "style", "textStyle"];

  var _templateObject$11, _templateObject2$L;
  var propTypes$1l = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any
  };
  var styles$13 = StyleSheet.create({
    '.card-header': css(_templateObject$11 || (_templateObject$11 = _taggedTemplateLiteral(["\n    padding: $card-cap-padding-y $card-cap-padding-x;\n    background-color: $card-cap-bg;\n    border-bottom-width: $card-border-width;\n    border-style: solid;\n    border-color: $card-border-color;\n    border-radius: $card-inner-border-radius $card-inner-border-radius 0 0;\n  "]))),
    '.card-header --text': css(_templateObject2$L || (_templateObject2$L = _taggedTemplateLiteral(["\n    margin-bottom: 0; // Removes the default margin-bottom of <hN>\n    color: $card-cap-color;\n  "])))
  });
  var CardHeader = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        textStyle = props.textStyle,
        elementProps = _objectWithoutProperties(props, _excluded$1h);

    var classes = getStyles(styles$13, ['.card-header']);
    var textClasses = getStyles(styles$13, ['.card-header --text']);
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style],
      textStyle: [textClasses, textStyle]
    }), children);
  });
  CardHeader.displayName = 'CardHeader';
  CardHeader.propTypes = propTypes$1l;

  var _excluded$1g = ["children", "style", "textStyle"];

  var _templateObject$10, _templateObject2$K;
  var propTypes$1k = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any
  };
  var styles$12 = StyleSheet.create({
    '.card-footer': css(_templateObject$10 || (_templateObject$10 = _taggedTemplateLiteral(["\n    padding: $card-cap-padding-y $card-cap-padding-x;\n    background-color: $card-cap-bg;\n    border-top-width: $card-border-width;\n    border-style: solid;\n    border-color: $card-border-color;\n    border-radius: 0 0 $card-inner-border-radius $card-inner-border-radius;\n  "]))),
    '.card-footer --text': css(_templateObject2$K || (_templateObject2$K = _taggedTemplateLiteral(["\n    color: $card-cap-color;\n  "])))
  });
  var CardFooter = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        textStyle = props.textStyle,
        elementProps = _objectWithoutProperties(props, _excluded$1g);

    var classes = getStyles(styles$12, ['.card-footer']);
    var textClasses = getStyles(styles$12, ['.card-footer --text']);
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style],
      textStyle: [textClasses, textStyle]
    }), children);
  });
  CardFooter.displayName = 'CardFooter';
  CardFooter.propTypes = propTypes$1k;

  var _excluded$1f = ["children", "style"];

  var _templateObject$$;
  var propTypes$1j = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$11 = StyleSheet.create({
    '.card': css(_templateObject$$ || (_templateObject$$ = _taggedTemplateLiteral(["\n    position: relative;\n    display: flex;\n    flex-direction: column;\n    min-width: 0;\n    height: $card-height;\n    // word-wrap: break-word;\n    background-color: $card-bg;\n    // background-clip: border-box;\n    border: $card-border-width solid $card-border-color;\n    border-radius: $card-border-radius;\n    // @include box-shadow($card-box-shadow);\n  "])))
  });
  var Card = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded$1f);

    var classes = getStyles(styles$11, ['.card']);
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style]
    }), children);
  });
  Card.displayName = 'Card';
  Card.propTypes = propTypes$1j;
  Card.Header = CardHeader;
  Card.Body = CardBody;
  Card.Footer = CardFooter;

  var ModalContext = /*#__PURE__*/React__default["default"].createContext();
  ModalContext.displayName = 'ModalContext';

  var OffcanvasContext = /*#__PURE__*/React__default["default"].createContext();
  OffcanvasContext.displayName = 'OffcanvasContext';

  var styles$10 = reactNative.StyleSheet.create({
    reset: {
      // Background repeat is not supported on native yet.
      backgroundRepeat: 'no-repeat'
    }
  });

  var normalizeValue = function normalizeValue(value) {
    return typeof value === 'number' && value !== 0 ? "".concat(value, "px") : value;
  };

  var resolveBackgroundSize = function resolveBackgroundSize(style) {
    var backgroundSize = style.backgroundSize;

    if (_typeof(backgroundSize) !== 'object') {
      return backgroundSize;
    }

    var _backgroundSize$width = backgroundSize.width,
        width = _backgroundSize$width === void 0 ? 'auto' : _backgroundSize$width,
        _backgroundSize$heigh = backgroundSize.height,
        height = _backgroundSize$heigh === void 0 ? 'auto' : _backgroundSize$heigh;
    return "".concat(normalizeValue(width), " ").concat(normalizeValue(height));
  };

  var resolveBackgroundPosition = function resolveBackgroundPosition(style) {
    var backgroundPosition = style.backgroundPosition,
        backgroundPositionX = style.backgroundPositionX,
        backgroundPositionY = style.backgroundPositionY;

    if (!backgroundPosition && !backgroundPositionX && !backgroundPositionY) {
      return null;
    }

    var value = {
      positionX: backgroundPosition || 'left',
      offsetX: 0,
      positionY: backgroundPosition || 'top',
      offsetY: 0
    };

    if (backgroundPositionX) {
      var _ref = _typeof(backgroundPositionX) === 'object' ? backgroundPositionX : {
        position: backgroundPositionX
      },
          _ref$position = _ref.position,
          positionX = _ref$position === void 0 ? 'left' : _ref$position,
          _ref$offset = _ref.offset,
          offsetX = _ref$offset === void 0 ? 0 : _ref$offset;

      value.positionX = positionX;
      value.offsetX = normalizeValue(offsetX);
    }

    if (backgroundPositionY) {
      var _ref2 = _typeof(backgroundPositionY) === 'object' ? backgroundPositionY : {
        position: backgroundPositionY
      },
          _ref2$position = _ref2.position,
          positionY = _ref2$position === void 0 ? 'top' : _ref2$position,
          _ref2$offset = _ref2.offset,
          offsetY = _ref2$offset === void 0 ? 0 : _ref2$offset;

      value.positionY = positionY;
      value.offsetY = normalizeValue(offsetY);
    }

    var valueX = value.offsetX ? "".concat(value.positionX, " ").concat(value.offsetX) : value.positionX;
    var valueY = value.offsetY ? "".concat(value.positionY, " ").concat(value.offsetY) : value.positionY;
    return "".concat(valueX, " ").concat(valueY);
  };

  function useBackgroundWeb(style) {
    var flattenedStyle = reactNative.StyleSheet.flatten(style);
    return {
      style: [flattenedStyle, styles$10.reset, {
        // Transform background size
        backgroundSize: resolveBackgroundSize(flattenedStyle),
        // Workaround, because some browsers do not support two-value syntax:
        // https://developer.mozilla.org/en-US/docs/Web/CSS/background-position-x#browser_compatibility
        backgroundPositionX: null,
        backgroundPositionY: null,
        backgroundPosition: resolveBackgroundPosition(flattenedStyle)
      }],
      element: null
    };
  }

  var styles$$ = reactNative.StyleSheet.create({
    container: {
      overflow: 'hidden'
    },
    object: {
      aspectRatio: 1
    }
  });
  var horizontalPositions = {
    left: function left() {
      var offset = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 0;
      return {
        alignItems: reactNative.I18nManager.isRTL ? 'flex-end' : 'flex-start',
        paddingLeft: offset
      };
    },
    right: function right() {
      var offset = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 0;
      return {
        alignItems: reactNative.I18nManager.isRTL ? 'flex-start' : 'flex-end',
        paddingRight: offset
      };
    },
    center: function center(offset) {
      if (offset !== undefined) {
        return null;
      }

      return {
        alignItems: 'center'
      };
    }
  };
  var verticalPositions = {
    top: function top() {
      var offset = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 0;
      return {
        justifyContent: 'flex-start',
        paddingTop: offset
      };
    },
    bottom: function bottom() {
      var offset = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 0;
      return {
        justifyContent: 'flex-end',
        paddingBottom: offset
      };
    },
    center: function center(offset) {
      if (offset !== undefined) {
        return null;
      }

      return {
        justifyContent: 'center'
      };
    }
  };

  var getXml = function getXml(value) {
    var match = value.match(/^url\("data:image\/svg\+xml,(.*?)"\)$/);

    if (!match) {
      return null;
    }

    return decodeURIComponent(match[1]);
  };

  var transforms = {
    backgroundSize: function backgroundSize(value) {
      if (value === 'cover') {
        return {
          width: '100%' // TODO: Support cover for views with height > width.
          // height: '100%',

        };
      }

      if (value === 'contain') {
        return {
          width: '100%',
          height: '100%'
        };
      }

      var width = value.width,
          _value$height = value.height,
          height = _value$height === void 0 ? width : _value$height;
      return {
        width: width,
        height: height
      };
    },
    backgroundPosition: function backgroundPosition(value) {
      if (value === 'center') {
        return {
          alignItems: 'center',
          justifyContent: 'center'
        };
      }

      if (horizontalPositions[value]) {
        return _objectSpread2(_objectSpread2({}, horizontalPositions[value]()), {}, {
          justifyContent: 'center'
        });
      }

      if (verticalPositions[value]) {
        return _objectSpread2({
          alignItems: 'center'
        }, verticalPositions[value]());
      }

      return null;
    },
    backgroundPositionX: function backgroundPositionX(value) {
      var _ref = _typeof(value) === 'object' ? value : {
        position: value
      },
          _ref$position = _ref.position,
          position = _ref$position === void 0 ? 'left' : _ref$position,
          offset = _ref.offset;

      if (!horizontalPositions[position]) {
        return null;
      }

      return horizontalPositions[position](offset);
    },
    backgroundPositionY: function backgroundPositionY(value) {
      var _ref2 = _typeof(value) === 'object' ? value : {
        position: value
      },
          _ref2$position = _ref2.position,
          position = _ref2$position === void 0 ? 'top' : _ref2$position,
          offset = _ref2.offset;

      if (!verticalPositions[position]) {
        return null;
      }

      return verticalPositions[position](offset);
    }
  };
  function useBackgroundNative(style) {
    var flattenedStyle = reactNative.StyleSheet.flatten(style);
    var background = {
      containerStyle: {},
      objectStyle: {},
      xml: null
    };
    Object.entries(flattenedStyle).forEach(function (_ref3) {
      var _ref4 = _slicedToArray(_ref3, 2),
          key = _ref4[0],
          value = _ref4[1];

      if (!value) {
        return;
      }

      if (key === 'backgroundImage') {
        background.xml = getXml(value);
      } else if (key === 'backgroundSize') {
        Object.assign(background.objectStyle, transforms[key](value));
      } else if (key === 'backgroundPosition' || key === 'backgroundPositionX' || key === 'backgroundPositionY') {
        Object.assign(background.containerStyle, transforms[key](value));
      }
    });
    return {
      style: flattenedStyle,
      element: /*#__PURE__*/React__default["default"].createElement(reactNative.View, {
        style: [reactNative.StyleSheet.absoluteFill, styles$$.container, background.containerStyle]
      }, /*#__PURE__*/React__default["default"].createElement(reactNative.View, {
        style: [styles$$.object, background.objectStyle]
      }, background.xml && /*#__PURE__*/React__default["default"].createElement(reactNativeSvg.SvgXml, {
        xml: background.xml
      })))
    };
  }

  //
  // type Position = 'center' | 'left' | 'right' | 'top' | 'bottom';
  // type PositionX = 'center' | 'left' | 'right';
  // type PositionY = 'center' | 'top' | 'bottom';
  //
  // type BackgroundStyles = {
  //   backgroundImage: string,
  //   backgroundSize: 'contain' | 'cover' | string | number,
  //   backgroundPosition: Position,
  //   backgroundPositionX:
  //     | PositionX
  //     | { position: PositionX, offset: string | number },
  //   backgroundPositionY:
  //     | PositionY
  //     | { position: PositionY, offset: string | number },
  // };

  function useBackground(style, styleName) {
    // TODO: Use *.web.js / *.native.js file endings to select platforms, but
    // before we need to make sure that the published bundles are all functional.
    var useBackgroundForPlatform = reactNative.Platform.select({
      web: useBackgroundWeb,
      default: useBackgroundNative
    });
    return useBackgroundForPlatform(style, styleName);
  }

  var _excluded$1e = ["children", "onFocus", "onBlur", "onHoverIn", "onHoverOut", "onPressIn", "onPressOut", "disabled", "style", "textStyle", "styleName"];

  var _templateObject$_, _templateObject2$J, _templateObject3$o, _templateObject4$l, _templateObject5$i;
  var propTypes$1i = {
    children: PropTypes.node,
    onFocus: PropTypes.func,
    onBlur: PropTypes.func,
    onHoverIn: PropTypes.func,
    onHoverOut: PropTypes.func,
    onPressIn: PropTypes.func,
    onPressOut: PropTypes.func,
    disabled: PropTypes.bool,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    styleName: PropTypes.any
  };
  var styles$_ = StyleSheet.create({
    '.btn-close': css(_templateObject$_ || (_templateObject$_ = _taggedTemplateLiteral(["\n    // Workaround for missing box-sizing in react native.\n    $additional-width: $btn-close-padding-x * 2;\n    $additional-height: $btn-close-padding-y * 2;\n\n    // box-sizing: content-box;\n    width: $btn-close-width + $additional-width;\n    height: $btn-close-height + $additional-height;\n    padding: $btn-close-padding-y $btn-close-padding-x;\n    background-color: transparent; // include transparent for button elements\n    background-image: ", ";\n    background-position: center;\n    background-size: $btn-close-width auto;\n    background-repeat: no-repeat;\n    border-width: 0; // for button elements\n    // @include border-radius();\n    opacity: $btn-close-opacity;\n\n    &:hover {\n      opacity: $btn-close-hover-opacity;\n    }\n\n    &:focus {\n      // outline: 0;\n      // box-shadow: $btn-close-focus-shadow;\n      opacity: $btn-close-focus-opacity;\n    }\n  "])), function (t) {
      return escapeSvg(t['btn-close-bg']);
    }),
    '.btn-close --text': css(_templateObject2$J || (_templateObject2$J = _taggedTemplateLiteral(["\n    color: $btn-close-color;\n\n    // Override <a>'s hover style\n    &:hover {\n      color: $btn-close-color;\n      text-decoration: none;\n    }\n  "]))),
    '.btn-close.disabled': css(_templateObject3$o || (_templateObject3$o = _taggedTemplateLiteral(["\n    // pointer-events: none;\n    // user-select: none;\n    opacity: $btn-close-disabled-opacity;\n  "]))),
    // Modal styles
    '.modal-header .btn-close': css(_templateObject4$l || (_templateObject4$l = _taggedTemplateLiteral(["\n    padding: $modal-header-padding-y * 0.5 $modal-header-padding-x * 0.5;\n    margin: -0.5 * $modal-header-padding-y -0.5 * $modal-header-padding-x -0.5 *\n      $modal-header-padding-y auto;\n\n    // Workaround for missing box-sizing in react native.\n    width: $btn-close-width + $modal-header-padding-x;\n    height: $btn-close-height + $modal-header-padding-y;\n  "]))),
    // Offcanvas styles
    '.offcanvas-header .btn-close': css(_templateObject5$i || (_templateObject5$i = _taggedTemplateLiteral(["\n    padding: $offcanvas-padding-y * 0.5 $offcanvas-padding-x * 0.5;\n    margin-top: -0.5 * $offcanvas-padding-y;\n    margin-right: -0.5 * $offcanvas-padding-x;\n    margin-bottom: -0.5 * $offcanvas-padding-y;\n\n    // Workaround for missing box-sizing in react native.\n    width: $btn-close-width + $offcanvas-padding-x;\n    height: $btn-close-height + $offcanvas-padding-y;\n  "])))
  });
  var CloseButton = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    props.children;
        var _props$onFocus = props.onFocus,
        _onFocus = _props$onFocus === void 0 ? function () {} : _props$onFocus,
        _props$onBlur = props.onBlur,
        _onBlur = _props$onBlur === void 0 ? function () {} : _props$onBlur,
        _props$onHoverIn = props.onHoverIn,
        _onHoverIn = _props$onHoverIn === void 0 ? function () {} : _props$onHoverIn,
        _props$onHoverOut = props.onHoverOut,
        _onHoverOut = _props$onHoverOut === void 0 ? function () {} : _props$onHoverOut,
        _props$onPressIn = props.onPressIn,
        _onPressIn = _props$onPressIn === void 0 ? function () {} : _props$onPressIn,
        _props$onPressOut = props.onPressOut,
        _onPressOut = _props$onPressOut === void 0 ? function () {} : _props$onPressOut,
        _props$disabled = props.disabled,
        disabled = _props$disabled === void 0 ? false : _props$disabled,
        style = props.style,
        textStyle = props.textStyle,
        styleName = props.styleName,
        elementProps = _objectWithoutProperties(props, _excluded$1e);

    var media = useMedia();

    var _useState = React.useState(false),
        _useState2 = _slicedToArray(_useState, 2),
        focused = _useState2[0],
        setFocused = _useState2[1];

    var _useState3 = React.useState(false),
        _useState4 = _slicedToArray(_useState3, 2),
        hovered = _useState4[0],
        setHovered = _useState4[1];

    var _useState5 = React.useState(false),
        _useState6 = _slicedToArray(_useState5, 2),
        pressed = _useState6[0],
        setPressed = _useState6[1];

    var modal = React.useContext(ModalContext);
    var offcanvas = React.useContext(OffcanvasContext);
    var classes = getStyles(styles$_, ['.btn-close', disabled && '.btn-close.disabled', // Modal styles
    modal && '.modal-header .btn-close', // Offcanvas styles
    offcanvas && '.offcanvas-header .btn-close']);
    var textClasses = getStyles(styles$_, ['.btn-close --text']);
    var resolveStyle = useStyle([classes, style], styleName);
    var background = useBackground(resolveStyle({
      media: media,
      interaction: {
        focused: focused,
        hovered: hovered,
        pressed: pressed
      }
    }));
    return /*#__PURE__*/React__default["default"].createElement(Pressable, _extends$1({}, elementProps, {
      component: Pressable,
      ref: ref,
      onFocus: function onFocus() {
        setFocused(true);

        _onFocus();
      },
      onBlur: function onBlur() {
        setFocused(false);

        _onBlur();
      },
      onHoverIn: function onHoverIn() {
        setHovered(true);

        _onHoverIn();
      },
      onHoverOut: function onHoverOut() {
        setHovered(false);

        _onHoverOut();
      },
      onPressIn: function onPressIn() {
        setPressed(true);

        _onPressIn();
      },
      onPressOut: function onPressOut() {
        setPressed(false);

        _onPressOut();
      },
      disabled: disabled,
      style: background.style,
      textStyle: [textClasses, textStyle]
    }), background.element);
  });
  CloseButton.displayName = 'CloseButton';
  CloseButton.propTypes = propTypes$1i;

  var CollapseContext = /*#__PURE__*/React__default["default"].createContext();
  CollapseContext.displayName = 'CollapseContext';

  function useIdentifier(prefix) {
    var context = React.useContext(Context);
    var ref = React.useRef();

    if (!ref.current) {
      ref.current = context.generateKey(prefix);
    }

    return ref.current;
  }

  function useControlledState(defaultValue, controlledValue) {
    var handleChange = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : function () {};

    var _useState = React.useState(defaultValue),
        _useState2 = _slicedToArray(_useState, 2),
        stateValue = _useState2[0],
        setStateValue = _useState2[1];

    var isControlled = controlledValue !== undefined && controlledValue !== null;
    var value = isControlled ? controlledValue : stateValue;

    var setValue = function setValue(next) {
      var nextValue = typeof next === 'function' ? next(value) : next;

      if (value === nextValue) {
        return;
      }

      if (!isControlled) {
        setStateValue(next);
      }

      handleChange(nextValue);
    };

    return [value, setValue];
  }

  function useCollapse(defaultVisible, controlledVisible, onToggle) {
    var identifier = useIdentifier('collapse');

    var _useControlledState = useControlledState(defaultVisible, controlledVisible, onToggle),
        _useControlledState2 = _slicedToArray(_useControlledState, 2),
        visible = _useControlledState2[0],
        setVisible = _useControlledState2[1];

    return React.useMemo(function () {
      return {
        identifier: identifier,
        visible: visible,
        setVisible: setVisible
      };
    }, [visible]);
  }

  var propTypes$1h = {
    children: PropTypes.node.isRequired,
    defaultVisible: PropTypes.bool,
    visible: PropTypes.bool,
    onToggle: PropTypes.func
  };

  var CollapseProvider = function CollapseProvider(props) {
    var children = props.children,
        _props$defaultVisible = props.defaultVisible,
        defaultVisible = _props$defaultVisible === void 0 ? false : _props$defaultVisible,
        visible = props.visible,
        onToggle = props.onToggle;
    var collapse = useCollapse(defaultVisible, visible, onToggle);
    return /*#__PURE__*/React__default["default"].createElement(CollapseContext.Provider, {
      value: collapse
    }, children);
  };

  CollapseProvider.displayName = 'CollapseProvider';
  CollapseProvider.propTypes = propTypes$1h;

  var _excluded$1d = ["onPress"];
  function useToggleCollapse(props) {
    var context = useForcedContext(CollapseContext);

    var handlePress = props.onPress,
        restProps = _objectWithoutProperties(props, _excluded$1d);

    return _objectSpread2(_objectSpread2({}, restProps), {}, {
      onPress: function onPress(event) {
        if (handlePress) handlePress(event);
        context.setVisible(function (value) {
          return !value;
        });
      },
      accessibilityExpanded: context.visible,
      accessibilityControls: context.identifier
    });
  }

  var _excluded$1c = ["children"];
  var propTypes$1g = {
    children: PropTypes.node
  };
  var Collapse = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        elementProps = _objectWithoutProperties(props, _excluded$1c);

    var _useForcedContext = useForcedContext(CollapseContext),
        identifier = _useForcedContext.identifier,
        visible = _useForcedContext.visible;

    if (!visible) {
      return null;
    }

    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      nativeID: identifier
    }), children);
  });
  Collapse.displayName = 'Collapse';
  Collapse.propTypes = propTypes$1g;
  Collapse.Provider = CollapseProvider;
  Collapse.useToggle = useToggleCollapse;

  function next(name) {
    var names = Object.keys(GRID_BREAKPOINTS);
    var n = names.indexOf(name);

    if (n === -1) {
      throw new Error("Breakpoint ".concat(name, " not found."));
    }

    return n < names.length ? names[n + 1] : '';
  }
  function infix(breakpoint) {
    if (!breakpoint || breakpoint === 'xs') {
      return '';
    }

    return "-".concat(breakpoint);
  }

  var NavbarContext = /*#__PURE__*/React__default["default"].createContext();
  NavbarContext.displayName = 'NavbarContext';

  var _excluded$1b = ["fluid", "style"];

  var _templateObject$Z, _templateObject2$I, _templateObject3$n, _templateObject4$k, _templateObject5$h, _templateObject6$f, _templateObject7$a, _templateObject8$a;
  var propTypes$1f = {
    children: PropTypes.node.isRequired,
    fluid: PropTypes.oneOf([true].concat(_toConsumableArray(Object.keys(CONTAINER_MAX_WIDTHS)))),
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$Z = StyleSheet.create(_objectSpread2({
    '.container': css(_templateObject$Z || (_templateObject$Z = _taggedTemplateLiteral(["\n    width: 100%;\n    padding-right: $container-padding-x;\n    padding-left: $container-padding-x;\n    margin-right: auto;\n    margin-left: auto;\n  "]))),
    '.container-sm': css(_templateObject2$I || (_templateObject2$I = _taggedTemplateLiteral(["\n    @include media-breakpoint-up(sm) {\n      max-width: ", ";\n    }\n    @include media-breakpoint-up(md) {\n      max-width: ", ";\n    }\n    @include media-breakpoint-up(lg) {\n      max-width: ", ";\n    }\n    @include media-breakpoint-up(xl) {\n      max-width: ", ";\n    }\n    @include media-breakpoint-up(xxl) {\n      max-width: ", ";\n    }\n  "])), function (t) {
      return t['container-max-widths'].sm;
    }, function (t) {
      return t['container-max-widths'].md;
    }, function (t) {
      return t['container-max-widths'].lg;
    }, function (t) {
      return t['container-max-widths'].xl;
    }, function (t) {
      return t['container-max-widths'].xxl;
    }),
    '.container-md': css(_templateObject3$n || (_templateObject3$n = _taggedTemplateLiteral(["\n    @include media-breakpoint-up(md) {\n      max-width: ", ";\n    }\n    @include media-breakpoint-up(lg) {\n      max-width: ", ";\n    }\n    @include media-breakpoint-up(xl) {\n      max-width: ", ";\n    }\n    @include media-breakpoint-up(xxl) {\n      max-width: ", ";\n    }\n  "])), function (t) {
      return t['container-max-widths'].md;
    }, function (t) {
      return t['container-max-widths'].lg;
    }, function (t) {
      return t['container-max-widths'].xl;
    }, function (t) {
      return t['container-max-widths'].xxl;
    }),
    '.container-lg': css(_templateObject4$k || (_templateObject4$k = _taggedTemplateLiteral(["\n    @include media-breakpoint-up(lg) {\n      max-width: ", ";\n    }\n    @include media-breakpoint-up(xl) {\n      max-width: ", ";\n    }\n    @include media-breakpoint-up(xxl) {\n      max-width: ", ";\n    }\n  "])), function (t) {
      return t['container-max-widths'].lg;
    }, function (t) {
      return t['container-max-widths'].xl;
    }, function (t) {
      return t['container-max-widths'].xxl;
    }),
    '.container-xl': css(_templateObject5$h || (_templateObject5$h = _taggedTemplateLiteral(["\n    @include media-breakpoint-up(xl) {\n      max-width: ", ";\n    }\n    @include media-breakpoint-up(xxl) {\n      max-width: ", ";\n    }\n  "])), function (t) {
      return t['container-max-widths'].xl;
    }, function (t) {
      return t['container-max-widths'].xxl;
    }),
    '.container-xxl': css(_templateObject6$f || (_templateObject6$f = _taggedTemplateLiteral(["\n    @include media-breakpoint-up(xxl) {\n      max-width: ", ";\n    }\n  "])), function (t) {
      return t['container-max-widths'].xxl;
    }),
    // Navbar styles
    '.navbar .container': css(_templateObject7$a || (_templateObject7$a = _taggedTemplateLiteral(["\n    display: flex;\n    flex-direction: row; // added for bootstrap-rn\n    flex-wrap: wrap;\n    align-items: center;\n    justify-content: space-between;\n  "])))
  }, each(GRID_BREAKPOINTS, function (breakpoint) {
    return _defineProperty({}, ".navbar-expand".concat(infix(next(breakpoint)), " .container"), css(_templateObject8$a || (_templateObject8$a = _taggedTemplateLiteral(["\n      @include media-breakpoint-up(", ") {\n        flex-wrap: nowrap;\n      }\n    "])), next(breakpoint)));
  })));
  var Container = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var _props$fluid = props.fluid,
        fluid = _props$fluid === void 0 ? 'sm' : _props$fluid,
        style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded$1b);

    var navbar = React.useContext(NavbarContext);
    var classes = getStyles(styles$Z, ['.container', // Hint: Bootstrap's .container class is identical with .container-sm.
    fluid !== true && ".container-".concat(fluid), // Navbar styles
    navbar && '.navbar .container', navbar && navbar.expand && ".navbar-expand".concat(navbar.expand === true ? '' : "-".concat(navbar.expand), " .container")]);
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style]
    }));
  });
  Container.displayName = 'Container';
  Container.propTypes = propTypes$1f;

  var FormCheckContext = /*#__PURE__*/React__default["default"].createContext();
  FormCheckContext.displayName = 'FormCheckContext';

  var _excluded$1a = ["style"];
  var propTypes$1e = {
    type: PropTypes.oneOf(['checkbox', 'radio', 'switch']).isRequired,
    value: PropTypes.bool.isRequired,
    onValueChange: PropTypes.func,
    onFocus: PropTypes.func,
    onBlur: PropTypes.func,
    disabled: PropTypes.bool,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    nativeID: PropTypes.any
  };
  var styles$Y = reactNative.StyleSheet.create({
    reboot: {
      margin: 0
    }
  }); // eslint-disable-next-line react/prop-types

  var Input$1 = /*#__PURE__*/React__default["default"].forwardRef(function (_ref, ref) {
    var style = _ref.style,
        props = _objectWithoutProperties(_ref, _excluded$1a);

    return reactNative.unstable_createElement('input', _objectSpread2(_objectSpread2({}, props), {}, {
      ref: ref,
      style: [styles$Y.reboot, style]
    }));
  });
  var FormCheckInputWeb = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var type = props.type,
        value = props.value,
        handleValueChange = props.onValueChange,
        _props$onFocus = props.onFocus,
        onFocus = _props$onFocus === void 0 ? function () {} : _props$onFocus,
        _props$onBlur = props.onBlur,
        onBlur = _props$onBlur === void 0 ? function () {} : _props$onBlur,
        _props$disabled = props.disabled,
        disabled = _props$disabled === void 0 ? false : _props$disabled,
        style = props.style,
        nativeID = props.nativeID;
    var inputBackground = useBackground(style);
    return /*#__PURE__*/React__default["default"].createElement(Input$1, {
      ref: ref,
      type: type === 'switch' ? 'checkbox' : type,
      checked: value,
      onChange: function onChange() {
        handleValueChange(!value);
      },
      onFocus: onFocus,
      onBlur: onBlur,
      disabled: disabled,
      style: inputBackground.style,
      nativeID: nativeID
    });
  });
  FormCheckInputWeb.displayName = 'FormCheckInputWeb';
  FormCheckInputWeb.propTypes = propTypes$1e;

  var propTypes$1d = {
    type: PropTypes.oneOf(['checkbox', 'radio', 'switch']).isRequired,
    value: PropTypes.bool.isRequired,
    onValueChange: PropTypes.func,
    onFocus: PropTypes.func,
    onBlur: PropTypes.func,
    hitSlop: PropTypes.number,
    disabled: PropTypes.bool,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    nativeID: PropTypes.any
  };
  var FormCheckInputNative = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var type = props.type,
        value = props.value,
        handleValueChange = props.onValueChange,
        _props$onFocus = props.onFocus,
        onFocus = _props$onFocus === void 0 ? function () {} : _props$onFocus,
        _props$onBlur = props.onBlur,
        onBlur = _props$onBlur === void 0 ? function () {} : _props$onBlur,
        _props$hitSlop = props.hitSlop,
        hitSlop = _props$hitSlop === void 0 ? 8 : _props$hitSlop,
        _props$disabled = props.disabled,
        disabled = _props$disabled === void 0 ? false : _props$disabled,
        style = props.style,
        nativeID = props.nativeID;
    var inputBackground = useBackground(style);
    return /*#__PURE__*/React__default["default"].createElement(Pressable, {
      ref: ref,
      accessibilityRole: type,
      accessibilityChecked: value,
      onPress: function onPress() {
        handleValueChange(!value);
      },
      onFocus: onFocus,
      onBlur: onBlur,
      hitSlop: hitSlop,
      disabled: disabled,
      style: inputBackground.style,
      nativeID: nativeID
    }, inputBackground.element);
  });
  FormCheckInputNative.displayName = 'FormCheckInputNative';
  FormCheckInputNative.propTypes = propTypes$1d;

  var _excluded$19 = ["type", "value", "onFocus", "onBlur", "disabled", "valid", "invalid", "useNativeComponent", "style"];

  var _templateObject$Y, _templateObject2$H, _templateObject3$m, _templateObject4$j, _templateObject5$g, _templateObject6$e, _templateObject7$9, _templateObject8$9, _templateObject9$9, _templateObject10$9, _templateObject11$6, _templateObject12$4, _templateObject13$4, _templateObject14$3, _templateObject15$2;
  /* eslint-disable react/no-unused-prop-types */

  var propTypes$1c = {
    type: PropTypes.oneOf(['checkbox', 'radio', 'switch']).isRequired,
    value: PropTypes.bool.isRequired,
    onFocus: PropTypes.func,
    onBlur: PropTypes.func,
    disabled: PropTypes.bool,
    valid: PropTypes.bool,
    invalid: PropTypes.bool,
    useNativeComponent: PropTypes.bool,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any // eslint-disable-next-line react/forbid-prop-types

  };
  /* eslint-enable */

  var styles$X = StyleSheet.create(_objectSpread2(_objectSpread2({
    '.form-check .form-check-input': css(_templateObject$Y || (_templateObject$Y = _taggedTemplateLiteral(["\n    // float: left;\n    // margin-left: $form-check-padding-start * -1;\n    margin-right: $form-check-padding-start - $form-check-input-width; // added for bootstrap-rn\n  "]))),
    '.form-check-reverse .form-check-input': css(_templateObject2$H || (_templateObject2$H = _taggedTemplateLiteral(["\n    // float: right;\n    // margin-right: $form-check-padding-start * -1;\n    margin-right: 0; // added for bootstrap-rn\n    // margin-left: 0;\n    margin-left: $form-check-padding-start - $form-check-input-width; // added for bootstrap-rn\n  "]))),
    '.form-check-input': css(_templateObject3$m || (_templateObject3$m = _taggedTemplateLiteral(["\n    width: $form-check-input-width;\n    height: $form-check-input-width;\n    // margin-top: ($line-height-base - $form-check-input-width) * 0.5; // line-height minus check height\n    // vertical-align: top;\n    background-color: $form-check-input-bg;\n    background-repeat: no-repeat;\n    background-position: center;\n    background-size: contain;\n    border: $form-check-input-border;\n    @include platform(web) {\n      appearance: none;\n      user-select: none; // added for bootstrap-rn\n      color-adjust: exact; // Keep themed appearance for print\n    }\n    // @include transition($form-check-transition);\n\n    &:active {\n      // filter: $form-check-input-active-filter;\n    }\n\n    &:focus {\n      border-color: $form-check-input-focus-border;\n      @include platform(web) {\n        outline-width: 0; // outline: 0;\n        box-shadow: $form-check-input-focus-box-shadow;\n      }\n    }\n  "]))),
    '.form-check-input[type="checkbox"]': css(_templateObject4$j || (_templateObject4$j = _taggedTemplateLiteral(["\n    border-radius: $form-check-input-border-radius;\n  "]))),
    '.form-check-input[type="radio"]': css(_templateObject5$g || (_templateObject5$g = _taggedTemplateLiteral(["\n    border-radius: $form-check-radio-border-radius;\n  "]))),
    '.form-check-input:checked': css(_templateObject6$e || (_templateObject6$e = _taggedTemplateLiteral(["\n    background-color: $form-check-input-checked-bg-color;\n    border-color: $form-check-input-checked-border-color;\n  "]))),
    '.form-check-input[type="checkbox"]:checked': css(_templateObject7$9 || (_templateObject7$9 = _taggedTemplateLiteral(["\n    // @if $enable-gradients {\n    //   background-image: escape-svg($form-check-input-checked-bg-image), var(--#{$variable-prefix}gradient);\n    // } @else {\n    background-image: ", ";\n    // }\n  "])), function (t) {
      return escapeSvg(t['form-check-input-checked-bg-image']);
    }),
    '.form-check-input[type="radio"]:checked': css(_templateObject8$9 || (_templateObject8$9 = _taggedTemplateLiteral(["\n    // @if $enable-gradients {\n    //   background-image: escape-svg($form-check-radio-checked-bg-image), var(--#{$variable-prefix}gradient);\n    // } @else {\n    background-image: ", ";\n    // }\n  "])), function (t) {
      return escapeSvg(t['form-check-radio-checked-bg-image']);
    }),
    '.form-check-input:disabled': css(_templateObject9$9 || (_templateObject9$9 = _taggedTemplateLiteral(["\n    @include platform(web) {\n      pointer-events: none;\n      filter: none;\n    }\n    opacity: $form-check-label-disabled-opacity;\n  "])))
  }, each(FORM_VALIDATION_STATES, function (state, data) {
    var _ref;

    return _ref = {}, _defineProperty(_ref, ".form-check-input:".concat(state), css(_templateObject10$9 || (_templateObject10$9 = _taggedTemplateLiteral(["\n      border-color: ", ";\n\n      &:focus {\n        border-color: ", "; // added for bootstrap-rn\n        @include platform(web) {\n          box-shadow: 0 0 $input-btn-focus-blur $input-focus-width\n            rgba(", ", $input-btn-focus-color-opacity);\n        }\n      }\n    "])), function (t) {
      return data(t).color;
    }, function (t) {
      return data(t).color;
    }, function (t) {
      return data(t).color;
    })), _defineProperty(_ref, ".form-check-input:".concat(state, ":checked"), css(_templateObject11$6 || (_templateObject11$6 = _taggedTemplateLiteral(["\n      background-color: ", ";\n    "])), function (t) {
      return data(t).color;
    })), _ref;
  })), {}, {
    '.form-switch.form-check .form-check-input': css(_templateObject12$4 || (_templateObject12$4 = _taggedTemplateLiteral(["\n    // float: left;\n    // margin-left: $form-switch-padding-start * -1;\n    margin-right: $form-switch-padding-start - $form-switch-width; // added for bootstrap-rn\n  "]))),
    '.form-switch.form-check-reverse .form-check-input': css(_templateObject13$4 || (_templateObject13$4 = _taggedTemplateLiteral(["\n    // margin-right: $form-switch-padding-start * -1;\n    margin-right: 0; // added for bootstrap-rn\n    // margin-left: 0;\n    margin-left: $form-switch-padding-start - $form-switch-width; // added for bootstrap-rn\n  "]))),
    '.form-switch .form-check-input': css(_templateObject14$3 || (_templateObject14$3 = _taggedTemplateLiteral(["\n    width: $form-switch-width;\n    background-image: ", ";\n    background-position: left center;\n    border-radius: $form-switch-border-radius;\n    // @include transition($form-switch-transition);\n\n    &:focus {\n      background-image: ", ";\n    }\n  "])), function (t) {
      return escapeSvg(t['form-switch-bg-image']);
    }, function (t) {
      return escapeSvg(t['form-switch-focus-bg-image']);
    }),
    '.form-switch .form-check-input:checked': css(_templateObject15$2 || (_templateObject15$2 = _taggedTemplateLiteral(["\n    background-position: $form-switch-checked-bg-position;\n\n    // @if $enable-gradients {\n    //   background-image: escape-svg($form-switch-checked-bg-image), var(--#{$prefix}gradient);\n    // } @else {\n    background-image: ", ";\n    // }\n\n    &:focus {\n      background-image: ", "; // added for bootstrap-rn\n    }\n  "])), function (t) {
      return escapeSvg(t['form-switch-checked-bg-image']);
    }, function (t) {
      return escapeSvg(t['form-switch-checked-bg-image']);
    })
  }));
  var FormCheckInput = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var _useModifier = useModifier('useFormField', props, ref),
        _useModifier2 = _slicedToArray(_useModifier, 2),
        modifierProps = _useModifier2[0],
        modifierRef = _useModifier2[1];

    var context = React.useContext(FormCheckContext);

    var type = modifierProps.type,
        value = modifierProps.value,
        _modifierProps$onFocu = modifierProps.onFocus,
        onFocus = _modifierProps$onFocu === void 0 ? function () {} : _modifierProps$onFocu,
        _modifierProps$onBlur = modifierProps.onBlur,
        onBlur = _modifierProps$onBlur === void 0 ? function () {} : _modifierProps$onBlur,
        _modifierProps$disabl = modifierProps.disabled,
        disabled = _modifierProps$disabl === void 0 ? context ? context.disabled : false : _modifierProps$disabl,
        _modifierProps$valid = modifierProps.valid,
        valid = _modifierProps$valid === void 0 ? context ? context.valid : false : _modifierProps$valid,
        _modifierProps$invali = modifierProps.invalid,
        invalid = _modifierProps$invali === void 0 ? context ? context.invalid : false : _modifierProps$invali,
        _modifierProps$useNat = modifierProps.useNativeComponent,
        useNativeComponent = _modifierProps$useNat === void 0 ? false : _modifierProps$useNat,
        style = modifierProps.style,
        elementProps = _objectWithoutProperties(modifierProps, _excluded$19);

    var media = useMedia();

    var _useState = React.useState(false),
        _useState2 = _slicedToArray(_useState, 2),
        focused = _useState2[0],
        setFocused = _useState2[1];

    var classes = getStyles(styles$X, [context && '.form-check .form-check-input', (context === null || context === void 0 ? void 0 : context.reverse) && '.form-check-reverse .form-check-input', '.form-check-input', type === 'checkbox' && '.form-check-input[type="checkbox"]', type === 'radio' && '.form-check-input[type="radio"]', value && '.form-check-input:checked', type === 'checkbox' && value && '.form-check-input[type="checkbox"]:checked', type === 'radio' && value && '.form-check-input[type="radio"]:checked', disabled && '.form-check-input:disabled', // validation
    valid && '.form-check-input:valid', valid && value && '.form-check-input:valid:checked', invalid && '.form-check-input:invalid', invalid && value && '.form-check-input:invalid:checked', // switch
    context && type === 'switch' && '.form-switch.form-check .form-check-input', (context === null || context === void 0 ? void 0 : context.reverse) && type === 'switch' && '.form-switch.form-check-reverse .form-check-input', type === 'switch' && '.form-switch .form-check-input', type === 'switch' && value && '.form-switch .form-check-input:checked']);
    var resolveStyle = useStyle([classes, style]);

    var handleFocus = function handleFocus() {
      setFocused(true);
      onFocus();
    };

    var handleBlur = function handleBlur() {
      setFocused(false);
      onBlur();
    };

    var BaseFormCheckInput = reactNative.Platform.OS === 'web' && !useNativeComponent ? FormCheckInputWeb : FormCheckInputNative;
    return /*#__PURE__*/React__default["default"].createElement(BaseFormCheckInput, _extends$1({}, elementProps, {
      ref: modifierRef,
      type: type,
      value: value,
      onFocus: handleFocus,
      onBlur: handleBlur,
      disabled: disabled,
      style: resolveStyle({
        media: media,
        interaction: {
          focused: focused
        }
      })
    }));
  });
  FormCheckInput.displayName = 'FormCheckInput';
  FormCheckInput.propTypes = propTypes$1c;

  var Checkbox = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var elementProps = _extends$1({}, props);

    return /*#__PURE__*/React__default["default"].createElement(FormCheckInput, _extends$1({}, elementProps, {
      ref: ref,
      type: "checkbox"
    }));
  });
  Checkbox.displayName = 'Checkbox';

  var _excluded$18 = ["children", "size", "sizeSm", "sizeMd", "sizeLg", "sizeXl", "style"];

  var _templateObject$X, _templateObject2$G, _templateObject3$l, _templateObject4$i, _templateObject5$f;
  var sizes = makeArray(GRID_COLUMNS).map(function (v) {
    return v + 1;
  });
  var propTypes$1b = {
    children: PropTypes.node.isRequired,
    size: PropTypes.oneOf(['auto'].concat(_toConsumableArray(sizes))),
    sizeSm: PropTypes.oneOf(['auto'].concat(_toConsumableArray(sizes))),
    sizeMd: PropTypes.oneOf(['auto'].concat(_toConsumableArray(sizes))),
    sizeLg: PropTypes.oneOf(['auto'].concat(_toConsumableArray(sizes))),
    sizeXl: PropTypes.oneOf(['auto'].concat(_toConsumableArray(sizes))),
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$W = StyleSheet.create(_objectSpread2({
    '*': css(_templateObject$X || (_templateObject$X = _taggedTemplateLiteral(["\n    // Add box sizing if only the grid is loaded\n    /* box-sizing: if(\n      variable-exists(include-column-box-sizing) and $include-column-box-sizing,\n      border-box,\n      null\n    ); */\n    // Prevent columns from becoming too narrow when at smaller grid tiers by\n    // always setting \"width: 100%;\". This works because we set the width\n    // later on to override this initial width.\n    flex-shrink: 0;\n    width: 100%;\n    @include platform(web) {\n      max-width: 100%; // Prevent \".col-auto\", \".col\" (& responsive variants) from breaking out the grid\n    }\n    padding-right: $grid-gutter-width * 0.5;\n    padding-left: $grid-gutter-width * 0.5;\n    margin-top: 0;\n  "])))
  }, each(GRID_BREAKPOINTS, function (breakpoint) {
    var _objectSpread2$1;

    return _objectSpread2((_objectSpread2$1 = {}, _defineProperty(_objectSpread2$1, ".col".concat(infix(breakpoint)), css(_templateObject2$G || (_templateObject2$G = _taggedTemplateLiteral(["\n      @include media-breakpoint-up(", ") {\n        flex: 1 0 0%; // Flexbugs #4: https://github.com/philipwalton/flexbugs#flexbug-4\n      }\n    "])), breakpoint)), _defineProperty(_objectSpread2$1, ".col".concat(infix(breakpoint), "-auto"), css(_templateObject3$l || (_templateObject3$l = _taggedTemplateLiteral(["\n      @include media-breakpoint-up(", ") {\n        flex: 0 0 auto;\n        width: auto;\n      }\n    "])), breakpoint)), _objectSpread2$1), normalize$1(makeArray(GRID_COLUMNS - 1, function (i) {
      var _ref;

      return _ref = {}, _defineProperty(_ref, ".col".concat(infix(breakpoint), "-").concat(i + 1), css(_templateObject4$i || (_templateObject4$i = _taggedTemplateLiteral(["\n          @include media-breakpoint-up(", ") {\n            flex: 0 0 auto;\n            width: ", "%;\n          }\n        "])), breakpoint, (i + 1) / GRID_COLUMNS * 100)), _defineProperty(_ref, ".offset".concat(infix(breakpoint), "-").concat(i), css(_templateObject5$f || (_templateObject5$f = _taggedTemplateLiteral(["\n          @include media-breakpoint-up(", ") {\n            margin-left: ", "%;\n          }\n        "])), breakpoint, i / GRID_COLUMNS * 100)), _ref;
    })));
  })));
  var Col = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        size = props.size,
        sizeSm = props.sizeSm,
        sizeMd = props.sizeMd,
        sizeLg = props.sizeLg,
        sizeXl = props.sizeXl,
        style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded$18);

    var classes = getStyles(styles$W, ['*', ".col-".concat(size.toString()), sizeSm && ".col-sm-".concat(sizeSm.toString()), sizeMd && ".col-md-".concat(sizeMd.toString()), sizeLg && ".col-lg-".concat(sizeLg.toString()), sizeXl && ".col-xl-".concat(sizeXl.toString())]);
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style]
    }), children);
  });
  Col.displayName = 'Col';
  Col.propTypes = propTypes$1b;

  var _excluded$17 = ["children", "style"];

  var _templateObject$W;
  var propTypes$1a = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$V = StyleSheet.create({
    code: css(_templateObject$W || (_templateObject$W = _taggedTemplateLiteral(["\n    font-family: $font-family-code;\n    font-size: $code-font-size;\n    color: $code-color;\n    @include platform(web) {\n      word-wrap: break-word;\n    }\n  "])))
  });
  var Code = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded$17);

    var classes = getStyles(styles$V, ['code']); // Accessiblity role code is only supported on web.

    var role = reactNative.Platform.OS === 'web' ? 'code' : null;
    return /*#__PURE__*/React__default["default"].createElement(Text, _extends$1({}, elementProps, {
      ref: ref,
      accessibilityRole: role,
      style: [classes, style]
    }), children);
  });
  Code.displayName = 'Code';
  Code.propTypes = propTypes$1a;

  var DropdownContext = /*#__PURE__*/React__default["default"].createContext();
  DropdownContext.displayName = 'DropdownContext';

  var _excluded$16 = ["onPress"];
  function useToggleDropdown(props) {
    var context = useForcedContext(DropdownContext);

    var handlePress = props.onPress,
        restProps = _objectWithoutProperties(props, _excluded$16);

    return _objectSpread2(_objectSpread2({}, restProps), {}, {
      nativeID: context.identifier,
      ref: context.toggleRef,
      onPress: function onPress(event) {
        if (handlePress) handlePress(event);
        context.setVisible(function (value) {
          return !value;
        });
      },
      accessibilityHasPopup: true,
      accessibilityExpanded: context.visible
    });
  }

  var propTypes$19 = {
    children: PropTypes.func.isRequired
  };

  var DropdownToggle = function DropdownToggle(props) {
    var children = props.children;
    return children(useToggleDropdown({}));
  };

  DropdownToggle.displayName = 'DropdownToggle';
  DropdownToggle.propTypes = propTypes$19;

  var propTypes$18 = {
    children: PropTypes.func.isRequired,
    placement: PropTypes.string.isRequired,
    targetRef: PropTypes.oneOfType([PropTypes.func, PropTypes.object]),
    offset: PropTypes.number,
    arrowOffset: PropTypes.number,
    visible: PropTypes.bool.isRequired
  };

  var Overlay = function Overlay(props) {
    var children = props.children,
        targetRef = props.targetRef,
        placement = props.placement,
        offset = props.offset,
        _props$arrowOffset = props.arrowOffset,
        arrowOffset = _props$arrowOffset === void 0 ? 0 : _props$arrowOffset,
        visible = props.visible;
    var overlayRef = React.useRef();
    var overlay = useOverlayPosition({
      placement: placement,
      targetRef: targetRef,
      overlayRef: overlayRef,
      offset: offset,
      isOpen: visible
    }); // Remove undefined arrow styles and adjust arrow offset.

    if (overlay.arrowProps.style.left === undefined) {
      delete overlay.arrowProps.style.left;

      if (overlay.arrowProps.style.top) {
        overlay.arrowProps.style.top -= arrowOffset;
      }
    }

    if (overlay.arrowProps.style.top === undefined) {
      delete overlay.arrowProps.style.top;

      if (overlay.arrowProps.style.left) {
        overlay.arrowProps.style.left -= arrowOffset;
      }
    } // Adjust bottom value by status bar height on Android


    if (reactNative.Platform.OS === 'android' && overlay.overlayProps.style.bottom !== undefined && reactNative.StatusBar.currentHeight) {
      overlay.overlayProps.style.bottom -= reactNative.StatusBar.currentHeight;
    }

    return children(overlay, overlayRef);
  };

  Overlay.displayName = 'Overlay';
  Overlay.propTypes = propTypes$18;

  var _templateObject$V;
  var propTypes$17 = {
    toggleRef: PropTypes.oneOfType([PropTypes.func, PropTypes.object]),
    dialogRef: PropTypes.oneOfType([PropTypes.func, PropTypes.object]),
    onClose: PropTypes.func,
    autoClose: PropTypes.oneOfType([PropTypes.bool, PropTypes.oneOf(['inside', 'outside'])]),
    backdrop: PropTypes.oneOfType([PropTypes.bool, PropTypes.oneOf(['static'])])
  };
  var styles$U = StyleSheet.create({
    handler: css(_templateObject$V || (_templateObject$V = _taggedTemplateLiteral(["\n    top: 0;\n    bottom: 0;\n    left: 0;\n    right: 0;\n    position: absolute;\n    flex-grow: 1;\n  "])))
  });
  var initialState = {
    waitingForMouseUp: false,
    ignoreBackdropClick: false
  };

  var BackdropHandler = function BackdropHandler(props) {
    var toggleRef = props.toggleRef,
        dialogRef = props.dialogRef,
        handleClose = props.onClose,
        _props$backdrop = props.backdrop,
        backdrop = _props$backdrop === void 0 ? true : _props$backdrop,
        _props$autoClose = props.autoClose,
        autoClose = _props$autoClose === void 0 ? 'outside' : _props$autoClose;

    if (reactNative.Platform.OS === 'web') {
      var state = React.useMemo(function () {
        return initialState;
      }, []);
      React.useEffect(function () {
        var toggle = toggleRef ? reactNative.findNodeHandle(toggleRef.current) : undefined;
        var dialog = reactNative.findNodeHandle(dialogRef.current);

        var handleDialogMouseDown = function handleDialogMouseDown() {
          state.waitingForMouseUp = true;
        }; // Workaround for chrome, because chrome does not fire onMouseDown event
        // for dialog when clicking on the <select> menu.


        var handleDialogMouseUp = function handleDialogMouseUp() {
          state.ignoreBackdropClick = true;
        };

        var handleDocumentClick = function handleDocumentClick(_ref) {
          var target = _ref.target;
          var isDialogClick = state.ignoreBackdropClick || dialog.contains(target);

          if (backdrop === 'static' || autoClose === false) {
            return;
          } // Click outside -> return if autoClose is inside.


          if (!isDialogClick && autoClose === 'inside') {
            return;
          } // Click inside / on dialog -> return if autoClose is outside.


          if (isDialogClick) {
            state.ignoreBackdropClick = false;

            if (autoClose === 'outside') {
              return;
            }
          } // Click on toggle -> return always.


          if (toggle && (target === toggle || toggle.contains(target))) {
            return;
          }

          handleClose();
        };

        var handleDocumentMouseUp = function handleDocumentMouseUp() {
          if (state.waitingForMouseUp) {
            state.ignoreBackdropClick = true;
          }

          state.waitingForMouseUp = false;
        };

        dialog.addEventListener('mousedown', handleDialogMouseDown);
        dialog.addEventListener('mouseup', handleDialogMouseUp); // See https://github.com/necolas/react-native-web/issues/2115

        document.addEventListener('click', handleDocumentClick, true);
        document.addEventListener('mouseup', handleDocumentMouseUp, true);
        return function () {
          dialog.addEventListener('mousedown', handleDialogMouseDown);
          dialog.addEventListener('mouseup', handleDialogMouseUp);
          document.removeEventListener('click', handleDocumentClick, true);
          document.removeEventListener('mouseup', handleDocumentMouseUp, true);
        };
      }, [backdrop, autoClose]);
      return null;
    }

    if (backdrop !== true) {
      return null;
    }

    return /*#__PURE__*/React__default["default"].createElement(Pressable, {
      style: styles$U.handler,
      onPress: function onPress() {
        handleClose();
      },
      accessible: false,
      importantForAccessibility: "no"
    });
  };

  BackdropHandler.displayName = 'BackdropHandler';
  BackdropHandler.propTypes = propTypes$17;

  var _excluded$15 = ["children", "start", "right", "end", "style", "textStyle"];

  var _templateObject$U, _templateObject2$F, _templateObject3$k, _templateObject4$h, _templateObject5$e, _templateObject6$d, _templateObject7$8, _templateObject8$8, _templateObject9$8, _templateObject10$8;
  var ALIGNMENT_BREAKPOINTS = [true, 'sm', 'md', 'lg', 'xl', 'xxl'];
  var propTypes$16 = {
    children: PropTypes.node.isRequired,
    start: PropTypes.oneOf(ALIGNMENT_BREAKPOINTS),
    right: PropTypes.oneOf(ALIGNMENT_BREAKPOINTS),
    end: PropTypes.oneOf(ALIGNMENT_BREAKPOINTS),
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any
  };
  var styles$T = StyleSheet.create(_objectSpread2(_objectSpread2(_objectSpread2({
    '.dropdown-menu': css(_templateObject$U || (_templateObject$U = _taggedTemplateLiteral(["\n    position: absolute;\n    z-index: $zindex-dropdown;\n    // display: none; // none by default, but block on \"open\" of the menu\n    min-width: $dropdown-min-width;\n    padding: $dropdown-padding-y $dropdown-padding-x;\n    margin: 0; // Override default margin of ul\n    // list-style: none;\n    background-color: $dropdown-bg;\n    // background-clip: padding-box;\n    border: $dropdown-border-width solid $dropdown-border-color;\n    border-radius: $dropdown-border-radius;\n    // @include box-shadow($dropdown-box-shadow);\n  "]))),
    '.dropdown-menu[data-bs-popper]': css(_templateObject2$F || (_templateObject2$F = _taggedTemplateLiteral(["\n    top: 100%;\n    left: 0;\n    margin-top: $dropdown-spacer;\n  "])))
  }, each(GRID_BREAKPOINTS, function (breakpoint) {
    var _ref;

    return _ref = {}, _defineProperty(_ref, ".dropdown-menu".concat(infix(breakpoint), "-start[data-bs-popper]"), css(_templateObject3$k || (_templateObject3$k = _taggedTemplateLiteral(["\n      @include media-breakpoint-up(", ") {\n        right: auto;\n        left: 0;\n      }\n    "])), breakpoint)), _defineProperty(_ref, ".dropdown-menu".concat(infix(breakpoint), "-end[data-bs-popper]"), css(_templateObject4$h || (_templateObject4$h = _taggedTemplateLiteral(["\n      @include media-breakpoint-up(", ") {\n        right: 0;\n        left: auto;\n      }\n    "])), breakpoint)), _ref;
  })), {}, {
    '.dropup .dropdown-menu[data-bs-popper]': css(_templateObject5$e || (_templateObject5$e = _taggedTemplateLiteral(["\n    top: auto;\n    bottom: 100%;\n    margin-top: 0;\n    margin-bottom: $dropdown-spacer;\n  "]))),
    '.dropend .dropdown-menu[data-bs-popper]': css(_templateObject6$d || (_templateObject6$d = _taggedTemplateLiteral(["\n    top: 0;\n    right: auto;\n    left: 100%;\n    margin-top: 0;\n    margin-left: $dropdown-spacer;\n  "]))),
    '.dropstart .dropdown-menu[data-bs-popper]': css(_templateObject7$8 || (_templateObject7$8 = _taggedTemplateLiteral(["\n    top: 0;\n    right: 100%;\n    left: auto;\n    margin-top: 0;\n    margin-right: $dropdown-spacer;\n  "]))),
    '.navbar-nav .dropdown-menu': css(_templateObject8$8 || (_templateObject8$8 = _taggedTemplateLiteral(["\n    position: relative; // static;\n  "])))
  }, each(GRID_BREAKPOINTS, function (breakpoint) {
    return _defineProperty({}, ".navbar-expand".concat(infix(next(breakpoint)), " .navbar-nav .dropdown-menu"), css(_templateObject9$8 || (_templateObject9$8 = _taggedTemplateLiteral(["\n      @include media-breakpoint-up(", ") {\n        position: absolute;\n      }\n    "])), next(breakpoint)));
  })), {}, {
    '.dropdown-menu --text': css(_templateObject10$8 || (_templateObject10$8 = _taggedTemplateLiteral(["\n    font-size: $dropdown-font-size;\n    color: $dropdown-color;\n    text-align: left; // Ensures proper alignment if parent has it changed (e.g., modal footer)\n  "])))
  }));

  var getAlignment = function getAlignment(media, start, end) {
    var alignStart = typeof start === 'boolean' ? start : media.up(start);
    var alignEnd = typeof end === 'boolean' ? end : media.up(end);

    if (!alignEnd) {
      return 'start';
    }

    if (!alignStart) {
      return 'end';
    }

    var startIndex = ALIGNMENT_BREAKPOINTS.indexOf(start);
    var endIndex = ALIGNMENT_BREAKPOINTS.indexOf(end);
    return startIndex > endIndex ? 'start' : 'end';
  };

  var transformPlacement = function transformPlacement(media, direction, start, end) {
    if (direction === 'start' || direction === 'end') {
      return "".concat(direction, " top");
    }

    return "".concat(direction, " ").concat(getAlignment(media, start, end));
  };

  var DropdownMenu = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        _props$start = props.start,
        start = _props$start === void 0 ? true : _props$start,
        right = props.right,
        _props$end = props.end,
        end = _props$end === void 0 ? false : _props$end,
        style = props.style,
        textStyle = props.textStyle,
        elementProps = _objectWithoutProperties(props, _excluded$15);

    if (right !== undefined) {
      // eslint-disable-next-line no-console
      console.warn('Prop "right" is deprecated, please use "end" instead.');
    }

    var navbar = React.useContext(NavbarContext);
    var media = useMedia();
    var dialogRef = React.useRef();
    var dropdown = useForcedContext(DropdownContext);
    var identifier = dropdown.identifier,
        toggleRef = dropdown.toggleRef,
        visible = dropdown.visible,
        setVisible = dropdown.setVisible,
        direction = dropdown.direction,
        display = dropdown.display,
        autoClose = dropdown.autoClose;

    if (!visible) {
      return null;
    }

    var isStatic = reactNative.Platform.OS === 'web' && display === 'static';
    var isCollapsedNavbar = navbar && !(navbar.expand && (navbar.expand === true || media.up(navbar.expand)));
    var hasStaticStyle = isStatic && !isCollapsedNavbar;
    var classes = getStyles(styles$T, ['.dropdown-menu', // Non-Popper styles
    hasStaticStyle && '.dropdown-menu[data-bs-popper]', hasStaticStyle && start && ".dropdown-menu".concat(start === true ? '' : "-".concat(start), "-start[data-bs-popper]"), hasStaticStyle && end && ".dropdown-menu".concat(end === true ? '' : "-".concat(end), "-end[data-bs-popper]"), hasStaticStyle && direction === 'up' && '.dropup .dropdown-menu[data-bs-popper]', hasStaticStyle && direction === 'end' && '.dropend .dropdown-menu[data-bs-popper]', hasStaticStyle && direction === 'start' && '.dropstart .dropdown-menu[data-bs-popper]', // Navbar styles
    navbar && '.navbar-nav .dropdown-menu', navbar && navbar.expand && ".navbar-expand".concat(navbar.expand === true ? '' : "-".concat(navbar.expand), " .navbar-nav .dropdown-menu")]);
    var textClasses = getStyles(styles$T, ['.dropdown-menu --text']);

    if (isStatic || isCollapsedNavbar) {
      return /*#__PURE__*/React__default["default"].createElement(React__default["default"].Fragment, null, !isCollapsedNavbar && /*#__PURE__*/React__default["default"].createElement(BackdropHandler, {
        toggleRef: toggleRef,
        dialogRef: dialogRef,
        onClose: function onClose() {
          setVisible(false);
        },
        autoClose: autoClose
      }), /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
        ref: concatRefs(dialogRef, ref),
        accessibilityLabelledBy: identifier,
        style: [classes, style],
        textStyle: [textClasses, textStyle]
      }), children));
    }

    return /*#__PURE__*/React__default["default"].createElement(OverlayContainer, null, /*#__PURE__*/React__default["default"].createElement(Overlay, {
      placement: transformPlacement(media, direction, start, end),
      targetRef: toggleRef,
      offset: convertToNumber(StyleSheet.value('dropdown-spacer')),
      visible: visible
    }, function (overlay, overlayRef) {
      return /*#__PURE__*/React__default["default"].createElement(React__default["default"].Fragment, null, /*#__PURE__*/React__default["default"].createElement(BackdropHandler, {
        toggleRef: toggleRef,
        dialogRef: overlayRef,
        onClose: function onClose() {
          setVisible(false);
        },
        autoClose: autoClose
      }), /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
        ref: concatRefs(overlayRef, ref),
        accessibilityLabelledBy: identifier,
        style: [classes, overlay.overlayProps.style, {
          maxHeight: 'auto',
          opacity: overlay.rendered ? 1 : 0
        }, style],
        textStyle: [textClasses, textStyle]
      }), /*#__PURE__*/React__default["default"].createElement(DropdownContext.Provider, {
        value: dropdown
      }, children)));
    }));
  });
  DropdownMenu.displayName = 'DropdownMenu';
  DropdownMenu.propTypes = propTypes$16;

  var _excluded$14 = ["children", "size", "style"];

  var _templateObject$T, _templateObject2$E;
  var propTypes$15 = {
    children: PropTypes.node.isRequired,
    size: PropTypes.oneOf(Object.keys(FONT_SIZES).map(function (k) {
      return Number(k);
    })).isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$S = StyleSheet.create(_objectSpread2({
    heading: css(_templateObject$T || (_templateObject$T = _taggedTemplateLiteral(["\n    margin-top: 0; // 1\n    margin-bottom: $headings-margin-bottom;\n    font-family: $headings-font-family;\n    font-style: $headings-font-style;\n    font-weight: $headings-font-weight;\n    color: $headings-color;\n  "])))
  }, each(FONT_SIZES, function (size, value) {
    return _defineProperty({}, ".h".concat(size), css(_templateObject2$E || (_templateObject2$E = _taggedTemplateLiteral(["\n      font-size: ", ";\n      line-height: ", " * $headings-line-height;\n    "])), value, value));
  })));
  var Heading$2 = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        size = props.size,
        style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded$14);

    var classes = getStyles(styles$S, ['heading', ".h".concat(size)]);
    return /*#__PURE__*/React__default["default"].createElement(Text, _extends$1({}, elementProps, {
      ref: ref,
      accessibilityRole: "header",
      accessibilityLevel: size,
      style: [classes, style]
    }), children);
  });
  Heading$2.displayName = 'Heading';
  Heading$2.propTypes = propTypes$15;

  var _excluded$13 = ["children", "style", "textStyle"];

  var _templateObject$S, _templateObject2$D;
  var propTypes$14 = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any
  };
  var styles$R = StyleSheet.create({
    '.dropdown-header': css(_templateObject$S || (_templateObject$S = _taggedTemplateLiteral(["\n    // display: block;\n    padding: $dropdown-header-padding;\n  "]))),
    '.dropdown-header --text': css(_templateObject2$D || (_templateObject2$D = _taggedTemplateLiteral(["\n    margin-bottom: 0; // for use with heading elements\n    font-size: $font-size-sm;\n    color: $dropdown-header-color;\n    // white-space: nowrap; // as with > li > a\n  "])))
  });
  var DropdownHeader = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        textStyle = props.textStyle,
        elementProps = _objectWithoutProperties(props, _excluded$13);

    var classes = getStyles(styles$R, ['.dropdown-header']);
    var textClasses = getStyles(styles$R, ['.dropdown-header --text']); // composite component

    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style]
    }), /*#__PURE__*/React__default["default"].createElement(Heading$2, {
      size: 6,
      style: [textClasses, textStyle]
    }, children));
  });
  DropdownHeader.displayName = 'DropdownHeader';
  DropdownHeader.propTypes = propTypes$14;

  var _excluded$12 = ["children", "onPress", "active", "disabled", "style", "textStyle"];

  var _templateObject$R, _templateObject2$C, _templateObject3$j, _templateObject4$g, _templateObject5$d, _templateObject6$c;
  var propTypes$13 = {
    children: PropTypes.node.isRequired,
    onPress: PropTypes.func,
    active: PropTypes.bool,
    disabled: PropTypes.bool,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any
  };
  var styles$Q = StyleSheet.create({
    '.dropdown-item': css(_templateObject$R || (_templateObject$R = _taggedTemplateLiteral(["\n    width: 100%;\n    padding: $dropdown-item-padding-y $dropdown-item-padding-x;\n    // clear: both;\n    background-color: transparent;\n    border: 0;\n\n    &:hover {\n      // @include gradient-bg($dropdown-link-hover-bg);\n      background-color: $dropdown-link-hover-bg;\n    }\n    &:focus {\n      // @include gradient-bg($dropdown-link-hover-bg);\n      background-color: $dropdown-link-hover-bg;\n    }\n  "]))),
    '.dropdown-item --text': css(_templateObject2$C || (_templateObject2$C = _taggedTemplateLiteral(["\n    font-weight: $font-weight-normal;\n    color: $dropdown-link-color;\n    // text-align: inherit;\n    text-decoration: none; // if($link-decoration == none, null, none);\n    // white-space: nowrap;\n\n    &:hover {\n      color: $dropdown-link-hover-color;\n      text-decoration: none; // if($link-hover-decoration == underline, none, null);\n    }\n    &:focus {\n      color: $dropdown-link-hover-color;\n      text-decoration: none; // if($link-hover-decoration == underline, none, null);\n    }\n  "]))),
    '.dropdown-item.active': css(_templateObject3$j || (_templateObject3$j = _taggedTemplateLiteral(["\n    // @include gradient-bg($dropdown-link-active-bg);\n    background-color: $dropdown-link-active-bg;\n\n    &:hover {\n      background-color: $dropdown-link-active-bg;\n    }\n    &:focus {\n      background-color: $dropdown-link-active-bg;\n    }\n  "]))),
    '.dropdown-item.active --text': css(_templateObject4$g || (_templateObject4$g = _taggedTemplateLiteral(["\n    color: $dropdown-link-active-color;\n    text-decoration: none;\n\n    &:hover {\n      color: $dropdown-link-active-color;\n    }\n    &:focus {\n      color: $dropdown-link-active-color;\n    }\n  "]))),
    '.dropdown-item.disabled': css(_templateObject5$d || (_templateObject5$d = _taggedTemplateLiteral(["\n    // pointer-events: none;\n    background-color: transparent;\n    // Remove CSS gradients if they're enabled\n    // background-image: if($enable-gradients, none, null);\n\n    &:hover {\n      background-color: transparent;\n    }\n    &:focus {\n      background-color: transparent;\n    }\n  "]))),
    '.dropdown-item.disabled --text': css(_templateObject6$c || (_templateObject6$c = _taggedTemplateLiteral(["\n    color: $dropdown-link-disabled-color;\n\n    &:hover {\n      color: $dropdown-link-disabled-color;\n    }\n    &:focus {\n      color: $dropdown-link-disabled-color;\n    }\n  "])))
  });

  var DropdownItem = function DropdownItem(props) {
    var children = props.children,
        handlePress = props.onPress,
        _props$active = props.active,
        active = _props$active === void 0 ? false : _props$active,
        _props$disabled = props.disabled,
        disabled = _props$disabled === void 0 ? false : _props$disabled,
        style = props.style,
        textStyle = props.textStyle,
        elementProps = _objectWithoutProperties(props, _excluded$12);

    var dropdown = useForcedContext(DropdownContext);
    var classes = getStyles(styles$Q, ['.dropdown-item', active && '.dropdown-item.active', disabled && '.dropdown-item.disabled']);
    var textClasses = getStyles(styles$Q, ['.dropdown-item --text', active && '.dropdown-item.active --text', disabled && '.dropdown-item.disabled --text']);
    return /*#__PURE__*/React__default["default"].createElement(Pressable, _extends$1({}, elementProps, {
      onPress: concatFns(function () {
        dropdown.setVisible(false);
      }, handlePress),
      disabled: disabled,
      style: [classes, style],
      textStyle: [textClasses, textStyle]
    }), children);
  };

  DropdownItem.displayName = 'DropdownItem';
  DropdownItem.propTypes = propTypes$13;

  var _excluded$11 = ["children", "style", "textStyle"];

  var _templateObject$Q, _templateObject2$B;
  var propTypes$12 = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any
  };
  var styles$P = StyleSheet.create({
    '.dropdown-item-text': css(_templateObject$Q || (_templateObject$Q = _taggedTemplateLiteral(["\n    // display: block;\n    padding: $dropdown-item-padding-y $dropdown-item-padding-x;\n  "]))),
    '.dropdown-item-text --text': css(_templateObject2$B || (_templateObject2$B = _taggedTemplateLiteral(["\n    color: $dropdown-link-color;\n  "])))
  });
  var DropdownItemText = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        textStyle = props.textStyle,
        elementProps = _objectWithoutProperties(props, _excluded$11);

    var classes = getStyles(styles$P, ['.dropdown-item-text']);
    var textClasses = getStyles(styles$P, ['.dropdown-item-text --text']); // composite component

    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style]
    }), /*#__PURE__*/React__default["default"].createElement(Text, {
      style: [textClasses, textStyle]
    }, children));
  });
  DropdownItemText.displayName = 'DropdownItemText';
  DropdownItemText.propTypes = propTypes$12;

  var _excluded$10 = ["style"];

  var _templateObject$P;
  var propTypes$11 = {
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$O = StyleSheet.create({
    '.dropdown-divider': css(_templateObject$P || (_templateObject$P = _taggedTemplateLiteral(["\n    height: 0;\n    margin: $dropdown-divider-margin-y 0;\n    overflow: hidden;\n    border-top-width: 1px;\n    border-style: solid;\n    border-color: $dropdown-divider-bg;\n  "])))
  });
  var DropdownDivider = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded$10);

    var classes = getStyles(styles$O, ['.dropdown-divider']);
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style]
    }));
  });
  DropdownDivider.displayName = 'DropdownDivider';
  DropdownDivider.propTypes = propTypes$11;

  function useDropdown(defaultVisible, controlledVisible, onToggle, direction, display, autoClose) {
    var identifier = useIdentifier('dropdown');
    var toggleRef = React.useRef();

    var _useControlledState = useControlledState(defaultVisible, controlledVisible, onToggle),
        _useControlledState2 = _slicedToArray(_useControlledState, 2),
        visible = _useControlledState2[0],
        setVisible = _useControlledState2[1];

    return React.useMemo(function () {
      return {
        identifier: identifier,
        visible: visible,
        setVisible: setVisible,
        toggleRef: toggleRef,
        direction: direction,
        display: display,
        autoClose: autoClose
      };
    }, [visible]);
  }

  var _excluded$$ = ["onPress"];
  function useDismissDropdown(props) {
    var context = useForcedContext(DropdownContext);

    var handlePress = props.onPress,
        restProps = _objectWithoutProperties(props, _excluded$$);

    return _objectSpread2(_objectSpread2({}, restProps), {}, {
      onPress: function onPress(event) {
        if (handlePress) handlePress(event);
        context.setVisible(false);
      }
    });
  }

  var _excluded$_ = ["children", "defaultVisible", "visible", "onToggle", "direction", "display", "autoClose", "style"];

  var _templateObject$O;
  var DIRECTIONS = ['top', 'bottom', 'start', 'end'];
  var propTypes$10 = {
    children: PropTypes.node,
    defaultVisible: PropTypes.bool,
    visible: PropTypes.bool,
    onToggle: PropTypes.func,
    direction: PropTypes.oneOf(DIRECTIONS),
    display: PropTypes.oneOf(['dynamic', 'static']),
    autoClose: PropTypes.oneOfType([PropTypes.bool, PropTypes.oneOf(['inside', 'outside'])]),
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$N = StyleSheet.create({
    '.dropdown': css(_templateObject$O || (_templateObject$O = _taggedTemplateLiteral(["\n    position: relative;\n  "])))
  });
  var Dropdown = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        _props$defaultVisible = props.defaultVisible,
        defaultVisible = _props$defaultVisible === void 0 ? false : _props$defaultVisible,
        visible = props.visible,
        onToggle = props.onToggle,
        _props$direction = props.direction,
        direction = _props$direction === void 0 ? 'bottom' : _props$direction,
        _props$display = props.display,
        display = _props$display === void 0 ? 'dynamic' : _props$display,
        _props$autoClose = props.autoClose,
        autoClose = _props$autoClose === void 0 ? 'outside' : _props$autoClose,
        style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded$_);

    var dropdown = useDropdown(defaultVisible, visible, onToggle, direction, display, autoClose);
    var classes = getStyles(styles$N, ['.dropdown']);
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style]
    }), /*#__PURE__*/React__default["default"].createElement(DropdownContext.Provider, {
      value: dropdown
    }, children));
  });
  Dropdown.displayName = 'Dropdown';
  Dropdown.propTypes = propTypes$10;
  Dropdown.Context = DropdownContext;
  Dropdown.Toggle = DropdownToggle;
  Dropdown.Menu = DropdownMenu;
  Dropdown.Header = DropdownHeader;
  Dropdown.Item = DropdownItem;
  Dropdown.ItemText = DropdownItemText;
  Dropdown.Divider = DropdownDivider;
  Dropdown.useDismiss = useDismissDropdown;
  Dropdown.useToggle = useToggleDropdown;

  var _excluded$Z = ["children", "size", "style"];

  var _templateObject$N;
  var propTypes$$ = {
    children: PropTypes.node.isRequired,
    size: PropTypes.oneOf(Object.keys(DISPLAY_FONT_SIZES).map(function (k) {
      return Number(k);
    })).isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$M = StyleSheet.create(_objectSpread2({}, each(DISPLAY_FONT_SIZES, function (size, value) {
    return _defineProperty({}, ".display-".concat(size), css(_templateObject$N || (_templateObject$N = _taggedTemplateLiteral(["\n      font-size: ", ";\n      line-height: ", " * $headings-line-height;\n    "])), value, value));
  })));
  var DisplayHeading = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        size = props.size,
        style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded$Z);

    var classes = getStyles(styles$M, [".display-".concat(size)]);
    return /*#__PURE__*/React__default["default"].createElement(Heading$2, _extends$1({}, elementProps, {
      ref: ref,
      size: 1,
      style: [classes, style]
    }), children);
  });
  DisplayHeading.displayName = 'Heading';
  DisplayHeading.propTypes = propTypes$$;

  var _excluded$Y = ["children", "type", "style"];

  var _templateObject$M;
  var propTypes$_ = {
    children: PropTypes.node.isRequired,
    type: PropTypes.oneOf(Object.keys(FORM_VALIDATION_STATES)),
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$L = StyleSheet.create(_objectSpread2({}, each(FORM_VALIDATION_STATES, function (state, data) {
    return _defineProperty({}, ".".concat(state, "-feedback"), css(_templateObject$M || (_templateObject$M = _taggedTemplateLiteral(["\n      // display: none;\n      width: 100%;\n      margin-top: $form-feedback-margin-top;\n      font-size: $form-feedback-font-size;\n      font-style: $form-feedback-font-style;\n      color: ", ";\n    "])), function (t) {
      return data(t).color;
    }));
  })));
  var Feedback = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        type = props.type,
        style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded$Y);

    var classes = getStyles(styles$L, [".".concat(type, "-feedback")]);
    return /*#__PURE__*/React__default["default"].createElement(Text, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style]
    }), children);
  });
  Feedback.displayName = 'Feedback';
  Feedback.propTypes = propTypes$_;

  var _excluded$X = ["children", "htmlFor"];
  var propTypes$Z = {
    children: PropTypes.node.isRequired,
    htmlFor: PropTypes.string
  };
  var Heading$1 = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        htmlFor = props.htmlFor,
        elementProps = _objectWithoutProperties(props, _excluded$X); // Ref: https://github.com/necolas/react-native-web/issues/1651


    var forRef = React__default["default"].useCallback(function (node) {
      if (reactNative.Platform.OS !== 'web' || !htmlFor || !node) {
        return;
      }

      node.setAttribute('for', htmlFor);
    }, []);
    var role = reactNative.Platform.OS === 'web' ? 'label' : null;
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: concatRefs(forRef, ref),
      accessibilityRole: role
    }), children);
  });
  Heading$1.displayName = 'Heading';
  Heading$1.propTypes = propTypes$Z;

  var _excluded$W = ["children", "style", "textStyle"];

  var _templateObject$L, _templateObject2$A, _templateObject3$i, _templateObject4$f;
  var propTypes$Y = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any
  };
  var styles$K = StyleSheet.create(_objectSpread2({
    '.form-check-input:disabled ~ .form-check-label': css(_templateObject$L || (_templateObject$L = _taggedTemplateLiteral(["\n    @include platform(web) {\n      cursor: default;\n    }\n    opacity: $form-check-label-disabled-opacity;\n  "]))),
    '.form-check-label': css(_templateObject2$A || (_templateObject2$A = _taggedTemplateLiteral(["\n    @include platform(web) {\n      cursor: $form-check-label-cursor;\n    }\n  "]))),
    '.form-check-label --text': css(_templateObject3$i || (_templateObject3$i = _taggedTemplateLiteral(["\n    color: $form-check-label-color;\n  "])))
  }, each(FORM_VALIDATION_STATES, function (state, data) {
    return _defineProperty({}, ".form-check-input:".concat(state, " ~ .form-check-label --text"), css(_templateObject4$f || (_templateObject4$f = _taggedTemplateLiteral(["\n      color: ", ";\n    "])), function (t) {
      return data(t).color;
    }));
  })));
  var FormCheckLabel = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        textStyle = props.textStyle,
        elementProps = _objectWithoutProperties(props, _excluded$W);

    var _useForcedContext = useForcedContext(FormCheckContext),
        disabled = _useForcedContext.disabled,
        valid = _useForcedContext.valid,
        invalid = _useForcedContext.invalid;

    var classes = getStyles(styles$K, [disabled && '.form-check-input:disabled ~ .form-check-label', '.form-check-label']);
    var textClasses = getStyles(styles$K, ['.form-check-label --text', // validation
    valid && '.form-check-input:valid ~ .form-check-label --text', invalid && '.form-check-input:invalid ~ .form-check-label --text']);
    return /*#__PURE__*/React__default["default"].createElement(Heading$1, _extends$1({}, elementProps, {
      ref: ref,
      disabled: disabled,
      style: [classes, style],
      textStyle: [textClasses, textStyle]
    }), children);
  });
  FormCheckLabel.displayName = 'FormCheckLabel';
  FormCheckLabel.propTypes = propTypes$Y;

  var _excluded$V = ["children", "reverse", "disabled", "valid", "invalid", "style"];

  var _templateObject$K, _templateObject2$z, _templateObject3$h;
  var propTypes$X = {
    children: PropTypes.node.isRequired,
    reverse: PropTypes.bool,
    disabled: PropTypes.bool,
    valid: PropTypes.bool,
    invalid: PropTypes.bool,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$J = StyleSheet.create({
    '.form-check': css(_templateObject$K || (_templateObject$K = _taggedTemplateLiteral(["\n    // display: block;\n    flex-direction: row; // added for bootstrap-rn\n    align-items: center; // added for bootstrap-rn\n    min-height: $form-check-min-height;\n    // padding-left: $form-check-padding-start;\n    margin-bottom: $form-check-margin-bottom;\n  "]))),
    '.form-check-reverse': css(_templateObject2$z || (_templateObject2$z = _taggedTemplateLiteral(["\n    flex-direction: row-reverse; // added for bootstrap-rn\n    // padding-right: $form-check-padding-start;\n    // padding-left: 0;\n    // text-align: right;\n  "]))),
    '.form-switch.form-check': css(_templateObject3$h || (_templateObject3$h = _taggedTemplateLiteral(["\n    // padding-left: $form-switch-padding-start;\n  "])))
  });
  var FormCheck = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        _props$reverse = props.reverse,
        reverse = _props$reverse === void 0 ? false : _props$reverse,
        _props$disabled = props.disabled,
        disabled = _props$disabled === void 0 ? false : _props$disabled,
        _props$valid = props.valid,
        valid = _props$valid === void 0 ? false : _props$valid,
        _props$invalid = props.invalid,
        invalid = _props$invalid === void 0 ? false : _props$invalid,
        style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded$V);

    var classes = getStyles(styles$J, ['.form-check', reverse && '.form-check-reverse']);
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style]
    }), /*#__PURE__*/React__default["default"].createElement(FormCheckContext.Provider, {
      value: {
        reverse: reverse,
        disabled: disabled,
        valid: valid,
        invalid: invalid
      }
    }, children));
  });
  FormCheck.displayName = 'FormCheck';
  FormCheck.propTypes = propTypes$X;
  FormCheck.Label = FormCheckLabel;

  var _excluded$U = ["children", "style", "textStyle"];

  var _templateObject$J, _templateObject2$y;
  var propTypes$W = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any
  };
  var styles$I = StyleSheet.create({
    '.form-label': css(_templateObject$J || (_templateObject$J = _taggedTemplateLiteral(["\n    margin-bottom: $form-label-margin-bottom;\n  "]))),
    '.form-label --text': css(_templateObject2$y || (_templateObject2$y = _taggedTemplateLiteral(["\n    font-size: $form-label-font-size;\n    line-height: $form-label-font-size * $line-height-base; // added for bootstrap-rn\n    font-style: $form-label-font-style;\n    font-weight: $form-label-font-weight;\n    color: $form-label-color;\n  "])))
  });
  var FormLabel = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        textStyle = props.textStyle,
        elementProps = _objectWithoutProperties(props, _excluded$U);

    var classes = getStyles(styles$I, ['.form-label']);
    var textClasses = getStyles(styles$I, ['.form-label --text']);
    return /*#__PURE__*/React__default["default"].createElement(Heading$1, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style],
      textStyle: [textClasses, textStyle]
    }), children);
  });
  FormLabel.displayName = 'FormLabel';
  FormLabel.propTypes = propTypes$W;

  var _excluded$T = ["children", "style", "textStyle"];

  var _templateObject$I, _templateObject2$x;
  var propTypes$V = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any
  };
  var styles$H = StyleSheet.create({
    '.form-text': css(_templateObject$I || (_templateObject$I = _taggedTemplateLiteral(["\n    margin-top: $form-text-margin-top;\n  "]))),
    '.form-text --text': css(_templateObject2$x || (_templateObject2$x = _taggedTemplateLiteral(["\n    font-size: $form-text-font-size;\n    font-style: $form-text-font-style;\n    font-weight: $form-text-font-weight;\n    color: $form-text-color;\n  "])))
  });
  var FormText = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        textStyle = props.textStyle,
        elementProps = _objectWithoutProperties(props, _excluded$T);

    var classes = getStyles(styles$H, ['.form-text']);
    var textClasses = getStyles(styles$H, ['.form-text --text']); // composite component

    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style]
    }), /*#__PURE__*/React__default["default"].createElement(Text, {
      style: [textClasses, textStyle]
    }, children));
  });
  FormText.displayName = 'FormText';
  FormText.propTypes = propTypes$V;

  var _excluded$S = ["onFocus", "onBlur", "style", "styleName"];
  var propTypes$U = {
    onFocus: PropTypes.func,
    onBlur: PropTypes.func,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    styleName: PropTypes.any
  };
  var TextInput = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var _props$onFocus = props.onFocus,
        _onFocus = _props$onFocus === void 0 ? function () {} : _props$onFocus,
        _props$onBlur = props.onBlur,
        _onBlur = _props$onBlur === void 0 ? function () {} : _props$onBlur,
        style = props.style,
        styleName = props.styleName,
        elementProps = _objectWithoutProperties(props, _excluded$S);

    var _useState = React.useState(false),
        _useState2 = _slicedToArray(_useState, 2),
        focused = _useState2[0],
        setFocused = _useState2[1];

    var media = useMedia();
    var resolveStyle = useStyle(style, styleName);
    return /*#__PURE__*/React__default["default"].createElement(reactNative.TextInput, _extends$1({}, elementProps, {
      ref: ref,
      onFocus: function onFocus() {
        setFocused(true);

        _onFocus();
      },
      onBlur: function onBlur() {
        setFocused(false);

        _onBlur();
      },
      style: resolveStyle({
        media: media,
        interaction: {
          focused: focused
        }
      })
    }));
  });
  TextInput.displayName = 'TextInput';
  TextInput.propTypes = propTypes$U;

  var _excluded$R = ["size", "placeholderTextColor", "multiline", "disabled", "valid", "invalid", "editable", "selectTextOnFocus", "style"];

  var _templateObject$H, _templateObject2$w, _templateObject3$g, _templateObject4$e, _templateObject5$c, _templateObject6$b, _templateObject7$7, _templateObject8$7, _templateObject9$7, _templateObject10$7, _templateObject11$5;
  var propTypes$T = {
    size: PropTypes.oneOf(['sm', 'lg']),
    placeholderTextColor: PropTypes.string,
    multiline: PropTypes.bool,
    disabled: PropTypes.bool,
    valid: PropTypes.bool,
    invalid: PropTypes.bool,
    editable: PropTypes.bool,
    selectTextOnFocus: PropTypes.bool,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  }; // Known issues:
  //
  // line-height (iOS)
  // If a line height is defined on iOS the text will be displayed on the bottom
  // of the line. As a workaround the line height is only defined for multi line
  // inputs.
  //
  // multi line height (iOS)
  // A multi line input on iOS has only the height of a single line input. As a
  // workaround we added a height of $input-height-sm + 8rem for multi line
  // inputs on iOS.
  //
  // single line height (Android)
  // If no height is defined, Android sets a text line height of 28px auto-
  // matically, which leads to a larger height than min height for the default
  // and sm size. As a workaround we set a height for single line inputs.

  var styles$G = StyleSheet.create(_objectSpread2({
    '.form-control': css(_templateObject$H || (_templateObject$H = _taggedTemplateLiteral(["\n    // display: block;\n    width: 100%;\n    min-height: $input-height; // added for bootstrap-rn\n    padding: $input-padding-y $input-padding-x;\n    font-family: $input-font-family;\n    font-size: $input-font-size;\n    font-weight: $input-font-weight;\n    @include platform(web) {\n      line-height: $input-font-size * $input-line-height;\n    }\n    color: $input-color;\n    background-color: $input-bg;\n    // background-clip: padding-box;\n    border: $input-border-width solid $input-border-color;\n    @include platform(web) {\n      appearance: none; // Fix appearance for date inputs in Safari\n    }\n\n    // Note: This has no effect on <select>s in some browsers, due to the limited stylability of \"<select>\"s in CSS.\n    border-radius: $input-border-radius;\n\n    // @include box-shadow($input-box-shadow);\n    // @include transition($input-transition);\n\n    // Customize the \":focus\" state to imitate native WebKit styles.\n    &:focus {\n      color: $input-focus-color;\n      background-color: $input-focus-bg;\n      border-color: $input-focus-border-color;\n      @include platform(web) {\n        outline-width: 0; // outline: 0;\n        // @if $enable-shadows {\n        //   @include box-shadow($input-box-shadow, $input-focus-box-shadow);\n        // } @else {\n        //   // Avoid using mixin so we can pass custom focus shadow properly\n        box-shadow: $input-focus-box-shadow;\n        // }\n      }\n    }\n  "]))),
    '.form-control.disabled': css(_templateObject2$w || (_templateObject2$w = _taggedTemplateLiteral(["\n    background-color: $input-disabled-bg;\n    border-color: $input-disabled-border-color;\n    // iOS fix for unreadable disabled content; see https://github.com/twbs/bootstrap/issues/11655.\n    opacity: 1;\n  "]))),
    '.form-control-sm': css(_templateObject3$g || (_templateObject3$g = _taggedTemplateLiteral(["\n    min-height: $input-height-sm;\n    padding: $input-padding-y-sm $input-padding-x-sm;\n    font-size: $input-font-size-sm;\n    @include platform(web) {\n      line-height: $input-font-size-sm * $line-height-base; // added for bootstrap-rn\n    }\n    border-radius: $input-border-radius-sm;\n  "]))),
    '.form-control-lg': css(_templateObject4$e || (_templateObject4$e = _taggedTemplateLiteral(["\n    min-height: $input-height-lg;\n    padding: $input-padding-y-lg $input-padding-x-lg;\n    font-size: $input-font-size-lg;\n    @include platform(web) {\n      line-height: $input-font-size-lg * $line-height-base; // added for bootstrap-rn\n    }\n    border-radius: $input-border-radius-lg;\n  "]))),
    '.form-control:not(textarea)': css(_templateObject5$c || (_templateObject5$c = _taggedTemplateLiteral(["\n    @include platform(android) {\n      height: $input-height; // added for bootstrap-rn\n    }\n  "]))),
    '.form-control-sm:not(textarea)': css(_templateObject6$b || (_templateObject6$b = _taggedTemplateLiteral(["\n    @include platform(android) {\n      height: $input-height-sm; // added for bootstrap-rn\n    }\n  "]))),
    '.form-control-lg:not(textarea)': css(_templateObject7$7 || (_templateObject7$7 = _taggedTemplateLiteral(["\n    @include platform(android) {\n      height: $input-height-lg; // added for bootstrap-rn\n    }\n  "]))),
    'textarea.form-control': css(_templateObject8$7 || (_templateObject8$7 = _taggedTemplateLiteral(["\n    text-align-vertical: top; // added for bootstrap-rn\n    min-height: $input-height;\n\n    @include platform(ios) {\n      min-height: $input-height-sm + 8rem; // added for bootstrap-rn\n    }\n    @include platform(native) {\n      line-height: $input-font-size * $input-line-height; // added for bootstrap-rn\n    }\n  "]))),
    'textarea.form-control-sm': css(_templateObject9$7 || (_templateObject9$7 = _taggedTemplateLiteral(["\n    min-height: $input-height-sm;\n\n    @include platform(ios) {\n      // TODO: Adjust ios height to sm size\n      min-height: $input-height-sm + 8rem; // added for bootstrap-rn\n    }\n    @include platform(native) {\n      line-height: $input-font-size-sm * $line-height-base; // added for bootstrap-rn\n    }\n  "]))),
    'textarea.form-control-lg': css(_templateObject10$7 || (_templateObject10$7 = _taggedTemplateLiteral(["\n    min-height: $input-height-lg;\n\n    @include platform(ios) {\n      // TODO: Adjust ios height to lg size\n      min-height: $input-height-sm + 8rem; // added for bootstrap-rn\n    }\n    @include platform(native) {\n      line-height: $input-font-size-sm * $line-height-base; // added for bootstrap-rn\n    }\n  "])))
  }, each(FORM_VALIDATION_STATES, function (state, data) {
    return _defineProperty({}, ".form-control:".concat(state), css(_templateObject11$5 || (_templateObject11$5 = _taggedTemplateLiteral(["\n      border-color: ", ";\n\n      &:focus {\n        border-color: ", ";\n        @include platform(web) {\n          box-shadow: 0 0 $input-btn-focus-blur $input-focus-width\n            rgba(", ", $input-btn-focus-color-opacity);\n        }\n      }\n    "])), function (t) {
      return data(t).color;
    }, function (t) {
      return data(t).color;
    }, function (t) {
      return data(t).color;
    }));
  })));
  var Input = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var _useModifier = useModifier('useFormField', props, ref),
        _useModifier2 = _slicedToArray(_useModifier, 2),
        modifierProps = _useModifier2[0],
        modifierRef = _useModifier2[1];

    var size = modifierProps.size,
        _modifierProps$placeh = modifierProps.placeholderTextColor,
        placeholderTextColor = _modifierProps$placeh === void 0 ? StyleSheet.value('input-placeholder-color') : _modifierProps$placeh,
        _modifierProps$multil = modifierProps.multiline,
        multiline = _modifierProps$multil === void 0 ? false : _modifierProps$multil,
        _modifierProps$disabl = modifierProps.disabled,
        disabled = _modifierProps$disabl === void 0 ? false : _modifierProps$disabl,
        _modifierProps$valid = modifierProps.valid,
        valid = _modifierProps$valid === void 0 ? false : _modifierProps$valid,
        _modifierProps$invali = modifierProps.invalid,
        invalid = _modifierProps$invali === void 0 ? false : _modifierProps$invali,
        _modifierProps$editab = modifierProps.editable,
        editable = _modifierProps$editab === void 0 ? true : _modifierProps$editab,
        _modifierProps$select = modifierProps.selectTextOnFocus,
        selectTextOnFocus = _modifierProps$select === void 0 ? true : _modifierProps$select,
        style = modifierProps.style,
        elementProps = _objectWithoutProperties(modifierProps, _excluded$R);

    var classes = getStyles(styles$G, ['.form-control', disabled && '.form-control.disabled', size === 'sm' && '.form-control-sm', size === 'lg' && '.form-control-lg', !multiline && '.form-control:not(textarea)', !multiline && size === 'sm' && '.form-control-sm:not(textarea)', !multiline && size === 'lg' && '.form-control-lg:not(textarea)', multiline && 'textarea.form-control', multiline && size === 'sm' && 'textarea.form-control-sm', multiline && size === 'lg' && 'textarea.form-control-lg', valid && '.form-control:valid', invalid && '.form-control:invalid']);
    return /*#__PURE__*/React__default["default"].createElement(TextInput, _extends$1({}, elementProps, {
      ref: modifierRef,
      placeholderTextColor: placeholderTextColor,
      multiline: multiline,
      disabled: disabled,
      editable: disabled ? !disabled : editable,
      selectTextOnFocus: disabled ? !disabled : selectTextOnFocus,
      style: [classes, style]
    }));
  });
  Input.displayName = 'Input';
  Input.propTypes = propTypes$T;

  var PLACEMENTS$1 = ['top', 'bottom', 'left', 'right'];
  var TRIGGERS = ['press', 'hover', 'focus', 'manual', 'press hover', 'hover press', 'hover focus', 'focus hover', 'press focus', 'focus press'];
  var TriggerPropTypes = {
    trigger: PropTypes.oneOf(TRIGGERS),
    placement: PropTypes.oneOf(PLACEMENTS$1),
    offset: PropTypes.number,
    defaultVisible: PropTypes.bool,
    visible: PropTypes.bool,
    onToggle: PropTypes.func
  };
  function useTrigger(rawTrigger, props, elementProps, ref) {
    var _props$defaultVisible = props.defaultVisible,
        defaultVisible = _props$defaultVisible === void 0 ? false : _props$defaultVisible,
        controlledVisible = props.visible,
        onToggle = props.onToggle;
    var _onPress = elementProps.onPress,
        _onFocus = elementProps.onFocus,
        _onBlur = elementProps.onBlur,
        _onMouseOver = elementProps.onMouseOver,
        _onMouseLeave = elementProps.onMouseLeave;
    var trigger = rawTrigger.split(' ');
    var identifier = useIdentifier('overlay');

    var _useControlledState = useControlledState(defaultVisible, controlledVisible, onToggle),
        _useControlledState2 = _slicedToArray(_useControlledState, 2),
        visible = _useControlledState2[0],
        setVisible = _useControlledState2[1];

    var _useState = React.useState(false),
        _useState2 = _slicedToArray(_useState, 2),
        focused = _useState2[0],
        setFocused = _useState2[1];

    var _useState3 = React.useState(false),
        _useState4 = _slicedToArray(_useState3, 2),
        hovered = _useState4[0],
        setHovered = _useState4[1];

    var targetRef = React.useRef();
    return {
      visible: visible,
      setVisible: setVisible,
      targetProps: _objectSpread2(_objectSpread2({
        ref: concatRefs(targetRef, ref)
      }, optional(visible, {
        accessibilityDescribedBy: identifier
      })), {}, {
        onPress: function onPress(event) {
          var handleHoverAsPress = (reactNative.Platform.OS === 'android' || reactNative.Platform.OS === 'ios') && trigger.includes('hover');

          if (trigger.includes('press') || handleHoverAsPress) {
            setVisible(function (value) {
              return !value;
            });
          }

          if (_onPress) {
            _onPress(event);
          }
        },
        onFocus: function onFocus(event) {
          if (trigger.includes('focus')) {
            setFocused(true);

            if (!visible) {
              setVisible(true);
            }
          }

          if (_onFocus) {
            _onFocus(event);
          }
        },
        onBlur: function onBlur(event) {
          if (trigger.includes('focus')) {
            setFocused(false);
            var activeHoverTrigger = trigger.includes('hover') && hovered;

            if (visible && !activeHoverTrigger) {
              setVisible(false);
            }
          }

          if (_onBlur) {
            _onBlur(event);
          }
        },
        onMouseOver: function onMouseOver(event) {
          if (trigger.includes('hover')) {
            setHovered(true);

            if (!visible && !focused) {
              setVisible(true);
            }
          }

          if (_onMouseOver) {
            _onMouseOver(event);
          }
        },
        onMouseLeave: function onMouseLeave(event) {
          if (trigger.includes('hover')) {
            setHovered(false);
            var activeFocusTrigger = trigger.includes('focus') && focused;

            if (visible && !activeFocusTrigger) {
              setVisible(false);
            }
          }

          if (_onMouseLeave) {
            _onMouseLeave(event);
          }
        }
      }),
      targetRef: targetRef,
      templateProps: {
        nativeID: identifier
      }
    };
  }

  var PopoverContext = /*#__PURE__*/React__default["default"].createContext();
  PopoverContext.displayName = 'PopoverContext';

  var _excluded$Q = ["style"];

  var _templateObject$G, _templateObject2$v, _templateObject3$f, _templateObject4$d, _templateObject5$b, _templateObject6$a, _templateObject7$6, _templateObject8$6, _templateObject9$6, _templateObject10$6, _templateObject11$4, _templateObject12$3, _templateObject13$3, _templateObject14$2, _templateObject15$1;
  var propTypes$S = {
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$F = StyleSheet.create({
    '.popover-arrow': css(_templateObject$G || (_templateObject$G = _taggedTemplateLiteral(["\n    position: absolute;\n    // display: block;\n    width: $popover-arrow-width;\n    height: $popover-arrow-height;\n  "]))),
    '.popover-arrow::before': css(_templateObject2$v || (_templateObject2$v = _taggedTemplateLiteral(["\n    position: absolute;\n    // display: block;\n    // content: \"\";\n    border-top-color: transparent;\n    border-right-color: transparent;\n    border-left-color: transparent;\n    border-bottom-color: transparent;\n    border-style: solid;\n  "]))),
    '.popover-arrow::after': css(_templateObject3$f || (_templateObject3$f = _taggedTemplateLiteral(["\n    position: absolute;\n    // display: block;\n    // content: \"\";\n    border-top-color: transparent;\n    border-right-color: transparent;\n    border-left-color: transparent;\n    border-bottom-color: transparent;\n    border-style: solid;\n  "]))),
    '.bs-popover-top .popover-arrow': css(_templateObject4$d || (_templateObject4$d = _taggedTemplateLiteral(["\n    bottom: ", ";\n  "])), subtract(function (t) {
      return "-".concat(t['popover-arrow-height']);
    }, function (t) {
      return t['popover-border-width'];
    })),
    '.bs-popover-top .popover-arrow::before': css(_templateObject5$b || (_templateObject5$b = _taggedTemplateLiteral(["\n    bottom: 0;\n    border-top-width: $popover-arrow-height;\n    border-right-width: $popover-arrow-width * 0.5;\n    border-left-width: $popover-arrow-width * 0.5;\n    border-bottom-width: 0;\n    border-top-color: $popover-arrow-outer-color;\n  "]))),
    '.bs-popover-top .popover-arrow::after': css(_templateObject6$a || (_templateObject6$a = _taggedTemplateLiteral(["\n    bottom: $popover-border-width;\n    border-top-width: $popover-arrow-height;\n    border-right-width: $popover-arrow-width * 0.5;\n    border-left-width: $popover-arrow-width * 0.5;\n    border-bottom-width: 0;\n    border-top-color: $popover-arrow-color;\n  "]))),
    '.bs-popover-end .popover-arrow': css(_templateObject7$6 || (_templateObject7$6 = _taggedTemplateLiteral(["\n    left: ", ";\n    width: $popover-arrow-height;\n    height: $popover-arrow-width;\n  "])), subtract(function (t) {
      return "-".concat(t['popover-arrow-height']);
    }, function (t) {
      return t['popover-border-width'];
    })),
    '.bs-popover-end .popover-arrow::before': css(_templateObject8$6 || (_templateObject8$6 = _taggedTemplateLiteral(["\n    left: 0;\n    border-top-width: $popover-arrow-width * 0.5;\n    border-right-width: $popover-arrow-height;\n    border-left-width: 0;\n    border-bottom-width: $popover-arrow-width * 0.5;\n    border-right-color: $popover-arrow-outer-color;\n  "]))),
    '.bs-popover-end .popover-arrow::after': css(_templateObject9$6 || (_templateObject9$6 = _taggedTemplateLiteral(["\n    left: $popover-border-width;\n    border-top-width: $popover-arrow-width * 0.5;\n    border-right-width: $popover-arrow-height;\n    border-left-width: 0;\n    border-bottom-width: $popover-arrow-width * 0.5;\n    border-right-color: $popover-arrow-color;\n  "]))),
    '.bs-popover-bottom .popover-arrow': css(_templateObject10$6 || (_templateObject10$6 = _taggedTemplateLiteral(["\n    top: ", ";\n  "])), subtract(function (t) {
      return "-".concat(t['popover-arrow-height']);
    }, function (t) {
      return t['popover-border-width'];
    })),
    '.bs-popover-bottom .popover-arrow::before': css(_templateObject11$4 || (_templateObject11$4 = _taggedTemplateLiteral(["\n    top: 0;\n    border-top-width: 0;\n    border-right-width: $popover-arrow-width * 0.5;\n    border-left-width: $popover-arrow-width * 0.5;\n    border-bottom-width: $popover-arrow-height;\n    border-bottom-color: $popover-arrow-outer-color;\n  "]))),
    '.bs-popover-bottom .popover-arrow::after': css(_templateObject12$3 || (_templateObject12$3 = _taggedTemplateLiteral(["\n    top: $popover-border-width;\n    border-top-width: 0;\n    border-right-width: $popover-arrow-width * 0.5;\n    border-left-width: $popover-arrow-width * 0.5;\n    border-bottom-width: $popover-arrow-height;\n    border-bottom-color: $popover-arrow-color;\n  "]))),
    '.bs-popover-start .popover-arrow': css(_templateObject13$3 || (_templateObject13$3 = _taggedTemplateLiteral(["\n    right: ", ";\n    width: $popover-arrow-height;\n    height: $popover-arrow-width;\n  "])), subtract(function (t) {
      return "-".concat(t['popover-arrow-height']);
    }, function (t) {
      return t['popover-border-width'];
    })),
    '.bs-popover-start .popover-arrow::before': css(_templateObject14$2 || (_templateObject14$2 = _taggedTemplateLiteral(["\n    right: 0;\n    border-top-width: $popover-arrow-width * 0.5;\n    border-right-width: 0;\n    border-left-width: $popover-arrow-height;\n    border-bottom-width: $popover-arrow-width * 0.5;\n    border-left-color: $popover-arrow-outer-color;\n  "]))),
    '.bs-popover-start .popover-arrow::after': css(_templateObject15$1 || (_templateObject15$1 = _taggedTemplateLiteral(["\n    right: $popover-border-width;\n    border-top-width: $popover-arrow-width * 0.5;\n    border-right-width: 0;\n    border-left-width: $popover-arrow-height;\n    border-bottom-width: $popover-arrow-width * 0.5;\n    border-left-color: $popover-arrow-color;\n  "])))
  });
  var PopoverArrow = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded$Q);

    var _useForcedContext = useForcedContext(PopoverContext),
        placement = _useForcedContext.placement,
        arrowStyle = _useForcedContext.arrowStyle,
        popper = _useForcedContext.popper;

    var classes = getStyles(styles$F, ['.popover-arrow', popper && ".bs-popover-".concat(placement, " .popover-arrow")]);
    var beforeClasses = getStyles(styles$F, ['.popover-arrow::before', popper && ".bs-popover-".concat(placement, " .popover-arrow::before")]);
    var afterClasses = getStyles(styles$F, ['.popover-arrow::after', popper && ".bs-popover-".concat(placement, " .popover-arrow::after")]);
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, arrowStyle, style]
    }), /*#__PURE__*/React__default["default"].createElement(View, {
      style: beforeClasses
    }), /*#__PURE__*/React__default["default"].createElement(View, {
      style: afterClasses
    }));
  });
  PopoverArrow.displayName = 'PopoverArrow';
  PopoverArrow.propTypes = propTypes$S;

  var _excluded$P = ["children", "style", "textStyle"];

  var _templateObject$F, _templateObject2$u;
  var propTypes$R = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any
  };
  var styles$E = StyleSheet.create({
    '.popover-header': css(_templateObject$F || (_templateObject$F = _taggedTemplateLiteral(["\n    padding: $popover-header-padding-y $popover-header-padding-x;\n    background-color: $popover-header-bg;\n    border-bottom-width: $popover-border-width;\n    border-style: solid;\n    border-color: $popover-border-color;\n    border-top-left-radius: $popover-border-radius;\n    border-top-right-radius: $popover-border-radius;\n  "]))),
    '.popover-header --text': css(_templateObject2$u || (_templateObject2$u = _taggedTemplateLiteral(["\n    margin-bottom: 0; // Reset the default from Reboot\n    font-size: $font-size-base;\n    line-height: $font-size-base * $headings-line-height; // added for bootstrap-rn\n    color: $popover-header-color;\n  "])))
  });
  var PopoverHeader = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        textStyle = props.textStyle,
        elementProps = _objectWithoutProperties(props, _excluded$P);

    var classes = getStyles(styles$E, ['.popover-header']);
    var textClasses = getStyles(styles$E, ['.popover-header --text']); // composite component

    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style]
    }), /*#__PURE__*/React__default["default"].createElement(Heading$2, {
      size: 3,
      style: [textClasses, textStyle]
    }, children));
  });
  PopoverHeader.displayName = 'PopoverHeader';
  PopoverHeader.propTypes = propTypes$R;

  var _excluded$O = ["children", "style", "textStyle"];

  var _templateObject$E, _templateObject2$t;
  var propTypes$Q = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any
  };
  var styles$D = StyleSheet.create({
    '.popover-body': css(_templateObject$E || (_templateObject$E = _taggedTemplateLiteral(["\n    padding: $popover-body-padding-y $popover-body-padding-x;\n  "]))),
    '.popover-body --text': css(_templateObject2$t || (_templateObject2$t = _taggedTemplateLiteral(["\n    color: $popover-body-color;\n  "])))
  });
  var PopoverBody = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        textStyle = props.textStyle,
        elementProps = _objectWithoutProperties(props, _excluded$O);

    var classes = getStyles(styles$D, ['.popover-body']);
    var textClasses = getStyles(styles$D, ['.popover-body --text']);
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style],
      textStyle: [textClasses, textStyle]
    }), children);
  });
  PopoverBody.displayName = 'PopoverBody';
  PopoverBody.propTypes = propTypes$Q;

  var _excluded$N = ["children", "placement", "popper", "style", "textStyle", "arrowStyle"];

  var _templateObject$D, _templateObject2$s;
  var propTypes$P = {
    children: PropTypes.node.isRequired,
    placement: PropTypes.string,
    popper: PropTypes.bool,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    arrowStyle: PropTypes.any
  };
  var styles$C = StyleSheet.create({
    '.popover': css(_templateObject$D || (_templateObject$D = _taggedTemplateLiteral(["\n    position: absolute;\n    // top: 0;\n    // left: 0 #{\"/* rtl:ignore */\"};\n    z-index: $zindex-popover;\n    // display: block;\n    max-width: $popover-max-width;\n    background-color: $popover-bg;\n    // background-clip: padding-box;\n    border: $popover-border-width solid $popover-border-color;\n    border-radius: $popover-border-radius;\n    // @include box-shadow($popover-box-shadow);\n  "]))),
    '.popover --text': css(_templateObject2$s || (_templateObject2$s = _taggedTemplateLiteral(["\n    // Our parent element can be arbitrary since tooltips are by default inserted as a sibling of their target element.\n    // So reset our font and text properties to avoid inheriting weird values.\n    // @include reset-text();\n    font-size: $popover-font-size;\n    // Allow breaking very long words so they don't overflow the popover's bounds\n    // word-wrap: break-word;\n  "])))
  });
  var Popover = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        _props$placement = props.placement,
        placement = _props$placement === void 0 ? 'right' : _props$placement,
        popper = props.popper,
        style = props.style,
        textStyle = props.textStyle,
        arrowStyle = props.arrowStyle,
        elementProps = _objectWithoutProperties(props, _excluded$N);

    var popover = {
      placement: transformPlacement$1(placement),
      arrowStyle: arrowStyle,
      popper: popper
    };
    var classes = getStyles(styles$C, ['.popover']);
    var textClasses = getStyles(styles$C, ['.popover --text']); // Accessiblity role tooltip is only supported on web.

    var role = reactNative.Platform.OS === 'web' ? 'tooltip' : null;
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      accessibilityRole: role,
      style: [classes, style],
      textStyle: [textClasses, textStyle]
    }), /*#__PURE__*/React__default["default"].createElement(PopoverContext.Provider, {
      value: popover
    }, children));
  });
  Popover.displayName = 'Popover';
  Popover.propTypes = propTypes$P;
  Popover.Arrow = PopoverArrow;
  Popover.Header = PopoverHeader;
  Popover.Body = PopoverBody;

  var _excluded$M = ["title", "content", "autoClose", "trigger", "placement"],
      _excluded2$1 = ["popover"];
  var propTypes$O = {
    popover: PropTypes.shape(_objectSpread2({
      title: PropTypes.node,
      content: PropTypes.node.isRequired,
      autoClose: PropTypes.oneOfType([PropTypes.bool, PropTypes.oneOf(['inside', 'outside'])])
    }, TriggerPropTypes))
  };
  function injectPopover(Target) {
    var OverlayPopover = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
      /* eslint-disable react/prop-types */
      var _props$popover = props.popover,
          title = _props$popover.title,
          content = _props$popover.content,
          _props$popover$autoCl = _props$popover.autoClose,
          autoClose = _props$popover$autoCl === void 0 ? 'outside' : _props$popover$autoCl,
          _props$popover$trigge = _props$popover.trigger,
          trigger = _props$popover$trigge === void 0 ? 'press' : _props$popover$trigge,
          _props$popover$placem = _props$popover.placement,
          placement = _props$popover$placem === void 0 ? 'right' : _props$popover$placem,
          tooltipProps = _objectWithoutProperties(_props$popover, _excluded$M),
          elementProps = _objectWithoutProperties(props, _excluded2$1);
      /* eslint-enable */


      var _useTrigger = useTrigger(trigger, tooltipProps, elementProps, ref),
          visible = _useTrigger.visible,
          setVisible = _useTrigger.setVisible,
          targetProps = _useTrigger.targetProps,
          targetRef = _useTrigger.targetRef,
          templateProps = _useTrigger.templateProps;

      var offset = convertToNumber(StyleSheet.value('popover-arrow-height'));
      return /*#__PURE__*/React__default["default"].createElement(React__default["default"].Fragment, null, /*#__PURE__*/React__default["default"].createElement(Target, _extends$1({}, elementProps, targetProps)), visible && /*#__PURE__*/React__default["default"].createElement(OverlayContainer, null, /*#__PURE__*/React__default["default"].createElement(Overlay, {
        placement: placement,
        offset: offset,
        arrowOffset: offset,
        targetRef: targetRef,
        visible: visible
      }, function (overlay, overlayRef) {
        return /*#__PURE__*/React__default["default"].createElement(React__default["default"].Fragment, null, /*#__PURE__*/React__default["default"].createElement(BackdropHandler, {
          toggleRef: targetRef,
          dialogRef: overlayRef,
          onClose: function onClose() {
            setVisible(false);
          },
          autoClose: autoClose
        }), /*#__PURE__*/React__default["default"].createElement(Popover, _extends$1({}, templateProps, {
          ref: overlayRef,
          placement: overlay.placement,
          popper: overlay.rendered,
          style: [overlay.overlayProps.style, {
            maxHeight: 'auto',
            opacity: overlay.rendered ? 1 : 0
          }],
          arrowStyle: overlay.arrowProps.style
        }), /*#__PURE__*/React__default["default"].createElement(Popover.Arrow, null), title && /*#__PURE__*/React__default["default"].createElement(Popover.Header, null, title), /*#__PURE__*/React__default["default"].createElement(Popover.Body, null, content)));
      })));
    });
    OverlayPopover.displayName = 'Overlay(Popover)';
    OverlayPopover.propTypes = propTypes$O;
    return OverlayPopover;
  }

  var TooltipContext = /*#__PURE__*/React__default["default"].createContext();
  TooltipContext.displayName = 'TooltipContext';

  var _excluded$L = ["style"];

  var _templateObject$C, _templateObject2$r, _templateObject3$e, _templateObject4$c, _templateObject5$a, _templateObject6$9, _templateObject7$5, _templateObject8$5, _templateObject9$5, _templateObject10$5;
  var propTypes$N = {
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$B = StyleSheet.create({
    '.tooltip-arrow': css(_templateObject$C || (_templateObject$C = _taggedTemplateLiteral(["\n    position: absolute;\n    // display: block;\n    width: $tooltip-arrow-width;\n    height: $tooltip-arrow-height;\n  "]))),
    '.tooltip-arrow::before': css(_templateObject2$r || (_templateObject2$r = _taggedTemplateLiteral(["\n    position: absolute;\n    // content: \"\";\n    border-top-color: transparent;\n    border-right-color: transparent;\n    border-left-color: transparent;\n    border-bottom-color: transparent;\n    border-style: solid;\n  "]))),
    '.bs-tooltip-top .tooltip-arrow': css(_templateObject3$e || (_templateObject3$e = _taggedTemplateLiteral(["\n    bottom: 0;\n  "]))),
    '.bs-tooltip-top .tooltip-arrow::before': css(_templateObject4$c || (_templateObject4$c = _taggedTemplateLiteral(["\n    top: -1px;\n    border-top-width: $tooltip-arrow-height;\n    border-right-width: $tooltip-arrow-width * 0.5;\n    border-left-width: $tooltip-arrow-width * 0.5;\n    border-bottom-width: 0;\n    border-top-color: $tooltip-arrow-color;\n  "]))),
    '.bs-tooltip-end .tooltip-arrow': css(_templateObject5$a || (_templateObject5$a = _taggedTemplateLiteral(["\n    left: 0;\n    width: $tooltip-arrow-height;\n    height: $tooltip-arrow-width;\n  "]))),
    '.bs-tooltip-end .tooltip-arrow::before': css(_templateObject6$9 || (_templateObject6$9 = _taggedTemplateLiteral(["\n    right: -1px;\n    border-top-width: $tooltip-arrow-width * 0.5;\n    border-right-width: $tooltip-arrow-height;\n    border-left-width: 0;\n    border-bottom-width: $tooltip-arrow-width * 0.5;\n    border-right-color: $tooltip-arrow-color;\n  "]))),
    '.bs-tooltip-bottom .tooltip-arrow': css(_templateObject7$5 || (_templateObject7$5 = _taggedTemplateLiteral(["\n    top: 0;\n  "]))),
    '.bs-tooltip-bottom .tooltip-arrow::before': css(_templateObject8$5 || (_templateObject8$5 = _taggedTemplateLiteral(["\n    bottom: -1px;\n    border-top-width: 0;\n    border-right-width: $tooltip-arrow-width * 0.5;\n    border-left-width: $tooltip-arrow-width * 0.5;\n    border-bottom-width: $tooltip-arrow-height;\n    border-bottom-color: $tooltip-arrow-color;\n  "]))),
    '.bs-tooltip-start .tooltip-arrow': css(_templateObject9$5 || (_templateObject9$5 = _taggedTemplateLiteral(["\n    right: 0;\n    width: $tooltip-arrow-height;\n    height: $tooltip-arrow-width;\n  "]))),
    '.bs-tooltip-start .tooltip-arrow::before': css(_templateObject10$5 || (_templateObject10$5 = _taggedTemplateLiteral(["\n    left: -1px;\n    border-top-width: $tooltip-arrow-width * 0.5;\n    border-right-width: 0;\n    border-left-width: $tooltip-arrow-height;\n    border-bottom-width: $tooltip-arrow-width * 0.5;\n    border-left-color: $tooltip-arrow-color;\n  "])))
  });
  var TooltipArrow = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded$L);

    var _useForcedContext = useForcedContext(TooltipContext),
        placement = _useForcedContext.placement,
        arrowStyle = _useForcedContext.arrowStyle,
        popper = _useForcedContext.popper;

    var classes = getStyles(styles$B, ['.tooltip-arrow', popper && ".bs-tooltip-".concat(placement, " .tooltip-arrow")]);
    var beforeClasses = getStyles(styles$B, ['.tooltip-arrow::before', popper && ".bs-tooltip-".concat(placement, " .tooltip-arrow::before")]);
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, arrowStyle, style]
    }), /*#__PURE__*/React__default["default"].createElement(View, {
      style: beforeClasses
    }));
  });
  TooltipArrow.displayName = 'TooltipArrow';
  TooltipArrow.propTypes = propTypes$N;

  var _excluded$K = ["children", "style", "textStyle"];

  var _templateObject$B, _templateObject2$q;
  var propTypes$M = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any
  };
  var styles$A = StyleSheet.create({
    '.tooltip-inner': css(_templateObject$B || (_templateObject$B = _taggedTemplateLiteral(["\n    max-width: $tooltip-max-width;\n    padding: $tooltip-padding-y $tooltip-padding-x;\n    background-color: $tooltip-bg;\n    border-radius: $tooltip-border-radius;\n  "]))),
    '.tooltip-inner --text': css(_templateObject2$q || (_templateObject2$q = _taggedTemplateLiteral(["\n    color: $tooltip-color;\n    text-align: center;\n  "])))
  });
  var TooltipInner = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        textStyle = props.textStyle,
        elementProps = _objectWithoutProperties(props, _excluded$K);

    var classes = getStyles(styles$A, ['.tooltip-inner']);
    var textClasses = getStyles(styles$A, ['.tooltip-inner --text']); // composite component

    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style]
    }), /*#__PURE__*/React__default["default"].createElement(Text, {
      style: [textClasses, textStyle]
    }, children));
  });
  TooltipInner.displayName = 'TooltipInner';
  TooltipInner.propTypes = propTypes$M;

  var _excluded$J = ["children", "placement", "popper", "style", "textStyle", "arrowStyle"];

  var _templateObject$A, _templateObject2$p, _templateObject3$d, _templateObject4$b, _templateObject5$9, _templateObject6$8;
  var propTypes$L = {
    children: PropTypes.node.isRequired,
    placement: PropTypes.string,
    popper: PropTypes.bool,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    arrowStyle: PropTypes.any
  };
  var styles$z = StyleSheet.create({
    '.tooltip': css(_templateObject$A || (_templateObject$A = _taggedTemplateLiteral(["\n    position: absolute;\n    z-index: $zindex-tooltip;\n    // display: block;\n    margin: $tooltip-margin;\n    // opacity: 0;\n  "]))),
    '.tooltip --text': css(_templateObject2$p || (_templateObject2$p = _taggedTemplateLiteral(["\n    // Our parent element can be arbitrary since tooltips are by default inserted as a sibling of their target element.\n    // So reset our font and text properties to avoid inheriting weird values.\n    // @include reset-text();\n    font-size: $tooltip-font-size;\n    // Allow breaking very long words so they don't overflow the tooltip's bounds\n    // word-wrap: break-word;\n  "]))),
    '.bs-tooltip-top': css(_templateObject3$d || (_templateObject3$d = _taggedTemplateLiteral(["\n    padding: $tooltip-arrow-height 0;\n  "]))),
    '.bs-tooltip-end': css(_templateObject4$b || (_templateObject4$b = _taggedTemplateLiteral(["\n    padding: 0 $tooltip-arrow-height;\n  "]))),
    '.bs-tooltip-bottom': css(_templateObject5$9 || (_templateObject5$9 = _taggedTemplateLiteral(["\n    padding: $tooltip-arrow-height 0;\n  "]))),
    '.bs-tooltip-start': css(_templateObject6$8 || (_templateObject6$8 = _taggedTemplateLiteral(["\n    padding: 0 $tooltip-arrow-height;\n  "])))
  });
  var Tooltip = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        _props$placement = props.placement,
        placement = _props$placement === void 0 ? 'top' : _props$placement,
        popper = props.popper,
        style = props.style,
        textStyle = props.textStyle,
        arrowStyle = props.arrowStyle,
        elementProps = _objectWithoutProperties(props, _excluded$J);

    var tooltip = {
      placement: transformPlacement$1(placement),
      arrowStyle: arrowStyle,
      popper: popper
    };
    var classes = getStyles(styles$z, ['.tooltip', // Wait for rendering (of Overlay) before setting the offset.
    popper && ".bs-tooltip-".concat(tooltip.placement)]);
    var textClasses = getStyles(styles$z, ['.tooltip --text']); // Accessiblity role tooltip is only supported on web.

    var role = reactNative.Platform.OS === 'web' ? 'tooltip' : null;
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      accessibilityRole: role,
      style: [classes, style],
      textStyle: [textClasses, textStyle]
    }), /*#__PURE__*/React__default["default"].createElement(TooltipContext.Provider, {
      value: tooltip
    }, children));
  });
  Tooltip.displayName = 'Tooltip';
  Tooltip.propTypes = propTypes$L;
  Tooltip.Arrow = TooltipArrow;
  Tooltip.Inner = TooltipInner;

  var _excluded$I = ["title", "autoClose", "trigger", "placement"],
      _excluded2 = ["tooltip"];
  var propTypes$K = {
    tooltip: PropTypes.shape(_objectSpread2({
      title: PropTypes.node.isRequired,
      autoClose: PropTypes.oneOfType([PropTypes.bool, PropTypes.oneOf(['inside', 'outside'])])
    }, TriggerPropTypes))
  };
  function injectTooltip(Target) {
    var OverlayTooltip = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
      /* eslint-disable react/prop-types */
      var _props$tooltip = props.tooltip,
          title = _props$tooltip.title,
          _props$tooltip$autoCl = _props$tooltip.autoClose,
          autoClose = _props$tooltip$autoCl === void 0 ? 'outside' : _props$tooltip$autoCl,
          _props$tooltip$trigge = _props$tooltip.trigger,
          trigger = _props$tooltip$trigge === void 0 ? 'hover focus' : _props$tooltip$trigge,
          _props$tooltip$placem = _props$tooltip.placement,
          placement = _props$tooltip$placem === void 0 ? 'top' : _props$tooltip$placem,
          tooltipProps = _objectWithoutProperties(_props$tooltip, _excluded$I),
          elementProps = _objectWithoutProperties(props, _excluded2);
      /* eslint-enable */


      var _useTrigger = useTrigger(trigger, tooltipProps, elementProps, ref),
          visible = _useTrigger.visible,
          setVisible = _useTrigger.setVisible,
          targetProps = _useTrigger.targetProps,
          targetRef = _useTrigger.targetRef,
          templateProps = _useTrigger.templateProps;

      var offset = convertToNumber(StyleSheet.value('tooltip-arrow-height'));
      return /*#__PURE__*/React__default["default"].createElement(React__default["default"].Fragment, null, /*#__PURE__*/React__default["default"].createElement(Target, _extends$1({}, elementProps, targetProps)), visible && /*#__PURE__*/React__default["default"].createElement(OverlayContainer, null, /*#__PURE__*/React__default["default"].createElement(Overlay, {
        placement: placement,
        targetRef: targetRef,
        arrowOffset: offset,
        visible: visible
      }, function (overlay, overlayRef) {
        return /*#__PURE__*/React__default["default"].createElement(React__default["default"].Fragment, null, /*#__PURE__*/React__default["default"].createElement(BackdropHandler, {
          toggleRef: targetRef,
          dialogRef: overlayRef,
          onClose: function onClose() {
            setVisible(false);
          },
          autoClose: autoClose
        }), /*#__PURE__*/React__default["default"].createElement(Tooltip, _extends$1({}, templateProps, {
          ref: overlayRef,
          placement: overlay.placement,
          popper: overlay.rendered,
          style: [overlay.overlayProps.style, {
            maxHeight: 'auto',
            opacity: overlay.rendered ? 1 : 0
          }],
          arrowStyle: overlay.arrowProps.style
        }), /*#__PURE__*/React__default["default"].createElement(Tooltip.Arrow, null), /*#__PURE__*/React__default["default"].createElement(Tooltip.Inner, null, title)));
      })));
    });
    OverlayTooltip.displayName = 'Overlay(Tooltip)';
    OverlayTooltip.propTypes = propTypes$K;
    return OverlayTooltip;
  }

  var _excluded$H = ["style", "styleName"];
  var propTypes$J = {
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    styleName: PropTypes.any
  };
  var Image = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var style = props.style,
        styleName = props.styleName,
        elementProps = _objectWithoutProperties(props, _excluded$H);

    var media = useMedia();
    var resolveStyle = useStyle(style, styleName);
    return /*#__PURE__*/React__default["default"].createElement(reactNative.Image, _extends$1({}, elementProps, {
      ref: ref,
      style: resolveStyle({
        media: media
      })
    }));
  });
  Image.displayName = 'Image';
  Image.propTypes = propTypes$J;

  var _excluded$G = ["style", "styleName"];
  var propTypes$I = {
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    styleName: PropTypes.any
  };
  var ImageBackground = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var style = props.style,
        styleName = props.styleName,
        elementProps = _objectWithoutProperties(props, _excluded$G);

    var media = useMedia();
    var resolveStyle = useStyle(style, styleName);
    return /*#__PURE__*/React__default["default"].createElement(reactNative.ImageBackground, _extends$1({}, elementProps, {
      ref: ref,
      style: resolveStyle({
        media: media
      })
    }));
  });
  ImageBackground.displayName = 'ImageBackground';
  ImageBackground.propTypes = propTypes$I;

  var ListGroupContext = /*#__PURE__*/React__default["default"].createContext();
  ListGroupContext.displayName = 'ListGroupContext';

  var _excluded$F = ["children", "color", "active", "disabled", "style", "textStyle"];

  var _templateObject$z, _templateObject2$o, _templateObject3$c, _templateObject4$a, _templateObject5$8, _templateObject6$7, _templateObject7$4, _templateObject8$4, _templateObject9$4, _templateObject10$4, _templateObject11$3, _templateObject12$2, _templateObject13$2, _templateObject14$1;
  var propTypes$H = {
    children: PropTypes.node.isRequired,
    color: PropTypes.oneOf(Object.keys(THEME_COLORS)),
    active: PropTypes.bool,
    disabled: PropTypes.bool,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any
  };
  var styles$y = StyleSheet.create(_objectSpread2({
    '.list-group-item': css(_templateObject$z || (_templateObject$z = _taggedTemplateLiteral(["\n    position: relative;\n    // display: block;\n    padding: $list-group-item-padding-y $list-group-item-padding-x;\n    background-color: $list-group-bg;\n    border: $list-group-border-width solid $list-group-border-color;\n  "]))),
    '.list-group-item --text': css(_templateObject2$o || (_templateObject2$o = _taggedTemplateLiteral(["\n    color: $list-group-color;\n    text-decoration: none; // if($link-decoration == none, null, none);\n  "]))),
    '.list-group-item:first-child': css(_templateObject3$c || (_templateObject3$c = _taggedTemplateLiteral(["\n    border-top-left-radius: $list-group-border-radius;\n    border-top-right-radius: $list-group-border-radius;\n  "]))),
    '.list-group-item:last-child': css(_templateObject4$a || (_templateObject4$a = _taggedTemplateLiteral(["\n    border-bottom-left-radius: $list-group-border-radius;\n    border-bottom-right-radius: $list-group-border-radius;\n  "]))),
    '.list-group-item.disabled': css(_templateObject5$8 || (_templateObject5$8 = _taggedTemplateLiteral(["\n    // pointer-events: none;\n    background-color: $list-group-disabled-bg;\n  "]))),
    '.list-group-item.disabled --text': css(_templateObject6$7 || (_templateObject6$7 = _taggedTemplateLiteral(["\n    color: $list-group-disabled-color;\n  "]))),
    '.list-group-item.active': css(_templateObject7$4 || (_templateObject7$4 = _taggedTemplateLiteral(["\n    z-index: 2; // Place active items above their siblings for proper border styling\n    background-color: $list-group-active-bg;\n    border-color: $list-group-active-border-color;\n  "]))),
    '.list-group-item.active --text': css(_templateObject8$4 || (_templateObject8$4 = _taggedTemplateLiteral(["\n    color: $list-group-active-color;\n  "]))),
    '.list-group-item + .list-group-item': css(_templateObject9$4 || (_templateObject9$4 = _taggedTemplateLiteral(["\n    border-top-width: 0;\n  "]))),
    '.list-group-item + .list-group-item.active': css(_templateObject10$4 || (_templateObject10$4 = _taggedTemplateLiteral(["\n    margin-top: -$list-group-border-width;\n    border-top-width: $list-group-border-width;\n  "]))),
    '.list-group-item-flush': css(_templateObject11$3 || (_templateObject11$3 = _taggedTemplateLiteral(["\n    border-top-left-radius: 0; // added for bootstrap-rn\n    border-top-right-radius: 0; // added for bootstrap-rn\n    border-bottom-left-radius: 0; // added for bootstrap-rn\n    border-bottom-right-radius: 0; // added for bootstrap-rn\n    border-top-width: 0;\n    border-right-width: 0;\n    border-bottom-width: $list-group-border-width;\n    border-left-width: 0;\n  "]))),
    '.list-group-item-flush:last-child': css(_templateObject12$2 || (_templateObject12$2 = _taggedTemplateLiteral(["\n    border-bottom-width: 0;\n  "])))
  }, each(THEME_COLORS, function (state, value) {
    var _ref;

    return _ref = {}, _defineProperty(_ref, ".list-group-item-".concat(state), css(_templateObject13$2 || (_templateObject13$2 = _taggedTemplateLiteral(["\n      background-color: ", ";\n    "])), shiftColor(function (t) {
      return t['list-group-item-bg-scale'];
    }, value))), _defineProperty(_ref, ".list-group-item-".concat(state, " --text"), css(_templateObject14$1 || (_templateObject14$1 = _taggedTemplateLiteral(["\n      color: ", ";\n    "])), shiftColor(function (t) {
      return t['list-group-item-color-scale'];
    }, value))), _ref;
  })));
  var ListGroupItem = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        color = props.color,
        _props$active = props.active,
        active = _props$active === void 0 ? false : _props$active,
        _props$disabled = props.disabled,
        disabled = _props$disabled === void 0 ? false : _props$disabled,
        style = props.style,
        textStyle = props.textStyle,
        elementProps = _objectWithoutProperties(props, _excluded$F);

    var _useForcedContext = useForcedContext(ListContext),
        first = _useForcedContext.first,
        last = _useForcedContext.last;

    var _useForcedContext2 = useForcedContext(ListGroupContext),
        flush = _useForcedContext2.flush;

    var classes = getStyles(styles$y, ['.list-group-item', first && '.list-group-item:first-child', last && '.list-group-item:last-child', active && '.list-group-item.active', disabled && '.list-group-item.disabled', !first && '.list-group-item + .list-group-item', !first && active && '.list-group-item + .list-group-item.active', flush && '.list-group-item-flush', flush && last && '.list-group-item-flush:last-child', color && ".list-group-item-".concat(color)]);
    var textClasses = getStyles(styles$y, ['.list-group-item --text', active && '.list-group-item.active --text', disabled && '.list-group-item.disabled --text', color && ".list-group-item-".concat(color, " --text")]);
    var role = reactNative.Platform.OS === 'web' ? 'listitem' : null;
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      accessibilityRole: role,
      style: [classes, style],
      textStyle: [textClasses, textStyle]
    }), children);
  });
  ListGroupItem.displayName = 'ListGroupItem';
  ListGroupItem.propTypes = propTypes$H;

  var _excluded$E = ["children", "color", "active", "disabled", "style", "activeStyle", "textStyle", "activeTextStyle"];

  var _templateObject$y, _templateObject2$n, _templateObject3$b, _templateObject4$9, _templateObject5$7, _templateObject6$6;
  var propTypes$G = {
    children: PropTypes.node.isRequired,
    color: PropTypes.oneOf(Object.keys(THEME_COLORS)),
    active: PropTypes.bool,
    disabled: PropTypes.bool,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    activeStyle: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    activeTextStyle: PropTypes.any
  };
  var actionStyles = StyleSheet.create(_objectSpread2({
    '.list-group-item-action': css(_templateObject$y || (_templateObject$y = _taggedTemplateLiteral(["\n    width: 100%; // For \"<button>\"s (anchors become 100% by default though)\n\n    // Hover state\n    &:hover {\n      z-index: 1; // Place hover/focus items above their siblings for proper border styling\n      background-color: $list-group-hover-bg;\n    }\n\n    &:focus {\n      z-index: 1; // Place hover/focus items above their siblings for proper border styling\n      background-color: $list-group-hover-bg;\n    }\n\n    &:active {\n      background-color: $list-group-action-active-bg;\n    }\n  "]))),
    '.list-group-item-action --text': css(_templateObject2$n || (_templateObject2$n = _taggedTemplateLiteral(["\n    color: $list-group-action-color;\n    // text-align: inherit; // For \"<button>\"s (anchors inherit)\n\n    // Hover state\n    &:hover {\n      color: $list-group-action-hover-color;\n      text-decoration: none;\n    }\n\n    &:focus {\n      color: $list-group-action-hover-color;\n      text-decoration: none;\n    }\n\n    &:active {\n      color: $list-group-action-active-color;\n    }\n  "])))
  }, each(THEME_COLORS, function (state, value) {
    var _ref;

    return _ref = {}, _defineProperty(_ref, ".list-group-item-".concat(state, "-action"), css(_templateObject3$b || (_templateObject3$b = _taggedTemplateLiteral(["\n      &:hover {\n        background-color: ", ";\n      }\n\n      &:focus {\n        background-color: ", ";\n      }\n    "])), shadeColor(0.1, shiftColor(function (t) {
      return t['list-group-item-bg-scale'];
    }, value)), shadeColor(0.1, shiftColor(function (t) {
      return t['list-group-item-bg-scale'];
    }, value)))), _defineProperty(_ref, ".list-group-item-".concat(state, "-action --text"), css(_templateObject4$9 || (_templateObject4$9 = _taggedTemplateLiteral(["\n      &:hover {\n        color: ", ";\n      }\n\n      &:focus {\n        color: ", ";\n      }\n    "])), shiftColor(function (t) {
      return t['list-group-item-color-scale'];
    }, value), shiftColor(function (t) {
      return t['list-group-item-color-scale'];
    }, value))), _defineProperty(_ref, ".list-group-item-".concat(state, "-action.active"), css(_templateObject5$7 || (_templateObject5$7 = _taggedTemplateLiteral(["\n      background-color: ", ";\n      border-color: ", ";\n    "])), shiftColor(function (t) {
      return t['list-group-item-color-scale'];
    }, value), shiftColor(function (t) {
      return t['list-group-item-color-scale'];
    }, value))), _defineProperty(_ref, ".list-group-item-".concat(state, "-action.active --text"), css(_templateObject6$6 || (_templateObject6$6 = _taggedTemplateLiteral(["\n      color: $white;\n    "])))), _ref;
  })));
  var ListGroupItemAction = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var _useModifier = useModifier('useTabbable', props, ref),
        _useModifier2 = _slicedToArray(_useModifier, 2),
        modifierProps = _useModifier2[0],
        modifierRef = _useModifier2[1];

    var children = modifierProps.children,
        color = modifierProps.color,
        _modifierProps$active = modifierProps.active,
        active = _modifierProps$active === void 0 ? false : _modifierProps$active,
        _modifierProps$disabl = modifierProps.disabled,
        disabled = _modifierProps$disabl === void 0 ? false : _modifierProps$disabl,
        style = modifierProps.style,
        activeStyle = modifierProps.activeStyle,
        textStyle = modifierProps.textStyle,
        activeTextStyle = modifierProps.activeTextStyle,
        elementProps = _objectWithoutProperties(modifierProps, _excluded$E);

    var _useForcedContext = useForcedContext(ListContext),
        first = _useForcedContext.first,
        last = _useForcedContext.last;

    var _useForcedContext2 = useForcedContext(ListGroupContext),
        flush = _useForcedContext2.flush;

    var styles = _objectSpread2(_objectSpread2({}, styles$y), actionStyles);

    var classes = getStyles(styles, ['.list-group-item', '.list-group-item-action', first && '.list-group-item:first-child', last && '.list-group-item:last-child', disabled && '.list-group-item.disabled', !first && '.list-group-item + .list-group-item', !first && active && '.list-group-item + .list-group-item.active', flush && '.list-group-item-flush', flush && last && '.list-group-item-flush:last-child', color && ".list-group-item-".concat(color), color && ".list-group-item-".concat(color, "-action")]);
    var activeClasses = getStyles(styles, ['.list-group-item.active', color && ".list-group-item-".concat(color, "-action.active")]);
    var textClasses = getStyles(styles, ['.list-group-item --text', '.list-group-item-action --text', disabled && '.list-group-item.disabled --text', color && ".list-group-item-".concat(color, " --text"), color && ".list-group-item-".concat(color, "-action --text")]);
    var activeTextClasses = getStyles(styles, ['.list-group-item.active --text', color && ".list-group-item-".concat(color, "-action.active --text")]);
    var role = reactNative.Platform.OS === 'web' ? 'listitem' : null;
    return /*#__PURE__*/React__default["default"].createElement(Pressable, _extends$1({}, elementProps, {
      ref: modifierRef,
      accessibilityRole: role,
      active: active,
      disabled: disabled,
      style: [].concat(_toConsumableArray(classes), [style]),
      activeStyle: [].concat(_toConsumableArray(activeClasses), [activeStyle]),
      textStyle: [].concat(_toConsumableArray(textClasses), [textStyle]),
      activeTextStyle: [].concat(_toConsumableArray(activeTextClasses), [activeTextStyle])
    }), children);
  });
  ListGroupItemAction.displayName = 'ListGroupItemAction';
  ListGroupItemAction.propTypes = propTypes$G;

  var _excluded$D = ["children", "flush", "style"];

  var _templateObject$x, _templateObject2$m;
  var propTypes$F = {
    children: PropTypes.node.isRequired,
    flush: PropTypes.bool,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$x = StyleSheet.create({
    '.list-group': css(_templateObject$x || (_templateObject$x = _taggedTemplateLiteral(["\n    display: flex;\n    flex-direction: column;\n\n    // No need to set list-style: none; since .list-group-item is block level\n    padding-left: 0; // reset padding because ul and ol\n    margin-bottom: 0;\n    border-radius: $list-group-border-radius;\n  "]))),
    '.list-group-flush': css(_templateObject2$m || (_templateObject2$m = _taggedTemplateLiteral(["\n    border-radius: 0;\n  "])))
  });

  var getRole$1 = function getRole(tabbable) {
    if (tabbable) {
      return 'tablist';
    }

    if (reactNative.Platform.OS === 'web') {
      return 'list';
    }

    return null;
  };

  var ListGroup = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        flush = props.flush,
        style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded$D);

    var list = useList(children);
    var classes = getStyles(styles$x, ['.list-group', flush && '.list-group-flush']); // TODO: Implement TabContext

    var tabbable = false;
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      accessibilityRole: getRole$1(tabbable),
      style: [classes, style]
    }), /*#__PURE__*/React__default["default"].createElement(ListGroupContext.Provider, {
      value: {
        flush: flush
      }
    }, list));
  });
  ListGroup.displayName = 'ListGroup';
  ListGroup.propTypes = propTypes$F;
  ListGroup.Item = ListGroupItem;
  ListGroup.ItemAction = ListGroupItemAction;

  var _excluded$C = ["children", "onMouseEnter", "onMouseLeave", "onFocus", "onBlur", "onPressIn", "onPressOut", "style"];

  var _templateObject$w;
  var propTypes$E = {
    children: PropTypes.node.isRequired,
    onMouseEnter: PropTypes.func,
    onMouseLeave: PropTypes.func,
    onFocus: PropTypes.func,
    onBlur: PropTypes.func,
    onPressIn: PropTypes.func,
    onPressOut: PropTypes.func,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$w = StyleSheet.create({
    link: css(_templateObject$w || (_templateObject$w = _taggedTemplateLiteral(["\n    color: $link-color;\n    text-decoration-color: $link-color; // added for bootstrap-rn\n    text-decoration-line: $link-decoration;\n\n    &:hover {\n      color: $link-hover-color;\n      text-decoration-color: $link-hover-color; // added for bootstrap-rn\n      text-decoration-line: $link-hover-decoration;\n    }\n  "])))
  });
  var Link = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var _useModifier = useModifier('useActionable', props, ref),
        _useModifier2 = _slicedToArray(_useModifier, 2),
        modifierProps = _useModifier2[0],
        modifierRef = _useModifier2[1];

    var _useAction = useAction(modifierProps, modifierRef),
        _useAction2 = _slicedToArray(_useAction, 2),
        actionProps = _useAction2[0],
        actionRef = _useAction2[1];

    var children = actionProps.children,
        _actionProps$onMouseE = actionProps.onMouseEnter,
        _onMouseEnter = _actionProps$onMouseE === void 0 ? function () {} : _actionProps$onMouseE,
        _actionProps$onMouseL = actionProps.onMouseLeave,
        _onMouseLeave = _actionProps$onMouseL === void 0 ? function () {} : _actionProps$onMouseL,
        _actionProps$onFocus = actionProps.onFocus,
        _onFocus = _actionProps$onFocus === void 0 ? function () {} : _actionProps$onFocus,
        _actionProps$onBlur = actionProps.onBlur,
        _onBlur = _actionProps$onBlur === void 0 ? function () {} : _actionProps$onBlur,
        _actionProps$onPressI = actionProps.onPressIn,
        _onPressIn = _actionProps$onPressI === void 0 ? function () {} : _actionProps$onPressI,
        _actionProps$onPressO = actionProps.onPressOut,
        _onPressOut = _actionProps$onPressO === void 0 ? function () {} : _actionProps$onPressO,
        style = actionProps.style,
        elementProps = _objectWithoutProperties(actionProps, _excluded$C);

    var media = useMedia();

    var _useState = React.useState(false),
        _useState2 = _slicedToArray(_useState, 2),
        focused = _useState2[0],
        setFocused = _useState2[1];

    var _useState3 = React.useState(false),
        _useState4 = _slicedToArray(_useState3, 2),
        hovered = _useState4[0],
        setHovered = _useState4[1];

    var _useState5 = React.useState(false),
        _useState6 = _slicedToArray(_useState5, 2),
        pressed = _useState6[0],
        setPressed = _useState6[1];

    var classes = getStyles(styles$w, ['link', hovered]);
    var resolveStyle = useStyle([classes, style]);
    return /*#__PURE__*/React__default["default"].createElement(Text, _extends$1({}, elementProps, {
      ref: actionRef,
      accessibilityRole: getRole$2(actionProps),
      accessible: true,
      onFocus: function onFocus(e) {
        setFocused(true);

        _onFocus(e);
      },
      onBlur: function onBlur(e) {
        setFocused(false);

        _onBlur(e);
      },
      onMouseEnter: function onMouseEnter(e) {
        setHovered(true);

        _onMouseEnter(e);
      },
      onMouseLeave: function onMouseLeave(e) {
        setHovered(false);

        _onMouseLeave(e);
      },
      onPressIn: function onPressIn(e) {
        setPressed(true);

        _onPressIn(e);
      },
      onPressOut: function onPressOut(e) {
        setPressed(false);

        _onPressOut(e);
      },
      style: resolveStyle({
        media: media,
        interaction: {
          focused: focused,
          hovered: hovered,
          pressed: pressed
        }
      })
    }), children);
  });
  Link.displayName = 'Link';
  Link.propTypes = propTypes$E;

  var _excluded$B = ["children", "contentContainerStyle", "style", "textStyle", "styleName"];
  var propTypes$D = {
    children: PropTypes.node,
    // eslint-disable-next-line react/forbid-prop-types
    contentContainerStyle: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    styleName: PropTypes.any
  };
  var ScrollView = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        contentContainerStyle = props.contentContainerStyle,
        style = props.style,
        textStyle = props.textStyle,
        styleName = props.styleName,
        elementProps = _objectWithoutProperties(props, _excluded$B);

    var media = useMedia();
    var context = React.useContext(TextStyleContext);
    var resolveContentContainerStyle = useStyle(contentContainerStyle);
    var resolveStyle = useStyle(style, styleName);
    var resolveTextStyle = useStyle([context && context.style, textStyle]);
    var hasTextStyle = context && context.style || textStyle;
    return /*#__PURE__*/React__default["default"].createElement(reactNative.ScrollView, _extends$1({}, elementProps, {
      ref: ref,
      contentContainerStyle: resolveContentContainerStyle({
        media: media
      }),
      style: resolveStyle({
        media: media
      })
    }), hasTextStyle ? /*#__PURE__*/React__default["default"].createElement(TextStyleContext.Provider, {
      value: {
        style: resolveTextStyle({
          media: media
        }),
        hasAncestor: context && context.hasTextAncestor
      }
    }, children) : children);
  });
  ScrollView.displayName = 'ScrollView';
  ScrollView.propTypes = propTypes$D;

  var computeScrollbarWidth = function computeScrollbarWidth() {
    var documentWidth = document.documentElement.clientWidth;
    return Math.abs(window.innerWidth - documentWidth);
  };

  function useScrollbarEffects(_ref) {
    var keepBodyScroll = _ref.keepBodyScroll,
        visible = _ref.visible;

    if (reactNative.Platform.OS !== 'web' || keepBodyScroll) {
      return;
    }

    var context = React.useContext(Context);
    var scrollbarWidth = React.useRef();
    React.useEffect(function () {
      if (!visible) {
        return undefined;
      }

      if (!scrollbarWidth.current) {
        scrollbarWidth.current = computeScrollbarWidth();
      }

      var rect = document.body.getBoundingClientRect();
      var isBodyOverflowing = rect.left + rect.right < window.innerWidth; // Set body and fixed elements padding adjustments.

      var fixedElements = context.fixed.filter(function (ref) {
        return ref.current;
      }).map(function (ref) {
        return reactNative.findNodeHandle(ref.current);
      });
      var elements = [document.body].concat(_toConsumableArray(fixedElements));
      var originalWidths = elements.map(function (el) {
        return el.style.width || '';
      });
      var originalBodyOverflow = document.body.style.overflow || '';

      if (isBodyOverflowing) {
        elements.forEach(function (el) {
          // eslint-disable-next-line no-param-reassign
          el.style.width = "calc(100% - ".concat(scrollbarWidth.current, "px)");
        });
      } // Add "overflow: hidden" to body element.


      document.body.style.overflow = 'hidden';
      return function () {
        // Reset body padding adjustments.
        elements.forEach(function (el, key) {
          // eslint-disable-next-line no-param-reassign
          el.style.width = originalWidths[key] || '';
        }); // Remove "overflow: hidden" from body element.

        document.body.style.overflow = originalBodyOverflow;
      };
    }, [visible]);
  }

  function useModal(scrollable) {
    return React.useMemo(function () {
      return {
        scrollable: scrollable
      };
    }, [scrollable]);
  }

  var _excluded$A = ["children", "style"];

  var _templateObject$v;
  var propTypes$C = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$v = StyleSheet.create({
    '.modal-header': css(_templateObject$v || (_templateObject$v = _taggedTemplateLiteral(["\n    display: flex;\n    flex-direction: row; // added for bootstrap-rn\n    flex-shrink: 0;\n    align-items: center;\n    justify-content: space-between; // Put modal header elements (title and dismiss) on opposite ends\n    padding: $modal-header-padding;\n    border-bottom-width: $modal-header-border-width;\n    border-style: solid;\n    border-color: $modal-header-border-color;\n    border-top-left-radius: $modal-content-inner-border-radius;\n    border-top-right-radius: $modal-content-inner-border-radius;\n  "])))
  });
  var ModalHeader = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded$A);

    var classes = getStyles(styles$v, ['.modal-header']);
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style]
    }), children);
  });
  ModalHeader.displayName = 'ModalHeader';
  ModalHeader.propTypes = propTypes$C;

  var _excluded$z = ["children", "style"];

  var _templateObject$u;
  var propTypes$B = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$u = StyleSheet.create({
    '.modal-title': css(_templateObject$u || (_templateObject$u = _taggedTemplateLiteral(["\n    margin-bottom: 0;\n    line-height: $font-size-base * $modal-title-line-height;\n  "])))
  });
  var ModalTitle = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded$z);

    var classes = getStyles(styles$u, ['.modal-title']);
    return /*#__PURE__*/React__default["default"].createElement(Heading$2, _extends$1({
      size: 5
    }, elementProps, {
      ref: ref,
      style: [classes, style]
    }), children);
  });
  ModalTitle.displayName = 'ModalTitle';
  ModalTitle.propTypes = propTypes$B;

  var _excluded$y = ["children", "style", "innerStyle"];

  var _templateObject$t;
  var propTypes$A = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    innerStyle: PropTypes.any
  };
  var styles$t = StyleSheet.create({
    '.modal-body': css(_templateObject$t || (_templateObject$t = _taggedTemplateLiteral(["\n    position: relative;\n    // Enable \"flex-grow: 1\" so that the body take up as much space as possible\n    // when there should be a fixed height on \".modal-dialog\".\n    // Note from bootstrap-rn: Centered modals do not work with this style, but\n    // everything just works fine without this style.\n    // flex: 1 1 auto;\n    padding: $modal-inner-padding;\n  "])))
  });
  var ModalBody = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        innerStyle = props.innerStyle,
        elementProps = _objectWithoutProperties(props, _excluded$y);

    var _useForcedContext = useForcedContext(ModalContext),
        scrollable = _useForcedContext.scrollable;

    var classes = getStyles(styles$t, ['.modal-body']);
    var FlexView = scrollable ? ScrollView : View;
    return /*#__PURE__*/React__default["default"].createElement(FlexView, _extends$1({}, elementProps, {
      ref: ref,
      style: scrollable ? style : [classes, style],
      contentContainerStyle: scrollable ? [classes, innerStyle] : undefined
    }), children);
  });
  ModalBody.displayName = 'ModalBody';
  ModalBody.propTypes = propTypes$A;

  var _excluded$x = ["children", "style"];

  var _templateObject$s;
  var propTypes$z = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$s = StyleSheet.create({
    '.modal-footer': css(_templateObject$s || (_templateObject$s = _taggedTemplateLiteral(["\n    display: flex;\n    flex-direction: row; // added for bootstrap-rn\n    flex-shrink: 0;\n    flex-wrap: wrap;\n    align-items: center; // vertically center\n    justify-content: flex-end; // Right align buttons with flex property because text-align doesn't work on flex items\n    padding: $modal-inner-padding;\n    border-top-width: $modal-footer-border-width;\n    border-style: solid;\n    border-color: $modal-footer-border-color;\n    border-bottom-start-radius: $modal-content-inner-border-radius;\n    border-bottom-end-radius: $modal-content-inner-border-radius;\n  "])))
  });
  var ModalFooter = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded$x);

    var classes = getStyles(styles$s, ['.modal-footer']);
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style]
    }), children);
  });
  ModalFooter.displayName = 'ModalFooter';
  ModalFooter.propTypes = propTypes$z;

  var _excluded$w = ["children", "visible", "size", "backdrop", "scrollable", "centered", "onToggle", "style", "innerStyle", "dialogStyle", "contentStyle", "textStyle", "dialogTextStyle", "contentTextStyle"];

  var _templateObject$r, _templateObject2$l, _templateObject3$a, _templateObject4$8, _templateObject5$6, _templateObject6$5, _templateObject7$3, _templateObject8$3, _templateObject9$3, _templateObject10$3, _templateObject11$2;
  var MODAL_SIZES = ['sm', 'lg', 'xl'];
  var propTypes$y = {
    children: PropTypes.node.isRequired,
    visible: PropTypes.bool.isRequired,
    size: PropTypes.oneOf(MODAL_SIZES),
    backdrop: PropTypes.oneOfType([PropTypes.bool, PropTypes.oneOf(['static'])]),
    scrollable: PropTypes.bool,
    centered: PropTypes.bool,
    onToggle: PropTypes.func.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    innerStyle: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    dialogStyle: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    contentStyle: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    dialogTextStyle: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    contentTextStyle: PropTypes.any
  };
  var styles$r = StyleSheet.create({
    '.modal': css(_templateObject$r || (_templateObject$r = _taggedTemplateLiteral(["\n    position: absolute; // fixed;\n    top: 0;\n    left: 0;\n    z-index: $zindex-modal;\n    // display: none;\n    width: 100%;\n    height: 100%;\n    // overflow-x: hidden;\n    // overflow-y: auto;\n    // Prevent Chrome on Windows from adding a focus outline. For details, see\n    // https://github.com/twbs/bootstrap/pull/10951.\n    @include platform(web) {\n      outline-width: 0; // outline: 0;\n    }\n    // We deliberately don't use \"-webkit-overflow-scrolling: touch;\" due to a\n    // gnarly iOS Safari bug: https://bugs.webkit.org/show_bug.cgi?id=158342\n    // See also https://github.com/twbs/bootstrap/issues/17695\n  "]))),
    '.modal-dialog': css(_templateObject2$l || (_templateObject2$l = _taggedTemplateLiteral(["\n    position: relative;\n    width: auto;\n    margin: $modal-dialog-margin;\n    // allow clicks to pass through for custom click handling to close modal\n    // pointer-events: none;\n\n    @include media-breakpoint-up(sm) {\n      width: 100%; // added for bootstrap-rn\n      max-width: $modal-md;\n      margin: $modal-dialog-margin-y-sm-up auto;\n    }\n  "]))),
    '.modal-dialog-scrollable': css(_templateObject3$a || (_templateObject3$a = _taggedTemplateLiteral(["\n    flex-shrink: 1; // added for bootstrap-rn\n    // height: calc(100% - var(--#{$prefix}modal-margin) * 2);\n  "]))),
    '.modal-dialog-scrollable .modal-content': css(_templateObject4$8 || (_templateObject4$8 = _taggedTemplateLiteral(["\n    max-height: 100%;\n    overflow: hidden;\n  "]))),
    '.modal-dialog-centered': css(_templateObject5$6 || (_templateObject5$6 = _taggedTemplateLiteral(["\n    display: flex;\n    flex-direction: row; // added for bootstrap-rn\n    flex-grow: 1; // added for bootstrap-rn\n    align-items: center;\n    // min-height: calc(100% - var(--#{$prefix}modal-margin) * 2);\n  "]))),
    '.modal-content': css(_templateObject6$5 || (_templateObject6$5 = _taggedTemplateLiteral(["\n    position: relative;\n    display: flex;\n    flex-direction: column;\n    width: 100%; // Ensure \".modal-content\" extends the full width of the parent \".modal-dialog\"\n    // counteract the pointer-events: none; in the .modal-dialog\n    // pointer-events: auto;\n    background-color: $modal-content-bg;\n    // background-clip: padding-box;\n    border: $modal-content-border-width solid $modal-content-border-color;\n    border-radius: $modal-content-border-radius;\n    // @include box-shadow($modal-content-box-shadow-xs);\n    // Remove focus outline from opened modal\n    // outline: 0;\n\n    @include media-breakpoint-up(sm) {\n      // @include box-shadow($modal-content-box-shadow-sm-up);\n    }\n  "]))),
    '.modal-content --text': css(_templateObject7$3 || (_templateObject7$3 = _taggedTemplateLiteral(["\n    color: $modal-content-color;\n  "]))),
    '.modal-backdrop': css(_templateObject8$3 || (_templateObject8$3 = _taggedTemplateLiteral(["\n    position: absolute;\n    top: 0;\n    left: 0;\n    z-index: $zindex-modal-backdrop;\n    width: 100%;\n    height: 100%;\n    background-color: $modal-backdrop-bg;\n    opacity: $modal-backdrop-opacity;\n  "]))),
    '.modal-sm': css(_templateObject9$3 || (_templateObject9$3 = _taggedTemplateLiteral(["\n    @include media-breakpoint-up(sm) {\n      max-width: $modal-sm;\n    }\n  "]))),
    '.modal-lg': css(_templateObject10$3 || (_templateObject10$3 = _taggedTemplateLiteral(["\n    @include media-breakpoint-up(lg) {\n      max-width: $modal-lg;\n    }\n  "]))),
    '.modal-xl': css(_templateObject11$2 || (_templateObject11$2 = _taggedTemplateLiteral(["\n    @include media-breakpoint-up(lg) {\n      max-width: $modal-lg;\n    }\n    @include media-breakpoint-up(xl) {\n      max-width: $modal-xl;\n    }\n  "])))
  });
  var Modal = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        visible = props.visible,
        size = props.size,
        _props$backdrop = props.backdrop,
        backdrop = _props$backdrop === void 0 ? true : _props$backdrop,
        _props$scrollable = props.scrollable,
        scrollable = _props$scrollable === void 0 ? false : _props$scrollable,
        _props$centered = props.centered,
        centered = _props$centered === void 0 ? false : _props$centered,
        handleToggle = props.onToggle,
        style = props.style,
        innerStyle = props.innerStyle,
        dialogStyle = props.dialogStyle,
        contentStyle = props.contentStyle,
        textStyle = props.textStyle,
        dialogTextStyle = props.dialogTextStyle,
        contentTextStyle = props.contentTextStyle,
        elementProps = _objectWithoutProperties(props, _excluded$w);

    var dialogRef = React.useRef();
    var modal = useModal(scrollable);
    useScrollbarEffects({
      keepBodyScroll: false,
      visible: visible
    });
    var backdropClasses = getStyles(styles$r, ['.modal-backdrop']);
    var classes = getStyles(styles$r, ['.modal']);
    var dialogClasses = getStyles(styles$r, ['.modal-dialog', size === 'sm' && '.modal-sm', size === 'lg' && '.modal-lg', size === 'xl' && '.modal-xl', scrollable && '.modal-dialog-scrollable', centered && '.modal-dialog-centered']);
    var contentClasses = getStyles(styles$r, ['.modal-content', scrollable && '.modal-dialog-scrollable .modal-content']);
    var contentTextClasses = getStyles(styles$r, ['.modal-content --text']); // If scrollable we use a ScrollView in ModalBody, so we can use a View here.

    var FlexView = scrollable ? View : ScrollView;
    return /*#__PURE__*/React__default["default"].createElement(reactNative.Modal, {
      transparent: true,
      visible: visible,
      onRequestClose: handleToggle
    }, backdrop && /*#__PURE__*/React__default["default"].createElement(View, {
      style: backdropClasses
    }), /*#__PURE__*/React__default["default"].createElement(FlexView, {
      style: [classes, style],
      textStyle: textStyle,
      contentContainerStyle: [scrollable ? undefined : {
        flexGrow: 1
      }, innerStyle]
    }, /*#__PURE__*/React__default["default"].createElement(BackdropHandler, {
      dialogRef: dialogRef,
      onClose: handleToggle,
      backdrop: backdrop
    }), /*#__PURE__*/React__default["default"].createElement(reactNative.SafeAreaView, {
      style: {
        flexShrink: 1
      }
    }, /*#__PURE__*/React__default["default"].createElement(View, {
      ref: dialogRef,
      style: [dialogClasses, dialogStyle],
      textStyle: dialogTextStyle
    }, /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [contentClasses, contentStyle],
      textStyle: [contentTextClasses, contentTextStyle]
    }), /*#__PURE__*/React__default["default"].createElement(ModalContext.Provider, {
      value: modal
    }, /*#__PURE__*/React__default["default"].createElement(OverlayProvider, null, children)))))));
  });
  Modal.displayName = 'Modal';
  Modal.propTypes = propTypes$y;
  Modal.Context = ModalContext;
  Modal.Header = ModalHeader;
  Modal.Title = ModalTitle;
  Modal.Body = ModalBody;
  Modal.Footer = ModalFooter;

  var NavContext = /*#__PURE__*/React__default["default"].createContext();
  NavContext.displayName = 'NavContext';

  var _excluded$v = ["children", "active", "disabled", "style", "activeStyle", "textStyle", "activeTextStyle"];

  var _templateObject$q, _templateObject2$k, _templateObject3$9, _templateObject4$7, _templateObject5$5, _templateObject6$4, _templateObject7$2, _templateObject8$2, _templateObject9$2, _templateObject10$2, _templateObject11$1, _templateObject12$1, _templateObject13$1, _templateObject14, _templateObject15, _templateObject16, _templateObject17, _templateObject18, _templateObject19, _templateObject20;
  var propTypes$x = {
    children: PropTypes.node.isRequired,
    active: PropTypes.bool,
    disabled: PropTypes.bool,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    activeStyle: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    activeTextStyle: PropTypes.any
  };
  var styles$q = StyleSheet.create(_objectSpread2(_objectSpread2({
    '.nav-link': css(_templateObject$q || (_templateObject$q = _taggedTemplateLiteral(["\n    // display: block;\n    flex-direction: row; // added for bootstrap-rn\n    align-items: center; // added for bootstrap-rn\n    padding: $nav-link-padding-y $nav-link-padding-x;\n    // @include transition($nav-link-transition);\n  "]))),
    '.nav-link --text': css(_templateObject2$k || (_templateObject2$k = _taggedTemplateLiteral(["\n    font-size: $nav-link-font-size;\n    font-weight: $nav-link-font-weight;\n    color: $nav-link-color;\n    text-decoration: none; // if($link-decoration == none, null, none);\n\n    &:hover {\n      color: $nav-link-hover-color;\n      text-decoration: none; // if($link-hover-decoration == underline, none, null);\n    }\n    &:focus {\n      color: $nav-link-hover-color;\n      text-decoration: none; // if($link-hover-decoration == underline, none, null);\n    }\n  "]))),
    '.nav-link.disabled': css(_templateObject3$9 || (_templateObject3$9 = _taggedTemplateLiteral(["\n    @include platform(web) {\n      pointer-events: none;\n      cursor: default;\n    }\n  "]))),
    '.nav-link.disabled --text': css(_templateObject4$7 || (_templateObject4$7 = _taggedTemplateLiteral(["\n    color: $nav-link-disabled-color;\n  "]))),
    '.nav-tabs .nav-link': css(_templateObject5$5 || (_templateObject5$5 = _taggedTemplateLiteral(["\n    margin-bottom: -$nav-tabs-border-width;\n    background: transparent; // none;\n    // Use longform for border, so that the border color is applied correctly on Android.\n    border-width: $nav-tabs-border-width;\n    border-style: solid;\n    border-color: transparent transparent;\n    border-top-left-radius: $nav-tabs-border-radius;\n    border-top-right-radius: $nav-tabs-border-radius;\n\n    &:hover {\n      // Prevents active .nav-link tab overlapping focus outline of previous/next .nav-link\n      // isolation: isolate;\n      border-color: $nav-tabs-link-hover-border-color;\n    }\n    &:focus {\n      // Prevents active .nav-link tab overlapping focus outline of previous/next .nav-link\n      // isolation: isolate;\n      border-color: $nav-tabs-link-hover-border-color;\n    }\n  "]))),
    '.nav-tabs .nav-link.disabled': css(_templateObject6$4 || (_templateObject6$4 = _taggedTemplateLiteral(["\n    background-color: transparent;\n    border-color: transparent;\n  "]))),
    '.nav-tabs .nav-link.disabled --text': css(_templateObject7$2 || (_templateObject7$2 = _taggedTemplateLiteral(["\n    color: $nav-link-disabled-color;\n  "]))),
    '.nav-tabs .nav-link.active': css(_templateObject8$2 || (_templateObject8$2 = _taggedTemplateLiteral(["\n    background-color: $nav-tabs-link-active-bg;\n    border-color: $nav-tabs-link-active-border-color;\n\n    &:hover {\n      background-color: $nav-tabs-link-active-bg; // added for bootstrap-rn\n      border-color: $nav-tabs-link-active-border-color; // added for bootstrap-rn\n    }\n    &:focus {\n      background-color: $nav-tabs-link-active-bg; // added for bootstrap-rn\n      border-color: $nav-tabs-link-active-border-color; // added for bootstrap-rn\n    }\n  "]))),
    '.nav-tabs .nav-link.active --text': css(_templateObject9$2 || (_templateObject9$2 = _taggedTemplateLiteral(["\n    color: $nav-tabs-link-active-color;\n\n    &:hover {\n      color: $nav-tabs-link-active-color; // added for bootstrap-rn\n    }\n    &:focus {\n      color: $nav-tabs-link-active-color; // added for bootstrap-rn\n    }\n  "]))),
    '.nav-pills .nav-link': css(_templateObject10$2 || (_templateObject10$2 = _taggedTemplateLiteral(["\n    background: transparent; // none;\n    border: 0;\n    border-radius: $nav-pills-border-radius;\n  "]))),
    '.nav-pills .nav-link.active': css(_templateObject11$1 || (_templateObject11$1 = _taggedTemplateLiteral(["\n    // @include gradient-bg($nav-pills-link-active-bg);\n    background-color: $nav-pills-link-active-bg; // added for bootstrap-rn\n\n    &:hover {\n      background-color: $nav-pills-link-active-bg; // added for bootstrap-rn\n    }\n    &:focus {\n      background-color: $nav-pills-link-active-bg; // added for bootstrap-rn\n    }\n  "]))),
    '.nav-pills .nav-link.active --text': css(_templateObject12$1 || (_templateObject12$1 = _taggedTemplateLiteral(["\n    color: $nav-pills-link-active-color;\n\n    &:hover {\n      color: $nav-pills-link-active-color; // added for bootstrap-rn\n    }\n    &:focus {\n      color: $nav-pills-link-active-color; // added for bootstyl\n    }\n  "]))),
    // Navbar styles
    '.navbar-nav .nav-link': css(_templateObject13$1 || (_templateObject13$1 = _taggedTemplateLiteral(["\n    padding-right: 0;\n    padding-left: 0;\n  "])))
  }, each(GRID_BREAKPOINTS, function (breakpoint) {
    return _defineProperty({}, ".navbar-expand".concat(infix(next(breakpoint)), " .navbar-nav .nav-link"), css(_templateObject14 || (_templateObject14 = _taggedTemplateLiteral(["\n      @include media-breakpoint-up(", ") {\n        padding-right: $navbar-nav-link-padding-x;\n        padding-left: $navbar-nav-link-padding-x;\n      }\n    "])), next(breakpoint)));
  })), {}, {
    '.navbar-light .navbar-nav .nav-link --text': css(_templateObject15 || (_templateObject15 = _taggedTemplateLiteral(["\n    color: $navbar-light-color;\n\n    &:hover {\n      color: $navbar-light-hover-color;\n    }\n    &:focus {\n      color: $navbar-light-hover-color;\n    }\n  "]))),
    '.navbar-light .navbar-nav .nav-link.disabled --text': css(_templateObject16 || (_templateObject16 = _taggedTemplateLiteral(["\n    color: $navbar-light-disabled-color;\n  "]))),
    '.navbar-light .navbar-nav .nav-link.active --text': css(_templateObject17 || (_templateObject17 = _taggedTemplateLiteral(["\n    color: $navbar-light-active-color;\n\n    &:hover {\n      color: $navbar-light-active-color; // added for bootstrap-rn\n    }\n    &:focus {\n      color: $navbar-light-active-color; // added for bootstrap-rn\n    }\n  "]))),
    '.navbar-dark .navbar-nav .nav-link --text': css(_templateObject18 || (_templateObject18 = _taggedTemplateLiteral(["\n    color: $navbar-dark-color;\n\n    &:hover {\n      color: $navbar-dark-hover-color;\n    }\n    &:focus {\n      color: $navbar-dark-hover-color;\n    }\n  "]))),
    '.navbar-dark .navbar-nav .nav-link.disabled --text': css(_templateObject19 || (_templateObject19 = _taggedTemplateLiteral(["\n    color: $navbar-dark-disabled-color;\n  "]))),
    '.navbar-dark .navbar-nav .nav-link.active --text': css(_templateObject20 || (_templateObject20 = _taggedTemplateLiteral(["\n    color: $navbar-dark-active-color;\n\n    &:hover {\n      color: $navbar-dark-active-color; // added for bootstrap-rn\n    }\n    &:focus {\n      color: $navbar-dark-active-color; // added for bootstrap-rn\n    }\n  "])))
  }));
  var NavLink = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var _useModifier = useModifier('useTabbable', props, ref),
        _useModifier2 = _slicedToArray(_useModifier, 2),
        modifierProps = _useModifier2[0],
        modifierRef = _useModifier2[1];

    var children = modifierProps.children,
        active = modifierProps.active,
        disabled = modifierProps.disabled,
        style = modifierProps.style,
        activeStyle = modifierProps.activeStyle,
        textStyle = modifierProps.textStyle,
        activeTextStyle = modifierProps.activeTextStyle,
        elementProps = _objectWithoutProperties(modifierProps, _excluded$v);

    var _useForcedContext = useForcedContext(NavContext),
        variant = _useForcedContext.variant;

    var navbar = React.useContext(NavbarContext);
    var classes = getStyles(styles$q, ['.nav-link', disabled && '.nav-link.disabled', variant && ".nav-".concat(variant, " .nav-link"), variant === 'tabs' && disabled && '.nav-tabs .nav-link.disabled', // Navbar styles
    navbar && '.navbar-nav .nav-link', navbar && navbar.expand && ".navbar-expand".concat(navbar.expand === true ? '' : "-".concat(navbar.expand), " .navbar-nav .nav-link"), navbar && ".navbar-".concat(navbar.variant, " .navbar-nav .nav-link"), navbar && disabled && ".navbar-".concat(navbar.variant, " .navbar-nav .nav-link.disabled")]);
    var activeClasses = getStyles(styles$q, [variant && ".nav-".concat(variant, " .nav-link.active"), // Navbar styles
    navbar && ".navbar-".concat(navbar.variant, " .navbar-nav .nav-link.active")]);
    var textClasses = getStyles(styles$q, ['.nav-link --text', disabled && '.nav-link.disabled --text', variant && ".nav-".concat(variant, " .nav-link --text"), variant === 'tabs' && disabled && '.nav-tabs .nav-link.disabled --text', // Navbar styles
    navbar && '.navbar-nav .nav-link --text', navbar && navbar.expand && ".navbar-expand".concat(infix(navbar.expand), " .navbar-nav .nav-link --text"), navbar && ".navbar-".concat(navbar.variant, " .navbar-nav .nav-link --text"), navbar && disabled && ".navbar-".concat(navbar.variant, " .navbar-nav .nav-link.disabled --text")]);
    var activeTextClasses = getStyles(styles$q, [variant && ".nav-".concat(variant, " .nav-link.active --text"), // Navbar styles
    navbar && ".navbar-".concat(navbar.variant, " .navbar-nav .nav-link.active --text")]);
    return /*#__PURE__*/React__default["default"].createElement(Pressable, _extends$1({}, elementProps, {
      ref: modifierRef,
      active: active,
      disabled: disabled,
      style: [].concat(_toConsumableArray(classes), [style]),
      activeStyle: [].concat(_toConsumableArray(activeClasses), [activeStyle]),
      textStyle: [].concat(_toConsumableArray(textClasses), [textStyle]),
      activeTextStyle: [].concat(_toConsumableArray(activeTextClasses), [activeTextStyle])
    }), children);
  });
  NavLink.displayName = 'NavLink';
  NavLink.propTypes = propTypes$x;

  var TabContext = /*#__PURE__*/React.createContext();
  TabContext.displayName = 'TabContext';

  var _excluded$u = ["children", "variant", "style"];

  var _templateObject$p, _templateObject2$j, _templateObject3$8, _templateObject4$6;
  var propTypes$w = {
    children: PropTypes.node.isRequired,
    variant: PropTypes.oneOf(['tabs', 'pills']),
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$p = StyleSheet.create(_objectSpread2({
    '.nav': css(_templateObject$p || (_templateObject$p = _taggedTemplateLiteral(["\n    display: flex;\n    flex-direction: row; // added for bootstrap-rn\n    // flex-wrap: wrap; // bootstrap-rn: width will shrink on native with \"flex-direction: column;\"\n    padding-left: 0;\n    margin-bottom: 0;\n    // list-style: none;\n  "]))),
    '.nav-tabs': css(_templateObject2$j || (_templateObject2$j = _taggedTemplateLiteral(["\n    border-bottom-width: $nav-tabs-border-width;\n    border-style: solid;\n    border-color: $nav-tabs-border-color;\n  "]))),
    // Navbar styles
    '.navbar-nav': css(_templateObject3$8 || (_templateObject3$8 = _taggedTemplateLiteral(["\n    display: flex;\n    flex-direction: column; // cannot use \"inherit\" to get the \".navbar\"s value\n    padding-left: 0;\n    margin-bottom: 0;\n    // list-style: none;\n  "])))
  }, each(GRID_BREAKPOINTS, function (breakpoint) {
    return _defineProperty({}, ".navbar-expand".concat(infix(next(breakpoint)), " .navbar-nav"), css(_templateObject4$6 || (_templateObject4$6 = _taggedTemplateLiteral(["\n      @include media-breakpoint-up(", ") {\n        flex-direction: row;\n      }\n    "])), next(breakpoint)));
  })));

  var getRole = function getRole(tabbable, navbar) {
    if (tabbable) {
      return 'tablist';
    }

    if (reactNative.Platform.OS === 'web' && !navbar) {
      return 'navigation';
    }

    return null;
  };

  var Nav = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        variant = props.variant,
        style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded$u);

    var navbar = React.useContext(NavbarContext);
    var tabbable = React.useContext(TabContext);
    var classes = getStyles(styles$p, [!navbar && '.nav', variant === 'tabs' && '.nav-tabs', // Navbar styles
    navbar && '.navbar-nav', navbar && navbar.expand && ".navbar-expand".concat(navbar.expand === true ? '' : "-".concat(navbar.expand), " .navbar-nav")]);
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      accessibilityRole: getRole(tabbable, navbar),
      style: [classes, style]
    }), /*#__PURE__*/React__default["default"].createElement(NavContext.Provider, {
      value: {
        variant: variant
      }
    }, children));
  });
  Nav.displayName = 'Nav';
  Nav.propTypes = propTypes$w;
  Nav.Context = NavContext;
  Nav.Link = NavLink;

  var _excluded$t = ["children", "style", "textStyle"];

  var _templateObject$o, _templateObject2$i, _templateObject3$7;
  var propTypes$v = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any
  };
  var styles$o = StyleSheet.create({
    '.navbar-text': css(_templateObject$o || (_templateObject$o = _taggedTemplateLiteral(["\n    padding-top: $nav-link-padding-y;\n    padding-bottom: $nav-link-padding-y;\n  "]))),
    '.navbar-light .navbar-text --text': css(_templateObject2$i || (_templateObject2$i = _taggedTemplateLiteral(["\n    color: $navbar-light-color;\n  "]))),
    '.navbar-dark .navbar-text --text': css(_templateObject3$7 || (_templateObject3$7 = _taggedTemplateLiteral(["\n    color: $navbar-dark-color;\n  "])))
  });
  var NavbarText = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        textStyle = props.textStyle,
        elementProps = _objectWithoutProperties(props, _excluded$t);

    var _useForcedContext = useForcedContext(NavbarContext),
        variant = _useForcedContext.variant;

    var classes = getStyles(styles$o, ['.navbar-text']);
    var textClasses = getStyles(styles$o, [".navbar-".concat(variant, " .navbar-text --text")]); // composite component

    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style]
    }), /*#__PURE__*/React__default["default"].createElement(Text, {
      style: [textClasses, textStyle]
    }, children));
  });
  NavbarText.displayName = 'NavbarText';
  NavbarText.propTypes = propTypes$v;

  var _excluded$s = ["children", "style", "textStyle"];

  var _templateObject$n, _templateObject2$h, _templateObject3$6, _templateObject4$5;
  var propTypes$u = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any
  };
  var styles$n = StyleSheet.create({
    '.navbar-brand': css(_templateObject$n || (_templateObject$n = _taggedTemplateLiteral(["\n    padding-top: $navbar-brand-padding-y;\n    padding-bottom: $navbar-brand-padding-y;\n    margin-right: $navbar-brand-margin-end;\n  "]))),
    '.navbar-brand --text': css(_templateObject2$h || (_templateObject2$h = _taggedTemplateLiteral(["\n    font-size: $navbar-brand-font-size;\n    line-height: $navbar-brand-font-size * $line-height-base; // added for bootstrap-rn\n    text-decoration: none; // if($link-decoration == none, null, none);\n    // white-space: nowrap;\n\n    &:hover {\n      text-decoration: none; // if($link-hover-decoration == underline, none, null);\n    }\n    &:focus {\n      text-decoration: none; // if($link-hover-decoration == underline, none, null);\n    }\n  "]))),
    '.navbar-light .navbar-brand --text': css(_templateObject3$6 || (_templateObject3$6 = _taggedTemplateLiteral(["\n    color: $navbar-light-brand-color;\n\n    &:hover {\n      color: $navbar-light-brand-hover-color;\n    }\n    &:focus {\n      color: $navbar-light-brand-hover-color;\n    }\n  "]))),
    '.navbar-dark .navbar-brand --text': css(_templateObject4$5 || (_templateObject4$5 = _taggedTemplateLiteral(["\n    color: $navbar-dark-brand-color;\n\n    &:hover {\n      color: $navbar-dark-brand-hover-color;\n    }\n    &:focus {\n      color: $navbar-dark-brand-hover-color;\n    }\n  "])))
  });
  var NavbarBrand = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        textStyle = props.textStyle,
        elementProps = _objectWithoutProperties(props, _excluded$s);

    var _useForcedContext = useForcedContext(NavbarContext),
        variant = _useForcedContext.variant;

    var classes = getStyles(styles$n, ['.navbar-brand']);
    var textClasses = getStyles(styles$n, ['.navbar-brand --text', ".navbar-".concat(variant, " .navbar-brand --text")]);
    return /*#__PURE__*/React__default["default"].createElement(Pressable, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style],
      textStyle: [textClasses, textStyle]
    }), children);
  });
  NavbarBrand.displayName = 'NavbarBrand';
  NavbarBrand.propTypes = propTypes$u;

  var _excluded$r = ["children", "style"];

  var _templateObject$m, _templateObject2$g;
  var propTypes$t = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$m = StyleSheet.create(_objectSpread2({
    '.navbar-collapse': css(_templateObject$m || (_templateObject$m = _taggedTemplateLiteral(["\n    flex-basis: 100%;\n    flex-grow: 1;\n    // For always expanded or extra full navbars, ensure content aligns itself\n    // properly vertically. Can be easily overridden with flex utilities.\n    // align-items: center;\n  "])))
  }, each(GRID_BREAKPOINTS, function (breakpoint) {
    return _defineProperty({}, ".navbar-expand".concat(infix(next(breakpoint)), " .navbar-collapse"), css(_templateObject2$g || (_templateObject2$g = _taggedTemplateLiteral(["\n      @include media-breakpoint-up(", ") {\n        flex-direction: row; // added for bootstrap-rn\n        display: flex;\n        flex-basis: auto;\n        align-items: center; // added for bootstrap-rn\n      }\n    "])), next(breakpoint)));
  })));
  var NavbarCollapse = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded$r);

    var _useForcedContext = useForcedContext(NavbarContext),
        expand = _useForcedContext.expand,
        expanded = _useForcedContext.expanded;

    var media = useMedia();
    var classes = getStyles(styles$m, ['.navbar-collapse', expand && ".navbar-expand".concat(expand === true ? '' : "-".concat(expand), " .navbar-collapse")]);
    var show = expanded || expand && (expand === true || media.up(expand));

    if (!show) {
      return null;
    }

    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style]
    }), children);
  });
  NavbarCollapse.displayName = 'NavbarCollapse';
  NavbarCollapse.propTypes = propTypes$t;

  var _excluded$q = ["onPress"];
  function useToggleNavbar(props) {
    var context = useForcedContext(NavbarContext);

    var handlePress = props.onPress,
        restProps = _objectWithoutProperties(props, _excluded$q);

    return _objectSpread2(_objectSpread2({}, restProps), {}, {
      nativeID: context.identifier,
      onPress: function onPress(event) {
        if (handlePress) handlePress(event);
        context.setExpanded(function (value) {
          return !value;
        });
      },
      accessibilitControls: context.identifier,
      accessibilityExpanded: context.expanded,
      accessibilityLabel: 'Toggle navigation'
    });
  }

  var _excluded$p = ["style", "textStyle", "iconStyle"];

  var _templateObject$l, _templateObject2$f, _templateObject3$5, _templateObject4$4, _templateObject5$4, _templateObject6$3, _templateObject7$1, _templateObject8$1, _templateObject9$1, _templateObject10$1;
  var propTypes$s = {
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    iconStyle: PropTypes.any
  };
  var styles$l = StyleSheet.create(_objectSpread2(_objectSpread2({
    '.navbar-toggler': css(_templateObject$l || (_templateObject$l = _taggedTemplateLiteral(["\n    padding: $navbar-toggler-padding-y $navbar-toggler-padding-x;\n    background-color: transparent; // remove default button style\n    border: $border-width solid transparent; // remove default button style\n    border-radius: $navbar-toggler-border-radius;\n    // @include transition($navbar-toggler-transition);\n\n    &:focus {\n      @include platform(web) {\n        outline-width: 0; // outline: 0;\n      }\n      // box-shadow: 0 0 0 $navbar-toggler-focus-width;\n    }\n  "]))),
    '.navbar-toggler --text': css(_templateObject2$f || (_templateObject2$f = _taggedTemplateLiteral(["\n    font-size: $navbar-toggler-font-size;\n    line-height: $navbar-toggler-font-size * $line-height-base;\n\n    &:hover {\n      text-decoration: none;\n    }\n\n    &:focus {\n      text-decoration: none;\n    }\n  "]))),
    '.navbar-toggler-icon': css(_templateObject3$5 || (_templateObject3$5 = _taggedTemplateLiteral(["\n    // display: inline-block;\n    width: $navbar-toggler-font-size * 1.5; // 1.5em;\n    height: $navbar-toggler-font-size * 1.5; // 1.5em;\n    // vertical-align: middle;\n    background-repeat: no-repeat;\n    background-position: center;\n    background-size: 100%;\n  "])))
  }, each(GRID_BREAKPOINTS, function (breakpoint) {
    return _defineProperty({}, ".navbar-expand".concat(infix(next(breakpoint)), " .navbar-toggler"), css(_templateObject4$4 || (_templateObject4$4 = _taggedTemplateLiteral(["\n      @include media-breakpoint-up(", ") {\n        display: none;\n      }\n    "])), next(breakpoint)));
  })), {}, {
    '.navbar-light .navbar-toggler': css(_templateObject5$4 || (_templateObject5$4 = _taggedTemplateLiteral(["\n    border-color: $navbar-light-toggler-border-color;\n  "]))),
    '.navbar-light .navbar-toggler --text': css(_templateObject6$3 || (_templateObject6$3 = _taggedTemplateLiteral(["\n    color: $navbar-light-color;\n  "]))),
    '.navbar-light .navbar-toggler-icon': css(_templateObject7$1 || (_templateObject7$1 = _taggedTemplateLiteral(["\n    background-image: ", ";\n  "])), function (t) {
      return escapeSvg(t['navbar-light-toggler-icon-bg']);
    }),
    '.navbar-dark .navbar-toggler': css(_templateObject8$1 || (_templateObject8$1 = _taggedTemplateLiteral(["\n    border-color: $navbar-dark-toggler-border-color;\n  "]))),
    '.navbar-dark .navbar-toggler --text': css(_templateObject9$1 || (_templateObject9$1 = _taggedTemplateLiteral(["\n    color: $navbar-dark-color;\n  "]))),
    '.navbar-dark .navbar-toggler-icon': css(_templateObject10$1 || (_templateObject10$1 = _taggedTemplateLiteral(["\n    background-image: ", ";\n  "])), function (t) {
      return escapeSvg(t['navbar-dark-toggler-icon-bg']);
    })
  }));
  var NavbarToggler = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var style = props.style,
        textStyle = props.textStyle,
        iconStyle = props.iconStyle,
        elementProps = _objectWithoutProperties(props, _excluded$p);

    var media = useMedia();

    var _useForcedContext = useForcedContext(NavbarContext),
        variant = _useForcedContext.variant,
        expand = _useForcedContext.expand;

    var classes = getStyles(styles$l, ['.navbar-toggler', ".navbar-".concat(variant, " .navbar-toggler"), expand && ".navbar-expand".concat(expand === true ? '' : "-".concat(expand), " .navbar-toggler")]);
    var textClasses = getStyles(styles$l, ['.navbar-toggler --text', ".navbar-".concat(variant, " .navbar-toggler --text")]);
    var iconClasses = getStyles(styles$l, ['.navbar-toggler-icon', ".navbar-".concat(variant, " .navbar-toggler-icon")]);
    var resolveIconStyle = useStyle([iconClasses, iconStyle]);
    var background = useBackground(resolveIconStyle({
      media: media
    }));
    return /*#__PURE__*/React__default["default"].createElement(Pressable, _extends$1({}, elementProps, {
      ref: ref,
      toggle: useToggleNavbar,
      style: [classes, style],
      textStyle: [textClasses, textStyle]
    }), /*#__PURE__*/React__default["default"].createElement(View, {
      style: background.style
    }, background.element));
  });
  NavbarToggler.displayName = 'NavbarToggler';
  NavbarToggler.propTypes = propTypes$s;

  function useNavbar(variant, defaultExpanded, controlledExpanded, onToggle, expand) {
    var identifier = useIdentifier('navbar');

    var _useControlledState = useControlledState(defaultExpanded, controlledExpanded, onToggle),
        _useControlledState2 = _slicedToArray(_useControlledState, 2),
        expanded = _useControlledState2[0],
        setExpanded = _useControlledState2[1];

    return React.useMemo(function () {
      return {
        identifier: identifier,
        variant: variant,
        expanded: expanded,
        setExpanded: setExpanded,
        expand: expand
      };
    }, [variant, expanded, expand]);
  }

  var _excluded$o = ["onPress"];
  function useDismissNavbar(props) {
    var context = useForcedContext(NavbarContext);

    var handlePress = props.onPress,
        restProps = _objectWithoutProperties(props, _excluded$o);

    return _objectSpread2(_objectSpread2({}, restProps), {}, {
      onPress: function onPress(event) {
        if (handlePress) handlePress(event);
        context.setExpanded(false);
      },
      accessibilityLabel: 'Close'
    });
  }

  var _excluded$n = ["children", "variant", "defaultExpanded", "expanded", "onToggle", "expand", "style"];

  var _templateObject$k, _templateObject2$e;
  var propTypes$r = {
    children: PropTypes.node.isRequired,
    variant: PropTypes.oneOf(['light', 'dark']),
    defaultExpanded: PropTypes.bool,
    expanded: PropTypes.bool,
    onToggle: PropTypes.func,
    expand: PropTypes.oneOf([true, 'sm', 'md', 'lg', 'xl', 'xxl']),
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$k = StyleSheet.create(_objectSpread2({
    '.navbar': css(_templateObject$k || (_templateObject$k = _taggedTemplateLiteral(["\n    position: relative;\n    display: flex;\n    flex-direction: row; // added for bootstrap-rn\n    flex-wrap: wrap; // allow us to do the line break for collapsing content\n    align-items: center;\n    justify-content: space-between; // space out brand from logo\n    padding-top: $navbar-padding-y;\n    padding-right: $navbar-padding-x; // default: null\n    padding-bottom: $navbar-padding-y;\n    padding-left: $navbar-padding-x; // default: null\n    // @include gradient-bg();\n  "])))
  }, each(GRID_BREAKPOINTS, function (breakpoint) {
    return _defineProperty({}, ".navbar-expand".concat(infix(next(breakpoint))), css(_templateObject2$e || (_templateObject2$e = _taggedTemplateLiteral(["\n      @include media-breakpoint-up(", ") {\n        flex-wrap: nowrap;\n        justify-content: flex-start;\n      }\n    "])), next(breakpoint)));
  })));
  var Navbar = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        _props$variant = props.variant,
        variant = _props$variant === void 0 ? 'light' : _props$variant,
        _props$defaultExpande = props.defaultExpanded,
        defaultExpanded = _props$defaultExpande === void 0 ? false : _props$defaultExpande,
        expanded = props.expanded,
        onToggle = props.onToggle,
        expand = props.expand,
        style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded$n);

    var navbar = useNavbar(variant, defaultExpanded, expanded, onToggle, expand);
    var classes = getStyles(styles$k, ['.navbar', expand && ".navbar-expand".concat(expand === true ? '' : "-".concat(expand))]);
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style]
    }), /*#__PURE__*/React__default["default"].createElement(NavbarContext.Provider, {
      value: navbar
    }, children));
  });
  Navbar.displayName = 'Navbar';
  Navbar.propTypes = propTypes$r;
  Navbar.Brand = NavbarBrand;
  Navbar.Text = NavbarText;
  Navbar.Collapse = NavbarCollapse;
  Navbar.Toggler = NavbarToggler;
  Navbar.useDismiss = useDismissNavbar;
  Navbar.useToggle = useToggleNavbar;

  function useOffcanvas() {
    return React.useMemo(function () {
      return {};
    }, []);
  }

  var _excluded$m = ["children", "style"];

  var _templateObject$j, _templateObject2$d;
  var propTypes$q = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$j = StyleSheet.create(_objectSpread2({
    '.offcanvas-header': css(_templateObject$j || (_templateObject$j = _taggedTemplateLiteral(["\n    display: flex;\n    flex-direction: row; // added for bootstrap-rn\n    align-items: center;\n    justify-content: space-between;\n    padding: $offcanvas-padding-y $offcanvas-padding-x;\n  "])))
  }, each(GRID_BREAKPOINTS, function (breakpoint) {
    return _defineProperty({}, ".navbar-expand".concat(infix(next(breakpoint)), " .offcanvas-header"), css(_templateObject2$d || (_templateObject2$d = _taggedTemplateLiteral(["\n      @include media-breakpoint-up(", ") {\n        display: none;\n      }\n    "])), next(breakpoint)));
  })));
  var OffcanvasHeader = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded$m);

    var navbar = React.useContext(NavbarContext);
    var classes = getStyles(styles$j, ['.offcanvas-header', navbar && navbar.expand && ".navbar-expand".concat(navbar.expand === true ? '' : "-".concat(navbar.expand), " .offcanvas-header")]);
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style]
    }), children);
  });
  OffcanvasHeader.displayName = 'OffcanvasHeader';
  OffcanvasHeader.propTypes = propTypes$q;

  var _excluded$l = ["children", "style"];

  var _templateObject$i;
  var propTypes$p = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$i = StyleSheet.create({
    '.offcanvas-title': css(_templateObject$i || (_templateObject$i = _taggedTemplateLiteral(["\n    margin-bottom: 0;\n    line-height: $font-size-base * $offcanvas-title-line-height;\n  "])))
  });
  var OffcanvasTitle = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded$l);

    var classes = getStyles(styles$i, ['.offcanvas-title']);
    return /*#__PURE__*/React__default["default"].createElement(Heading$2, _extends$1({
      size: 5
    }, elementProps, {
      ref: ref,
      style: [classes, style]
    }), children);
  });
  OffcanvasTitle.displayName = 'OffcanvasTitle';
  OffcanvasTitle.propTypes = propTypes$p;

  var _excluded$k = ["children", "style", "contentContainerStyle"];

  var _templateObject$h, _templateObject2$c;
  var propTypes$o = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    contentContainerStyle: PropTypes.any
  };
  var styles$h = StyleSheet.create(_objectSpread2({
    '.offcanvas-body': css(_templateObject$h || (_templateObject$h = _taggedTemplateLiteral(["\n    // flex-grow: 1;\n    padding: $offcanvas-padding-y $offcanvas-padding-x;\n    // overflow-y: auto;\n  "])))
  }, each(GRID_BREAKPOINTS, function (breakpoint) {
    return _defineProperty({}, ".navbar-expand".concat(infix(next(breakpoint)), " .offcanvas-body"), css(_templateObject2$c || (_templateObject2$c = _taggedTemplateLiteral(["\n      @include media-breakpoint-up(", ") {\n        display: flex;\n        flex-grow: 0;\n        padding: 0;\n        // overflow-y: visible;\n      }\n    "])), next(breakpoint)));
  })));
  var OffcanvasBody = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        contentContainerStyle = props.contentContainerStyle,
        elementProps = _objectWithoutProperties(props, _excluded$k);

    var navbar = React.useContext(NavbarContext);
    var contentContainerClasses = getStyles(styles$h, ['.offcanvas-body', navbar && navbar.expand && ".navbar-expand".concat(navbar.expand === true ? '' : "-".concat(navbar.expand), " .offcanvas-body")]);
    return /*#__PURE__*/React__default["default"].createElement(ScrollView, _extends$1({}, elementProps, {
      ref: ref,
      style: style,
      contentContainerStyle: [contentContainerClasses, contentContainerStyle]
    }), children);
  });
  OffcanvasBody.displayName = 'OffcanvasBody';
  OffcanvasBody.propTypes = propTypes$o;

  var _excluded$j = ["children", "visible", "placement", "backdrop", "scroll", "onToggle", "style", "dialogStyle", "textStyle", "dialogTextStyle"];

  var _templateObject$g, _templateObject2$b, _templateObject3$4, _templateObject4$3, _templateObject5$3, _templateObject6$2, _templateObject7, _templateObject8, _templateObject9, _templateObject10, _templateObject11, _templateObject12, _templateObject13;
  var PLACEMENTS = ['top', 'bottom', 'start', 'end']; // , 'auto'

  var propTypes$n = {
    children: PropTypes.node.isRequired,
    visible: PropTypes.bool,
    placement: PropTypes.oneOf(PLACEMENTS),
    backdrop: PropTypes.oneOfType([PropTypes.bool, PropTypes.oneOf(['static'])]),
    // Currently only supported on web.
    scroll: PropTypes.bool,
    onToggle: PropTypes.func,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    dialogStyle: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    dialogTextStyle: PropTypes.any
  };
  var styles$g = StyleSheet.create(_objectSpread2({
    '.offcanvas': css(_templateObject$g || (_templateObject$g = _taggedTemplateLiteral(["\n    position: absolute; // fixed;\n    // bottom: 0;\n    z-index: $zindex-offcanvas;\n    display: flex;\n    flex-direction: column;\n    max-width: 100%;\n    // visibility: hidden;\n    background-color: $offcanvas-bg-color;\n    // background-clip: padding-box;\n    @include platform(web) {\n      outline-width: 0; // outline: 0;\n    }\n    // @include box-shadow($offcanvas-box-shadow);\n    // @include transition(transform $offcanvas-transition-duration ease-in-out);\n  "]))),
    '.offcanvas --text': css(_templateObject2$b || (_templateObject2$b = _taggedTemplateLiteral(["\n    color: $offcanvas-color;\n  "]))),
    '.offcanvas-backdrop': css(_templateObject3$4 || (_templateObject3$4 = _taggedTemplateLiteral(["\n    position: absolute;\n    top: 0;\n    left: 0;\n    z-index: $zindex-offcanvas-backdrop;\n    width: 100%;\n    height: 100%;\n    background-color: $offcanvas-backdrop-bg;\n    opacity: $offcanvas-backdrop-opacity;\n  "]))),
    '.offcanvas-start': css(_templateObject4$3 || (_templateObject4$3 = _taggedTemplateLiteral(["\n    top: 0;\n    bottom: 0; // added for bootstrap-rn\n    left: 0;\n    // width: $offcanvas-horizontal-width;\n    border-right-width: $offcanvas-border-width;\n    border-style: solid;\n    border-color: $offcanvas-border-color;\n    // transform: translateX(-100%);\n  "]))),
    '.offcanvas-end': css(_templateObject5$3 || (_templateObject5$3 = _taggedTemplateLiteral(["\n    top: 0;\n    bottom: 0; // added for bootstrap-rn\n    right: 0;\n    // width: $offcanvas-horizontal-width;\n    border-left-width: $offcanvas-border-width;\n    border-style: solid;\n    border-color: $offcanvas-border-color;\n    // transform: translateX(100%);\n  "]))),
    '.offcanvas-top': css(_templateObject6$2 || (_templateObject6$2 = _taggedTemplateLiteral(["\n    top: 0;\n    right: 0;\n    left: 0;\n    // height: $offcanvas-vertical-height;\n    max-height: 100%;\n    border-bottom-width: $offcanvas-border-width;\n    border-style: solid;\n    border-color: $offcanvas-border-color;\n    // transform: translateY(-100%);\n  "]))),
    '.offcanvas-bottom': css(_templateObject7 || (_templateObject7 = _taggedTemplateLiteral(["\n    bottom: 0; // added for bootstrap-rn\n    right: 0;\n    left: 0;\n    // height: $offcanvas-vertical-height;\n    max-height: 100%;\n    width: 100%;\n    border-top-width: $offcanvas-border-width;\n    border-style: solid;\n    border-color: $offcanvas-border-color;\n    // transform: translateY(100%);\n  "]))),
    // The following .offcanvas-dialog classes are added for bootstrap-rn,
    // because otherwise the text would exceed a width of 100% on native
    // and also additional width by SafeAreaView would not be applied.
    '.offcanvas-dialog': css(_templateObject8 || (_templateObject8 = _taggedTemplateLiteral(["\n    max-width: 100%;\n    max-height: 100%;\n  "]))),
    '.offcanvas-dialog-start': css(_templateObject9 || (_templateObject9 = _taggedTemplateLiteral(["\n    width: $offcanvas-horizontal-width;\n  "]))),
    '.offcanvas-dialog-end': css(_templateObject10 || (_templateObject10 = _taggedTemplateLiteral(["\n    width: $offcanvas-horizontal-width;\n  "]))),
    '.offcanvas-dialog-top': css(_templateObject11 || (_templateObject11 = _taggedTemplateLiteral(["\n    height: $offcanvas-vertical-height;\n  "]))),
    '.offcanvas-dialog-bottom': css(_templateObject12 || (_templateObject12 = _taggedTemplateLiteral(["\n    height: $offcanvas-vertical-height;\n  "])))
  }, each(GRID_BREAKPOINTS, function (breakpoint) {
    return _defineProperty({}, ".navbar-expand".concat(infix(next(breakpoint)), " .offcanvas"), css(_templateObject13 || (_templateObject13 = _taggedTemplateLiteral(["\n      @include media-breakpoint-up(", ") {\n        position: relative; // inherit;\n        bottom: 0;\n        // z-index: auto;\n        flex-grow: 1;\n        // visibility: visible !important; // stylelint-disable-line declaration-no-important\n        background-color: transparent;\n        border-right-width: 0;\n        border-left-width: 0;\n        // @include box-shadow(none);\n        // @include transition(none);\n        // transform: none;\n      }\n    "])), next(breakpoint)));
  })));
  var Offcanvas = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        visible = props.visible,
        _props$placement = props.placement,
        placement = _props$placement === void 0 ? 'top' : _props$placement,
        _props$backdrop = props.backdrop,
        backdrop = _props$backdrop === void 0 ? true : _props$backdrop,
        _props$scroll = props.scroll,
        scroll = _props$scroll === void 0 ? false : _props$scroll,
        handleToggle = props.onToggle,
        style = props.style,
        dialogStyle = props.dialogStyle,
        textStyle = props.textStyle,
        dialogTextStyle = props.dialogTextStyle,
        elementProps = _objectWithoutProperties(props, _excluded$j);

    var media = useMedia();
    var navbar = React.useContext(NavbarContext);
    var offcanvasRef = React.useRef();
    var offcanvas = useOffcanvas();
    useScrollbarEffects({
      keepBodyScroll: scroll,
      visible: visible
    });
    var backdropClasses = getStyles(styles$g, ['.offcanvas-backdrop']);
    var classes = getStyles(styles$g, ['.offcanvas', ".offcanvas-".concat(placement), navbar && navbar.expand && ".navbar-expand".concat(navbar.expand === true ? '' : "-".concat(navbar.expand), " .offcanvas")]);
    var dialogClasses = getStyles(styles$g, ['.offcanvas-dialog', ".offcanvas-dialog-".concat(placement)]);
    var textClasses = getStyles(styles$g, ['.offcanvas-content --text']); // Render children without modal for navbar.

    if (navbar && navbar.expand && (navbar.expand === true || media.up(navbar.expand))) {
      return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
        ref: ref,
        style: [classes, style],
        textStyle: [textClasses, textStyle]
      }), children);
    }

    return /*#__PURE__*/React__default["default"].createElement(reactNative.Modal, {
      transparent: true,
      visible: navbar ? navbar.expanded : visible,
      onRequestClose: handleToggle
    }, backdrop && /*#__PURE__*/React__default["default"].createElement(View, {
      style: backdropClasses
    }, /*#__PURE__*/React__default["default"].createElement(BackdropHandler, {
      dialogRef: offcanvasRef,
      onClose: handleToggle,
      backdrop: backdrop
    })), /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: concatRefs(offcanvasRef, ref),
      style: [classes, style],
      textStyle: [textClasses, textStyle]
    }), /*#__PURE__*/React__default["default"].createElement(reactNative.SafeAreaView, {
      style: {
        flexShrink: 1
      }
    }, /*#__PURE__*/React__default["default"].createElement(View, {
      style: [dialogClasses, dialogStyle],
      textStyle: dialogTextStyle
    }, /*#__PURE__*/React__default["default"].createElement(OffcanvasContext.Provider, {
      value: offcanvas
    }, /*#__PURE__*/React__default["default"].createElement(OverlayProvider, null, children))))));
  });
  Offcanvas.displayName = 'Offcanvas';
  Offcanvas.propTypes = propTypes$n;
  Offcanvas.Context = OffcanvasContext;
  Offcanvas.Header = OffcanvasHeader;
  Offcanvas.Title = OffcanvasTitle;
  Offcanvas.Body = OffcanvasBody;

  var PickerWebContext = /*#__PURE__*/React__default["default"].createContext();
  PickerWebContext.displayName = 'PickerWebContext';

  var _excluded$i = ["children", "selectedValue", "onValueChange", "onFocus", "onBlur", "placeholder", "placeholderTextColor", "disabled", "style"];
  var propTypes$m = {
    children: PropTypes.node.isRequired,
    selectedValue: PropTypes.oneOfType([PropTypes.bool, PropTypes.number, PropTypes.string, PropTypes.object]),
    onValueChange: PropTypes.func,
    onFocus: PropTypes.func,
    onBlur: PropTypes.func,
    placeholder: PropTypes.string,
    placeholderTextColor: PropTypes.string,
    disabled: PropTypes.bool,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var PLACEHOLDER = '__PLACEHOLDER__';

  var getOptionStyle = function getOptionStyle(style, showPlaceholder) {
    if (!showPlaceholder) {
      return null;
    }

    var flattenedStyle = reactNative.StyleSheet.flatten(style);
    return flattenedStyle.color;
  };

  var PickerWeb = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        selectedValue = props.selectedValue,
        _props$onValueChange = props.onValueChange,
        onValueChange = _props$onValueChange === void 0 ? function () {} : _props$onValueChange,
        _props$onFocus = props.onFocus,
        onFocus = _props$onFocus === void 0 ? function () {} : _props$onFocus,
        _props$onBlur = props.onBlur,
        onBlur = _props$onBlur === void 0 ? function () {} : _props$onBlur,
        placeholder = props.placeholder,
        placeholderTextColor = props.placeholderTextColor,
        disabled = props.disabled,
        style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded$i);

    var background = useBackground(style);
    var showPlaceholder = placeholder && (selectedValue === undefined || selectedValue === null);
    return /*#__PURE__*/React__default["default"].createElement(reactNative.Picker, _extends$1({}, elementProps, {
      ref: ref,
      selectedValue: showPlaceholder ? PLACEHOLDER : selectedValue,
      onValueChange: onValueChange,
      onFocus: onFocus,
      onBlur: onBlur,
      disabled: disabled,
      style: [background.style, showPlaceholder && {
        color: placeholderTextColor
      }]
    }), placeholder && /*#__PURE__*/React__default["default"].createElement("option", {
      value: PLACEHOLDER,
      disabled: true,
      hidden: true
    }, placeholder), /*#__PURE__*/React__default["default"].createElement(PickerWebContext.Provider, {
      value: {
        optionColor: getOptionStyle(background.style, showPlaceholder)
      }
    }, children));
  });
  PickerWeb.propTypes = propTypes$m;

  var PickerNativeContext = /*#__PURE__*/React__default["default"].createContext();
  PickerNativeContext.displayName = 'PickerNativeContext';

  var _excluded$h = ["children", "selectedValue", "onValueChange", "onFocus", "onBlur", "placeholder", "placeholderTextColor", "disabled", "MenuComponent", "style"];

  var _templateObject$f;
  var propTypes$l = {
    children: PropTypes.node.isRequired,
    selectedValue: PropTypes.oneOfType([PropTypes.bool, PropTypes.number, PropTypes.string, PropTypes.object]),
    onValueChange: PropTypes.func,
    onFocus: PropTypes.func,
    onBlur: PropTypes.func,
    placeholder: PropTypes.string,
    placeholderTextColor: PropTypes.string,
    disabled: PropTypes.bool,
    MenuComponent: PropTypes.elementType,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$f = StyleSheet.create({
    menu: css(_templateObject$f || (_templateObject$f = _taggedTemplateLiteral(["\n    align-items: center;\n  "])))
  }); // Ref: https://reactnative.dev/docs/text-style-props

  var textStyleKeys = ['color', 'fontFamily', 'fontSize', 'fontStyle', 'fontWeight', 'includeFontPaddingAndroid', 'fontVariant', 'letterSpacing', 'lineHeight', 'textAlign', 'textAlignVerticalAndroid', 'textDecorationColoriOS', 'textDecorationLine', 'textDecorationStyleiOS', 'textShadowColor', 'textShadowOffset', 'textShadowRadius', 'textTransform', 'writingDirection'];

  var extractTextStyles = function extractTextStyles(style) {
    var textStyles = {};
    Object.entries(style).forEach(function (_ref) {
      var _ref2 = _slicedToArray(_ref, 2),
          key = _ref2[0],
          value = _ref2[1];

      if (textStyleKeys.includes(key)) {
        textStyles[key] = value;
      }
    });
    return textStyles;
  };

  var getText = function getText(_ref3) {
    var children = _ref3.children,
        selectedValue = _ref3.selectedValue;
    var items = React__default["default"].Children.map(children, function (child) {
      return {
        label: child.props.label,
        value: child.props.value
      };
    });
    var selectedItem = items.find(function (item) {
      return item.value === selectedValue;
    });
    return selectedItem === null || selectedItem === void 0 ? void 0 : selectedItem.label;
  };
  /* eslint-disable react/prop-types */


  var DefaultMenuComponent = function DefaultMenuComponent(_ref4) {
    var children = _ref4.children,
        selectedValue = _ref4.selectedValue,
        handleValueChange = _ref4.onValueChange,
        handleClose = _ref4.onClose;
    return /*#__PURE__*/React__default["default"].createElement(Offcanvas, {
      placement: "bottom",
      visible: true,
      onToggle: handleClose
    }, /*#__PURE__*/React__default["default"].createElement(Offcanvas.Body, {
      contentContainerStyle: styles$f.menu
    }, /*#__PURE__*/React__default["default"].createElement(PickerNativeContext.Provider, {
      value: {
        selectedValue: selectedValue,
        handleValueChange: handleValueChange
      }
    }, children)));
  };
  /* eslint-enable */


  var PickerNative = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        selectedValue = props.selectedValue,
        _props$onValueChange = props.onValueChange,
        onValueChange = _props$onValueChange === void 0 ? function () {} : _props$onValueChange,
        _props$onFocus = props.onFocus,
        onFocus = _props$onFocus === void 0 ? function () {} : _props$onFocus,
        _props$onBlur = props.onBlur,
        onBlur = _props$onBlur === void 0 ? function () {} : _props$onBlur,
        placeholder = props.placeholder,
        placeholderTextColor = props.placeholderTextColor,
        _props$disabled = props.disabled,
        disabled = _props$disabled === void 0 ? false : _props$disabled,
        _props$MenuComponent = props.MenuComponent,
        MenuComponent = _props$MenuComponent === void 0 ? DefaultMenuComponent : _props$MenuComponent,
        style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded$h);

    var background = useBackground(style);

    var _useState = React.useState(false),
        _useState2 = _slicedToArray(_useState, 2),
        visible = _useState2[0],
        setVisible = _useState2[1];

    var textStyle = extractTextStyles(background.style);
    var showPlaceholder = placeholder && (selectedValue === undefined || selectedValue === null);

    var handleValueChange = function handleValueChange(nextValue) {
      onValueChange(nextValue);
      setVisible(false);
    };

    var handleClose = function handleClose() {
      setVisible(false);
    };

    return /*#__PURE__*/React__default["default"].createElement(React__default["default"].Fragment, null, /*#__PURE__*/React__default["default"].createElement(Pressable, _extends$1({}, elementProps, {
      ref: ref,
      accessibilityRole: "combobox",
      onPress: function onPress() {
        setVisible(true);
      },
      onFocus: onFocus,
      onBlur: onBlur,
      disabled: disabled,
      style: background.style
    }), background.element, /*#__PURE__*/React__default["default"].createElement(Text, {
      numberOfLines: 1,
      style: [textStyle, showPlaceholder && {
        color: placeholderTextColor
      }]
    }, showPlaceholder ? placeholder : getText({
      children: children,
      selectedValue: selectedValue
    }))), visible && /*#__PURE__*/React__default["default"].createElement(MenuComponent, {
      selectedValue: selectedValue,
      onValueChange: handleValueChange,
      onClose: handleClose
    }, children));
  });
  PickerNative.propTypes = propTypes$l;

  var PickerContext = /*#__PURE__*/React__default["default"].createContext();
  PickerContext.displayName = 'PickerContext';

  var propTypes$k = {
    label: PropTypes.string.isRequired,
    value: PropTypes.oneOfType([PropTypes.bool, PropTypes.number, PropTypes.string, PropTypes.object]),
    disabled: PropTypes.bool
  };
  var PickerWebItem = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var label = props.label,
        value = props.value,
        _props$disabled = props.disabled,
        disabled = _props$disabled === void 0 ? false : _props$disabled;

    var _useForcedContext = useForcedContext(PickerWebContext),
        optionColor = _useForcedContext.optionColor;

    return /*#__PURE__*/React__default["default"].createElement(reactNative.Picker.Item, {
      ref: ref,
      label: label,
      value: value,
      disabled: disabled,
      color: optionColor
    });
  });
  PickerWebItem.displayName = 'PickerWebItem';
  PickerWebItem.propTypes = propTypes$k;

  var _templateObject$e, _templateObject2$a;
  var propTypes$j = {
    label: PropTypes.string.isRequired,
    value: PropTypes.oneOfType([PropTypes.bool, PropTypes.number, PropTypes.string, PropTypes.object]),
    disabled: PropTypes.bool
  };
  var styles$e = StyleSheet.create({
    item: css(_templateObject$e || (_templateObject$e = _taggedTemplateLiteral(["\n    margin: 0.25rem 1rem;\n    padding: 0.25rem;\n  "]))),
    itemDisabled: css(_templateObject2$a || (_templateObject2$a = _taggedTemplateLiteral([""])))
  });
  var PickerNativeItem = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var label = props.label,
        value = props.value,
        _props$disabled = props.disabled,
        disabled = _props$disabled === void 0 ? false : _props$disabled;

    var _useForcedContext = useForcedContext(PickerNativeContext),
        selectedValue = _useForcedContext.selectedValue,
        handleValueChange = _useForcedContext.handleValueChange;

    var media = useMedia();
    var classes = getStyles(styles$e, ['item', disabled && 'itemDisabled']);
    var resolveStyle = useStyle(classes);
    var selected = value === selectedValue;
    return /*#__PURE__*/React__default["default"].createElement(Pressable, {
      ref: ref,
      onPress: function onPress() {
        handleValueChange(value);
      },
      accessibilitySelected: selected,
      disabled: disabled,
      style: resolveStyle({
        media: media
      })
    }, /*#__PURE__*/React__default["default"].createElement(Text, {
      styleName: selected && 'text-primary'
    }, label));
  });
  PickerNativeItem.displayName = 'PickerNativeItem';
  PickerNativeItem.propTypes = propTypes$j;

  var propTypes$i = {
    label: PropTypes.string.isRequired,
    value: PropTypes.oneOfType([PropTypes.bool, PropTypes.number, PropTypes.string, PropTypes.object]),
    disabled: PropTypes.bool
  };
  var PickerItem = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var label = props.label,
        value = props.value,
        _props$disabled = props.disabled,
        disabled = _props$disabled === void 0 ? false : _props$disabled;

    var _useForcedContext = useForcedContext(PickerContext),
        useNativeComponent = _useForcedContext.useNativeComponent;

    var BasePickerItem = reactNative.Platform.OS === 'web' && !useNativeComponent ? PickerWebItem : PickerNativeItem;
    return /*#__PURE__*/React__default["default"].createElement(BasePickerItem, {
      ref: ref,
      label: label,
      value: value,
      disabled: disabled
    });
  });
  PickerItem.displayName = 'PickerItem';
  PickerItem.propTypes = propTypes$i;

  var _excluded$g = ["children", "onFocus", "onBlur", "placeholderTextColor", "size", "disabled", "valid", "invalid", "useNativeComponent", "style", "styleName"];

  var _templateObject$d, _templateObject2$9, _templateObject3$3, _templateObject4$2, _templateObject5$2, _templateObject6$1;
  /* eslint-disable react/no-unused-prop-types */

  var propTypes$h = {
    children: PropTypes.node.isRequired,
    onFocus: PropTypes.func,
    onBlur: PropTypes.func,
    placeholderTextColor: PropTypes.string,
    size: PropTypes.oneOf(['sm', 'lg']),
    disabled: PropTypes.bool,
    valid: PropTypes.bool,
    invalid: PropTypes.bool,
    useNativeComponent: PropTypes.bool,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    styleName: PropTypes.any
  };
  /* eslint-enable */

  var styles$d = StyleSheet.create(_objectSpread2({
    select: css(_templateObject$d || (_templateObject$d = _taggedTemplateLiteral(["\n    opacity: 1;\n  "]))),
    '.form-select': css(_templateObject2$9 || (_templateObject2$9 = _taggedTemplateLiteral(["\n    // display: block;\n    width: 100%;\n    padding: $form-select-padding-y $form-select-indicator-padding\n      $form-select-padding-y $form-select-padding-x;\n    /* @include platform(web) {\n      // See https://github.com/twbs/bootstrap/issues/32636\n      -moz-padding-start: subtract($form-select-padding-x, 3px);\n    } */\n    font-family: $form-select-font-family;\n    font-size: $form-select-font-size;\n    font-weight: $form-select-font-weight;\n    line-height: $form-select-font-size * $form-select-line-height;\n    color: $form-select-color;\n    background-color: $form-select-bg;\n    background-image: ", ";\n    background-repeat: no-repeat;\n    background-position: $form-select-bg-position;\n    background-size: $form-select-bg-size;\n    border: $form-select-border-width solid $form-select-border-color;\n    border-radius: $form-select-border-radius;\n    // @include box-shadow($form-select-box-shadow);\n    // @include transition($form-select-transition);\n    @include platform(web) {\n      appearance: none;\n    }\n\n    &:focus {\n      border-color: $form-select-focus-border-color;\n      @include platform(web) {\n        outline-width: 0; // outline: 0;\n        // @if $enable-shadows {\n        //   @include box-shadow(\n        //     $form-select-box-shadow,\n        //     $form-select-focus-box-shadow\n        //   );\n        // } @else {\n        //   // Avoid using mixin so we can pass custom focus shadow properly\n        box-shadow: $form-select-focus-box-shadow;\n        // }\n      }\n    }\n  "])), function (t) {
      return escapeSvg(t['form-select-indicator']);
    }),
    '.form-select.disabled': css(_templateObject3$3 || (_templateObject3$3 = _taggedTemplateLiteral(["\n    color: $form-select-disabled-color;\n    background-color: $form-select-disabled-bg;\n    border-color: $form-select-disabled-border-color;\n  "]))),
    '.form-select-sm': css(_templateObject4$2 || (_templateObject4$2 = _taggedTemplateLiteral(["\n    padding-top: $form-select-padding-y-sm;\n    padding-bottom: $form-select-padding-y-sm;\n    padding-left: $form-select-padding-x-sm;\n    font-size: $form-select-font-size-sm;\n    border-radius: $form-select-border-radius-sm;\n  "]))),
    '.form-select-lg': css(_templateObject5$2 || (_templateObject5$2 = _taggedTemplateLiteral(["\n    padding-top: $form-select-padding-y-lg;\n    padding-bottom: $form-select-padding-y-lg;\n    padding-left: $form-select-padding-x-lg;\n    font-size: $form-select-font-size-lg;\n    border-radius: $form-select-border-radius-lg;\n  "])))
  }, each(FORM_VALIDATION_STATES, function (state, data) {
    return _defineProperty({}, ".form-select:".concat(state), css(_templateObject6$1 || (_templateObject6$1 = _taggedTemplateLiteral(["\n      border-color: ", ";\n\n      &:focus {\n        border-color: ", ";\n        @include platform(web) {\n          box-shadow: 0 0 $input-btn-focus-blur $input-focus-width\n            rgba(", ", $input-btn-focus-color-opacity);\n        }\n      }\n    "])), function (t) {
      return data(t).color;
    }, function (t) {
      return data(t).color;
    }, function (t) {
      return data(t).color;
    }));
  })));
  var Picker = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var _useModifier = useModifier('useFormField', props, ref),
        _useModifier2 = _slicedToArray(_useModifier, 2),
        modifierProps = _useModifier2[0],
        modifierRef = _useModifier2[1];

    var children = modifierProps.children,
        _modifierProps$onFocu = modifierProps.onFocus,
        onFocus = _modifierProps$onFocu === void 0 ? function () {} : _modifierProps$onFocu,
        _modifierProps$onBlur = modifierProps.onBlur,
        onBlur = _modifierProps$onBlur === void 0 ? function () {} : _modifierProps$onBlur,
        _modifierProps$placeh = modifierProps.placeholderTextColor,
        placeholderTextColor = _modifierProps$placeh === void 0 ? StyleSheet.value('input-placeholder-color') : _modifierProps$placeh,
        size = modifierProps.size,
        _modifierProps$disabl = modifierProps.disabled,
        disabled = _modifierProps$disabl === void 0 ? false : _modifierProps$disabl,
        _modifierProps$valid = modifierProps.valid,
        valid = _modifierProps$valid === void 0 ? false : _modifierProps$valid,
        _modifierProps$invali = modifierProps.invalid,
        invalid = _modifierProps$invali === void 0 ? false : _modifierProps$invali,
        _modifierProps$useNat = modifierProps.useNativeComponent,
        useNativeComponent = _modifierProps$useNat === void 0 ? false : _modifierProps$useNat,
        style = modifierProps.style,
        styleName = modifierProps.styleName,
        elementProps = _objectWithoutProperties(modifierProps, _excluded$g);

    var media = useMedia();

    var _useState = React.useState(false),
        _useState2 = _slicedToArray(_useState, 2),
        focused = _useState2[0],
        setFocused = _useState2[1];

    var classes = getStyles(styles$d, ['select', // reboot
    '.form-select', disabled && '.form-select.disabled', size === 'sm' && '.form-select-sm', size === 'lg' && '.form-select-lg', valid && '.form-select:valid', invalid && '.form-select:invalid']);
    var resolveStyle = useStyle([classes, style], styleName);

    var handleFocus = function handleFocus() {
      setFocused(true);
      onFocus();
    };

    var handleBlur = function handleBlur() {
      setFocused(false);
      onBlur();
    };

    var BasePicker = reactNative.Platform.OS === 'web' && !useNativeComponent ? PickerWeb : PickerNative;
    return /*#__PURE__*/React__default["default"].createElement(PickerContext.Provider, {
      value: {
        useNativeComponent: useNativeComponent
      }
    }, /*#__PURE__*/React__default["default"].createElement(BasePicker, _extends$1({}, elementProps, {
      ref: modifierRef,
      placeholderTextColor: placeholderTextColor,
      onFocus: handleFocus,
      onBlur: handleBlur,
      disabled: disabled,
      style: resolveStyle({
        media: media,
        interaction: {
          focused: focused
        }
      })
    }), children));
  });
  Picker.displayName = 'Picker';
  Picker.propTypes = propTypes$h;
  Picker.Item = PickerItem;

  var _excluded$f = ["children", "style"];

  var _templateObject$c;
  var propTypes$g = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$c = StyleSheet.create({
    '.placeholders': css(_templateObject$c || (_templateObject$c = _taggedTemplateLiteral([""])))
  });
  var Placeholders = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded$f);

    var classes = getStyles(styles$c, ['.placeholders']);
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style]
    }), children);
  });
  Placeholders.displayName = 'Placeholders';
  Placeholders.propTypes = propTypes$g;
  /*
  $placeholder-opacity-max:           .5;
  $placeholder-opacity-min:           .2;
  */

  var ProgressContext = /*#__PURE__*/React__default["default"].createContext();
  ProgressContext.displayName = 'ProgressContext';

  var _excluded$e = ["children", "value", "style", "textStyle"];

  var _templateObject$b, _templateObject2$8;
  var propTypes$f = {
    children: PropTypes.node,
    value: PropTypes.number.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any
  };
  var styles$b = StyleSheet.create({
    '.progress-bar': css(_templateObject$b || (_templateObject$b = _taggedTemplateLiteral(["\n    display: flex;\n    flex-direction: column;\n    justify-content: center;\n    overflow: hidden;\n    background-color: $progress-bar-bg;\n    // @include transition($progress-bar-transition);\n  "]))),
    '.progress-bar --text': css(_templateObject2$8 || (_templateObject2$8 = _taggedTemplateLiteral(["\n    color: $progress-bar-color;\n    text-align: center;\n    // white-space: nowrap;\n  "])))
  });
  var ROUND_PRECISION = 1000;

  var getPercentage = function getPercentage(value, min, max) {
    var percentage = (value - min) / (max - min) * 100;
    return Math.round(percentage * ROUND_PRECISION) / ROUND_PRECISION;
  };

  var ProgressBar = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        value = props.value,
        style = props.style,
        textStyle = props.textStyle,
        elementProps = _objectWithoutProperties(props, _excluded$e);

    var _useForcedContext = useForcedContext(ProgressContext),
        min = _useForcedContext.min,
        max = _useForcedContext.max;

    var classes = getStyles(styles$b, ['.progress-bar']);
    var textClasses = getStyles(styles$b, ['.progress-bar --text']); // composite component

    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      accessibilityRole: "progressbar",
      accessibilityValueNow: value,
      accessibilityValueMin: min,
      accessibilityValueMax: max,
      style: [classes, style, {
        width: "".concat(getPercentage(value, min, max), "%")
      }]
    }), children && /*#__PURE__*/React__default["default"].createElement(Text, {
      style: [textClasses, textStyle]
    }, children));
  });
  ProgressBar.displayName = 'ProgressBar';
  ProgressBar.propTypes = propTypes$f;

  function useProgress(min, max) {
    return React.useMemo(function () {
      return {
        min: min,
        max: max
      };
    }, [min, max]);
  }

  var _excluded$d = ["children", "min", "max", "style", "textStyle"];

  var _templateObject$a, _templateObject2$7;
  var propTypes$e = {
    children: PropTypes.node.isRequired,
    min: PropTypes.number,
    max: PropTypes.number,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any
  };
  var styles$a = StyleSheet.create({
    '.progress': css(_templateObject$a || (_templateObject$a = _taggedTemplateLiteral(["\n    display: flex;\n    flex-direction: row; // added for bootstrap-rn\n    height: $progress-height;\n    overflow: hidden; // force rounded corners by cropping it\n    background-color: $progress-bg;\n    border-radius: $progress-border-radius;\n    // @include box-shadow($progress-box-shadow);\n  "]))),
    '.progress --text': css(_templateObject2$7 || (_templateObject2$7 = _taggedTemplateLiteral(["\n    font-size: $progress-font-size;\n    line-height: $progress-font-size * $line-height-base; // added for bootstrap-rn\n  "])))
  });
  var Progress = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        _props$min = props.min,
        min = _props$min === void 0 ? 0 : _props$min,
        _props$max = props.max,
        max = _props$max === void 0 ? 100 : _props$max,
        style = props.style,
        textStyle = props.textStyle,
        elementProps = _objectWithoutProperties(props, _excluded$d);

    var progress = useProgress(min, max);
    var classes = getStyles(styles$a, ['.progress']);
    var textClasses = getStyles(styles$a, ['.progress --text']);
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style],
      textStyle: [textClasses, textStyle]
    }), /*#__PURE__*/React__default["default"].createElement(ProgressContext.Provider, {
      value: progress
    }, children));
  });
  Progress.displayName = 'Progress';
  Progress.propTypes = propTypes$e;
  Progress.Bar = ProgressBar;

  var _excluded$c = ["children", "lead", "style"];

  var _templateObject$9, _templateObject2$6;
  var propTypes$d = {
    children: PropTypes.node.isRequired,
    lead: PropTypes.bool,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$9 = StyleSheet.create({
    paragraph: css(_templateObject$9 || (_templateObject$9 = _taggedTemplateLiteral(["\n    margin-top: 0;\n    margin-bottom: $paragraph-margin-bottom;\n  "]))),
    '.lead': css(_templateObject2$6 || (_templateObject2$6 = _taggedTemplateLiteral(["\n    font-size: $lead-font-size;\n    line-height: $lead-font-size * $line-height-base; // added for bootstrap-rn\n    font-weight: $lead-font-weight;\n  "])))
  });
  var Heading = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        lead = props.lead,
        style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded$c);

    var classes = getStyles(styles$9, ['paragraph', lead && '.lead']); // Accessiblity role paragraph is only supported on web.

    var role = reactNative.Platform.OS === 'web' ? 'paragraph' : null;
    return /*#__PURE__*/React__default["default"].createElement(Text, _extends$1({}, elementProps, {
      ref: ref,
      accessibilityRole: role,
      style: [classes, style]
    }), children);
  });
  Heading.displayName = 'Heading';
  Heading.propTypes = propTypes$d;

  var _excluded$b = ["children", "active", "disabled", "style", "textStyle"];

  var _templateObject$8, _templateObject2$5, _templateObject3$2, _templateObject4$1, _templateObject5$1;
  var propTypes$c = {
    children: PropTypes.node.isRequired,
    active: PropTypes.bool,
    disabled: PropTypes.bool,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any
  };
  var styles$8 = StyleSheet.create({
    '.pagination-item': css(_templateObject$8 || (_templateObject$8 = _taggedTemplateLiteral(["\n    padding-bottom: $pagination-padding-y;\n    padding-top: $pagination-padding-y;\n    padding-left: $pagination-padding-x;\n    padding-right: $pagination-padding-x;\n    border: $list-group-border-width solid $list-group-border-color;\n\n    &:hover {\n      color: $pagination-hover-color;\n      background-color: $pagination-hover-bg;\n      border-color: $pagination-hover-border-color;\n    }\n\n    &:focus {\n      color: $pagination-focus-color;\n      background-color: $pagination-focus-bg;\n      //$pagination-focus-box-shadow:\n      //$pagination-focus-outline:\n    }\n  "]))),
    '.pagination-item:first-child': css(_templateObject2$5 || (_templateObject2$5 = _taggedTemplateLiteral(["\n    border-top-left-radius: $list-group-border-radius;\n    border-bottom-left-radius: $list-group-border-radius;\n  "]))),
    '.pagination-item:last-child': css(_templateObject3$2 || (_templateObject3$2 = _taggedTemplateLiteral(["\n    border-top-right-radius: $list-group-border-radius;\n    border-bottom-right-radius: $list-group-border-radius;\n  "]))),
    '.pagination-item.active': css(_templateObject4$1 || (_templateObject4$1 = _taggedTemplateLiteral(["\n    color: $pagination-active-color;\n    background-color: $pagination-active-bg;\n    border-color: $pagination-active-border-color;\n  "]))),
    '.pagination-item.disabled': css(_templateObject5$1 || (_templateObject5$1 = _taggedTemplateLiteral(["\n    color: $pagination-disabled-color;\n    background-color: $pagination-disabled-bg;\n    border-color: $pagination-disabled-border-color;\n  "])))
  });
  var PaginationItem = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        _props$active = props.active,
        active = _props$active === void 0 ? false : _props$active,
        _props$disabled = props.disabled,
        disabled = _props$disabled === void 0 ? false : _props$disabled,
        style = props.style,
        textStyle = props.textStyle,
        elementProps = _objectWithoutProperties(props, _excluded$b);

    var _useForcedContext = useForcedContext(ListContext),
        first = _useForcedContext.first,
        last = _useForcedContext.last;

    var classes = getStyles(styles$8, ['.pagination-item', first && '.pagination-item:first-child', last && '.pagination-item:last-child', active && '.pagination-item.active', disabled && '.pagination-item.disabled']);
    var textClasses = getStyles(styles$8, [active && '.pagination-item.active', disabled && '.pagination-item.disabled']);
    var role = reactNative.Platform.OS === 'web' ? 'listitem' : null;
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      accessibilityRole: role,
      style: [classes, style],
      textStyle: [textClasses, textStyle]
    }), children);
  });
  PaginationItem.displayName = 'PaginationItem';
  PaginationItem.propTypes = propTypes$c;
  /*
  $pagination-padding-y:              .375rem;
  $pagination-padding-x:              .75rem;
  $pagination-padding-y-sm:           .25rem;
  $pagination-padding-x-sm:           .5rem;
  $pagination-padding-y-lg:           .75rem;
  $pagination-padding-x-lg:           1.5rem;

  $pagination-color:                  $link-color;
  $pagination-bg:                     $white;
  $pagination-border-width:           $border-width;
  $pagination-border-radius:          $border-radius;
  $pagination-margin-start:           -$pagination-border-width;
  $pagination-border-color:           $gray-300;

  $pagination-focus-color:            $link-hover-color;
  $pagination-focus-bg:               $gray-200;
  $pagination-focus-box-shadow:       $input-btn-focus-box-shadow;
  $pagination-focus-outline:          0;

  $pagination-hover-color:            $link-hover-color;
  $pagination-hover-bg:               $gray-200;
  $pagination-hover-border-color:     $gray-300;

  $pagination-active-color:           $component-active-color;
  $pagination-active-bg:              $component-active-bg;
  $pagination-active-border-color:    $pagination-active-bg;

  $pagination-disabled-color:         $gray-600;
  $pagination-disabled-bg:            $white;
  $pagination-disabled-border-color:  $gray-300;

  $pagination-transition:              color .15s ease-in-out, background-color .15s ease-in-out, border-color .15s ease-in-out, box-shadow .15s ease-in-out;

  $pagination-border-radius-sm:       $border-radius-sm;
  $pagination-border-radius-lg:       $border-radius-lg;

  */

  var _excluded$a = ["children", "style"];

  var _templateObject$7;
  var propTypes$b = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$7 = StyleSheet.create({
    '.pagination': css(_templateObject$7 || (_templateObject$7 = _taggedTemplateLiteral(["\n    background-color: $white;\n    flex-direction: row;\n  "])))
  });
  var Pagination = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded$a);

    var list = useList(children);
    var classes = getStyles(styles$7, ['.pagination']);
    var role = reactNative.Platform.OS === 'web' ? 'list' : null;
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      accessibilityRole: role,
      style: [classes, style]
    }), list);
  });
  Pagination.displayName = 'Pagination';
  Pagination.propTypes = propTypes$b;
  Pagination.Item = PaginationItem;

  var RadioContext = /*#__PURE__*/React__default["default"].createContext();
  RadioContext.displayName = 'RadioContext';

  var _excluded$9 = ["children", "selectedValue", "onValueChange", "disabled"];
  var propTypes$a = {
    children: PropTypes.node.isRequired,
    selectedValue: PropTypes.oneOfType([PropTypes.bool, PropTypes.number, PropTypes.string]),
    onValueChange: PropTypes.func,
    disabled: PropTypes.bool
  };
  var RadioGroup = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        selectedValue = props.selectedValue,
        _props$onValueChange = props.onValueChange,
        onValueChange = _props$onValueChange === void 0 ? function () {} : _props$onValueChange,
        _props$disabled = props.disabled,
        disabled = _props$disabled === void 0 ? false : _props$disabled,
        elementProps = _objectWithoutProperties(props, _excluded$9);

    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      accessibilityRole: "radiogroup"
    }), /*#__PURE__*/React__default["default"].createElement(RadioContext.Provider, {
      value: {
        selectedValue: selectedValue,
        onValueChange: onValueChange,
        disabled: disabled
      }
    }, children));
  });
  RadioGroup.displayName = 'RadioGroup';
  RadioGroup.propTypes = propTypes$a;

  var _excluded$8 = ["value"];
  var propTypes$9 = {
    value: PropTypes.oneOfType([PropTypes.bool, PropTypes.number, PropTypes.string, PropTypes.object])
  };
  var Radio = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var value = props.value,
        elementProps = _objectWithoutProperties(props, _excluded$8);

    var _useForcedContext = useForcedContext(RadioContext),
        selectedValue = _useForcedContext.selectedValue,
        _onValueChange = _useForcedContext.onValueChange,
        disabled = _useForcedContext.disabled;

    return /*#__PURE__*/React__default["default"].createElement(FormCheckInput, _extends$1({}, elementProps, {
      ref: ref,
      type: "radio",
      value: value === selectedValue,
      onValueChange: function onValueChange() {
        _onValueChange(value);
      },
      disabled: disabled
    }));
  });
  Radio.displayName = 'Radio';
  Radio.propTypes = propTypes$9;
  Radio.Group = RadioGroup;

  var _excluded$7 = ["children", "style"];

  var _templateObject$6;
  var propTypes$8 = {
    children: PropTypes.node.isRequired,
    rows: PropTypes.number,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$6 = StyleSheet.create({
    '.row': css(_templateObject$6 || (_templateObject$6 = _taggedTemplateLiteral(["\n    display: flex;\n    flex-direction: row; // added for bootstrap-rn\n    flex-wrap: wrap;\n    margin-top: 0;\n    margin-right: -0.5 * $grid-gutter-width;\n    margin-left: -0.5 * $grid-gutter-width;\n  "])))
  });
  var Row = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded$7);

    var classes = getStyles(styles$6, ['.row']);
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style]
    }), children);
  });
  Row.displayName = 'Row';
  Row.propTypes = propTypes$8;

  var Switch = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var elementProps = _extends$1({}, props);

    return /*#__PURE__*/React__default["default"].createElement(FormCheckInput, _extends$1({}, elementProps, {
      ref: ref,
      type: "switch"
    }));
  });
  Switch.displayName = 'Switch';

  var _excluded$6 = ["variant", "color", "size", "style"];

  var _templateObject$5, _templateObject2$4, _templateObject3$1, _templateObject4, _templateObject5, _templateObject6;
  var propTypes$7 = {
    variant: PropTypes.oneOf(['border', 'grow']),
    color: PropTypes.oneOf(Object.keys(THEME_COLORS)),
    size: PropTypes.oneOf(['sm']),
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$5 = StyleSheet.create(_objectSpread2(_objectSpread2(_objectSpread2({
    '.spinner-border': css(_templateObject$5 || (_templateObject$5 = _taggedTemplateLiteral(["\n    // display: inline-block;\n    width: $spinner-width;\n    height: $spinner-height;\n    // vertical-align: $spinner-vertical-align;\n    border-width: $spinner-border-width;\n    border-style: solid;\n    border-top-color: $body-color;\n    border-bottom-color: $body-color;\n    border-left-color: $body-color;\n    border-right-color: transparent;\n    border-radius: $spinner-width * 0.5; // 50%;\n    // animation: $spinner-animation-speed linear infinite spinner-border;\n  "])))
  }, each(THEME_COLORS, function (color, value) {
    return _defineProperty({}, ".spinner-border-".concat(color), css(_templateObject2$4 || (_templateObject2$4 = _taggedTemplateLiteral(["\n      border-top-color: ", ";\n      border-bottom-color: ", ";\n      border-left-color: ", ";\n    "])), value, value, value));
  })), {}, {
    '.spinner-border-sm': css(_templateObject3$1 || (_templateObject3$1 = _taggedTemplateLiteral(["\n    width: $spinner-width-sm;\n    height: $spinner-height-sm;\n    border-width: $spinner-border-width-sm;\n  "]))),
    '.spinner-grow': css(_templateObject4 || (_templateObject4 = _taggedTemplateLiteral(["\n    // display: inline-block;\n    width: $spinner-width;\n    height: $spinner-height;\n    // vertical-align: $spinner-vertical-align;\n    background-color: $body-color;\n    border-radius: $spinner-width * 0.5; // 50%;\n    opacity: 0;\n    // animation: $spinner-animation-speed linear infinite spinner-grow;\n  "])))
  }, each(THEME_COLORS, function (color, value) {
    return _defineProperty({}, ".spinner-grow-".concat(color), css(_templateObject5 || (_templateObject5 = _taggedTemplateLiteral(["\n      background-color: ", ";\n    "])), value));
  })), {}, {
    '.spinner-grow-sm': css(_templateObject6 || (_templateObject6 = _taggedTemplateLiteral(["\n    width: $spinner-width-sm;\n    height: $spinner-height-sm;\n  "])))
  }));
  var AnimatedView = reactNative.Animated.createAnimatedComponent(View);

  var getAnimationStyle = function getAnimationStyle(variant, animation) {
    switch (variant) {
      case 'border':
        return {
          transform: [{
            rotate: animation.interpolate({
              inputRange: [0, 1],
              outputRange: ['0deg', '360deg']
            })
          }]
        };

      case 'grow':
        return {
          transform: [{
            scale: animation.interpolate({
              inputRange: [0, 0.5, 1],
              outputRange: [0, 1, 1]
            })
          }],
          opacity: animation.interpolate({
            inputRange: [0, 0.5, 1],
            outputRange: [0, 1, 0]
          })
        };

      default:
        throw new Error('Unknown spinner variant.');
    }
  };

  var Spinner = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var _props$variant = props.variant,
        variant = _props$variant === void 0 ? 'border' : _props$variant,
        color = props.color,
        size = props.size,
        style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded$6);

    var classes = getStyles(styles$5, [".spinner-".concat(variant), color && ".spinner-".concat(variant, "-").concat(color), size === 'sm' && ".spinner-".concat(variant, "-sm")]);
    var role = reactNative.Platform.OS === 'web' ? 'status' : null;
    var animation = React.useMemo(function () {
      return new reactNative.Animated.Value(0);
    }, []);
    React.useEffect(function () {
      var duration = parseFloat(StyleSheet.value('spinner-animation-speed')) * 1000;
      reactNative.Animated.loop(reactNative.Animated.timing(animation, {
        toValue: 1,
        duration: duration,
        easing: reactNative.Easing.linear,
        useNativeDriver: reactNative.Platform.OS !== 'web'
      })).start();
    }, []);
    return /*#__PURE__*/React__default["default"].createElement(AnimatedView, _extends$1({}, elementProps, {
      ref: ref,
      accessibilityRole: role,
      accessibilityHidden: true,
      style: [classes, getAnimationStyle(variant, animation), style]
    }));
  });
  Spinner.displayName = 'Spinner';
  Spinner.propTypes = propTypes$7;

  function useTabbable(defaultActiveTarget, controlledActiveTarget, onChange) {
    var identifier = useIdentifier('tabbable');

    var _useControlledState = useControlledState(defaultActiveTarget, controlledActiveTarget, onChange),
        _useControlledState2 = _slicedToArray(_useControlledState, 2),
        activeTarget = _useControlledState2[0],
        setActiveTarget = _useControlledState2[1];

    return React.useMemo(function () {
      return {
        identifier: identifier,
        activeTarget: activeTarget,
        setActiveTarget: setActiveTarget
      };
    }, [activeTarget]);
  }

  var propTypes$6 = {
    children: PropTypes.node.isRequired,
    defaultActiveTarget: PropTypes.string.isRequired,
    activeTarget: PropTypes.string,
    onChange: PropTypes.func
  };

  var TabProvider = function TabProvider(props) {
    var children = props.children,
        defaultActiveTarget = props.defaultActiveTarget,
        activeTarget = props.activeTarget,
        onChange = props.onChange;
    var tabbable = useTabbable(defaultActiveTarget, activeTarget, onChange);
    return /*#__PURE__*/React__default["default"].createElement(TabContext.Provider, {
      value: tabbable
    }, children);
  };

  TabProvider.displayName = 'TabProvider';
  TabProvider.propTypes = propTypes$6;

  var propTypes$5 = {
    children: PropTypes.node.isRequired
  };
  var TabContent = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var elementProps = _extends$1({}, props);

    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref
    }));
  });
  TabContent.displayName = 'TabContent';
  TabContent.propTypes = propTypes$5;

  var _excluded$5 = ["id", "style"];

  var _templateObject$4, _templateObject2$3;
  var propTypes$4 = {
    children: PropTypes.node.isRequired,
    id: PropTypes.string.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles$4 = StyleSheet.create({
    '.tab-pane': css(_templateObject$4 || (_templateObject$4 = _taggedTemplateLiteral(["\n    display: none;\n  "]))),
    '.active': css(_templateObject2$3 || (_templateObject2$3 = _taggedTemplateLiteral(["\n    display: flex;\n  "])))
  });
  var TabPane = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var target = props.id,
        style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded$5);

    var tabbable = useForcedContext(TabContext);
    var classes = getStyles(styles$4, ['.tab-pane', tabbable.activeTarget === target && '.active']);
    var id = getElementId(tabbable.identifier, target); // Accessiblity role tabpanel is only supported on web.

    var role = reactNative.Platform.OS === 'web' ? 'tabpanel' : null;
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      nativeID: id,
      accessibilityRole: role,
      accessibilityLabelledBy: "".concat(id, "-tab"),
      style: [classes, style]
    }));
  });
  TabPane.displayName = 'TabPane';
  TabPane.propTypes = propTypes$4;

  var _excluded$4 = ["target", "onPress"];
  function useToggleTab(props) {
    var context = useForcedContext(TabContext);

    var target = props.target,
        handlePress = props.onPress,
        restProps = _objectWithoutProperties(props, _excluded$4);

    invariant(target, 'Prop "target" is required.');
    var id = getElementId(context.identifier, target);
    var active = context.activeTarget === target;
    return _objectSpread2(_objectSpread2({}, restProps), {}, {
      nativeID: "".concat(id, "-tab"),
      onPress: function onPress(event) {
        if (handlePress) handlePress(event);
        event.preventDefault();
        context.setActiveTarget(target);
      },
      active: active,
      accessibilityRole: 'tab',
      accessibilityControls: id,
      accessibilitySelected: active
    });
  }

  var Tab = {};
  Tab.Context = TabContext;
  Tab.Provider = TabProvider;
  Tab.Content = TabContent;
  Tab.Pane = TabPane;
  Tab.useToggle = useToggleTab;

  var _excluded$3 = ["children", "style", "textStyle"];

  var _templateObject$3, _templateObject2$2;
  var propTypes$3 = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any
  };
  var styles$3 = StyleSheet.create({
    '.toast-header': css(_templateObject$3 || (_templateObject$3 = _taggedTemplateLiteral(["\n    display: flex;\n    flex-direction: row; // added for bootstrap-rn\n    align-items: center;\n    padding: $toast-padding-y $toast-padding-x;\n    background-color: $toast-header-background-color;\n    // background-clip: padding-box;\n    border-bottom-width: $toast-border-width;\n    border-style: solid;\n    border-color: $toast-header-border-color;\n    border-top-left-radius: ", ";\n    border-top-right-radius: ", ";\n  "])), subtract(function (t) {
      return t['toast-border-radius'];
    }, function (t) {
      return t['toast-border-width'];
    }), subtract(function (t) {
      return t['toast-border-radius'];
    }, function (t) {
      return t['toast-border-width'];
    })),
    '.toast-header --text': css(_templateObject2$2 || (_templateObject2$2 = _taggedTemplateLiteral(["\n    color: $toast-header-color;\n  "])))
  });
  var ToastHeader = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        textStyle = props.textStyle,
        elementProps = _objectWithoutProperties(props, _excluded$3);

    var classes = getStyles(styles$3, ['.toast-header']);
    var textClasses = getStyles(styles$3, ['.toast-header --text']);
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style],
      textStyle: [textClasses, textStyle]
    }), children);
  });
  ToastHeader.displayName = 'ToastHeader';
  ToastHeader.propTypes = propTypes$3;

  var _excluded$2 = ["children", "style", "textStyle"];

  var _templateObject$2, _templateObject2$1;
  var propTypes$2 = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any
  };
  var styles$2 = StyleSheet.create({
    '.toast-body': css(_templateObject$2 || (_templateObject$2 = _taggedTemplateLiteral(["\n    padding: $toast-padding-x; // apply to both vertical and horizontal\n  "]))),
    '.toast-body --text': css(_templateObject2$1 || (_templateObject2$1 = _taggedTemplateLiteral(["\n    @include platform(web) {\n      word-wrap: break-word;\n    }\n  "])))
  });
  var ToastBody = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        textStyle = props.textStyle,
        elementProps = _objectWithoutProperties(props, _excluded$2);

    var classes = getStyles(styles$2, ['.toast-body']);
    var textClasses = getStyles(styles$2, ['.toast-body --text']);
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style],
      textStyle: [textClasses, textStyle]
    }), children);
  });
  ToastBody.displayName = 'ToastBody';
  ToastBody.propTypes = propTypes$2;

  var ToastContainerContext = /*#__PURE__*/React__default["default"].createContext();
  ToastContainerContext.displayName = 'ToastContainerContext';

  var _excluded$1 = ["children", "style", "textStyle"];

  var _templateObject$1, _templateObject2, _templateObject3;
  var propTypes$1 = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any,
    // eslint-disable-next-line react/forbid-prop-types
    textStyle: PropTypes.any
  };
  var styles$1 = StyleSheet.create({
    '.toast': css(_templateObject$1 || (_templateObject$1 = _taggedTemplateLiteral(["\n    width: $toast-max-width;\n    max-width: 100%;\n    // pointer-events: auto;\n    background-color: $toast-background-color;\n    // background-clip: padding-box;\n    border: $toast-border-width solid $toast-border-color;\n    // box-shadow: $toast-box-shadow;\n    border-radius: $toast-border-radius;\n  "]))),
    '.toast --text': css(_templateObject2 || (_templateObject2 = _taggedTemplateLiteral(["\n    font-size: $toast-font-size;\n    line-height: $toast-font-size * $line-height-base; // added for bootstrap-rn\n    color: $toast-color;\n  "]))),
    '.toast-container > :not(:last-child)': css(_templateObject3 || (_templateObject3 = _taggedTemplateLiteral(["\n    margin-bottom: $toast-spacing;\n  "])))
  });
  var Toast = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        textStyle = props.textStyle,
        elementProps = _objectWithoutProperties(props, _excluded$1);

    var listItem = React.useContext(ListContext);
    var container = React.useContext(ToastContainerContext);
    var classes = getStyles(styles$1, ['.toast', container && !listItem.last && '.toast-container > :not(:last-child)']);
    var textClasses = getStyles(styles$1, ['.toast --text']);
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      accessibilityRole: "alert",
      accessibilityLive: "assertive",
      accessibilityAtomic: true,
      style: [classes, style],
      textStyle: [textClasses, textStyle]
    }), children);
  });
  Toast.displayName = 'Toast';
  Toast.propTypes = propTypes$1;
  Toast.Header = ToastHeader;
  Toast.Body = ToastBody;

  var _excluded = ["children", "style"];

  var _templateObject;
  var propTypes = {
    children: PropTypes.node.isRequired,
    // eslint-disable-next-line react/forbid-prop-types
    style: PropTypes.any
  };
  var styles = StyleSheet.create({
    '.toast-container': css(_templateObject || (_templateObject = _taggedTemplateLiteral(["\n    width: 100%; // max-content;\n    max-width: 100%;\n    // pointer-events: none;\n  "])))
  });
  var ToastContainer = /*#__PURE__*/React__default["default"].forwardRef(function (props, ref) {
    var children = props.children,
        style = props.style,
        elementProps = _objectWithoutProperties(props, _excluded);

    var list = useList(children);
    var classes = getStyles(styles, ['.toast-container']);
    return /*#__PURE__*/React__default["default"].createElement(View, _extends$1({}, elementProps, {
      ref: ref,
      style: [classes, style]
    }), /*#__PURE__*/React__default["default"].createElement(ToastContainerContext.Provider, {
      value: true
    }, list));
  });
  ToastContainer.displayName = 'ToastContainer';
  ToastContainer.propTypes = propTypes;

  function useFixedElement() {
    var context = React.useContext(Context);
    var ref = React.useRef();
    React.useEffect(function () {
      var link = context.addFixedElement(ref);
      return function () {
        link.remove();
      };
    }, []);
    return ref;
  }

  exports.Alert = Alert;
  exports.Badge = Badge;
  exports.Blockquote = Blockquote;
  exports.Body = Body;
  exports.Breadcrumb = Breadcrumb;
  exports.Button = Button;
  exports.ButtonGroup = ButtonGroup;
  exports.ButtonToolbar = ButtonToolbar;
  exports.Card = Card;
  exports.Checkbox = Checkbox;
  exports.CloseButton = CloseButton;
  exports.Code = Code;
  exports.Col = Col;
  exports.Collapse = Collapse;
  exports.Container = Container;
  exports.Context = Context;
  exports.DisplayHeading = DisplayHeading;
  exports.Dropdown = Dropdown;
  exports.Feedback = Feedback;
  exports.FormCheck = FormCheck;
  exports.FormLabel = FormLabel;
  exports.FormText = FormText;
  exports.Heading = Heading$2;
  exports.Image = Image;
  exports.ImageBackground = ImageBackground;
  exports.Input = Input;
  exports.Label = Heading$1;
  exports.Link = Link;
  exports.ListGroup = ListGroup;
  exports.Modal = Modal;
  exports.Nav = Nav;
  exports.Navbar = Navbar;
  exports.Offcanvas = Offcanvas;
  exports.Pagination = Pagination;
  exports.Paragraph = Heading;
  exports.Picker = Picker;
  exports.Placeholders = Placeholders;
  exports.Popover = Popover;
  exports.PortalProvider = PortalProvider;
  exports.Pressable = Pressable;
  exports.Progress = Progress;
  exports.Provider = Provider;
  exports.Radio = Radio;
  exports.Row = Row;
  exports.ScrollView = ScrollView;
  exports.Spinner = Spinner;
  exports.StyleSheet = StyleSheet;
  exports.Switch = Switch;
  exports.Tab = Tab;
  exports.Text = Text;
  exports.TextInput = TextInput;
  exports.Toast = Toast;
  exports.ToastContainer = ToastContainer;
  exports.Tooltip = Tooltip;
  exports.View = View;
  exports.add = add;
  exports.colorContrast = colorContrast;
  exports.css = css;
  exports.divide = divide;
  exports.escapeSvg = escapeSvg;
  exports.fn = fn;
  exports.injectPopover = injectPopover;
  exports.injectTooltip = injectTooltip;
  exports.makeTheme = makeTheme;
  exports.makeUtilities = makeUtilities;
  exports.shadeColor = shadeColor;
  exports.shiftColor = shiftColor;
  exports.subtract = subtract;
  exports.tintColor = tintColor;
  exports.useFixedElement = useFixedElement;
  exports.useMedia = useMedia;
  exports.useStyle = useStyle;

  Object.defineProperty(exports, '__esModule', { value: true });

}));
